(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     21512,        685]*)
(*NotebookOutlinePosition[     25941,        826]*)
(*  CellTagsIndexPosition[     25757,        815]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["1. Getting Started", "Section",
  CellTags->"1.0"],

Cell[TextData[{
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " is a collection of ",
  StyleBox["Mathematica", "TI"],
  " programs that extend ",
  StyleBox["Mathematica", "TI"],
  " to solve a wide range of control system problems. Both classical and \
modern approaches are supported for continuous\[Hyphen]time (analog) and \
discrete\[Hyphen]time (sampled) systems. This guide describes in detail the \
new data types introduced in ",
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " and the new functions that operate on these data types. Also given are a \
number of examples of how to use the ",
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " functions together with the rest of ",
  StyleBox["Mathematica", "TI"],
  ". It is beyond the scope of this guide to address those innumerable \
control problems that could be solved simply with \
step\[Hyphen]by\[Hyphen]step application of the usual ",
  StyleBox["Mathematica", "TI"],
  " functionality. Nor can the guide be considered an introduction to control \
systems theory. Although an attempt was made to put the new functions into \
the relevant control theory context, the guide is by no means a substitute \
for standard texts such as the ones listed in the References. \nThe many \
illustrations, solved examples, and other features included should make it \
possible for the interested reader to tackle most of the problems just after \
reading the corresponding parts of this guide. However, the guide is \
definitely not an introduction to ",
  StyleBox["Mathematica", "TI"],
  " itself. To gain the most from this application package, the reader is \
advised to consult the standard ",
  StyleBox["Mathematica", "TI"],
  " reference by Stephen Wolfram, ",
  StyleBox["Mathematica: A System for Doing Mathematics by Computer", "TI"],
  ", Second Edition (Addison\[Hyphen]Wesley, 1991). "
}], "Text",
  CellTags->"1.0"],

Cell[CellGroupData[{

Cell["1.1 Using the Package for the First Time", "Subsection",
  CellTags->"1.1"],

Cell[TextData[{
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " is one of many available ",
  StyleBox["Mathematica", "TI"],
  " applications and is normally installed in a separate directory in \
parallel to them. If this has been done at the installation stage, the \
application package should be visible to ",
  StyleBox["Mathematica", "TI",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "without further effort on your part. Then, to make all the functionality \
of the application package available at once, you simply load ",
  StyleBox["Master.m", "MR"],
  " package with, for instance, the ",
  StyleBox["Needs", "MR"],
  " command"
}], "Text",
  CellTags->"1.1"],

Cell["\<\
This makes all the functionality of the application available. \
\
\>", "MathCaption",
  CellTags->"1.1"],

Cell["<<ControlSystems`", "Input",
  CellLabel->"In[1]:=",
  CellTags->"1.1"],

Cell[TextData[{
  "If you get a failure message at this stage, it is probably due to a \
nonstandard location of the application package on your system, and you will \
have to check that the directory enclosing the ",
  StyleBox["ControlSystems", "MR"],
  " directory is included in your ",
  StyleBox["$Path", "MR"],
  " variable. Commands such as  ",
  StyleBox["AppendTo[$Path,", "MR",
    FontFamily->"Courier"],
  " ",
  StyleBox["theDirectoryControlSystemsIsIn", "TI"],
  StyleBox["]", "MR"],
  "  can be used to inform ",
  StyleBox["Mathematica", "TI"],
  " of how to find the application. You may want to add this command to your \
",
  StyleBox["init.m", "MR"],
  " file to have it executed automatically at the outset of any of your ",
  StyleBox["Mathematica", "TI"],
  " sessions. The installation card that came with ",
  StyleBox["Control System Professional", "TI"],
  " contains the detailed instructions on the installation procedure. "
}], "Text",
  CellTags->"1.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2 Structure of the Application", "Subsection",
  CellTags->"1.2"],

Cell[TextData[{
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " consists of the following packages. The packages listed in the first part \
of the table typically correspond to separate sections of this guide and can \
be loaded into your ",
  StyleBox["Mathematica", "TI"],
  " session independently (with or without prior loading of the ",
  StyleBox["Master.m", "MR"],
  " package). The packages in the second part of the table are supplemental \
to the ones in the first. "
}], "Text",
  CellTags->"1.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(Common . m\),
              "Text"], 
            
            StyleBox[
              \(control\ systems\ objects\ and\ conversion\ between\ them\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Conversions . m\),
              "Text"], 
            
            StyleBox[
              \(conversion\ between\ continuous - time\ and\ discrete - 
                time\ domains\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Simulations . m\),
              "Text"], 
            
            StyleBox[
              \(investigating\ system\ behavior\ in\ the\ time\ domain\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Plots . m\),
              "Text"], 
            
            StyleBox[
              \(classical\ methods\[LongDash]root\ locus\ and\ frequency\ 
                response\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Connections . m\),
              "Text"], 
            
            StyleBox[
              \(system\ interconnections\ and\ manipulating\ system\ contents
                \),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Properties . m\),
              "Text"], 
            StyleBox[\(controllability\ and\ observability\ properties\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Realizations . m\),
              "Text"], 
            
            StyleBox[
              \(equivalent\ and\ reduced\ representations\ of\ the\ same\ 
                system\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(PoleAssignment . m\),
              "Text"], 
            StyleBox[\(pole\ assignment\ using\ state\ feedback\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(LQdesign . m\),
              "Text"], 
            
            StyleBox[
              \(optimal\ linear\ quadratic\ design\ of\ control\ systems\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Linearization . m\),
              "Text"], 
            StyleBox[\(local\ linearization\ of\ nonlinear\ systems\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Lyapunov . m\),
              "Text"], 
            StyleBox[\(Lyapunov\ equations\ solver\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(Riccati . m\),
              "Text"], 
            StyleBox[\(Riccati\ equations\ solver\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(SolversCommon . m\),
              "Text"], 
            
            StyleBox[
              \(common\ definitions\ for\ the\ Lyapunov\ and\ Riccati\ 
                equations\ solvers\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(SchurOrdered . m\),
              "Text"], 
            StyleBox[\(ordered\ Schur\ decomposition\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(CycleOptions . m\),
              "Text"], 
            StyleBox[\(options\ handling\ routine\),
              SingleLetterItalics->False]},
          {
            StyleBox[\(EEPlotsExtensions . m\),
              "Text"], 
            RowBox[{
              StyleBox["extensions",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Electrical",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox["Engineering",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["package",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["plotting",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["routines",
                SingleLetterItalics->False]}]},
          {
            StyleBox[\(Master . m\),
              "Text"], 
            StyleBox["indexfile",
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox",
  GeneratedCell->True,
  GridBoxOptions->{
  RowLines->{
    False, False, False, False, False, False, False, False, False, True, 
      False}},
  CellTags->"1.2"],

Cell[TextData[{
  "Packages within ",
  StyleBox["Control System Professional",
    FontSlant->"Italic"],
  ". "
}], "Caption",
  CellTags->"1.2"],

Cell[TextData[{
  "Under MS\[Hyphen]DOS and Microsoft Windows 3.x, the same file structure is \
preserved, but file names are truncated to eight characters plus an extension \
to match the limitations of the file system. Because the \
MS\[Hyphen]DOS/Windows version is also used for OS/2 and Microsoft Windows \
NT, they inherit the truncated file names, although they can support long \
file names. \nAlso included in ",
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " is the ",
  StyleBox["Mathematica", "TI"],
  " notebook ",
  StyleBox["Examples.ma", "MR"],
  ", which contains an on\[Hyphen]line version of all examples from this \
guide. Line\[Hyphen]by\[Hyphen]line execution of these examples may be a good \
way to get acquainted with the application package. "
}], "Text",
  CellTags->"1.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.3 The Control Objects", "Subsection",
  CellTags->"1.3"],

Cell[TextData[{
  "Most ",
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " functions operate on special data types, or control objects, that contain \
the available information of the control system, are freely convertible from \
one to another, and are easy to pass from one function to another. Currently \
available control objects are ",
  StyleBox["TransferFunction", "MR"],
  ", ",
  StyleBox["StateSpace", "MR"],
  ", ",
  StyleBox["ZeroPoleGain", "MR"],
  ". Control objects behave like what may be called \"active wrappers\". On \
the one hand, they are wrappers that conveniently combine the information \
about the system in one ",
  StyleBox["Mathematica", "TI"],
  " expression. On the other hand, they work like functions when one is \
applied to another. "
}], "Text",
  CellTags->"1.3"],

Cell["\<\
Let us create an integrator system in the transfer function form. \
\
\>", "MathCaption",
  CellTags->"1.3"],

Cell[CellGroupData[{

Cell["TransferFunction[s, 1/s]", "Input",
  CellLabel->"In[2]:=",
  CellTags->"1.3"],

Cell[BoxData[
    \(TransferFunction[s, {{1\/s}}]\)], "Output",
  CellLabel->"Out[2]=",
  CellTags->"1.3"]
}, Open  ]],

Cell[TextData[{
  "We find a state\[Hyphen]space realization of the transfer function object \
by applying the ",
  StyleBox["StateSpace", "MR"],
  " head to it. In this case, the resultant state\[Hyphen]space system \
contains very simple matrices ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.4"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.4"],
  ", and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.4"],
  ". The percentage mark, ",
  StyleBox["%", "MR"],
  " refers as usual to the result of the preceding computation. "
}], "MathCaption",
  CellTags->"1.3"],

Cell[CellGroupData[{

Cell["StateSpace[%]", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"1.3"],

Cell[BoxData[
    \(StateSpace[{{0}}, {{1}}, {{1}}]\)], "Output",
  CellLabel->"Out[3]= ",
  CellTags->"1.3"]
}, Open  ]],

Cell[TextData[
"\[Bullet] No special functions are needed to convert one control object to \
another. Simply apply the desired head to the object you wish to convert."], 
  "Text",
  CellFrame->True,
  Background->RGBColor[1, 0.6, 0.6],
  CellTags->"1.3"],

Cell["Converting between control objects. ", "Caption",
  CellTags->"1.3"],

Cell["\<\
Along with the structural information about the system, control \
objects contain a reference to the domain (continuous\[Hyphen]time or \
discrete\[Hyphen]time) the system is in and, optionally, the period at which \
the (discrete\[Hyphen]time) system was sampled. \
\>", "Text",
  CellTags->"1.3"],

Cell[TextData[{
  "This finds a discrete\[Hyphen]time approximation to the integrator system. \
Notice that the result is still the ",
  StyleBox["TransferFunction", "MR"],
  " object, in which the discrete\[Hyphen]time domain is indicated by the \
option ",
  StyleBox["Sampled", "MR"],
  ". "
}], "MathCaption",
  CellTags->"1.3"],

Cell[CellGroupData[{

Cell["\<\
ToDiscreteTime[TransferFunction[s, 1/s],
 Sampled -> Period[T]]\
\>", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"1.3"],

Cell[BoxData[
    \(TransferFunction[s, {{T\/\(\(-1\) + s\)}}, Sampled \[Rule] Period[T]]
      \)], "Output",
  CellLabel->"Out[4]= ",
  CellTags->"1.3"]
}, Open  ]],

Cell["\<\
This converts the discrete\[Hyphen]time object back to continuous \
time. \
\>", "MathCaption",
  CellTags->"1.3"],

Cell[CellGroupData[{

Cell["ToContinuousTime[%]", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"1.3"],

Cell[BoxData[
    \(TransferFunction[s, {{1\/s}}]\)], "Output",
  CellLabel->"Out[5]= ",
  CellTags->"1.3"]
}, Open  ]],

Cell[TextData[{
  "By default, the system is assumed to be in the continuous\[Hyphen]time \
domain if the ",
  StyleBox["Sampled", "MR"],
  " option is not supplied. You can reverse this if you are mainly dealing \
with the discrete\[Hyphen]time systems. "
}], "Text",
  CellTags->"1.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.4 The Notation for the Imaginary Unit", "Subsection",
  CellTags->"1.4"],

Cell[TextData[{
  StyleBox["Mathematica", "TI"],
  " reserves the letter ",
  StyleBox["I", "MR"],
  " for the imaginary unit, ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(-1\)\)], "InlineFormula",
    CellTags->"S0.0.5"],
  ", which is not the standard notation in the control literature. However, \
it is quite easy to set things up in a different way. To do so, we need to \
recall that the expression ",
  StyleBox["2", "MR"],
  " ",
  StyleBox["+", "MR"],
  " ",
  StyleBox["3I", "MR"],
  ", for example, is a shortcut for ",
  StyleBox["Complex[2,", "MR"],
  " ",
  StyleBox["3]", "MR"],
  ". Therefore, to change the appearance of complex numbers, it is sufficient \
to change the formatting rule for ",
  StyleBox["Complex", "MR"],
  ". You may want to add the following lines to your ",
  StyleBox["init.m", "MR"],
  " file if you prefer the ",
  StyleBox["j", "MR"],
  " notation to the built\[Hyphen]in one. "
}], "Text",
  CellTags->"1.4"],

Cell["This changes the way complex numbers appear on the screen. ", 
  "MathCaption",
  CellTags->"1.4"],

Cell["\<\
(
 j = I;
 Unprotect[Complex];
 Format[Complex[x_, y_]] := x + \"j\" y;
 Protect[j, Complex];
)\
\>", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"1.4"],

Cell[TextData[{
  "From now on, ",
  StyleBox["Sqrt[-1]", "MR"],
  " appears as the letter ",
  StyleBox["j", "MR"],
  ". "
}], "MathCaption",
  CellTags->"1.4"],

Cell[CellGroupData[{

Cell["2 + 3 Sqrt[-1]", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"1.4"],

Cell[BoxData[
    \(2 + 3\ "j"\)], "Output",
  CellLabel->"Out[7]= ",
  CellTags->"1.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.5 Numericalizing for Speed", "Subsection",
  CellTags->"1.5"],

Cell[TextData[{
  "A word of common sense is in order before you start trying ",
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " functions. As is the case with many built\[Hyphen]in ",
  StyleBox["Mathematica", "TI"],
  " routines, the ",
  StyleBox["Control System Professional", "TI",
    FontSlant->"Italic"],
  " functions, unless stated otherwise in this guide, accept both exact and \
inexact input (or a mix of the two) and handle them appropriately, attempting \
to give an exact answer to a problem involving an exact input. You do not \
have to worry about choosing the right algorithm, it is done in transparent \
fashion. However, you do have to realize that the algorithms invoked with the \
two types of input can be quite different, as can the computing time, with \
the exact computation sometimes being considerably more time consuming. You \
are therefore advised, whenever possible, to make sure that at least a part \
of the input contains an inexact expression to prevent running into a long \
exact calculation unnecessarily. "
}], "Text",
  CellTags->"1.5"],

Cell[TextData[{
  "Consider, for example, a random ",
  Cell[BoxData[
      \(TraditionalForm\`4\[Cross]4\)], "InlineFormula",
    CellTags->"S0.0.6"],
  " exact matrix. "
}], "MathCaption",
  CellTags->"1.5"],

Cell[CellGroupData[{

Cell["Array[Random[Integer]&, {4, 4}]//MatrixForm", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"1.5"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "0", "0", "0"},
            {"0", "0", "0", "1"},
            {"1", "0", "1", "0"},
            {"1", "1", "0", "1"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[8]//MatrixForm= ",
  CellTags->"1.5"]
}, Open  ]],

Cell["\<\
This is its exact eigenvalues together with the time taken by the \
CPU to compute the result. \
\>", "MathCaption",
  CellTags->"1.5"],

Cell[CellGroupData[{

Cell["Eigenvalues[%]//Timing", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"1.5"],

Cell[BoxData[
    \({0.0312519999999985031`\ Second, {1, 1, 1\/2\ \((1 - \@5)\), 
        1\/2\ \((1 + \@5)\)}}\)], "Output",
  CellLabel->"Out[9]= ",
  CellTags->"1.5"]
}, Open  ]],

Cell[TextData[{
  "If an inexact result suffices for the particular purpose, considerable \
savings in computing time can be realized just by using inexact input at the \
outset. (The double percentage mark, ",
  StyleBox["%%", "MR"],
  " is the familiar reference to the result of the \
next\[Hyphen]to\[Hyphen]previous computation.) "
}], "MathCaption",
  CellTags->"1.5"],

Cell[CellGroupData[{

Cell["Eigenvalues[N[%%]]//Timing", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"1.5"],

Cell[BoxData[
    \({0.`\ Second, {1.6180339887498949`, 1.`, 1.`, 
        \(-0.618033988749894813`\)}}\)], "Output",
  CellLabel->"Out[10]= ",
  CellTags->"1.5"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 1152}, {0, 850}},
ScreenStyleEnvironment->"Working",
WindowSize->{500, 300},
WindowMargins->{{4, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> "Manual.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002mT8o?mooh<<HPUi0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@:=b]0000000000060801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "1.0"->{
    Cell[1731, 51, 56, 1, 68, "Section",
      CellTags->"1.0"],
    Cell[1790, 54, 1976, 39, 311, "Text",
      CellTags->"1.0"]},
  "1.1"->{
    Cell[3791, 97, 81, 1, 56, "Subsection",
      CellTags->"1.1"],
    Cell[3875, 100, 726, 19, 100, "Text",
      CellTags->"1.1"],
    Cell[4604, 121, 115, 4, 28, "MathCaption",
      CellTags->"1.1"],
    Cell[4722, 127, 77, 2, 27, "Input",
      CellTags->"1.1"],
    Cell[4802, 131, 985, 24, 151, "Text",
      CellTags->"1.1"]},
  "1.2"->{
    Cell[5824, 160, 73, 1, 56, "Subsection",
      CellTags->"1.2"],
    Cell[5900, 163, 538, 12, 82, "Text",
      CellTags->"1.2"],
    Cell[6441, 177, 5050, 146, 70, "DefinitionBox",
      CellTags->"1.2"],
    Cell[11494, 325, 146, 6, 70, "Caption",
      CellTags->"1.2"],
    Cell[11643, 333, 831, 17, 70, "Text",
      CellTags->"1.2"]},
  "1.3"->{
    Cell[12511, 355, 64, 1, 70, "Subsection",
      CellTags->"1.3"],
    Cell[12578, 358, 832, 20, 70, "Text",
      CellTags->"1.3"],
    Cell[13413, 380, 118, 4, 70, "MathCaption",
      CellTags->"1.3"],
    Cell[13556, 388, 84, 2, 70, "Input",
      CellTags->"1.3"],
    Cell[13643, 392, 106, 3, 70, "Output",
      CellTags->"1.3"],
    Cell[13764, 398, 844, 27, 70, "MathCaption",
      CellTags->"1.3"],
    Cell[14633, 429, 74, 2, 70, "Input",
      CellTags->"1.3"],
    Cell[14710, 433, 109, 3, 70, "Output",
      CellTags->"1.3"],
    Cell[14834, 439, 255, 6, 70, "Text",
      CellTags->"1.3"],
    Cell[15092, 447, 74, 1, 70, "Caption",
      CellTags->"1.3"],
    Cell[15169, 450, 308, 6, 70, "Text",
      CellTags->"1.3"],
    Cell[15480, 458, 332, 9, 70, "MathCaption",
      CellTags->"1.3"],
    Cell[15837, 471, 132, 5, 70, "Input",
      CellTags->"1.3"],
    Cell[15972, 478, 154, 4, 70, "Output",
      CellTags->"1.3"],
    Cell[16141, 485, 124, 4, 70, "MathCaption",
      CellTags->"1.3"],
    Cell[16290, 493, 80, 2, 70, "Input",
      CellTags->"1.3"],
    Cell[16373, 497, 107, 3, 70, "Output",
      CellTags->"1.3"],
    Cell[16495, 503, 287, 7, 70, "Text",
      CellTags->"1.3"]},
  "1.4"->{
    Cell[16819, 515, 80, 1, 70, "Subsection",
      CellTags->"1.4"],
    Cell[16902, 518, 954, 29, 70, "Text",
      CellTags->"1.4"],
    Cell[17859, 549, 104, 2, 70, "MathCaption",
      CellTags->"1.4"],
    Cell[17966, 553, 164, 9, 70, "Input",
      CellTags->"1.4"],
    Cell[18133, 564, 161, 7, 70, "MathCaption",
      CellTags->"1.4"],
    Cell[18319, 575, 75, 2, 70, "Input",
      CellTags->"1.4"],
    Cell[18397, 579, 88, 3, 70, "Output",
      CellTags->"1.4"]},
  "1.5"->{
    Cell[18534, 588, 69, 1, 70, "Subsection",
      CellTags->"1.5"],
    Cell[18606, 591, 1110, 20, 70, "Text",
      CellTags->"1.5"],
    Cell[19719, 613, 209, 7, 70, "MathCaption",
      CellTags->"1.5"],
    Cell[19953, 624, 104, 2, 70, "Input",
      CellTags->"1.5"],
    Cell[20060, 628, 305, 10, 70, "Output",
      CellTags->"1.5"],
    Cell[20380, 641, 145, 4, 70, "MathCaption",
      CellTags->"1.5"],
    Cell[20550, 649, 83, 2, 70, "Input",
      CellTags->"1.5"],
    Cell[20636, 653, 169, 4, 70, "Output",
      CellTags->"1.5"],
    Cell[20820, 660, 374, 8, 70, "MathCaption",
      CellTags->"1.5"],
    Cell[21219, 672, 88, 2, 70, "Input",
      CellTags->"1.5"],
    Cell[21310, 676, 162, 4, 70, "Output",
      CellTags->"1.5"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"1.0", 22417, 709},
  {"1.1", 22560, 714},
  {"1.2", 22907, 725},
  {"1.3", 23263, 736},
  {"1.4", 24491, 773},
  {"1.5", 24980, 788}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 56, 1, 68, "Section",
  CellTags->"1.0"],
Cell[1790, 54, 1976, 39, 311, "Text",
  CellTags->"1.0"],

Cell[CellGroupData[{
Cell[3791, 97, 81, 1, 56, "Subsection",
  CellTags->"1.1"],
Cell[3875, 100, 726, 19, 100, "Text",
  CellTags->"1.1"],
Cell[4604, 121, 115, 4, 28, "MathCaption",
  CellTags->"1.1"],
Cell[4722, 127, 77, 2, 27, "Input",
  CellTags->"1.1"],
Cell[4802, 131, 985, 24, 151, "Text",
  CellTags->"1.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5824, 160, 73, 1, 56, "Subsection",
  CellTags->"1.2"],
Cell[5900, 163, 538, 12, 82, "Text",
  CellTags->"1.2"],
Cell[6441, 177, 5050, 146, 70, "DefinitionBox",
  CellTags->"1.2"],
Cell[11494, 325, 146, 6, 70, "Caption",
  CellTags->"1.2"],
Cell[11643, 333, 831, 17, 70, "Text",
  CellTags->"1.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12511, 355, 64, 1, 70, "Subsection",
  CellTags->"1.3"],
Cell[12578, 358, 832, 20, 70, "Text",
  CellTags->"1.3"],
Cell[13413, 380, 118, 4, 70, "MathCaption",
  CellTags->"1.3"],

Cell[CellGroupData[{
Cell[13556, 388, 84, 2, 70, "Input",
  CellTags->"1.3"],
Cell[13643, 392, 106, 3, 70, "Output",
  CellTags->"1.3"]
}, Open  ]],
Cell[13764, 398, 844, 27, 70, "MathCaption",
  CellTags->"1.3"],

Cell[CellGroupData[{
Cell[14633, 429, 74, 2, 70, "Input",
  CellTags->"1.3"],
Cell[14710, 433, 109, 3, 70, "Output",
  CellTags->"1.3"]
}, Open  ]],
Cell[14834, 439, 255, 6, 70, "Text",
  CellTags->"1.3"],
Cell[15092, 447, 74, 1, 70, "Caption",
  CellTags->"1.3"],
Cell[15169, 450, 308, 6, 70, "Text",
  CellTags->"1.3"],
Cell[15480, 458, 332, 9, 70, "MathCaption",
  CellTags->"1.3"],

Cell[CellGroupData[{
Cell[15837, 471, 132, 5, 70, "Input",
  CellTags->"1.3"],
Cell[15972, 478, 154, 4, 70, "Output",
  CellTags->"1.3"]
}, Open  ]],
Cell[16141, 485, 124, 4, 70, "MathCaption",
  CellTags->"1.3"],

Cell[CellGroupData[{
Cell[16290, 493, 80, 2, 70, "Input",
  CellTags->"1.3"],
Cell[16373, 497, 107, 3, 70, "Output",
  CellTags->"1.3"]
}, Open  ]],
Cell[16495, 503, 287, 7, 70, "Text",
  CellTags->"1.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16819, 515, 80, 1, 70, "Subsection",
  CellTags->"1.4"],
Cell[16902, 518, 954, 29, 70, "Text",
  CellTags->"1.4"],
Cell[17859, 549, 104, 2, 70, "MathCaption",
  CellTags->"1.4"],
Cell[17966, 553, 164, 9, 70, "Input",
  CellTags->"1.4"],
Cell[18133, 564, 161, 7, 70, "MathCaption",
  CellTags->"1.4"],

Cell[CellGroupData[{
Cell[18319, 575, 75, 2, 70, "Input",
  CellTags->"1.4"],
Cell[18397, 579, 88, 3, 70, "Output",
  CellTags->"1.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18534, 588, 69, 1, 70, "Subsection",
  CellTags->"1.5"],
Cell[18606, 591, 1110, 20, 70, "Text",
  CellTags->"1.5"],
Cell[19719, 613, 209, 7, 70, "MathCaption",
  CellTags->"1.5"],

Cell[CellGroupData[{
Cell[19953, 624, 104, 2, 70, "Input",
  CellTags->"1.5"],
Cell[20060, 628, 305, 10, 70, "Output",
  CellTags->"1.5"]
}, Open  ]],
Cell[20380, 641, 145, 4, 70, "MathCaption",
  CellTags->"1.5"],

Cell[CellGroupData[{
Cell[20550, 649, 83, 2, 70, "Input",
  CellTags->"1.5"],
Cell[20636, 653, 169, 4, 70, "Output",
  CellTags->"1.5"]
}, Open  ]],
Cell[20820, 660, 374, 8, 70, "MathCaption",
  CellTags->"1.5"],

Cell[CellGroupData[{
Cell[21219, 672, 88, 2, 70, "Input",
  CellTags->"1.5"],
Cell[21310, 676, 162, 4, 70, "Output",
  CellTags->"1.5"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

