(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    693096,      17385]*)
(*NotebookOutlinePosition[    707257,      17798]*)
(*  CellTagsIndexPosition[    707187,      17792]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "2. Introduction: Extending ",
  StyleBox["Mathematica", "SBO"],
  " to Solve Control Problems"
}], "Section",
  CellTags->"2"],

Cell[TextData[{
  "In this chapter, using the classical example of controlling an inverted \
pendulum, we learn how to formulate a control problem in ",
  StyleBox["Mathematica", "TI"],
  ", solve the problem using the ",
  StyleBox["Control System Professional", "TI"],
  " functionality, and analyze the results using the standard ",
  StyleBox["Mathematica", "TI"],
  " functions. We will see that, by being seamlessly incorporated with the \
rest of ",
  StyleBox["Mathematica", "TI"],
  ", this application package provides a convenient environment for solving \
typical control engineering problems. Additional solved examples will be \
given in later chapters when individual functions are discussed. \nThe \
inverted pendulum shown in Figure\[NonBreakingSpace]2.1 is a massive rod \
mounted on a cart that moves in a horizontal direction in such a way that the \
rod remains vertical. The vertical position of the rod is unstable, and the \
cart exerts a force to provide the attitude control of the pendulum. This or \
a similar model is considered in many textbooks on control systems. We will \
follow Brogan (1991), pp. 590\[Dash]92. "
}], "Text",
  CellTags->"2"],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 47 4 249 191
%%HiResBoundingBox: 47 4 249 191
%%Creator: (Mathematica Macintosh 3.0)
%%Title: Clipboard
%%CreationDate: (Friday, January 31, 1997) (10:50:28 AM)
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 195 translate 1 -1 scale
gsave
47 191 translate
202 -187 scale
1 string
803 743 1 [803 0 0 743 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } image
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFE1F
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF0F
FFFFFFFFFFFFEFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF3FFFFFFFFF9FFFFFFFFFFDFFFFFFFFFFFFFFFFFFF1FFFFFFFFF87
FFFFFFFFFFFFC3FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF3FFFFFFFFF8FFFFFFFFFF8FFFFFFFFFFFFFFFFFFF8FFFFFFFFFE3
FFFFFFFFFFFFE1FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF7FFFFFFFFF1FFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF07FFFFFFFF07FFFFFFFFFC7FFFFFFFFC7FFFFFFFFC1FFFFFFFFF0
7FFFFFFFFFFFF07FFFFFE0
FFBFFFFFFFFFEFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFE3FFFFFFFFF3FFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFA3FFFFFFFFE3FFFFFFFFFE3FFFFFFFFC3FFFFFFFFF1FFFFFFFFF8
7FFFFFFFFFFFFE3FFFFFE0
FF87FFFFFFFFC7FFFFFFFFFC1FFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0FFFFFFFFF07FFFFFFFFF87FFFFFFFFDFFFFFFFFFC7FFFFFFFFFC7
FFFFFFFC1FFFFFFFFF1FFFFFFFFFF07FFFFFFFC1FFFFFFFFF87FFFFFFFFC
1FFFFFFFFFFFFE1FFFFFE0
FFE3FFFFFFFFE3FFFFFFFFFE0FFFFFFFFE3FFFFFFFFFBFFFFFFFFFFBFFFF
FFFFFF87FFFFFFFFE3FFFFFFFFFE3FFFFFFFF8FFFFFFFFFC3FFFFFFFFFE3
FFFFFFFF8FFFFFFFFF8FFFFFFFFFFC3FFFFFFFF8FFFFFFFFFE3FFFFFFFFF
8FFFFFFFFFFFFF8FFFFFE0
FFE1FFFFFFFFF07FFFFFFFFF07FFFFFFFE1FFFFFFFFF07FFFFFFFFF07FFF
FFFFFFC1FFFFFFFFE1FFFFFFFFFF07FFFFFFFC1FFFFFFFFE1FFFFFFFFFF1
FFFFFFFFC7FFFFFFFFC1FFFFFFFFFE1FFFFFFFFC7FFFFFFFFF1FFFFFFFFF
07FFFFFFFFFFFFC7FFFFE0
FFF8FFFFFFFFF83FFFFFFFFFE3FFFFFFFF8FFFFFFFFF87FFFFFFFFFA3FFF
FFFFFFF0FFFFFFFFF8FFFFFFFFFF87FFFFFFFF0FFFFFFFFF8FFFFFFFFFF8
FFFFFFFFE3FFFFFFFFF0FFFFFFFFFF8FFFFFFFFE3FFFFFFFFF8FFFFFFFFF
E3FFFFFFFFFFFFE3FFFFE0
FFFC1FFFFFFFFC1FFFFFFFFFF1FFFFFFFFC3FFFFFFFFC1FFFFFFFFFC1FFF
FFFFFFF87FFFFFFFFC1FFFFFFFFFC1FFFFFFFF87FFFFFFFFC3FFFFFFFFFC
1FFFFFFFF07FFFFFFFF87FFFFFFFFFC3FFFFFFFF0FFFFFFFFFC1FFFFFFFF
F0FFFFFFFFFFFFF0FFFFE0
FFFE0FFFFFFFFF8FFFFFFFFFF8FFFFFFFFE1FFFFFFFFF8FFFFFFFFFF8FFF
FFFFFFFE3FFFFFFFFE0FFFFFFFFFF8FFFFFFFFE3FFFFFFFFE3FFFFFFFFFE
0FFFFFFFFC3FFFFFFFFE3FFFFFFFFFE3FFFFFFFF87FFFFFFFFE0FFFFFFFF
F87FFFFFFFFFFFF87FFFE0
FFFF07FFFFFFFFC7FFFFFFFFFC1FFFFFFFF07FFFFFFFF07FFFFFFFFFC7FF
FFFFFFFF07FFFFFFFF07FFFFFFFFF07FFFFFFFF0FFFFFFFFF07FFFFFFFFF
07FFFFFFFE1FFFFFFFFF07FFFFFFFFF07FFFFFFFC1FFFFFFFFF07FFFFFFF
FC1FFFFFFFFFFFFC1FFFE0
FFFFE3FFFFFFFFE3FFFFFFFFFE3FFFFFFFFE3FFFFFFFFE3FFFFFFFFFE3FF
FFFFFFFF83FFFFFFFFE3FFFFFFFFFE3FFFFFFFF87FFFFFFFFE3FFFFFFFFF
E3FFFFFFFF8FFFFFFFFF87FFFFFFFFFA3FFFFFFFF8FFFFFFFFFE3FFFFFFF
FF0FFFFFFFFFFFFF0FFFE0
FFFFF1FFFFFFFFF07FFFFFFFFF07FFFFFFFE1FFFFFFFFF0FFFFFFFFFF07F
FFFFFFFFC1FFFFFFFFF1FFFFFFFFFF0FFFFFFFFC1FFFFFFFFE1FFFFFFFFF
F1FFFFFFFFC3FFFFFFFFC1FFFFFFFFFC1FFFFFFFFC7FFFFFFFFF1FFFFFFF
FFC7FFFFFFFFFFFF87FFE0
FFFFF8FFFFFFFFF83FFFFFFFFFE3FFFFFFFF8FFFFFFFFF87FFFFFFFFFC3F
FFFFFFFFF8FFFFFFFFF8FFFFFFFFFF87FFFFFFFE0FFFFFFFFF8FFFFFFFFF
F8FFFFFFFFE1FFFFFFFFF8FFFFFFFFFF8FFFFFFFFE3FFFFFFFFF8FFFFFFF
FFE3FFFFFFFFFFFFE3FFE0
FFFFFC1FFFFFFFFC1FFFFFFFFFE1FFFFFFFFC3FFFFFFFFC1FFFFFFFFFE1F
FFFFFFFFF47FFFFFFFFC1FFFFFFFFFC1FFFFFFFF07FFFFFFFFC3FFFFFFFF
FC1FFFFFFFF07FFFFFFFF07FFFFFFFFFC7FFFFFFFF07FFFFFFFFC1FFFFFF
FFF07FFFFFFFFFFFF0FFE0
FFFFFE1FFFFFFFFF8FFFFFFFFFF8FFFFFFFFE3FFFFFFFFF0FFFFFFFFFF8F
FFFFFFFFFE3FFFFFFFFE1FFFFFFFFFF0FFFFFFFFE3FFFFFFFFE3FFFFFFFF
FF0FFFFFFFFE3FFFFFFFFE3FFFFFFFFFE3FFFFFFFF83FFFFFFFFE3FFFFFF
FFF83FFFFFFFFFFFF8FFE0
FFFFFF07FFFFFFFFC7FFFFFFFFFC1FFFFFFFF07FFFFFFFF87FFFFFFFFFC3
FFFFFFFFFF0FFFFFFFFF07FFFFFFFFF87FFFFFFFF1FFFFFFFFF07FFFFFFF
FF87FFFFFFFE1FFFFFFFFF0FFFFFFFFFF07FFFFFFFC1FFFFFFFFF07FFFFF
FFFC1FFFFFFFFFFFFDFFE0
FFFFFFE3FFFFFFFFE3FFFFFFFFFE0FFFFFFFFC3FFFFFFFFE3FFFFFFFFFE1
FFFFFFFFFF87FFFFFFFFE3FFFFFFFFFE3FFFFFFFF8FFFFFFFFFC3FFFFFFF
FFE3FFFFFFFF8FFFFFFFFF87FFFFFFFFFC3FFFFFFFF8FFFFFFFFFE3FFFFF
FFFF8FFFFFFFFFFFFFFFE0
FFFFFFF1FFFFFFFFF07FFFFFFFFF07FFFFFFFE1FFFFFFFFF07FFFFFFFFF0
7FFFFFFFFFC1FFFFFFFFF1FFFFFFFFFF07FFFFFFFC1FFFFFFFFE1FFFFFFF
FFF0FFFFFFFFC3FFFFFFFFC1FFFFFFFFFE1FFFFFFFFC7FFFFFFFFE1FFFFF
FFFFC7FFFFFFFFFFFFFFE0
FFFFFFF8FFFFFFFFFA3FFFFFFFFFE3FFFFFFFF8FFFFFFFFF83FFFFFFFFFE
3FFFFFFFFFF0FFFFFFFFF8FFFFFFFFFF83FFFFFFFF0FFFFFFFFF8FFFFFFF
FFF87FFFFFFFE3FFFFFFFFF0FFFFFFFFFF8FFFFFFFFE3FFFFFFFFF8FFFFF
FFFFE3FFFFFFFFFFFFFFE0
FFFFFFFC1FFFFFFFFC1FFFFFFFFFF1FFFFFFFFC3FFFFFFFFC1FFFFFFFFFE
1FFFFFFFFFFC7FFFFFFFFC1FFFFFFFFFC1FFFFFFFF87FFFFFFFFC3FFFFFF
FFFC1FFFFFFFF07FFFFFFFF87FFFFFFFFFC3FFFFFFFF0FFFFFFFFFC1FFFF
FFFFF07FFFFFFFFFFFFFE0
FFFFFFFE0FFFFFFFFF8FFFFFFFFFF8FFFFFFFFE1FFFFFFFFF8FFFFFFFFFF
8FFFFFFFFFFE3FFFFFFFFE0FFFFFFFFFF8FFFFFFFFE3FFFFFFFFE1FFFFFF
FFFF0FFFFFFFFC3FFFFFFFFE3FFFFFFFFFE1FFFFFFFF83FFFFFFFFE1FFFF
FFFFFC3FFFFFFFFFFFFFE0
FFFFFFFF07FFFFFFFFC7FFFFFFFFFC1FFFFFFFF07FFFFFFFF47FFFFFFFFF
C3FFFFFFFFFF07FFFFFFFF07FFFFFFFFF47FFFFFFFF07FFFFFFFF07FFFFF
FFFF07FFFFFFFE1FFFFFFFFF07FFFFFFFFF07FFFFFFFC1FFFFFFFFF07FFF
FFFFFE1FFFFFFFFFFFFFE0
FFFFFFFFE3FFFFFFFFE3FFFFFFFFFE1FFFFFFFFE3FFFFFFFFE3FFFFFFFFF
E3FFFFFFFFFF83FFFFFFFFE3FFFFFFFFFE3FFFFFFFF87FFFFFFFFE3FFFFF
FFFFE3FFFFFFFF8FFFFFFFFF83FFFFFFFFFE3FFFFFFFF8FFFFFFFFFE3FFF
FFFFFF8FFFFFFFFFFFFFE0
FFFFFFFFF1FFFFFFFFF07FFFFFFFFF07FFFFFFFF1FFFFFFFFF0FFFFFFFFF
F07FFFFFFFFFC1FFFFFFFFF1FFFFFFFFFF0FFFFFFFFC1FFFFFFFFF1FFFFF
FFFFF1FFFFFFFFC3FFFFFFFFC1FFFFFFFFFE1FFFFFFFFC7FFFFFFFFF1FFF
FFFFFFC3FFFFFFFFFFFFE0
FFFFFFFFF8FFFFFFFFFC3FFFFFFFFFE3FFFFFFFF8FFFFFFFFF87FFFFFFFF
FC3FFFFFFFFFF8FFFFFFFFF8FFFFFFFFFF87FFFFFFFF0FFFFFFFFF8FFFFF
FFFFF8FFFFFFFFE1FFFFFFFFF8FFFFFFFFFF8FFFFFFFFE3FFFFFFFFF8FFF
FFFFFFE1FFFFFFFFFFFFE0
FFFFFFFFFC1FFFFFFFFE1FFFFFFFFFF1FFFFFFFFC3FFFFFFFFC1FFFFFFFF
FE1FFFFFFFFFFC7FFFFFFFFC1FFFFFFFFFC1FFFFFFFF07FFFFFFFFC3FFFF
FFFFFC1FFFFFFFF07FFFFFFFF47FFFFFFFFFC3FFFFFFFF07FFFFFFFFC3FF
FFFFFFF07FFFFFFFFFFFE0
FFFFFFFFFF0FFFFFFFFF8FFFFFFFFFF8FFFFFFFFE3FFFFFFFFF0FFFFFFFF
FF8FFFFFFFFFFE3FFFFFFFFF0FFFFFFFFFF0FFFFFFFFE3FFFFFFFFE3FFFF
FFFFFF0FFFFFFFFE3FFFFFFFFE3FFFFFFFFFE3FFFFFFFF83FFFFFFFFE3FF
FFFFFFFE3FFFFFFFFFFFE0
FFFFFFFFFF87FFFFFFFFC3FFFFFFFFFC1FFFFFFFF07FFFFFFFFC7FFFFFFF
FFC3FFFFFFFFFF0FCFFFFFFF87FFFFFFFFFC7FFFFFFFF1FFFFFFFFF07FFF
FFFFFF87FFFFFFFF1FFFFFFFFF0FFFFFFFFFF07FFFFFFFC1FFFFFFFFF07F
FFFFFFFF1FFFFFFFFFFFE0
FFFFFFFFFFE3FFFFFFFFE3FFFFFFFFFE0FFFFFFFFC3FFFFFFFFE3FFFFFFF
FFE1FFFFFFFFFF83EFFFFFFFE3FFFFFFFFFE3FFFFFFFF8FFFFFFFFFC3FFF
FFFFFFE3FFFFFFFF8FFFFFFFFF87FFFFFFFFFC3FFFFFFFF8FFFFFFFFFE3F
FFFFFFFF8FFFFFFFFFFFE0
FFFFFFFFFFF1FFFFFFFFF07FFFFFFFFF07FFFFFFFE1FFFFFFFFF07FFFFFF
FFF07FFFFFFFFFC1CFFFFFFFF1FFFFFFFFFF07FFFFFFFC1FFFFFFFFE1FFF
FFFFFFF07FFFFFFFC3FFFFFFFFC1FFFFFFFFFE1FFFFFFFFC7FFFFFFFFE1F
FFFFFFFFC3FFFFFFFFFFE0
FFFFFFFFFFF8FFFFFFFFFA3FFFFFFFFFE3FFFFFFFF8FFFFFFFFF83FFFFFF
FFFE3FFFFFFFFFF8EFFFFFFFF8FFFFFFFFFF83FFFFFFFF0FFFFFFFFF8FFF
FFFFFFF87FFFFFFFE3FFFFFFFFF0FFFFFFFFFF8FFFFFFFFE3FFFFFFFFF8F
FFFFFFFFE3FFFFFFFFFFE0
FFFFFFFFFFFC1FFFFFFFFC1FFFFFFFFFF1FFFFFFFFC1FFFFFFFFC1FFFFFF
FFFF1FFFFFFFFFFC4FFFFFFFFC1FFFFFFFFFC1FFFFFFFF87FFFFFFFFC3FF
FFFFFFFC1FFFFFFFF07FFFFFFFFC7FFFFFFFFFC3FFFFFFFF07FFFFFFFFC3
FFFFFFFFF07FFFFFFFFFE0
FFFFFFFFFFFE0FFFFFFFFF8FFFFFFFFFF8FFFFFFFFE1FFFFFFFFF8FFFFFF
FFFF8FFFFFFFFFFE0FFFFFFFFE0FFFFFFFFFF8FFFFFFFFE3FFFFFFFFE1FF
FFFFFFFF0FFFFFFFFE3FFFFFFFFE3FFFFFFFFFE1FFFFFFFFC3FFFFFFFFE1
FFFFFFFFFE3FFFFFFFFFE0
FFFFFFFFFFFF07FFFFFFFFC7FFFFFFFFFC1FFFFFFFF07FFFFFFFFC7FFFFF
FFFFC3FFFFFFFFFF07FFFFFFFF07FFFFFFFFFC7FFFFFFFF07FFFFFFFF07F
FFFFFFFF07FFFFFFFE1FFFFFFFFF07FFFFFFFFF07FFFFFFFC1FFFFFFFFF0
7FFFFFFFFE1FFFFFFFFFE0
FFFFFFFFFFFFE3FFFFFFFFE3FFFFFFFFFF0FFFFFFFFE3FFFFFFFFE3FFFFF
FFFFE3FFFFFFFFFF83FFFFFFFFE3FFFFFFFFFE3FFFFFFFF87FFFFFFFFE3F
FFFFFFFFE3FFFFFFFF8FFFFFFFFF83FFFFFFFFFE3FFFFFFFF8FFFFFFFFFE
3FFFFFFFFF8FFFFFFFFFE0
FFFFFFFFFFFFF1FFFFFFFFF07FFFFFFFFF87FFFFFFFF1FFFFFFFFF0FFFFF
FFFFF07FFFFFFFFFC1FFFFFFFFF1FFFFFFFFFF0FFFFFFFFC1FFFFFFFFF1F
FFFFFFFFF1FFFFFFFFC1FFFFFFFFC1FFFFFFFFFF1FFFFFFFFC7FFFFFFFFF
1FFFFFFFFFC1FFFFFFFFE0
FFFFFFFFFFFFF8FFFFFFFFFC3FFFFFFFFFE3FFFFFFFF8FFFFFFFFF83FFFF
FFFFFE3FFFFFFFFFE8FFFFFFFFF8FFFFFFFFFF83FFFFFFFF8FFFFFFFFF8F
FFFFFFFFF8FFFFFFFFE1FFFFFFFFF8FFFFFFFFFF8FFFFFFFFE3FFFFFFFFF
8FFFFFFFFFE0FFFFFFFFE0
FFFFFFFFFFFFFC1FFFFFFFFE1FFFFFFFFFF1FFFFFFFFC3FFFFFFFFC1FFFF
FFFFFE1FFFFFFFFFCC7FFFFFFFFC1FFFFFFFFFC1FFFFFFFF07FFFFFFFFC3
FFFFFFFFFC1FFFFFFFF07FFFFFFFFC7FFFFFFFFFC3FFFFFFFF07FFFFFFFF
C3FFFFFFFFF07FFFFFFFE0
FFFFFFFFFFFFFF0FFFFFFFFF8FFFFFFFFFF8FFFFFFFFE3FFFFFFFFF8FFFF
FFFFFF8FFFFFFFFFEE3FFFFFFFFF0FFFFFFFFFF8FFFFFFFFE3FFFFFFFFE3
FFFFFFFFFF0FFFFFFFFE3FFFFFFFFE3FFFFFFFFFE3FFFFFFFFA3FFFFFFFF
E3FFFFFFFFFE3FFFFFFFE0
FFFFFFFFFFFFFF87FFFFFFFFC3FFFFFFFFFC1FFFFFFFF07FFFFFFFFC7FFF
FFFFFFC1FFFFFFFFCF07FFFFFFFF87FFFFFFFFFC7FFFFFFFF0FFFFFFFFF0
7FFFFFFFFF87FFFFFFFF1FFFFFFFFF0FFFFFFFFFF07FFFFFFFC1FFFFFFFF
F07FFFFFFFFF1FFFFFFFE0
FFFFFFFFFFFFFFE3FFFFFFFFE1FFFFFFFFFE0FFFFFFFFE3FFFFFFFFE3FFF
FFFFFFE1FFFFFFFFEF83FFFFFFFFE3FFFFFFFFFE3FFFFFFFF87FFFFFFFFE
3FFFFFFFFFE3FFFFFFFF8FFFFFFFFF83FFFFFFFFFE3FFFFFFFF8FFFFFFFF
FC3FFFFFFFFF8FFFFFFFE0
FFFFFFFFFFFFFFF0FFFFFFFFF07FFFFFFFFF07FFFFFFFE1FFFFFFFFF07FF
FFFFFFF07FFFFFFFCFC1FFFFFFFFF0FFFFFFFFFF07FFFFFFFC1FFFFFFFFE
1FFFFFFFFFF07FFFFFFFC3FFFFFFFFC1FFFFFFFFFE1FFFFFFFFC7FFFFFFF
FE1FFFFFFFFFC1FFFFFFE0
FFFFFFFFFFFFFFF87FFFFFFFFE3FFFFFFFFFE3FFFFFFFF8FFFFFFFFF83FF
FFFFFFFE3FFFFFFFEFF8FFFFFFFFF87FFFFFFFFF83FFFFFFFF0FFFFFFFFF
8FFFFFFFFFF87FFFFFFFE3FFFFFFFFF9FFFFFFFFFF8FFFFFFFFE3FFFFFFF
FF8FFFFFFFFFF0FFFFFFE0
FFFFFFFFFFFFFFFC1FFFFFFFFE1FFFFFFFFFF1FFFFFFFFC1FFFFFFFFC1FF
FFFFFFFF1FFFFFFFCFFC7FFFFFFFFC1FFFFFFFFFC1FFFFFFFF87FFFFFFFF
C1FFFFFFFFFC1FFFFFFFF7FFFFFFFFFDFFFFFFFFFFDFFFFFFFFF07FFFFFF
FFC3FFFFFFFFF87FFFFFE0
FFFFFFFFF800000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0003FFFFFFFFFE3FFFFFE0
FFFFFFFFF800000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00007FFFFFFFFF07FFFFE0
FFFFFFFFF800000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00023FFFFFFFFF87FFFFE0
FFFFFFFFF800000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00041FFFFFFFFFC1FFFFE0
FFFFFFFFF800000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00038FFFFFFFFFF8FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000007FFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFF0000500001FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07C7FFFFFFFFF07FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8002AA0003FFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFE000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83E3FFFFFFFFFE3FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFD001FFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFF8017FFFFC007FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07F07FFFFFFFFF0FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFE00FFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFF803FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FC3FFFFFFFFF87FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFF001FFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFC01FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FC1FFFFFFFFFC1FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFE00FFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFF80FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FF8FFFFFFFFFF3FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFF007FFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFC07FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFC7FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFF807FFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFE01FFFFFFFFFE03FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFE3FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFC01FFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFF01FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFF07FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFF80FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFA3FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFFFFFF80FFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFC07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFC1FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFC0FFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFE03FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFF8FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF807FFFFFFFFFFC07FFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFFFF03FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFC7FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFF03FFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFF83FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFE3FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFFFF01FFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFFFFFFFF81FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFF07FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFF81FFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFC0FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFF83FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFC1FFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFC07FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFC1FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFE0FFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFE0FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFF8FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFC0FFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFF07FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFC7FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFE0FFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFF07FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFE3FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFE07FFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFF07FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFF07FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFF07FFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFF83FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFF83FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFF07FFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF01FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFC1FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFF83FFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFF83FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFF8FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFF03FFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF81FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFC7FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFF83FFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFF83FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFE3FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFF03FFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFFFFC1FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFF0FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE000000000003FFFFFFFFFFFFFF80000000
00000000000000000000000000000000000000000FFFFFFFFFFFFFFF8000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFF87FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000007FFFFFFFFFFFFFF80000000
000000000000000000000000000000000000000007FFFFFFFFFFFFFFC000
000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF03FFFFFFFFFC1FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE000000000003FFFFFFFFFFFFFF80000000
00000000000000000000000000000000000000000FFFFFFFFFFFFFFFC000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFF0FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000007FFFFFFFFFFFFFF80000000
000000000000000000000000000000000000000007FFFFFFFFFFFFFFC000
000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF007FFFFFFFFFC7FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE000000000003FFFFFFFFFFFFFF80000000
00000000000000000000000000000000000000000FFFFFFFFFFFFFFFC000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF823FFFFFFFFFE3FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF055555555503FFFFFFFFFFFFFF01555555
555555555555555545555555555555555555555407FFFFFFFFFFFFFFC155
555541FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF061FFFFFFFFFF07FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFF83FFFFFFFFFFFFFF83FFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFF83FF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF838FFFFFFFFFF83FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFF03FFFFFFFFFFFFFF03FFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF81FF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07C1FFFFFFFFFC1FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFF83FFFFFFFFFFFFFF83FFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFF83FF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83E1FFFFFFFFFF8FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFF01FFFFFFFFFFFFFF03FFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFF01FF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07F07FFFFFFFFF47FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFF83FFFFFFFFFFFFFF03FFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFF83FF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FE3FFFFFFFFFE3FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFF81FFFFFFFFFFFFFF07FFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFF03FF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FF1FFFFFFFFFF3FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFC1FFFFFFFFFFFFFE0FFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFF03FF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FF8FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFC0FFFFFFFFFFFFFE07FFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFFFFFF07FF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFC3FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFE0FFFFFFFFFFFFFE0FFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFE07FF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFE3FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFC07FFFFFFFFFFFFC0FFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFC07FF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFF07FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFE07FFFFFFFFFFFF80FFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFC0FFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFE3FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFF03FFFFFFFFFFFF01FFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFFFFFFFFC0FFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFE1FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFF83FFFFFFFFFFFF03FFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF81FFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFF8FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFF01FFFFFFFFFFFF03FFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF01FFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFC1FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFF80FFFFFFFFFFFE07FFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFE03FFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFE0FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFC07FFFFFFFFFFC07FFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFFFC07FFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFF07FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFE03FFFFFFFFFF80FFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFE07FFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFE3FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFF01FFFFFFFFFF01FFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFFFFFF80FFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFF1FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFF80FFFFFFFFFE03FFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFF01FFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFF8FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFF807FFFFFFFF407FFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFC01FFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFC1FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFE03FFFFFFFF00FFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFF803FFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFE1FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFE007FFFFFFC01FFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFF007FFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFF07FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFF803FFFFFF803FFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFE00FFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFE3FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFC007FFFF4007FFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFF001FFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFF1FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFE002FFFE000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFA00FFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFF8FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF0000100001FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFC001FFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFC1FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFE00000000FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000A80003FFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFE0FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF00000001FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000007FFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFF07FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFE000002FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000003FFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFE3FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFC00007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000001FFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFF1FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFEABFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0000FFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFF8FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5457FFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFC1FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFF0FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFF87FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFFE3FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFFF1FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFFF8FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF01FFFFFFFFFFFFC7FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF80FFFFFFFFFFFFEFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF041FFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF830FFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0787FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83E3FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07F07FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83F87FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FC1FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FF0FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FF07FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFE3FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFF1FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFF8FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFC1FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFF0FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFF87FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFE3FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFF07FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFF87FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFC1FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFF8FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFF07FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFE3FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC7FFFFFFD07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFF0FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF81FFFFFA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFF87FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE007FFD0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFC1FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE2E7FA0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFF0FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC4C5000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFC1F07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFF87FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFCEA0000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFBF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFE3FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC44000000000000000000000000000000000000000000
000000000003FFF1F1FFFFD5555555555555555555555555555555555555
5507FFFFFFFFF07FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE6E2800000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFF1FFFFC0000000000000000000000000000000000000
0003FFFFFFFFF87FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC0C7F000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFC71FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF01FFFFFFFFFC1FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE08FFFE8003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFE63FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF80FFFFFFFFFF8FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF01FFFFD0017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFF23FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF007FFFFFFFFF47FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEBFFFFFFA03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFA3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF823FFFFFFFFFE3FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFD1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF071FFFFFFFFFF0FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF838FFFFFFFFFF87FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFF87FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07C1FFFFFFFFFC1FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFF8BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83F0FFFFFFFFFF0FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFF1DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07F87FFFFFFFFF9FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFF9EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FE3FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFF1E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FF07FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFE3F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FF87FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFC3F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFC1FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFF83F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFF0FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFF07FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFE3FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFF1FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFF8FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFC1FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFF0FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFF87FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFE3FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFF07FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFF87FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFC1FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFF0FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFF07FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFE3FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFF1FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFF8FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFC1FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFF0FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFF87FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFE3FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFF07FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFF87FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFC1FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFF8FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFF07FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFFE3FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF03FFFFFFFFFFFF1FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF81FFFFFFFFFFFF9FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF007FFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF823FFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF071FFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF838FFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07C3FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83E3FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07F07FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FC3FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FE1FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FF8FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFC3FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFE1FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFF07FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFE3FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFF1FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFF8FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFCFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFC3FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFE3FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFF07FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFE3FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF0555555555555555555555555555555555
555555555555555555415555555555555555555555555555555555555555
555541FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFE1FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFF8FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFC1FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFE1FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFF07FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAA800AAA22A800AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAABFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFE3FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFC00FFE73F001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFF1FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE007FEF3E003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFF8FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF001FE77C007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFC1FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE01FEEF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFE3FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC007E4F001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFF07FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF803ECE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFE3FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF401F5401FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFE1FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE00FB003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFF8FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0040007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFC1FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF800000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFE0FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFC00001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFF07FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFFE3FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFFF1FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFFF8FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF40001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF01FFFFFFFFFFFFC1FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFA00003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF80FFFFFFFFFFFFE3FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF041FFFFFFFFFFFF7FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF8000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF820FFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0707FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF002E007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83E3FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF01FC00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07F1FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07F981FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83F8FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFC07F1C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FC1FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFC0FFBE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FF0FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF81FF7C0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FF87FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF81FEFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFE3FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF01FC7C0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFF0FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF03FEFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFF87FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FDFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFC1FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFBFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFF0FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC07F1FE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFF07FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC0FF3FE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFE3FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF81FF7FC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFF1FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF83FEFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFF8FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF03FC7F81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFC1FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF03FEFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFF0FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFE07FDFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFF87FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFE0FFBFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFE3FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFC07F3FE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFF07FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF80FF3FE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFF87FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF81FF7FC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFC1FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FEFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFF0FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FCFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFF07FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE03FDFF82FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFE3FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFC07F9FF027FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFF1FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE0FFBFE02FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFF8FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFC0FF3FE067FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF01FFFFFFFFFC1FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF81FF7FE0EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF80FFFFFFFFFF0FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF01FE7FC0E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF007FFFFFFFFF87FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF83FEFF80EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF823FFFFFFFFFE3FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF03FCFF01E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF071FFFFFFFFFF07FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFE07F9FF83EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF838FFFFFFFFFF87FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC07F9FF03E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07C1FFFFFFFFFC1FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC0FFBFE07EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83E0FFFFFFFFFF8FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC0FFFFC07E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07F07FFFFFFFFF07FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFE0FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FE3FFFFFFFFFEFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF01FFFFC0FE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FF1FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF03FFFF81FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FF8FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF07FFFF01FE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFC1FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE07FFFF03FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFF0FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC07F9FF03FE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFF87FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC0FFBFE07FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFE3FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC1FF7FC07FE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFF0FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF83FEFFE0FFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFF87FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF01FC7FC1FFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFC1FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF03FEFF81FFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFE0FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFE07FDFF01FFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFF07FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFE0FFFFF03FFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFE3FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFC07FFFF07FFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFF1FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFC0FFFFE07FFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFF8FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF81FFFFC07FFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFC1FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF83FFFFC0FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFF0FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF01FFFF81FFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFF87FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE03FFFF81FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFE3FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE07FDFF01FFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFF07FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE0FFBFF03FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFF87FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC0FF3FE07FFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFC1FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF80FF7FE0FFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFF0FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF01FE7FC07FFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFF07FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF83FEFFC0FFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFE3FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF03FCFF81FFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFF1FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFE07FDFF83FFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFF8FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFC07F9FF03FFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFC1FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFE0FFBFF03FFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFF0FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFC0FF3FE07FFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF01FFFFFFFFFFF87FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF81FF7FE0FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF80FFFFFFFFFFFE3FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF01FE7FC07FFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF003FFFFFFFFFFF07FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF03FEFF80FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF823FFFFFFFFFFF8FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF03FDFF81FFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0707FFFFFFFFFFCFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE07FDFF83FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83E3FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFC07F1FF03FFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07E1FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE0FFBFE03FFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83F8FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFC1FF7FC07FFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FC1FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF81FE7FE0FFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FE0FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF01FE7FC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FF07FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF03FEFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFE3FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FDFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFF1FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FE0FF9FF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFF8FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FC07F1FF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFC1FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FC0FFBFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFE3FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F81FF7FC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFF07FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F83FEFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFE3FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F01FC7FC0FFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFF1FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F03FEFF81FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFF8FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E07FDFF01FFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFC1FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0FFBFF83FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFE0FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C07F3FF07FFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFF07FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
80FF3FE07FFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFE3FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
81FF7FC07FFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFF1FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
83FEFFC0FFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFF8FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
03FC7FC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFC1FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
03FEFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFF0FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
07FDFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFF87FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
0FFBFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFE3FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
07F3FE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFF1FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
1FF3FE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFF8FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
1FF7FC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFC1FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
3FEFFC0FFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFE0FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0
3FCFFC1FFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFF07FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
3FDFF83FFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFE3FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
7F9FF01FFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFF1FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
FFBFF03FFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFF8FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
FF3FE07FFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFFC1FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81
FF7FE0FFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFFF0FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01
FE7FC0FFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF01FFFFFFFFFFFF87FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83
FEFFC0FFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF80FFFFFFFFFFFFE3FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07
FCFF81FFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF007FFFFFFFFFFFF7FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07
FBFF83FFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF823FFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07
F9FF01FFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF071FFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0F
FBFE03FFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF838FFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1F
F7FE07FFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07C1FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83F
E7FE0FFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83F0FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01F
C7FC0FFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07F87FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03F
EFF80FFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FE3FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07F
DFF01FFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FF07FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07F
BFF83FFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FF87FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F
1FF03FFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFC1FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF
BFE07FFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFF0FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FF
7FE07FFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFF07FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FE
FFE0FFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFE3FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FC
FFC0FFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFF0FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FC
FF81FFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFF87FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FD
FF01FFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFC1FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFB
FF83FFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFF0FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF9
FF03FFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFF87FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFF
FE07FFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFE3FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFF
FC07FFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFF07FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFF
FE0FFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFF87FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFF
FC1FFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFC1FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFF
F81FFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFF8FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFF
F01FFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFF47FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBF
F03FFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFE3FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF3F
F07FFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFF0FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FF7F
E07FFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFF87FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FE7F
C07FFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFC1FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFF
E0FFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFF0FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FCFF
C1FFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFF87FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FDFF
81FFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFE3FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FDFF
01FFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF007FFFFFFFFF07FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFF
03FFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF807FFFFFFFFF83FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFF
07FFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF041FFFFFFFFFC1FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFE
0FFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF830FFFFFFFFFF8FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFC
07FFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0707FFFFFFFFFC7FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFC
0FFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83E3FFFFFFFFFE3FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFF8
1FFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07F1FFFFFFFFFF0FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFF8
3FFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83F8FFFFFFFFFF8FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F1FF0
1FFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FC1FFFFFFFFFDFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF0
3FFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FF0FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FF7FE0
7FFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FF87FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FEFFE0
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFE3FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FE7FC0
7FFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFF07FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FEFF80
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFF87FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FDFF81
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFC1FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF83
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFF0FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F1FF03
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFF07FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFBFE03
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFE3FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FF7FE07
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFF1FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE0F
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFF8FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FC7FC07
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFC1FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FEFF81F
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFF0FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FDFF81F
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFF87FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF83F
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFE3FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F3FF03F
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFF07FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FF3FE03F
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFF87FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FF7FC07F
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFC1FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE0FF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFF8FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FCFFC0FF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFF07FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FDFF81FF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFE3FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07F9FF01FF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFF0FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF83FF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFF87FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF3FF07FF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFC1FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FF7FE07FF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFF0FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FE7FC07FF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFF87FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFC0FFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFE3FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FCFFC0FFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFF07FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07F9FF83FFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFF83FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F9FF01FFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFFC1FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF03FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFFF8FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF7FF07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF01FFFFFFFFFFFF4FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FE7FE07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF80FFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FE7FC07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF003FFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFC0FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF821FFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FDFFC1FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0707FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FBFF83FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83E3FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F9FF01FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07F1FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFBFF03FFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83F8FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FF7FE07FFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FC3FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FE7FE0FFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FE3FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FC7FC07FFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FF07FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FEFFC0FFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFE3FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FDFF81FFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFE1FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FBFF83FFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFF8FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F1FF01FFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFC1FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFBFE03FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFE1FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FF7FE07FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFF07FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFE3FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FCFFC0FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFF1FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FCFF80FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFF8FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FDFF01FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFC1FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF83FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFE3FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF3FF03FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFF07FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FF3FE03FFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFE3FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FE7FE07FFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFE1FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE0FFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFF8FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FCFFC0FFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFC1FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FCFF80FFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFE0FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07F9FF01FFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFF07FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF83FFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFE3FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF3FF03FFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFF1FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FF7FE07FFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFF8FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FE7FC07FFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFC1FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE0FFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFE1FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FDFFC0FFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFF07FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FDFF81FFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFE3FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F9FF01FFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFF1FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF03FFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFF8FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFFFFC1FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFE07FFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFFFE0FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFC07FFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF01FFFFFFFFFFFF07FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFE0FFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF80FFFFFFFFFFFFE3FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF007FFFFFFFFFFFF1FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFF81FFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF823FFFFFFFFFFFFBFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F7FF01FFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF070FFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF03FFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF8BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF8387FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FF7FF07FFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF1DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07C1FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FEFFE0FFFFAFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83F0FFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01F07FC07F401FFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07F07FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03E03FC0FA007FFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FE3FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07C11F800001FFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FD7DF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FF1FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0F8B8F800003FFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FE3CF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FF8FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC071FC0000001555555
555555555555555545555555555555555555555555555555555555555FFF
FF5CFDF7FFC0000000000000000000000000000000000000000000000000
0007FFC1FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0F9E00000002AAAAAA
AAAAAAAAAAAAAAAAA2AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAABFFF
FFF9FEE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFF0FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81F9F80000003FFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF9FF77FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFF87FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83F8F8E000003FFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFBFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFE3FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FC71C040001FFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFF07FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FE0380FE800FFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFF87FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FF0781FFD001FFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFC1FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF83FFFFA0FFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFF0FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F3FF03FFFFFD1FFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF25FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFF07FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FF3FF03FFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE31FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFE3FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FF7FE07FFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFD79FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFF1FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFF8FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FCFFC07FFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFC1FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FDFF80FFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFF0FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F9FF81FFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFF87FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF83FFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFE3FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF3FF03FFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFF07FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FF7FE03FFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFF87FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FE7FC07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFC1FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFF8FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FCFFC0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFFFFFFF07FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07F9FF81FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFFFFFFFFE3FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F9FF01FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF01FFFFFFFFFF0FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFBFF83FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF80FFFFFFFFFF87FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF7FF03FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF041FFFFFFFFFC1FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FE7FE07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF830FFFFFFFFFF0FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FC7FC07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0787FFFFFFFFF87FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FEFFC0FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83E3FFFFFFFFFE3FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FDFFC0FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07F0FFFFFFFFFF07FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FBFF81FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83F87FFFFFFFFF87FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F9FF01FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FC1FFFFFFFFFC7FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFBFF83FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FE0FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FF7FF07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FF07FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFE3FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FC7FC07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFF1FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FEFFC0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF83FFF8FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FDFFC1FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF07FFFC1FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0FFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F1FF01FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF87FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFBFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE3FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FF7FE07FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF07FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE07FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF87FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FCFFC07FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFC1FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FCFFC0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0FFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FDFF81FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE3FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF3FF01FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF1FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FF7FF03FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FE7FE07FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFC1FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE0FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FCFFC0FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF87FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FDFFC0FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE3FFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07F9FF81FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF07FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF83FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF87FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF3FF03FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFC1FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FE7FE03FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0FFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FE7FE07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF07FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE3FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FDFFC0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF1FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07F9FF80FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF8FFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F1FF01FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC1FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF83FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0FFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FF7FF03FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF87FFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FEFFE07FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FE7FE07FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FEFFE0FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FDFFC0FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FBFF81FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F1FF01FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFBFF83FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FF7FF03FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FEFFE07FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FC7FC07FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FEFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FDFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F3FF01FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFBFF03FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFF07FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFE07FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFC07FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFBFE0FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFDF81FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFE381FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F7F001FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FF3F803FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FE7FC07FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE03FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FCFFC007FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FDFFC003FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07F9FF80007FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF80003FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFF030007FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFF038002FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFE07C0005FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFE0FE0000FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFC07F00001FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFF80FF80028FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FBFF81FFC00FF7FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFBFF83FFE00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FF7FF03FFF011FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFF83FE7FE03FFF838FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFF01FC7FE07FFFC1C7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFF03FEFFE0FFFFE1F9FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFF07FDFFC0FFFFF1FC7FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFE07FBFF81FFFFF8FF3FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFC07F1FF81FFFFFC7FC7FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFBFF83FFFFFEFFE3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FF7FF03FFFFFF7FF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE07FFFFFFBFFE3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFF01FCFFC07FFFFFFDFFF1FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFF03FCFFE0FFFFFFFFFFFEFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFE07FDFFC0FFFFFFFFFFFF1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF81FFFFFFFFFFFFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFC07F3FF01FFFFFFFFFFFFF1FFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFC0FF3FF83FFFFFFFFFFFFFCFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF81FF7FF07FFFFFFFFFFFFFF1FFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE07FFFFFFFFFFFFFFAFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFF01FCFFC07FFFFFFFFFFFFFFF1FFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE03FCFFC0FFFFFFFFFFFFFFFFCFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE07FDFFC1FFFFFFFFFFFFFFFFF1FFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF83FFFFFFFFFFFFFFFFFAFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFC0FF3FF01FFFFFFFFFFFFFFFFFF1FFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFF80FF7FF03FFFFFFFFFFFFFFFFFFE3FFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFF01FE7FF07FFFFFFFFFFFFFFFFFFF07FFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFF83FEFFE07FFFFFFFFFFFFFFFFFFFE3FFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFF03FDFFC07FFFFFFFFFFFFFFFFFFFFC7FFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFE07FDFFC0FFFFFFFFFFFFFFFFFFFFFE8FFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFE07F9FFC1FFFFFFFFFFFFFFFFFFFFFFC5FFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFE0FFBFF83FFFFFFFFFFFFFFFFFFFFFFF8FFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFC0FF3FF01FFFFFFFFFFFFFFFFFFFFFFFD1FF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF81FE7FF03FFFFFFFFFFFFFFFFFFFFFFFFE3F
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF01FE7FE07FFFFFFFFFFFFFFFFFFFFFFFFF47
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FEFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFF8
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FDFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFD
1FFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFE07F9FFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFF
E3FFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFC07F1FF81FFFFFFFFFFFFFFFFFFFFFFFFFFFF
F41FFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFE0FFBFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFA3FFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFC1FF7FF01FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF01FFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFF81FEFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFA2FFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFF01FC7FE07FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF417FFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFF03FEFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA0BFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFF07FDFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFD015FFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFE0FFBFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFA82BFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFC07F1FF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF4000147FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFC0FF3FF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFF81FF7FF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFF83FEFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFF01FC7FE07FFFFFFFFFFFFFFFFFFFFF7FFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFF03FEFFE0FFFFFFFFFFFFFFFFFFFFFABFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFE07FDFFC0FFFFFFFFFFFFFFFFFFFFF3CFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFE0FFBFF81FFFFFFFFFFFFFFFFFFFFE3EFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFC07F3FF01FFFFFFFFFFFFFFFFFFFFE7E7FFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFF80FF3FF83FFFFFFFFFFFFFFFFFFFFE7E3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFF81FF7FF03FFFFFFFFFFFFFFFFFFFFC7E3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFF83FEFFE07FFFFFFFFFFFFFFFFFFFFEFE3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFF03FCFFC07FFFFFFFFFFFFFFFFFFFFC7E3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFE03FDFFE0FFFFFFFFFFFFFFFFFFFFFCFE3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFE07F9FFC1FFFFFFFFFFFFFFFFFFFFFC543FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFE0FFBFF81FFFFFFFFFFFFFFFFFFFFFCAA3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFC07F3FF01FFFFFFFFFFFFFFFFFFFFFC7E3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFF81FF7FF03FFFFFFFFFFFFFFFFFFFFFEFE3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFF81FE7FF07FFFFFFFFFFFFFFFFFFFFFC7E3FFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFF83FEFFE07FFFFFFFFFFFFFFFFFFFFFE7E7FFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFF03FCFFC07FFFFFFFFFFFFFFFFFFFFFE7E7FFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFE03F9FFE0FFFFFFFFFFFFFFFFFFFFFFF3EFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFC07F9FFC1FFFFFFFFFFFFFFFFFFFFFFF1DFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFE0FFBFF81FFFFFFFFFFFFFFFFFFFFFFFEBFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFC0FF7FF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFF81FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFF01FFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFF83FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFF07FFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFE07FFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFC07FFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFC0FFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFC1FF7FF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFF83FEFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFF01FC7FE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFF03FEFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFE07FDFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFE07FBFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFC07F1FF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFC0FFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFF81FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFF83FFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFF01FFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFF03FFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFE07FFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFE0FFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFC0FF3FF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFC0FF7FF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFF81FE7FF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFF83FEFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFF03FCFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFE03FDFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFE07F9FFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFE0FFBFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFC0FF3FF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFF80FE7FF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFF01FE7FF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFF83FEFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFF03FDFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFE07F9FFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFC07F1FFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFE0FFBFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFC0FF7FF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFF81FE7FF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFF01FE7FF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFF03FEFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFF03FDFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFE07F9FFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFC07F1FFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFE0FFBFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFC1FF7FF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFF81FEFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFF01FC7FE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFF03FEFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFF07FDFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFE0FFBFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFC07F3FF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFC0FF3FF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFF81FF7FF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFF83FEFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFF01FC7FE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFF03FEFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFE07F9FFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFE0FFBFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFC07F3FF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFF803F3FF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFF801F7FF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFE00EFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFF000FFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFE00FFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFF001FC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFF800F80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFC00701FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFF00383FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFE40003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFEF8007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFDF4007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFBFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFF9FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFBFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFF7FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFE7FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
pop
grestore
%%Trailer
%%EOF
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{202, 187},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003:0000^a000`40O003h00ObWoo003:Ool00:Qo
o`03>LiW>Goo00Moo`03Mke:DWoo00eoo`03Mkeoogoo00Eoo`000Woo00=g_GooOol01goo00=g_Goo
Ool02Goo00=g_GooOol09goo00=NmgooOol01goo00=S67NmOol027oo0VLi9Woo00=W>CW>Mkd01goo
00=g_BU:Mkd02Goo00=:DVLiOol01goo00=S66LiOol01goo00=245:DOol01goo00=Nmc6<JeX02goo
00=g_C6<F]H01Woo0002Ool00eJe>Lioo`07Ool00fLi<HaW>@08Ool00gNm:DYBU008Ool00c6<Mkeo
o`07Ool00e:DHaQoo`08Ool00eJeF]Ioo`08Ool00fLi:DYW>@07Ool00fmk<HaW>@08Ool00gNm>LiB
U007Ool00gNm>LiW>@08Ool00d8@DYAoo`08Ool2DY@7Ool00fLi<Hag_@07Ool00gNm>LiJeP09Ool0
0dYB>Lioo`06Ool00fmk>LiW>@08Ool00ekg>Lioo`07Ool00fmk:DYBU00<Ool00dYBDYAoo`04Ool0
00=oo`03IcTQ26Li00Moo`03Kg/icVLi00Uoo`03DYA247oo00Ioo`03MkdaS5[F00Moo`03MkdicU:D
00Qoo`03Mke:DU:D00Uoo`03MkdicTYB00Qoo`8icPUoo`03BU8icWoo00Ioo`03MkdicU[F00Qoo`03
DYA247Nm00Qoo`03DY@YBWNm00Ioo`03MkdicU:D00Qoo`03BU8e[Fmk00Qoo`03IcTaS6Li00Moo`03
>Li:DWoo00Moo`03IcTQ26Li00Qoo`03DY@aS7Nm00]oo`03DY@aS7Nm00=oo`001Goo00<icU:DOol0
1goo0SW>2Goo00=W>BU:Mkd01goo0TYB27oo00=BU36<Mkd027oo00=NmbU:Mkd02Goo00=BU3W>Ool0
1goo00=W>C6<Kg/027oo00=W>BU:IcT01goo00<icRU:Mkd01goo00=_Nc6<Kg/027oo00=g_CW>F]H0
1goo00=BU3W>Mkd01goo00=[FRU:IcT027oo00=_NcW>IcT01goo00=W>C6<IcT027oo00<icU[FOol0
1goo00=g_C6<F]H02goo00=_Nc6<Kg/00Woo0006Ool00eJe>Lioo`07Ool00fLi>LiW>@08Ool00gNm
:DYBU007Ool00ekg:DYg_@07Ool00fmk<HaJeP08Ool00gNm<Ha:DP09Ool00fLi:DYW>@07Ool00fmk
>LiW>@08Ool00gNm>Li:DP07Ool00gNm>LiJeP07Ool00gNm>LiBU009Ool00dYB@Q1oo`06Ool00fmk
<Ha_N`08Ool00cW>@Q1oo`08Ool00dYB>Lioo`06Ool00fmk>LiW>@08Ool00dic>Lioo`07Ool00gNm
BU9BU00;Ool00gNmOomoo`01Ool000Moo`03IcTQ26Li00Moo`03Kg/icVLi00Uoo`03DY@icWoo00Io
o`03MkdaS5[F00Moo`03Mke245:D00Uoo`03E[DaS7oo00Uoo`03>Li:DWoo00Moo`8icPUoo`03DY@i
cWoo00Moo`03BU8icWoo00Moo`03DY@icWNm00Qoo`03E[DYBWNm00Ioo`03MkdicU:D00Qoo`03G_La
S6Li00Qoo`03IcTaS6Li00Moo`03>Li247oo00Moo`03IcTYBVLi00Qoo`03G_LYBWNm00eoo`002Goo
00=244YBOol01goo00=:DRU:Mkd027oo00=W>C6<Mkd01goo00=BU4YBOol01goo00=BU36<Mkd027oo
00=_NbU:IcT02Goo00=F]CW>Ool01goo00=W>CW>IcT027oo00=W>BU:IcT01goo00=F]BU:Mkd01goo
00=g_C6<Kg/027oo00=g_CW>F]H01goo00=BU3W>Mkd01goo00=_Nc6<IcT027oo00=g_CW>HaP01goo
00=W>C6<IcT027oo00<icV<HOol01goo00=g_C6<F]H037oo000:Ool00ekg>Lioo`07Ool00gNm<HaJ
eP08Ool00gNm:DYBU007Ool00ekg:DYg_@07Ool00gNm<HaJeP09Ool00cW>BU9oo`08Ool016Li:DYW
>E:D1Woo00=g_CW>IcT02Goo00<icTYBOol01Woo00=g_CW>F]H01goo00=g_CW>DY@02Goo00=:DSW>
Ool01Woo00=g_C6<Kg/027oo00<icT8@Ool027oo00=:DSW>Ool01Woo00=_NcW>IcT027oo00=>LcW>
Ool027oo00=BU4YBOol02Woo000;Ool00fLi8@QW>@07Ool00gNmBU9BU009Ool00e:D@Q1g_@06Ool0
0gNm:DYJeP07Ool00gNmBU9BU009Ool00fLi<Haoo`09Ool00cW>:DYoo`07Ool2>Lh9Ool00eJe>Lio
o`07Ool00dYB>Lioo`07Ool00e:D>Lig_@08Ool00eJe:DYg_@06Ool00gNm@Q1BU008Ool00fLi<HaW
>@08Ool00fLi<HaW>@07Ool00d8@>Lioo`07Ool00fLi<HaNm`08Ool00fLi:DYg_@09Ool000eoo`03
@Q1:DWoo00Moo`03G_LYBWNm00Qoo`03Kg/aS7Nm00Moo`03DYA:DWoo00Moo`03DY@aS7Nm00Qoo`03
Kg/aS6Li00Uoo`8icPQoo`03IcTicVLi00Qoo`03IcTYBVLi00Moo`03G_LYBWNm00Moo`03MkdaS6mk
00Qoo`03MkdicU[F00Moo`03DY@aS7Nm00Moo`03Kg/icVLi00Uoo`03>LiS67oo00Ioo`03IcTicVLi
00Qoo`03@Q1:DWoo00Moo`03MkdYBU:D00Qoo`003Woo00=Nmc6<Mkd01goo00=g_C6<F]H027oo00=g
_BU:DY@01goo00=W>BU:Mkd01goo00=g_C6<F]H02Goo00<icT8@Ool01goo00ABU6Li8@QW>@Moo`03
MkdicU[F00Uoo`03>Li247Nm00Ioo`03MkdYBU[F00Moo`03Mke245:D00Uoo`03BU8icWoo00Ioo`03
MkdYBV<H00Qoo`03>Li:DWoo00Qoo`03CW<icWoo00Ioo`03Kg/icVLi00Qoo`03G_LYBWNm00Qoo`03
DYA247Nm00Ioo`002Goo00<icR488@P00b4800<@Q0Q28@P0224800<002488@P0224800<8@R488@P0
1R4800<HaP008@P01b4800<HaP008@P02B4800<@Q1S68@P01R4800@@Q2488@P8@PTQ2003000HaR48
00PQ2003000@Q24800LQ2003000Q224800LQ2003248@Q24800PQ2003248@Q24800LQ20036<HQ2248
00LQ20036<HQ224800PQ20036<HQ224800LQ2003000HaR4800LQ208HaP03F]Ioogoo00Ioo`03Kg/a
S6<H00Eoo`002Goo00=BU48@@Q00748@00@YBP000008@P8@Q0<000036<I2448@01U24003:DY2448@
01Q24008:DX000006<HQ236<8@P@Q08000036<I2448@049240046<HYBTYBDY@8Ool00gNm>LiBU004
Ool002Moo`04<H`001S6E[D3Ool01WNmIcTYBP00>Lig_AUoo`03DYAoogoo01Moo`04>Lh001S6G_L5
Ool016Li:DX005:D@goo0S6<00AooeJe:DYg_@Qoo`03DY@icWoo009oo`009Woo00<aS0Q2BU8027oo
00=BU0Q2:DX06Goo00=BU7ooOol05Woo00=24000BU802Goo00=BU000DY@0@Woo0S6<0Woo00=g_CW>
F]H037oo000UOol00eJe001:DP0:Ool00eJe001F]@0HOol00dYBOomoo`0EOol00g>L000e[@0;Ool0
0d8@001[FP11Ool00bU:=Jeoo`02Ool00gNm=JeNm`0;Ool002Eoo`036<HQ27oo00]oo`03>Lh8@Woo
01Moo`03DYAoogoo01Eoo`03248@Q7Nm00aoo`0348@aS7oo041oo`8aS0Eoo`8icPYoo`0097oo00=W
>@00IcT037oo00=g_@00E[D05goo00=BU7ooOol057oo00=F]@00DY@03Goo00=F]@Q2Ool0@7oo0S6<
1Woo00=W>CW>Kg/027oo000TOol00cW>6<Ioo`0=Ool00bU:<Haoo`0FOol00e:DOomoo`0DOol00cW>
001g_@0=Ool00gNm001BU010Ool2<H`7Ool00fLi<HaW>@07Ool001Yoo`03BU92448@00M240036<HY
BWoo00eoo`03>Lh@Q48@01I24003:DY2448@01A2400348@DYGoo00ioo`0348@YBT8@00I24003F]Io
ogoo03Ioo`03<H`YBWoo00Qoo`03>Li:DWoo00Eoo`006Woo00<@Q0Q248@01a2400<8@RU:Ool03Goo
00<icP0048@01A2400<DYA2448@03Q2400<8@Q2448@0512400<001BUOol03Woo00<Q20Q248@01A24
00<8@S6<Ool0=goo00<aS248>Lh02Goo00=NmcW>Kg/017oo000JOol00a24DYAoo`07Ool00c6<6<Io
o`0=Ool00c6<8@Qoo`0FOol00e:DOomoo`0DOol00c6<5:Eoo`0=Ool00gNm001BU006Ool2<H`hOol2
<H`00fLi8@Q_N`08Ool00fLi:DYW>@03Ool001Yoo`0348ABU7oo00Moo`03DY@8@WNm00eoo`0348A2
47oo01Ioo`03DYAoogoo01Aoo`03BU8005Je00eoo`03IcT006Li00Ioo`8aS3Qoo`8aS09oo`03>LiN
mgoo00Qoo`03F]Ioogoo005oo`006Woo00<@Q5:DOol01goo00=g_@Q2@Q0037oo00=BU000IcT05goo
00=BU7ooOol057oo00=_N`00<H`03Goo00<YBQ24Ool01Woo0S6<>7oo0S6<0goo00=BU3W>Ool02goo
000JOol00a24DYAoo`08Ool00d8@249W>@0:Ool00gNm48@aS00HOol00e:DOomoo`0EOol00dYB001W
>@0;Ool00e:D001JeP07Ool2<H`hOol2<H`4Ool00fLi8@QW>@0:Ool001Yoo`0348ABU7oo00Uoo`03
:DX8@VLi00Qoo`04Kg/HaQS6MkdHOol00e:DOomoo`0FOol00c6<249W>@09Ool00ekg48@YBP08Ool2
<H`hOol2<H`6Ool00cW>E[Eoo`08Ool001Yoo`0348ABU7oo00Yoo`04:DX8@SW>Kg/4Ool01FmkBU88
@QS6Mkd06Goo00=BU7ooOol05goo00<YBPQ2>Lh01Woo00Eg_DYB000HaWNm00Qoo`8aS3Qoo`8aS0Mo
o`03BU9247oo00Moo`006Woo00<@Q5:DOol02goo00M:DPQ2248HaR48:DXQ200200000cW>Mkeoo`0d
Ool02dYB2488@S6<BU9BU48@:DX8@P00DY@02Woo0S6<>7oo0S6<27oo00=W>B48IcT01Woo000JOol0
0a24DYAoo`0=Ool01eJe@Q0aS36<@Q1JeWNm03Qoo`09Mke:DRU:48@8@Q24:DYBU7Nm00]oo`8aS3Qo
o`8aS0Yoo`03>LiF]Goo00Aoo`006Woo00<@Q5:DOol0<7oo00=BU7ooOol0;Goo0S6<>7oo0S6<2goo
00=JeSW>Ool00goo000JOol00a24DYAoo`0`Ool00e:DOomoo`0]Ool2<H`hOol00c6<48AF]@0;Ool0
0fLiG_Moo`02Ool001Yoo`0348ABU7oo061oo`8aS3Qoo`8aS003F]HicVmk00ioo`006Woo00<@Q5:D
Ool0H7oo0S6<>7oo0S6<00AoofLi8@QW>@eoo`006Woo00<@Q5:DOol0<7oo00=BU7ooOol0;Goo0S6<
>7oo0S6<0goo00<icUJeOol02goo000JOol00a24DYAoo`0`Ool00e:DOomoo`0]Ool2<H`hOol2<H`4
Ool00e[F>Li_N`0:Ool001Yoo`0348ABU7oo031oo`03DYAoogoo02eoo`8aS3Qoo`8aS0Eoo`03IcTY
BVLi00Uoo`006Woo00<@Q5:DOol0;goo00=Nmb48G_L00goo00EW>EJeBU8YBU:D02Ioo`8aS3Qoo`8a
S0Moo`03>Li:DWoo00Moo`006Woo00<@Q5:DOol0;goo00HYBT8@8@PYBQS6248300000c6<G_MNm`0U
G_L00bU:8@QNm`04G_L01gNmOomooekgF]I_NcW>00Aoo`03Mke_Nfmk02=_N`04JeY_Nc6<<H`8Ool0
0e[F>Li_N`06Ool001Yoo`0348ABU7oo02moo`0;:DXaS3W>Kg]BU48@<H`8@P006<I_N`0VOol2<H`9
Ool00e:DBU9BU004Ool00fmkG_MNm`0UG_L00b48249W>@08Ool00fLi<HaW>@05Ool001Yoo`0348AB
U7oo031oo`03BU9oogoo00Aoo`04MkeW>DYBMkdUOol2<H`:Ool00b48Mkeoo`0[Ool2<H`00cW>E[Eo
o`08Ool00cW>BU9oo`03Ool001Yoo`0348ABU7oo031oo`03DYAoogoo02eoo`8aS0Uoo`03Kg/icUJe
02aoo`8aS004OomJeSW>Kg/8Ool00e[FMkeoo`02Ool001Yoo`0348ABU7oo031oo`03DYAoogoo02eo
o`8aS0Uoo`04>LiW>FmkDY@[Ool2<H`2Ool00fLi8@QW>@0<Ool001Yoo`0348ABU7oo031oo`03DYAo
ogoo02eoo`8aS3Qoo`8aS0Aoo`03>LiF]Goo00Yoo`006Woo00<@Q5:DOol0<7oo00=BU7ooOol0;Goo
0S6<>7oo0S6<1Goo00=JeSW>Kg/02Goo000JOol00a24DYAoo`0`Ool00e:DOomoo`0]Ool2<H`hOol2
<H`6Ool00fLi8@QW>@08Ool001Yoo`0348ABU7oo031oo`03DYAoogoo02eoo`8aS3Qoo`8aS0Qoo`03
>LiF]Goo00Ioo`006Woo00<@Q5:DOol0<7oo00=BU7ooOol0;Goo0S6<>7oo0S6<2Goo00=JeSW>Kg/0
1Goo000JOol00a24DYAoo`0`Ool00e:DOomoo`0]Ool2<H`hOol2<H`:Ool00fLi:DYW>@04Ool001Yo
o`0348ABU7oo031oo`03DYAoogoo02eoo`8aS3Qoo`03<H`@Q6mk00]oo`03@Q1oogoo009oo`006Woo
00<@Q5:DOol0<7oo00=BU7ooOol0;Goo0S6<>7oo0S6<00<icUkgOol03Woo000JOol00a24DYAoo`0`
Ool00e:DOomoo`0]Ool2<H`hOol2<H`00gooBU8icP0>Ool001Yoo`0348ABU7oo031oo`05DYAoogoo
G_Mg_@0[Ool2<H`hOol2<H`2Ool00fLi:DY_N`0<Ool001Yoo`0348ABU7oo031oo`04DYAoogooBU8/
Ool2<H`hOol2<H`4Ool00cW>G_Moo`0:Ool001Yoo`03249F]Goo039oo`03E[Eg_Goo02]oo`03=JdY
BWoo03Moo`03=JdYBWoo00Aoo`03@Q1:DWoo00Uoo`006Woo00<@Q0Q248@07a2400<DYA2448@04124
00<0012448@04a2400<8@Q2448@05A2400<8@S6<Ool0=goo0S6<1Woo00=:DSW>Ool027oo000JOol0
0ekgDYABU00ODY@00dYBDYABU009DY@00`Q2000Q2002DY@0136<:DYBU2U:0P0000=245:DDY@03e:D
00=F]E:DDY@05U:D00=W>GooOol0=Woo0S6<1goo00=W>C6<Mkd01goo0018Ool01Fmk8@P003W>Ool0
0e:D00<00124G_L0I7oo0S6<27oo00=g_C6<F]H01Woo0019Ool00gNm<H`00002<H`01248000HaWNm
IGoo0S6<2Woo00=:DSW>Mkd017oo001;Ool01S6<00000000>Lig_FIoo`8aS0]oo`03IcTaS7Nm00=o
o`00B7oo00=g_CW>8@P0100000=_NgooOol0IGoo00@aS124>Lig_@Yoo`03Mke247oo009oo`00B7oo
00LicPQ2>LiBU1S6000aS01XOol2<H`00fLi<Hag_@0>Ool004Moo`08Kg/004YBOomJeWNm48A:DVQo
o`8aS004Oomg_CW>DY@=Ool004Moo`08<H`HaWNmMkeJeWoo6<HicVQoo`8aS0=oo`03DY@aS7Nm00]o
o`00AWoo00U_N`00DYAooe:DMkeooa24<H`0J7oo0S6<17oo00=W>C6<Mkd02Woo0016Ool02C6<6<Io
ogNmF]Iooe:D001_N`1XOol2<H`5Ool00gNm>LiBU009Ool004Eoo`05IcT005:DOomBU002Ool00a24
<Haoo`1XOol2<H`7Ool00e:D:DYg_@07Ool004Eoo`098@PHaWooKg]NmgooBU8004YB06Uoo`8aS0Qo
o`03IcTaS7Nm00Ioo`00A7oo00YNm`00G_Mooe:DOomg_A24>LiBU6Uoo`03<H`8@U:D00Qoo`03Mkdi
cU:D00Eoo`00A7oo00XHaR48OomW>EkgOom240Q2MkeBU6Uoo`8aS003DY@icWNm00Qoo`03DY@aS7Nm
00=oo`00@goo00=JeP00IcT00goo00Eg_@Q2@Q1ooe:D06Uoo`8aS004OomW>C6<Mkd8Ool2IcT3Ool0
04=oo`0;6<HYBWooKg]g_Goo>Lh8@WNmOomBU01YOol2<H`2Ool00gNm>LiBU00<Ool0049oo`09F]H0
06mkOomBU7ooMkd8@TYB009oo`03DYAoogoo06Moo`8aS0Aoo`03DY@YBWNm00Yoo`00@Woo00T@Q36<
OomoogNmOolicQ24Mkd00Woo00=BU7ooOol0Igoo0S6<1Goo00=W>C6<Mkd02Goo0011Ool00dYB001_
N`03Ool00fmk001:DP03Ool00e:DOomoo`1WOol2<H`6Ool00gNm>LiBU008Ool0041oo`0:Mkd@Q3W>
OomS67NmOolaS1S6Mkd3Ool00e:DOomoo`1WOol2<H`8Ool00e:D:DYg_@06Ool0041oo`09@Q08@WNm
OomBU7ooKg/005:D00Aoo`03DYAoogoo06Moo`8aS0Uoo`03IcTaS7Nm00Eoo`00?goo00Ug_@Q2@Q1o
oe[FMkeooc6<6<H01Goo00=BU7ooOol0Igoo00<aS1S6Mkd02Goo00=g_CW>DY@017oo000oOol02CW>
249g_GooF]IoofLi001BU005Ool00e:DOomoo`1WOol0136<8@PicU[F2Woo00=BU5kgOol00Woo000n
Ool02GNm249:DWooDYAg_Goo8@PHaP06Ool00e:DOomoo`1WOol2<H`017ooBU8icWNm3Goo000nOol0
2CW>6<Ig_GNmF]IoofLi001Nm`1`Ool2<H`2Ool00fLi<Hag_@0<Ool003eoo`07Kg/005:DOomJeWNm
Ool00R48LGoo0S6<0goo00=g_C6<F]H02goo000mOol02C6<6<Ig_GNmF]Iooekg001Nm`07Ool00e:D
Oomoo`1WOol2<H`5Ool00e:D>Lig_@09Ool003aoo`05G_L005:DOomBU002Ool00aS6:DYoo`07Ool0
0e:DOomoo`1WOol2<H`6Ool00fLi<Hag_@08Ool003aoo`09248HaWooMkeJeWooF]H006mk079oo`8a
S0Moo`03MkdicU:D00Moo`00>goo00E:DP00E[Eooe:D009oo`0348@YBWoo00Qoo`03Mkeoogoo06Mo
o`8aS0Uoo`03DY@icWNm00Eoo`00>Woo00Yg_@Q28@QoofmkG_Mooe[F001_N`Uoo`03DYAoogoo06Mo
o`8aS0Yoo`03IcTaS7Nm00Aoo`00>Woo00E240Q2Mkeooe:D009oo`0348@icWoo00Uoo`03DYAoogoo
06Moo`03<H`HaWNm00Yoo`03MkdicU:D00=oo`00>Goo00A_N`Q2BU9oo`9W>@04Oom:DP00Kg/:Ool0
0e:DOomoo`1WOol0136<8@PaS7Nm2goo00=g_GooOol00Goo000iOol02CW>48AoogooBU9oogNm48@i
cP0;Ool00e:DOomoo`1WOol2<H`00gNm>LiBU00>Ool003Qoo`0:Kg/004YBOomF]FmkOom240Q2Mkd;
Ool00e:DOomoo`1WOol2<H`2Ool00e:D:DYg_@0<Ool003Qoo`05=Jd8@WooMkeF]@02Ool00aBU=Jeo
o`0;Ool00dYBOomoo`1WOol00bU:=Jeoo`02Ool00ekg:DYg_@0;Ool003Moo`0:Mkd8@TYBOomJeWNm
OomBU000Kg/<Ool00e:DOomoo`1WOol2<H`4Ool00fLi:DYW>@0:Ool003Moo`03@Q0@Q7Nm00Aoo`03
48@icWoo00aoo`03DYAoogoo06Moo`8aS0Ioo`03>Li247oo00Qoo`00=Woo00Eg_@00BU9oofLi009o
o`03BU88@Vmk00eoo`03DYAoogoo06Moo`8aS0Moo`03G_LicWNm00Moo`00=Woo00DaS124Mkeg_E[F
009oo`0348@icWoo00eoo`03DYAoogoo06Moo`8aS0Qoo`03IcTYBVLi00Ioo`00=Goo00E_N`00DYAo
ofmk009oo`03=Jd8@Vmk00ioo`03DYAoogoo06Moo`03<H`@Q48@00Uoo`8icPEoo`00=Goo00<YBQ24
Ool00goo00=Nm`00@Q003goo00=BU7ooOol0Igoo0S6<00=BU3W>Ool027oo00=W>CW>Mkd00goo000d
Ool01Fmk001JeWooF]H00Woo00<Q20Q2Mkd03goo00=BU7ooOol0Igoo0S6<00AoofLi<HaW>@Qoo`03
IcUg_Goo009oo`00=7oo00TYBQS6Oomg_EkgOomJeP00E[D047oo00=BU7ooOol0Igoo0S6<0goo00<i
cT8@Ool02goo000cOol01Ekg001NmgooDY@00Woo00<HaRU:Ool047oo00=BU7ooOol0Igoo0S6<17oo
00=BU3W>Ool02Woo000cOol28@P01gooKg]NmgooF]H006Li015oo`03DYAoogoo06Moo`8aS0Eoo`03
IcTaS6Li00Uoo`00<Woo00UJeP00G_Mooe:DOomg_AS6:DX04Woo00=BU7ooOol0Igoo0S6<1goo00<i
cT8@Ool01goo000bOol02AS6:DYooekgKg]ooe:D001_N`0BOol00e:DOomoo`1WOol2<H`8Ool00e[F
>Lig_@06Ool0035oo`09F]H006mkOomBU7ooMkdHaSW>01=oo`03DYAoogoo06Moo`8aS0Uoo`03IcTY
BVLi00Eoo`00<7oo00Yg_AS6<Haooe[FKg]oodYB249_Na=oo`03DYAoogoo06Moo`8aS0]oo`8icPAo
o`00<7oo00UBU000Kg]ooe:DOomg_A24>Lh0OWoo00<aS0Q2G_L02goo00=NmfmkOol00Woo000_Ool0
2WNm6<HicWooHaQg_GooBU88@WNmOWoo0S6<00=:DT8@Ool03Woo000_Ool02DYB249g_GNmDYAoogNm
2492400EOol00e:DOomoo`1WOol2<H`017ooIcTaS6mk3Goo000^Ool02WNm248icWooF]Ig_Goo@Q08
@WNm5Goo00=BU7ooOol0Igoo0S6<0goo00<aS5JeOol02goo000^Ool02D8@249g_GNmG_MoogNm001:
DP20Ool2<H`4Ool00dYB@Q1oo`0:Ool002eoo`0:Mkd004YBOomJeWNmOolaS124Mkf0Ool2<H`5Ool0
0fLi:DY_N`09Ool002eoo`09<H`@Q7NmMkeBU7ooMkd004YB01Moo`03DYAoogoo06Moo`8aS0Moo`03
<HaF]Goo00Moo`00;7oo00Yg_@00BU9ooe:DMkeooc6<48Ag_AMoo`03DYAoogoo06Moo`8aS0Qoo`03
BU8icWoo00Ioo`00;7oo00TaS124Mkeg_F<HOom_N`00DY@067oo00=BU7ooOol0Igoo0S6<2Goo00=W
>B48Kg/01Goo000[Ool01Fmk001JeWooHaP00Woo00<YBQ24Ool067oo00=BU7ooOol0Igoo0S6<2goo
00<icUJeOol00goo000[Ool00bU:6<Ioo`03Ool00fmk001JeP0IOol00e:DOomoo`1WOol00c6<249W
>@0;Ool00dYB>Lioo`02Ool002Yoo`05Kg/005[FOomW>@02Ool00bU:6<Ioo`0IOol00e:DOomoo`0]
Ool00gNmDYA_N`0gOol2<H`00cW>BU9oo`0:Ool00gNmOomoo`01Ool002Yoo`0>:DXHaWNm:DXicWoo
G_L0048@E[DaS248BU9g_AEoo`03DYAoogoo02Yoo`05Kg]oogNmKg]BU00hOol2<H`00gooDY@icP0>
Ool002Uoo`08G_L005kg>Li_NcW>6<H@Q0@000036<INmekg01ENm`03>LiNmekg02ENm`03Kg]oogoo
009oo`07IcU_Nd8@OomF]EkgMkd00Woo00=W>EkgG_L0<Ekg00LYBS6<OomoofLi<HaW>@0<Ool002Uo
o`048@PYBWooIcT2<H`01E:D0012448@8@P00PQ200=F]GooOol057oo00=BU7ooOol0:goo00E_Ne:D
OomoogNm03Moo`8aS0Aoo`03>Li247oo00Yoo`00:7oo00EJeP00G_Mooe:D009oo`038@PYBWoo00=o
o`03MkeF]Ekg01Eoo`03DYAoogoo02]oo`03CW=BU5[F03Uoo`8aS0Eoo`03DY@icWoo00Uoo`009goo
00Yg_AS6:DYooekgKg]ooe[F001Nmaaoo`03DYAoogoo06Moo`8aS0Ioo`03IcTaS6Li00Qoo`009goo
00UBU000Kg]ooe:DOomg_AS6:DX07Goo00=BU7ooOol0Igoo0S6<27oo00<icT8@Ool01Woo000VOol0
2WNm6<HaS7ooF]I_NgooDY@006mk7Goo00=BU7ooOol0Igoo00<aS248Ool027oo00=JeSW>Mkd01Goo
000VOol02DYB001_NgNmDYAoogNm6<HaS00NOol00e:DOomoo`1WOol0136<8@PaS6Li27oo00=W>BU:
IcT017oo000UOol02WNm48@icWooHaQg_GooBU8006mk7Woo00=BU7ooOol0Igoo0S6<00=oocW>BU80
2Goo00<icU:DOol00Woo000UOol02DYB249g_GNmF]IoogNm6<HicP0OOol00e:DOomoo`1WOol2<H`2
Ool00dYB>Lioo`0<Ool002Eoo`09249247ooJeYg_GooE[D8@WNm01moo`03E[Eoogoo06Moo`9:DP=o
o`03G_LYBWNm00]oo`0097oo00EBU0Q2IcUooe:D009oo`0348@YBWoo01moo`03DYAoogoo06eoo`03
Kg/aS6<H00Yoo`0097oo00T8@S6<OomNmfmkOomBU0Q2IcT087oo00=BU7ooOol0KWoo00=g_C6<DY@0
2Goo000SOol01D8@249_NgooDY@00Woo00<@Q36<Ool087oo00=BU7ooOol0L7oo00=BU48@Mkd01goo
000SOol02@Q2@Q1ooe[FMkeooe:D249_N`0QOol00gNmOomoo`1aOol00fmk<HaS6006Ool0029oo`05
@Q08@WNmOom:DP02Ool00`Q2>Lioo`2FOol00gNm<HaBU005Ool0025oo`05Mkd8@T8@Oom:DP02Ool0
0d8@249_N`0ROol00e[FOomoo`1dOol00e:D@Q1g_@03Ool0025oo`05>Lh8@WooOomJeP02Ool00`Q2
@Q1oo`0ROol00e:DOomoo`1eOol00fmkIcUoo`02Ool0021oo`05Kg/8@TYBOomBU002Ool00d8@249g
_@0SOol00gNmOomoo`1jOol0021oo`09<H`8@WooMkeJeWooMkd8@T8@0:5oo`007goo00E_N`00DYAo
oeJe009oo`03>Lh8@Woo02Aoo`03F]Ioogoo07Yoo`007goo00TaS1S6OomoogNmOomg_@Q2BU809Goo
00=BU7ooOol0NWoo000NOol02FLi001BU7ooIcUg_D8@8@P8@P0VOol00e:DOomoo`1jOol001ioo`0:
:DXHaWooKg]NmgooIcT001S6F]HUOol00e:DOomoo`1jOol001eoo`05G_L005kgOomW>@02Ool01c6<
48@HaP006<IJeWNm029oo`03DYAoogoo07Yoo`007Goo0R4817oo00EW>@00DYAg_AS60080000348A2
47Nm021oo`03DYAoogoo07Yoo`0077oo00EF]@Q2G_Mooe[F009oo`08:DXHaWooOomg_AS6249:DP9g
_B1oo`03DYAoogoo07Yoo`0077oo00<HaRU:Ool00VLi00AoofLi001Nm`=oo`05MkdHaVmkE[ENm`0P
Ool00e:DOomoo`1jOol001]oo`05E[D8@VLiOomBU002Ool00bU:8@Qoo`04Ool01WNmF]IoogNm@Q1J
eQioo`03HaQoogoo07Yoo`006goo00T@Q36<OomNmfmkOomNm`00G_L01Woo00Mg_GooOomoofLiE[Eg
_@0LOol00f<HOomoo`1jOol001Yoo`05DY@8@VLiOomBU002Ool00b48:DYoo`0<Ool00ekgE[Eg_@0J
Ool00f<HOomoo`1jOol001Yoo`09248aS7ooG_M_NgooE[D8@VLi00moo`03G_MF]GNm01Qoo`03HaQo
ogoo07Yoo`006Goo00E240Q2Kg]ooe:D009oo`036<HYBWoo015oo`03IcUBU5[F01Ioo`03HaQoogoo
07Yoo`006Goo00@8@T8@OomJeP9oo`03E[D8@VLi01Aoo`04MkeBU5:DMkdCOol00f<HOomoo`1jOol0
01Qoo`05@Q08@WNmOom:DP02Ool00a24<Haoo`0FOol01GNmIcUF]EkgMkd047oo00=S67ooOol0NWoo
000GOol01GNm249247ooBU800Woo00=BU0Q2IcT06Woo00Eg_F]JE[EF]Ekg00eoo`03HaQoogoo07Yo
o`005goo00DicPQ2Oomg_E[F009oo`03248aS7oo01ioo`06Kg]F]EJeDYAF]FLi27oo00=S67ooOol0
NWoo000FOol01Fmk249BU7ooBU800Woo00=240Q2Kg/097oo00=W>EJeG_L00U:D00ENmeJeDYANme:D
07aoo`005Woo00DaS124Oomg_E[F009oo`03249247oo01=oo`03MkeW>Goo01Moo`03HaQoogoo07Yo
o`005Goo00EW>@00DYAooe:D009oo`03@Q08@WNm01Aoo`03>Lig_DYB01Moo`03IcUoogoo07Yoo`00
5Goo00TYBQS6Oom_NfLiOomg_@Q2@Q0057oo00AW>E:DOolQ29Aoo`0057oo00ENm`00F]Iooe:D009o
o`03>Lh8@Woo01Aoo`04IcU245kg8@RDOol001=oo`0:MkdDYAS6OomW>EkgOomg_@Q2BU8EOol017Nm
@Q1ood8@5goo00=S67ooOol0NWoo000COol01D8@001NmgooG_L00Woo00<icPQ2Ool05Woo0VLi67oo
00=W>GooOol0NWoo000BOol00gNm248e[@04Ool00fmk249BU02^Ool0019oo`05>LhHaWNmOom_N`02
Ool00c6<48Aoo`2^Ool0015oo`04Kg/004YBOol2IcT017ooIcT005:D<Woo00=S67ooOol0NWoo000A
Ool01C6<6<Ig_GooIcT00Woo00<YBQS6Ool0<Woo00=S67ooOol0NWoo000@Ool00gNm00124004Ool0
0gNm001:DP0cOol00ekgOomoo`1jOol0011oo`05@Q08@WooMkeF]@02Ool00cW>48Ag_@0cOol00f<H
Oomoo`1jOol000moo`05Kg/8@TYBOomBU002Ool00fmk001:DP0dOol00f<HOomoo`1jOol000moo`05
<H`8@WooKg]JeP02Ool00c6<48Aoo`0dOol00f<HOomoo`1jOol000ioo`05IcT8@U:DOom:DP02Ool0
0fLi001BU00eOol00f<HOomoo`1jOol000ioo`05<H`@Q7ooKg]Nm`02Ool00bU:6<Ioo`0eOol00f<H
Oomoo`1jOol000eoo`05IcT005:DOom:DP02Ool00ekg001JeP0fOol00f<HOomoo`1jOol000eoo`03
<H`HaWoo009W>@04Oomg_@Q28@PgOol00f<HOomoo`1jOol000aoo`05IcT005kgOomF]@02Ool00d8@
001Nm`0gOol00f<HOomoo`1jOol000aoo`8Q2007OomW>EkgOom_N`Q2:DX0>7oo00=S67ooOol0NWoo
000;Ool01Ekg001NmgooCW<00Woo00<icPQ2Ool0>7oo00=g_GooOol0NWoo000;Ool02DYB000HaUJe
IcUoofmk249:DP2fOol000aoo`07MkdHaP00:DYg_C6<2480]goo000=Ool01VLiBU8@Q124249BU;Mo
o`003Goo00EF]GooMkdicQ240;Qoo`0037oo00=JeVmkOol00Woo00=g_GooOol0]Woo000<Ool00e:D
Oomoo`2kOol00<Yoo`00bWoo0000\
\>"],
  CellTags->"2"],

Cell[TextData[{
  StyleBox["Figure 2.1. ",
    FontWeight->"Bold"],
  "Inverted pendulum."
}], "Caption",
  CellTags->"2"],

Cell[TextData[{
  "Let us obtain a mathematical model for the system. Assume that the length \
of the pendulum is ",
  Cell[BoxData[
      \(TraditionalForm\`L\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ", and its mass and the moment of inertia  about its center of gravity are \
",
  Cell[BoxData[
      \(TraditionalForm\`m\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`J\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ", respectively. The mass of the cart is ",
  Cell[BoxData[
      \(TraditionalForm\`M\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ". Then, summing the forces applied to the pendulum in horizontal and \
vertical directions (Figure\[NonBreakingSpace]2.2a), we have "
}], "Text",
  CellTags->"2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(F\_x = m \( x\&\[DoubleDot]\_c\)\&\),
              "InlineFormula"]},
          {
            
            StyleBox[
              \(F\_y - m  g = m \( y\&\[DoubleDot]\_c\)\&\(\(\ \) \)\),
              "InlineFormula"]}
          },
        ColumnAlignments->{Right}], TraditionalForm]], "DisplayFormula",
  CellTags->"2"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`F\_x\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_y\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " are the components of the reaction force at the support point, and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_c = X + L/2  sin  \[Theta]\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\_c = L/2  cos  \[Theta]\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " are the horizontal and vertical displacements of the center of gravity of \
the pendulum; ",
  Cell[BoxData[
      \(TraditionalForm\`x\_c\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " depends on the horizontal displacement ",
  Cell[BoxData[
      \(TraditionalForm\`X\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " of the cart. Summing all the moments around the center of gravity of the \
pendulum gives the dynamical equation   \n"
}], "Text",
  CellTags->"2"],

Cell[BoxData[
    \(TraditionalForm
    \`\(\(\(F\_y\) L\)\/2\) sin  \[Theta] - 
        \(\(\(F\_x\) L\)\/2\) cos  \[Theta] = 
      J \( \[Theta]\&\[DoubleDot]\)\&\)], "DisplayFormula",
  CellTags->"2"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`J = m\ L\^2/12\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ", which corresponds to the case of uniform mass distribution along the \
pendulum.  "
}], "Text",
  CellTags->"2"],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 47 4 363 171
%%HiResBoundingBox: 47 4 363 171
%%Creator: (Mathematica Macintosh 3.0)
%%Title: Clipboard
%%CreationDate: (Friday, January 31, 1997) (10:51:03 AM)
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 175 translate 1 -1 scale
gsave
47 171 translate
316 -167 scale
1 string
1255 663 1 [1255 0 0 663 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } image
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE7FFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFF
BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFF
CFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF9FFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBEF
EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFBFFBFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7E043
E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF3FC47F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7E38F
E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF3F9F3F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7C7C7
F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE7F1F1FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFE7CF
F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE7F9F9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7E7C7
F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFC7F1F9FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFBCF
F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE7F9F8FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FC47
F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFC7F1F8FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFF8F
F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE7F9F8FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7F7C7
F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFC7F1F1FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFE3CF
F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE7F9F9FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7F3CF
F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE7F0F1FCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FB8F
E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE3F823F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FC5F
E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF7F147F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFF
EFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFBF9FFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFF
CFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF9F1FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFF
DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFDF9FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFF
9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC71FFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFF
BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFDFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFBFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC71FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB2FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBFFFEFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFC7FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFEBFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFC47FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFF8E7FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FBFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FBFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC51FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC23FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7DFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3DFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF151FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAAAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF47FFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA3FFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD007FFFFFFFF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA003FFFFFFFFF
FFFFFFFFFFFFFFFFFFFE8BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD00007FFFFFFFFF
FFFFFFFFFFFFFFFFFFFC017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA000000000000000
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD00000000000000000
00000000000000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE800000000000000000
00000000000000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF40000000000000000000
00000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE80000000000000000000
00000000000000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4000000000000000000
00000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA0000000000000000
00000000000000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4000000000000000
00000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA0003FFFFFFFFF
FFFFFFFFFFFFFFF80020003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD0007FFFFFFFF
FFFFFFFFFFFFFFF005F0007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE83FFFFFFFF
FFFFFFFFFFFFFFE03FF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD47FFFFFFF
FFFFFFFFFFFFFFE07FFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE0FFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFC0FFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF80FFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF01FFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF03FFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF03FFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE07FFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFC07FFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFC0FFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF81FFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF81FFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF01FFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF03FFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBF9E3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE07FFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCDFFC5FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFE0FFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFECFFEFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFC07FFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7F4FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF80FFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFF8FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF01FFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FDFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF83FFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FCFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF03FFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FC7FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFF801FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FBBFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFC07FFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F19FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFC0FFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFC1FFFFFE001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF83FFFFFE001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF01FFFFFC001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE03FFFFFC001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE07FFFFF0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0FFFFFF8201FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC0FFFFFF0201FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF80FFFFFE0201FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF01FFFFFC0601FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7D
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF83FFFFFE0E01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF03FFFFFC0E01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFC
7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF77FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFE07FFFFF81E01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA7FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFC07FFFFF01E01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD5FF55670
7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF37FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFE0FFFFFF03E01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3EFE3FA3
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF81FFFFFF07E01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3E7E3F07
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF81FFFFFE0FE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBE3E3F9F
FFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF01FFFFFC07E01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBE1F1FDF
FFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFFFFC0FE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBE3F3FEB
FFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE07FFFFF81FE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDC4F1F9C
7FFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE0FFFFFF83FE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDE6F9FBE
7FFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFC07FFFFF03FE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDC770F1E
7FFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF80FFFFFE03FE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7B8F9E
3FFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFA3FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF81FFFFFC07FE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDC7D8F9F
3FFFC7FFFFFFFFFFFFFFFFFFFFFFFFFD01FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF83FFFFFE0FFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFECFECFCE
3FFF83FFFFFFFFFFFFFFFFFFFFFFFFE803FFFFFFFFFFFFFFFFBFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF03FFFFFC0FFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE47C47F4
7FFFC3FFFFFFFFFFFFFFFFFFFFFFF40007FFFFFFFFFFFFFFFC07FFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFE07FFFFF81FFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAFFFFFFFFFFFFFFFFFE8FF67FF
FFFF83FFFFFFFFFFFFFFFFFFFFFE80002AAAAAAAAAAAAAAAA003FFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC07FFFFF01FFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFF0FF07FF
FFFF81FFFFFFFFFFFFFFFFFFFF40000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC0FFFFFF83FFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE001FFFFFFFFFFFFFFFFF0FFA3FF
FFFF83FFFFFFFFFFFFFFFFFFE800000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC1FFFFFF07FFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFFFFFFFFFFFFFFF0FFC3FF
FFFF01FFFFFFFFFFFFFFFFF400000000000000000000000000007FFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF83FFFFFE07FFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFFFFFFFFFFFFFFF8FFE3FF
FFFF83FFFFFFFFFFFFFFFFA000000000000000000000000000002FFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF01FFFFFC07FFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00001FFFFFFFFFFFFFFFD1FFE1FF
FFFF01FFFFFFFFFFFFFFFFD0000000000000000000000000000001FFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF03FFFFFC0FFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0000003FFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFA000000000000000000000000000003FFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE07FFFFF81FFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000007FFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFD000000000000000000000000000007FFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE0FFFFFF83FFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFA000000000FFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFA80000AAAAAAAAAAAA00000000003FFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC0FFFFFF01FFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000001FFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFD40007FFFFFFFFFFC001400040007FFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF80FFFFFE03FFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC000C000A000FFFFFFFFFFFFFFFFFFFF
FFFE00FFFFFFFFFFFFFFFFFFFFFFFFE803FFFFFFFFFF800FE000FA003FFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF01FFFFFE07FFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0007C00074007FFFFFFFFFFFFFFFFFFF
FFFE007FFFFFFFFFFFFFFFFFFFFFFFFF407FFFFFFFFC007FF001FF001FFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF83FFFFFE0FFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFE003FE001FF003FFFFFFFFFFFFFFFFFFF
FFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFFFFFF803FFF007FFE00FFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF03FFFFFC0FFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFF001FFC00FFFFFFFFFFFFFFFFFFF
FFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFF007FFF003FF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFE07FFFFF80FFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF803FFF00FFFF807FFFFFFFFFFFFFFFFFF
FFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFF00FFFFE01FF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFC07FFFFF01FFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE007FFF00FFFFC01FFFFFFFFFFFFFFFFFF
FFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFF007FFFF007F
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFE0FFFFFF03FFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFF00FFFFE01FFFFFFFFFFFFFFFFFF
FFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFF00FFFFF807F
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFC1FFFFFF03FFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF807FFFF00FFFFF007FFFFFFFFFFFFFFFFF
FFFC003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFF007FFFFC03F
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF81FFFFFE07FFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFF00FFFFFC07FFFFFFFFFFFFFFFFF
FFFC003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFF00FFFFFE03F
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD7FFFFFFFFDFFFFFFFFFFFFFFFF
FFFFF01FFFFFC07FFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFF00FFFFFC01FFFFFFFFFFFFFFFFF
FFFC001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFF007FFFFF00F
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBAFFFFFFFFDFFFFFFFFFFFFFFFF
FFFFF03FFFFFC0FFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFF00FFFFFF03FFFFFFFFFFFFFFFFF
FFF8003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFF00FFFFFF80F
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7C7FFFFFFFDFFFFFFFFFFFFFFFF
FFFFE07FFFFF81FFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFF00FFFFFF01FFFFFFFFFFFFFFFFF
FFF8001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFF007FFFFFC07
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFE7FFFFFFF8FFFFFFFFFFFFFFFF
FFFFE0FFFFFF81FFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFF00FFFFFFC0FFFFFFFFFFFFFFFFF
FFF8001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFF00FFFFFFE03
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7E7FFFFFFF8FFFFFFFFFFFFFFFF
FFFFC07FFFFF01FFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFF00FFFFFFC07FFFFFFFFFFFFFFFF
FFF0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFF007FFFFFF01
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFF8FFFFFFFFFFFFFFFF
FFFF80FFFFFF03FFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFF00FFFFFFE03FFFFFFFFFFFFFFFF
FFF8001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFF00FFFFFFF83
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFF7CF9F907FFFFFFF0FFFFFFFFFFFFFFFF
FFFF81FFFFFE07FFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFF00FFFFFFF01FFFFFFFFFFFFFFFF
FFF0001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFF007FFFFFF81
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFE3EF9FC0FFFFFFFF8FFFFFFFFFFFFFFFF
FFFF83FFFFFE0FFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFF00FFFFFFF83FFFFFFFFFFFFFFFF
FFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFF00FFFFFFFC0
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFF3C797C7FFFFFFFF07FFFFFFFFFFFFFFF
FFFF03FFFFFC07FFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFF00FFFFFFF01FFFFFFFFFFFFFFFF
FFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFF007FFFFFFC0
7FFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFF3E79FEFFFFFFFFF0FFFFFFFFFFFFFFFF
FFFE03FFFFF80FFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFF00FFFFFFF81FFFFFFFFFFFFFFFF
FFF3008FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFF00FFFFFFFE0
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFF1E7DFF5FFFFFFFF07FFFFFFFFFFFFFFF
FFFC07FFFFF81FFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFF00FFFFFFFC0FFFFFFFFFFFFFFFF
FFF100C7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFF007FFFFFFF0
7FFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFF9E3CFEEFFFFFFFF07FFFFFFFFFFFFFFF
FFFC0FFFFFF83FFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFF00FFFFFFFE0FFFFFFFFFFFFFFFF
FFE300EFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFF00FFFFFFFF0
7FFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFF1F3C7CF3FFFFFFF07FFFFFFFFFFFFFFF
FFFC0FFFFFF03FFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFF00FFFFFFFE07FFFFFFFFFFFFFFF
FFE700E7FFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFF007FFFFFFF0
3FFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFF8F3EF8F3FFFFFFE03FFFFFFFFFFFFFFF
FFF83FFFFFE07FFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFF00FFFFFFFE07FFFFFFFFFFFFFFF
FFEF00F7FFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFF00FFFFFFFF8
3FFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFD71C7CF1FFFFFFE03FFFFFFFFFFFFFFF
FFF01FFFFFC07FFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFF00FFFFFFFF07FFFFFFFFFFFFFFF
FFCF00F7FFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFF007FFFFFFF8
1FFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFCBAE7CFBFFFFFFE03FFFFFFFFFFFFFFF
FFF03FFFFFC0FFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFF00FFFFFFFF07FFFFFFFFFFFFFFF
FFEF00FBFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFF00FFFFFFFF8
3FFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC5167C71FFFFFFC01FFFFFFFFFFFFFFF
FFE07FFFFFC1FFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFF00FFFFFFFF07FFFFFFFFFFFFFFF
FFDF00FFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFF007FFFFFFFC
1FFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFF8E3A7F33FFFFFFE03FFFFFFFFFFFFFFF
FFE0FFFFFF83FFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFF00FFFFFFFF83FFFFFFFFFFFFFFF
FFFF00FFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFF00FFFFFFFF8
3FFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFD77D7FD7FFFFFFC01FFFFFFFFFFFFFFF
FFC0FFFFFF01FFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFF00FFFFFFFF03FFFFFFFFFFFFFFF
FFFF00FFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFF007FFFFFFFC
1FFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFF
FF80FFFFFF03FFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFEAAAAAAAAAAAA07FFFFFFF00FFFFFFFF82AAAAAAAAAAAAAAA
AAAA00AAAAAA0AAAAAAAAAAAAAAAAAAAAAAAAAAA0FFFFFFFF00FFFFFFFFC
0AAAAAAAAABFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFF
FF01FFFFFE07FFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE00000000000007FFFFFFF00FFFFFFFF00000000000000000
00000000000000000000000000000000000000000FFFFFFFF007FFFFFFFC
00000000003FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFF
FF83FFFFFE0FFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE00000000000007FFFFFFF00FFFFFFFF80000000000000000
00000000000000000000000000000000000000000FFFFFFFF00FFFFFFFFC
00000000003FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFF
FF03FFFFFC0FFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE00000000000007FFFFFFF00FFFFFFFF00000000000000000
00000000000000000000000000000000000000000FFFFFFFF007FFFFFFFC
00000000003FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFF
FE07FFFFF80FFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE00000000000007FFFFFFF00FFFFFFFF80000000000000000
00000000000000000000000000000000000000000FFFFFFFF00FFFFFFFFC
00000000003FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8007FFFFFFFFFFFFFF
FC07FFFFF01FFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE05555555555407FFFFFFF00FFFFFFFF01555555555555555
55550055555405555555555555555555555555540FFFFFFFF007FFFFFFFC
05555555503FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFF
FE0FFFFFF83FFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFF07FFFFFFF00FFFFFFFF83FFFFFFFFFFFFFFF
FFFF00FFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFF00FFFFFFFFC
1FFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8007FFFFFFFFFFFFFF
FC1FFFFFF03FFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFF07FFFFFFF00FFFFFFFF03FFFFFFFFFFFFFFF
FFFF00FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFF007FFFFFFFC
1FFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFF
F81FFFFFE07FFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFF07FFFFFFF00FFFFFFFF83FFFFFFFFFFFFFFF
FFFF00FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFF00FFFFFFFF8
3FFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFFFFF
F01FFFFFC07FFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFF07FFFFFFF00FFFFFFFF07FFFFFFFFFFFFFFF
FFFF00FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFF007FFFFFFF8
1FFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8007FFFFFFFFFFFFFF
F03FFFFFE0FFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFF83FFFFFFF00FFFFFFFF07FFFFFFFFFFFFFFF
FFFF00FFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFF00FFFFFFFF8
3FFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFFFFF
E07FFFFFC1FFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFF01FFFFFFF00FFFFFFFF07FFFFFFFFFFFFFFF
FFFF00FFFFFC03FFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFF007FFFFFFF0
1FFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FFFFFFFFFFFFFF
E0FFFFFF81FFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFF83FFFFFFF00FFFFFFFE0FFFFFFFFFFFFFFFF
FFFF00FFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFF00FFFFFFFF8
3FFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FFFFFFFFFFFFFF
C07FFFFF01FFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFC1FFFFFFF00FFFFFFFC07FFFFFFFFFFFFFFF
FFFF00FFFFF801FFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFF007FFFFFFF0
7FFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0003FFFFFFFFFFFFFF
80FFFFFF03FFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFF81FFFFFFF00FFFFFFFE0FFFFFFFFFFFFFFFF
FFFF00FFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFF00FFFFFFFF0
7FFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0001FFFFFFFFFFFFFF
81FFFFFE07FFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFC1FFFFFFF00FFFFFFFC1FFFFFFFFFFFFFFFF
FFFF00FFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFF007FFFFFFE0
7FFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0003FFFFFFFFFFFFFF
83FFFFFE0FFFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFE0FFFFFFF00FFFFFFF81FFFFFFFFFFFFFFFF
FFFF00FFFFF801FFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFF00FFFFFFFE0
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0001FFFFFFFFFFFFFF
03FFFFFC07FFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFC07FFFFFF00FFFFFFF01FFFFFFFFFFFFFFFF
FFFF00FFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFF007FFFFFFC0
7FFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0023FFFFFFFFFFFFFE
03FFFFF80FFFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFE03FFFFFF00FFFFFFF03FFFFFFFFFFFFFFFF
FFFF00FFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFF00FFFFFFF80
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC4031FFFFFFFFFFFFFC
07FFFFF81FFFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFF01FFFFFF00FFFFFFF03FFFFFFFFFFFFFFFF
FFFF00FFFFF001FFFFFFFFF7FFFFFFFFFFFFFFFFC07FFFFFF007FFFFFF81
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEC038FFFFFFFFFFFFFC
0FFFFFF83FFFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFF83FFFFFF00FFFFFFE07FFFFFFFFFFFFFFFF
FFFF00FFFFE000FFFFFFFFF3FFFFFFFFFFFFFFFFE03FFFFFF00FFFFFFF83
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC403CFFFFFFFFFFFFFC
0FFFFFF03FFFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFF80FFFFFF00FFFFFFC07FFFFFFFFFFFFFFFF
FFFF00FFFFE0007FFFFFFFF6FFFFFFFFFFFFFFFFF01FFFFFF007FFFFFF03
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCC03EFFFFFFFFFFFFF8
1FFFFFE03FFFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFC0FFFFFF00FFFFFF80FFFFFFFFFFFFFFFFF
FFFF00FFFFE000FFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFF00FFFFFFE07
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDC03EFFFFFFFFFFFFF0
1FFFFFC07FFFFFFFFFFE01FFFFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFC07FFFFF00FDFFFF01FFFFFFFFFFFFFFFFF
FFFF00FFFFE0007FFFFFFFFF7FFFFFFFFFFFFFFFF80FFFFFF007DFFFFC07
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBC03EFFFFFFFFFFFFF0
3FFFFFE0FFFFFFFFFFFE01FFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFE03FFFFF00FFFFFE03FFFFFFFFFFFFFFFFF
FFFF00FFFFE000FFFFFFFFFFBFFFFFFFFFFFFFFFFC0FFFFEF00FBFFFF80F
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBC03F7FFFFFFFFFFFE0
7FFFFFC0FFFFFFFFFFFE01FFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFF01FFFDF00FBFFFC07FFFFFFFFFFFFFFFFF
FFFF00FFFFC0007FFFFFFFFF1FFFFFFFFFFFFFFFFC03FFFE70073FFFF01F
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBC03FFFFFFFFFFFFFE0
7FFFFF81FFFFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFF80FFFEF00FBFFF80FFFFFFFFFFFFFFFFFF
FFFF00FFFFE0007FFFFFFFFFBFFFFFFFFFFFFFFFFE03FFFEF00F3FFFE03F
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFFFC0
7FFFFF01FFFFFFFFFFFE01FFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFC01FFEF00F7FFF00FFFFFFFFFFFFFFFFFF
FFFF00FFFFC0007FFFFFFFFF1FFFFFFFFFFFFFFFFF007FFF70077FFFC07F
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFFF80
FFFFFF03FFFFFFFFFFFE01FFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFE00FFEF00E7FFE03FFFFFFFFFFFFFFFFFF
FFFF00FFFFC0003FFFFFFFFFBFFFFFFFFFFFFFFFFF803FFF300E7FFF80FF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFFF01
FFFFFE07FFFFFFFFFFFE01FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFF007FF700E7FF003FFFFFFFFFFFFFFFFFF
FFFF00FFFFC0043FFFFFFFFF37FFFFFFFFFFFFFFFFC01FFF10047FFC01FF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFFF83
FFFFFE07FFFFFFFFFFFE01FFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFF803FF300E7FE00FFFFFFFFFFFFFFFFFFF
FFFF00FFFF80063FFFFABFFF3FFFFFFFFFFFFFFFFFE00FFF80087FF803FF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFFF03
FFFFFC07FFFFFFFFFFFE01FFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFC007F100C7F001FFFFFFFFFFFFFFFFFFF
FFFF00FFFFC0071FFFF87FFF7FFFFFFFFFFFFFFFFFF001FF00007FD007FF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFFE03
FFFFFC0FFFFFFFFFFFFE01FFFFFFFFFFFF9BFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFF002F8008FE003FFFFFFFFFFFFFFFFFFF
FFFF00FFFF8807BFFFF8FFFE7BFFFFFFFFFFFFFFFFFE00FF8000FF800FFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFFC07
FFFFF81FFFFFFFFFFFFE01FFFFFFF55FFF9DFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFF0001000040007FFFFFFFFFFFFFFFFFFF
FFFF00FFFF98071FFFFC7FFC71FFFFFFFFFFFFFFFFFE001F80007C001FFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFFE0F
FFFFF83FFFFFFFFFFFFE01FFFFFFFE3FFFBFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFE00000000003FFFFFFFFFFFFFFFFFFFF
FFFF00FFFFB807BFFFFE7FFAF3FFFFFFFFFFFFFFFFFF80038000E0007FFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFFC0F
FFFFF01FFFFFFFFFFFFE01FFFFFFFC3FFF1DFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFF00000000007FFFFFFFFFFFFFFFFFFFF
FFFF00FFFF3807DFFFFC7FFFFFFFFFFFFFFFFFFFFFFFC00000000001FFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFF81F
FFFFE03FFFFFFFFFFFFE01FFFFFFFE3FFFBCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFE000000003FFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFB807EFFFFE3FFFFFFFFFFFFFFFFFFFFFFFF8000000000FFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFF01F
FFFFE07FFFFFFFFFFFFE01FFFFFFFE3FFC79FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFF400000007FFFFFFFFFFFFFFFFFFFFF
FFFF00FFFF7807FFFFFE3DFFFFFFFFFFFFFFFFFFFFFFFC000000001FFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFF03F
FFFFE0FFFFFFFFFFFFFE01FFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFA00000FFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFE3EFFFFFFFFFFFFFFFFFFFFFFFFA0000000FFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFF07F
FFFFC0FFFFFFFFFFFFFE01FFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFF40015FFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFF14FFFFFFFFFFFFFFFFFFFFFFFFF0000005FFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFE0FF
FFFF81FFFFFFFFFFFFFE01FFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFF08FFFFFFFFFFFFFFFFFFFFFFFFFFA000BFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFFC07F
FFFF01FFFFFFFFFFFF7E01E7FFFFFF1F7FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFF1E7FFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFF80FF
FFFF03FFFFFFFFFFFFBE01EFFFFFFF8F3FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFF9F7FFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFF81FF
FFFF07FFFFFFFFFFFF9E01DFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFF1F7FFFFFFFFFFFFFFFFFFFFFFFFFE001FFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFF83FF
FFFE07FFFFFFFFFFFFBE01CFFFFFFF8FBFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFF03FF
FFFC07FFFFFFFFFFFFDE01DFFFFFFFC79FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFF8FF7FFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFE03FF
FFFC0FFFFFFFFFFFFFCE019FFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFF8FF7FFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFC07FF
FFF81FFFFFFFFFFFFFC6011FFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFF8547FFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFE0FFF
FFF83FFFFFFFFFFFFFE2003FFFFFFFE7FBFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFAAAFFFFFFFFFFFFFFFFFFFFFFFFFF807FFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFFC0FFF
FFF01FFFFFFFFFFFFFC0001FFFFFFFC7FBFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFF81FFF
FFE03FFFFFFFFFFFFFE0003FFFFFFFE3FBFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF807FFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFF01FFF
FFE07FFFFFFFFFFFFFE0001FFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF807FFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFF03FFF
FFE0FFFFFFFFFFFFFFE0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFE07FFF
FFC0FFFFFFFFFFFFFFE0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFE07FFF
FF81FFFFFFFFFFFFFFF0003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFC07FFF
FF01FFFFFFFFFFFFFFF0007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFF001FFFF80FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFF003FFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFFC0FFFF
FF83FFFFFFFFFFFFFFF0007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFC01FFFF80FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFF803FFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFF01FFFF
FF07FFFFFFFFFFFFFFF0007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFC54FFFFC0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFD55FFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFF83FFFF
FE07FFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFF7FFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFEFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFF03FFFF
FC07FFFFFFFFFFFFFFF0007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFF3FFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFF7FFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFE03FFFF
FC0FFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFBFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFBFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFC07FFFF
F81FFFFFFFFFFFFFFFF8007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFC7FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFDFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFE0FFFFF
F83FFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFE7FFFFE3FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFEFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFFC0FFFFF
F01FFFFFFFFFFFFFFFFC00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFF3FFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFE7FFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFF81FFFFF
E03FFFFFFFFFFFFFFFFC00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFBFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFF3FFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFF01FFFFF
E07FFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFDFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFF1FFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFF03FFFFF
E0FFFFFFFFFFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFEFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFF9FFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFF07FFFFF
C0FFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFC7FFFF3FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFDFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFE0FFFFFF
80FFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFE7FFFFBFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFFC07FFFFF
01FFFFFFFFFFFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFDFC7FFFF7FFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFF80FFFFFF
83FFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFEFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFF81FFFFFF
03FFFFFFFFFFFFFFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFF507FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC51FFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFF83FFFFFE
07FFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFF03FFFFFC
07FFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF007FFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFE03FFFFFE
0FFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFE003FFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFC07FFFFF8
1FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFC001FFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFE0FFFFFF8
1FFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8000FFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFFC0FFFFFF0
1FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFD555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF00007FFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD555FF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFF81FFFFFF0
3FFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFC000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8000FFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8001FF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFF01FFFFFE0
7FFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C050000555500555555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFF03FFFFFE0
FFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFEBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFE07FFFFFC0
7FFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
D540000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFE07FFFFF80
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF8000FFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFC07FFFFF81
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFC001FFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFC0FFFFFF83
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFBFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFE003FFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFEFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFF81FFFFFF03
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFF47FE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF007FFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC5FFC7F
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFF83FFFFFE07
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFE6FFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFEBFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEEFFEFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFF01FFFFFC07
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFF7FE5FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7FD7F
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFE03FFFFFC0F
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFF3FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFCBF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFE07FFFFFC0F
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFF3FC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FDDF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFE0FFFFFF83F
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFBFEEFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FBFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFC0FFFFFF01F
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFF1FDF7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F9DF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFF81FFFFFF03F
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFF9FCEFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FBEF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFF01FFFFFE07F
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFF9F1C7FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1F3CF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFF03FFFFFE0FF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFF8FBEFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBEBFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFF07FFFFFC0FF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFE07FFFFF80FF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFC07FFFFF01FF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFC0FFFFFF83FF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFF81FFFFFF03FF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFF83FFFFFE07FF
FFFFFFFFFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFF03FFFFFC07FF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFC17FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF45FFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFE03FFFFFE0FFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFA2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA3FFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFC07FFFFFC1FFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFE0FFFFFF81FFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFC0FFFFFF01FFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FF81FFFFFF03FFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFBBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FF01FFFFFF07FFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFD1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF33FF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FF83FFFFFE0FFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFEBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB3FF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FF07FFFFFC07FFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD7FF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FE07FFFFF80FFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FC07FFFFF81FFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FC0FFFFFF83FFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03F81FFFFFF03FFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03F83FFFFFE03FFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03F01FFFFFC07FFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03E03FFFFFE0FFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03E07FFFFFC0FFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03E0FFFFFF81FFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03C0FFFFFF01FFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0380FFFFFF03FFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0301FFFFFE07FFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0303FFFFFE07FFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0303FFFFFC07FFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0207FFFFFC0FFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0007FFFFF81FFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000FFFFFF83FFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFF01FFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC003FFFFFE03FFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFE07FFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC003FFFFFE0FFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFC0FFFFFFF
FFFFFFFFFFFFFFFFFFFFD7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFF81FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFF01FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFF03FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFF03FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFE07FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFC07FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFFC0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFF81FFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC03FFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFF01FFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFF03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFE07FFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFE0FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFC07FFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFF81FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC003FFFF01FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFD7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFF83FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FFFF03FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF03FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FFFE07FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF83FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0003FFFC07FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE055555555555555555555555555555555555555555555555
555555555550055555555555555555555555555555555555555555555555
55555555503FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0403FFFC0FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00000000003FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0403FFFC1FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00000000003FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0C03FFF83FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00000000003FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81C03FFF01FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00000000003FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81C03FFE03FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00000000003FFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01C03FFE07FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF001FF807FFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03C03FFE0FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFA00FF807FF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07C01FFC0FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC007F807FF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0F800FF80FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF803F807FE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC060007F01FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF401F807F0007FFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80E0003F83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFE00F807F003FFFFFFFFFFFFFFFFFFFFFFFABFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01C0003F03FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF003807C007FFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83C0003E07FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF803807800FFFFFFFFFFFFFFFFFFFFFFFFF802FFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03C0001C07FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFC00001001FFFFFFFFFFFFFFFFFFFFFFFFFC0005FFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07C0003E0FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFE00000002AAAAAAAAAAAAAAAAAAAAAAAAAA00002FFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07C0003C1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF00000000000000000000000000000000000000005FFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FE000381FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFC0000000000000000000000000000000000000000AFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FE000701FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFC0000000000000000000000000000000000000000007FFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FF000F03FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF8000000000000000000000000000000000000000000BFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FF001E07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF8000000000000000000000000000000000000000005FFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFE8FE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC000000000000000000000000000000000000000AFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFC07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC000000000000000000000000000000000000005FFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFF80FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE0002AAAAAAAAAAAAAAAAAAAAAAAAAAA80000BFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFF81FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFC0007FFFFFFFFFFFFFFFFFFFFFFFFFFF00017FFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFF83FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFE000FFFFFFFFFFFFFFFFFFFFFFFFFFFE00BFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFF03FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFF017FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFE03FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFABFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFC07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFC0FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFC0FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFF83FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFF01FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFF03FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFE07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFE07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFC07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFC0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFF01FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC79FFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFE03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEBAFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFC07FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD17FFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFE0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFC0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFF81FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFF01FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFF7FFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFF03FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFE3FFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFF07FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFE5FFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFE0FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFEEBFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFC07FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF477FFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFF80FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFF81FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7DFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFF83FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFF03FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC7DFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFE03FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE29FFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFC07FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC11FFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFE0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3EFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFC0FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1E7FFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFF81FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFF01FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFF03FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FEFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFF07FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FCFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFE07FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0A8FFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFC07FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD555FFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFC0FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFF81FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFF83FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFF01FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFE03FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFE07FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFC0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFF80FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFF01FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFF03FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFF03FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFE07FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFC07FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFC0FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFF81FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFF81FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFF01FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFF03FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFE07FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFE0FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFC07FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFF80FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFF01FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFF83FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFF03FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFE07FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFC07FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFC0FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFC1FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFF83FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFF01FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFF03FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFE07FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFE0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFC0FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFF80FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFDFF01FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFF81FFFEFF83FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFF01FFFF1F03FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFF03FFFF8E07FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFC007FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFE00FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFC07FFFFF00FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFF803FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFF0007FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFF0003FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFE00007FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFE08003FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFC07FFFFFC040007FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFF80E0003FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFF81F00007FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF81FFFFFF83F80003FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF01FFFFFF03FC00007FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFE03FE003FBFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFC07FF001FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFE0FFF800FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFC07FFFFFC0FFFC007FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFF80FFFFFF81FFFE0E3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFF81FFFFFF01FFFF0707FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFF83FFFFFF03FFFF8FC3FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFF03FFFFFE07FFFFC7F07FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFE03FFFFFE07FFFFE3F83FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFC07FFFFFC07FFFFF1FC1FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFE0FFFFFFC0FFFFFF9FF83FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFC0FFFFFF01FFFFFFDFFC17FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFF81FFFFFF83FFFFFFEFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFF01FFFFFF03FFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFF03FFFFFE03FFFFFFFFFFF8FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFE07FFFFFC07FFFFFFFFFFFC1FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFE07FFFFFE0FFFFFFFFFFFFF0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFC07FFFFFC0FFFFFFFFFFFFFC1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFC0FFFFFF81FFFFFFFFFFFFFE8FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFF81FFFFFF01FFFFFFFFFFFFFF41FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFF83FFFFFF03FFFFFFFFFFFFFFE0BFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFF01FFFFFF07FFFFFFFFFFFFFFFC1FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFE03FFFFFE07FFFFFFFFFFFFFFFE83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFC07FFFFFC07FFFFFFFFFFFFFFFFC07FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFE0FFFFFFC0FFFFFFFFFFFFFFFFFF83FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFC0FFFFFF81FFFFFFFFFFFFFFFFFFC07FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFF81FFFFFF83FFFFFFFFFFFFFFFFFFF83FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFF01FFFFFF03FFFFFFFFFFFFFFFFFFFC07FFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFF03FFFFFE03FFFFFFFFFFFFFFFFFFFF83FFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFF07FFFFFC07FFFFFFFFFFFFFFFFFFFFF05FFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFE0FFFFFFE0FFFFFFFFFFFFFFFFFFFFFFE0FFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFC07FFFFFC0FFFFFFFFFFFFFFFFFFFFFFF01FFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFF80FFFFFF81FFFFFFFFFFFFFFFFFFFFFFFE0BFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFF81FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFC17FFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFF83FFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFF83FFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFF03FFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFC05FFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFE03FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFA0FFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFC07FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFF01FF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFE0FFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFE03F
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFC0FFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC05
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFF81FFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA0
BFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFF01FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0
07FFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFF03FFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
80FFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFE07FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C007FFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFE07FFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FE02FFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFC07FFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFC017FFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFC0FFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFE00FFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFF81FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC005FFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFF83FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFE003FFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFF01FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFD0015FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFE03FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFA00AFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFE07FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF400015FFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFE0FFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFA0002AFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFC0FFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFD400000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFF81FFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFAA8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFF01FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF5547FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFF03FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFF07FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFE07FFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFC07FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFF11FFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFC0FFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFE7BFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFF81FFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFC7CFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFF83FFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFCFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFF03FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC7C7FFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFE03FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFF8FE7FFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFC07FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFCFC7FFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFE0FFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFF8FE7FFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFC0FFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFF8FC7FFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFF81FFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFF8AA7FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFF01FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFF8547FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFF83FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFF8FE7FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFF07FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFCFC7FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFE07FFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFF8FE7FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFC07FFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFC7C7FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFC0FFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFEFCFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFF81FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFE7CFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFF83FFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF3BFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFF01FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFE03FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFE07FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFE0FFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFC0FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFF80FFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFF01FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFF03FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFF03FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFE07FFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFC07FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFC0FFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFF81FFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFF83FFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFF01FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFF03FFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFE07FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFE0FFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFC07FFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFF81FFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFF01FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFF83FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFF03FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFE07FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFC07FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFC0FFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFF81FFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFF83FFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFF01FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFE03FFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFE07FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFE0FFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFC0FFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFF80FFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFF01FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFF03FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFF03FFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFE07FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFC07FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFC0FFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFF81FFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFF81FFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFF01FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFF03FFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFE07FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFE0FFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFC07FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFF80FFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFF01FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFF83FFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFF03FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFE07FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFC07FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFC0FFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFC1FFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFF83FFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFF01FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFE03FFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFE07FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFE0FFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFC0FFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFF80FFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFF01FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFF83FFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFF03FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFE07FFFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFC07FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFE0FFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFF81FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFF81FFFFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFF007FFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFF003FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFF8007FFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFE003FFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFF0017FFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFE003FF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFF001FF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFE00FF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFF001F03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFA00E03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFF00007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFC000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE
pop
grestore
%%Trailer
%%EOF
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{316, 167},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004l0000Ya000`40O003h00Oogoo?Goo003oOolm
Ool00?mooceoo`00ogoo?Goo000gOol00gNmIcUoo`02Ool00ekgOomoo`2oOol00fmkOomoo`02Ool0
0ekgOomoo`0fOol003Moo`07F]Ig_DYBG_M:DWoo@Q00_goo00=_NeJeOol00UJe0WNm00=:DWooOol0
=Goo000gOol023W>Oom247oo<Haood8@MkfnOol023W>Oom_Nd8@MkdicWoo>LhgOol003Moo`08>Lio
oekgG_LaS7oo@Q1_Nkioo`08<Haoofmk@Q1g_C6<OolaS3Moo`00=goo00LicWooIcUNme[FOom2402o
Ool025[FKg]_Nb48BU9W>Goo@Q0gOol003Moo`03IcU_Ngoo009oo`03Kg]Nmgoo0;moo`03CW=Nmd8@
009oo`03G_M_Ngoo03Ioo`00>7oo00=g_GooOol0aGoo00Ag_GooOomg_CQoo`00ogoo?Goo003oOolm
Ool00?mooceoo`00ogoo?Goo001@Ool00gNmIcUoo`3YOol0051oo`03Mke247oo0>Uoo`00D7oo00=_
Nd8@Ool0jGoo000YOol00gNmIcUNm`0TOol00fmk@Q1oo`3YOol002Yoo`03Kg]:DWNm02=oo`03Kg]2
47oo0>Uoo`009Woo00LaS7ooOomoofmk@Q1_N`0SOol00fmk@Q1oo`3YOol002Ioo`07>Li_NgNmOom_
NgNmKg/08goo00=_Nd8@Ool0jGoo000VOol00eJe>Li2400WOol00gNm@Q1oo`3YOol002Ioo`04MkdH
aWNmMkdWOol00d8@Oomoo`3XOol002Moo`04@Q1NmeJeMkdVOol00d8@Oomoo`3XOol0055oo`03@Q1o
ogoo0>Qoo`00DGoo00=247ooOol0j7oo001AOol00d8@Oomoo`3XOol003=oo`03Kg][FWoo01]oo`03
@Q1oogoo0>Qoo`00;Goo00Mg_FLiE[DicRU:<HaJeP0LOol00e:D:DY_N`3YOol002Qoo`05Kg]Nmd8@
:DXHaP0U00000aS6Mkeoo`3WOol002Qoo`05IcUBU48@>Lh@Q00V00000fmkOomoo`3VOol002ioo`07
MkeF]DYB@Q0YBTYBJeX05Woo00DicPQ2BU9F]E:D00800003<Haoogoo0>Moo`00BWoo00=W>@Q2BU80
0goo00<Q2000DY@0jGoo001:Ool00bU:48Aoo`03Ool00b48000icP3YOol004Uoo`03G_L005Je00Ao
o`038@P0036<0<Aoo`03Kg]oogNm029oo`00BGoo0R481Goo00<Q2000E[D0`Goo00INme:DMke_NdYB
G_LROol004Qoo`03DY@006Li00Eoo`03248005kg0<9oo`9W>@03Oom247Nm029oo`00B7oo00<8@SW>
Ool017oo00A24000001Nml=oo`04>LiooekgIcTROol004Moo`03>Lh8@WNm00Aoo`05Kg/8@P00001N
m`33Ool00d8@Oomoo`0SOol004Ioo`03IcT8@TYB00Eoo`05<H`8@R48001Nm`2LOol00fLiKg]_N`0T
Ool00c6<G_Moo`0SOol004Ioo`03<H`@Q7oo00Aoo`06IcT8@U:D8@P005kgUWoo00A_NgNmOomg_@9_
N`03G_Mg_C6<02Aoo`03MkeBU6Li02=oo`00AGoo00=Nm`Q2E[D01Goo00HYBR48OolQ2000G_NFOol0
2FmkG_M:DVLiBU9F]GNm<Hag_@04Ool00fmkOomoo`0NOol00gNmOomoo`0ROol004Eoo`8Q20Eoo`07
G_L006LiOolQ2000G_L0Ugoo00QNmc6<E[EW>D8@MkeBU48@17oo00=247ooOol06goo00=g_GooOol0
9Goo0014Ool00eJe001W>@05Ool01a24:DYoogoo8@P005kg09Moo`09G_LaS7ooDY@YBWooBU9246Li
00=oo`036<I_Ngoo01Ioo`06IcUF]D8@8@Q246mk3Woo00=_NeJeMkd05Woo0014Ool00`Q2>Lioo`04
Ool00e:D249_N`02Ool00b48001Nm`23Ool013W>48@HaUJe47oo00INmb48Oom_Nb48Kg/5Ool00gNm
001BU00AOol01VLiE[E:DRU:6<H8@P<00003248@Q12400h@Q080000348Ag_Goo01Aoo`00@goo00=2
40Q2Mkd017oo00=g_@Q2>Lh00goo00<Q2000G_L0P7oo00=_NdYB8@P00`0000<8@SW>IcT03Woo00I_
Ne[FOomoof<HIcT5Ool00fLi000icP0@Ool016Li@Q0aS1S66P0000@8@RU:DYAg_A9oo`00@Woo00=W
>@Q2BU801Goo00<icPQ2Mkd00goo00<Q2000G_L0OWoo00E_NbU:2488@S6<00<0000548@Q200048AB
U00GOol00e:D000HaP0EOol026mkG_M:DSW>:DX8@SW>IcT8Kg/01Ukg:DX001S6BU9240800006249:
DS6<000@Q48@4Goo0012Ool00c6<48Aoo`04Ool00fLi249:DP04Ool00b48001Nm`1mOol015kg2488
@UJe0Woo00XicP008@Q_NgooKg/icP00>Lig_AEoo`03<H`000Q201aoo`03Kg]oogoo00Eoo`04IcT8
@PQ2IcT3Ool2000026LiOomoogNm>Lh00248Kg/?Ool0025oo`9g_@Qoo`03Mkeoogoo01=oo`03IcT8
@UJe00Eoo`03:DX@Q7oo00Aoo`038@P005kg07aoo`03G_L8@S6<00Aoo`03@Q00048@00Aoo`04F]H0
02U:MkdDOol012U:000005Je8Woo00=W>@Q2<H`01Goo0P0000=_NgooOol00Woo00ANm`Q28@Qg_@io
o`008Goo00=F]F]JBU801goo00=F]GNmOol04goo00<YBR48Ool017oo00=[FP00E[D01Goo00<Q2000
G_L0Ngoo00=g_@Q28@P01Goo00=24000@Q001Goo00=F]@00G_L057oo0`0000=:DWooOol087oo00<D
YB48Ool01Goo0P0000=g_GooOol00goo00=Nm`00@Q003Woo000LOol025kgMke_Nf<HOomF]DYB@Q07
Ool00cW>G_Moo`0BOol00fLi001BU005Ool00c6<6<Ig_@05Ool00b48001Nm`1kOol00cW>249g_@05
Ool00d8@00124006Ool00c6<249g_@0BOol01FLi00000000>Lh08Goo00=JeP00G_L01Woo0P0000=_
NgooOol017oo00=240Q2Mkd03Goo000LOol023W>MkdicU:DKg]g_E:DMkd7Ool00b48BU9oo`0BOol2
6<H5Ool00fLi001BU006Ool00b48001Nm`1jOol00gNm249:DP06Ool00d8@00124006Ool00fLi249B
U00BOol01EJe:DX001S6<H`01Goo00=g_GooOol06Goo00<Q236<Ool01Woo0P0000=_NgooOol017oo
00=g_A24BU803Goo000LOol024YBG_M246LiBU9F]Ekg@Q07Ool00`Q2:DYoo`0AOol00e[F001W>@05
Ool00aS68@Qoo`06Ool00b48001Nm`1jOol00eJe001g_@06Ool00d8@00124007Ool00c6<8@Qoo`0A
Ool01TicG_L00248G_Mg_@=oo`03Kg]F]Goo01Uoo`03Mkd006Li00Moo`800003Kg]oogoo00Eoo`03
>LhHaWoo00aoo`0077oo00QNme[FBU9W>E[FMkeF]E:D1Woo00=W>@0024804Goo00=g_A24>Lh01Goo
00=JeP00Kg/01goo00<Q2000G_L0KWoo00=[FVmkKg/02Fmk00<icR48Ool01Woo00=24000@Q001goo
00EBU0Q2Kg]_NgNm00m_N`04IcU>L`008@P5Kg/00dic>Li_N`07Kg/00f]JKg]_N`0?Kg/00dic001g
_@07Ool200000fmkOomoo`05Ool00eJe249_N`09Kg/3Ool002Yoo`04E[D00000Mkd@Ool00d8@249g
_@04Ool00gNm48@icP08Ool00b48001Nm`1^Ool=00000b48Oomoo`05Ool00d8@00124007Ool00e:D
0000000h0008Ool200000fmkOomoo`05Ool00ekg0000000800000b48Oomoo`01Ool002Yoo`04@Q00
0000DY@?Ool00gNm249:DP05Ool00d8@249g_@08Ool00b48001Nm`1^Ool00`00<Ha_N`09Kg/00c6<
8@Qoo`06Ool00d8@00124007Ool01E:D001_NfmkJeX046mk00=F]@006<H01Fmk00<YBPQ2Kg/01fmk
00=g_FmkKg/03fmk00=:DP00Ool01goo0P0000=_NgooOol01Goo00=F]@Q2IcT01fmk00<aS248Ool0
0Woo000ZOol012U:000003W>3goo00<aS1S6Mkd017oo00=g_@Q2BU802Goo00<Q2000G_L0KWoo00<0
036<Ool02Goo00=BU0Q2Mkd01Woo00=24000@Q001goo00<icRU:Ool04Woo00=Nm`008@P01Goo00<@
Q000IcT06Goo00=_N`00G_L01goo0P0000=_NgooOol01Goo00<icQ24Ool01goo00<aS248Ool00Woo
000ZOol010Q2000001S63Woo00=W>@00DY@01Goo00<aS1S6Mkd02Goo00<Q2000G_L0KWoo00<0036<
Ool02Goo00=g_@Q2E[D01Woo00=24000@Q001Woo00=g_@Q2BU804goo00=Nm`008@P017oo00Ag_@00
001:DQYoo`036<HaS7oo00Ioo`800003Kg]oogoo00Eoo`0348A:DWoo00Moo`03<H`Q27oo009oo`00
:Goo00I_NaS6000HaR48Mkd=Ool26<H5Ool00fLi001BU00:Ool00b48001Nm`1^Ool00`00<Haoo`0:
Ool00c6<249g_@05Ool00d8@00124006Ool00cW>249g_@0COol00ekg000Q2004Ool015Je000003W>
2Goo00=W>GooOol03Woo00=BU000IcT01Woo0P0000=_NgooOol017oo00=:DPQ2IcT027oo00<aS248
Ool00Woo000YOol01UkgBU800248MkeNm`aoo`03F]H005kg00Eoo`038@PHaWoo00Yoo`038@P005kg
00]oo`03IcUoogoo061oo`03000aS7oo00Yoo`03Mkd8@RU:00Eoo`05@Q00048@Oomg_@03Ool00e:D
001BU00DOol00ekg000Q2004Ool0148@000001242Goo0Vmk47oo00<Q21S6Ool00goo00Ag_Goo0000
009_N`Aoo`03IcT8@T8@00Uoo`03<H`Q27oo009oo`00:Goo00I_Nekg000Q27ooMkd;Ool00gNm48@Y
BP05Ool00e[F001Nm`0;Ool00b48001Nm`0;Ool00gNmKg]oo`1POol00`00<Haoo`0;Ool016Li248Y
BVLi0Woo00ENmd8@001245[F00=oo`03DY@004YB01Eoo`03G_L0024800Aoo`05:DX00000001g_@09
Ool00d8@Oomoo`0>Ool016Li248Q26Li0Woo00I_Nekg000006LiDY@3Ool00ekg248aS00:Ool00c6<
8@Qoo`02Ool002Yoo`03G_L0024800eoo`03@Q0007Nm00Eoo`0348@YBWoo00]oo`038@P005kg00ao
o`03@Q1g_Goo05moo`03000aS7oo00aoo`08IcT@Q0Q2BU9g_E:D:DX0008icP05OomJeQS6001:DP0F
Ool00ekg000Q2004Ool01AS6000005:DE[D017oo00LicWNmOomoogNmDYA_N`0@Ool016Li6<H8@TYB
0Woo00XHaP00000@Q6LiOomNmaS6000aS0]oo`03<H`Q27oo009oo`00:Woo00=Nm`008@P037oo00=g
_@Q2@Q001Goo00=:DP00Kg/037oo00<Q2000G_L01Woo00=g_CW>G_L00Woo00=g_E:DG_L0H7oo00<0
036<Ool03Goo00E_NcW>248000Q200<0000524800000:DYW>@0GOol00ekg000Q2003Ool01WNmE[D0
0000MkeJePAoo`07<Hag_GooOomNmgNmF]H04Goo00Ig_CW>2488@S6<48@300001C6<48@002U:E[D0
37oo00<aS248Ool00Woo000ZOol00ekg000Q200<Ool00cW>6<Ig_@04Ool00gNm48A2400=Ool00b48
001Nm`07Ool01ekgDYAoogooIcUoofmk061oo`03000aS7oo00moo`03MkeF]D8@00<00003:DY:DVLi
01Uoo`03G_L0024800=oo`04Mkeoo`000006Ool00e:D@Q0e[@0GOol016mkDY@Q21240`0000<HaS6<
IcT03Woo00<aS248Ool00Woo000ZOol00ekg000Q200;Ool00fLi001BU005Ool00cW>48Ag_@0;Ool0
1UkgMkdQ2000G_MBU0Ioo`04MkdQ24icKg]SOol00`00<Haoo`0BOol01124000006mk6goo00=Nm`00
8@P01Goo0P001Woo00A_NcW>MkeW>AUoo`04E[D00000<H`AOol00c6<8@Qoo`02Ool002Yoo`03G_L0
024800]oo`038@PHaWoo00Aoo`03Kg/005:D00eoo`05>LhQ2000<HaW>@07Ool0136<Oom_NgNmHWoo
00<0036<Ool04Woo00<aS000000077oo00=Nm`008@P01Goo0P001goo00@Q25kgE[EW>AUoo`032480
05:D015oo`03<H`Q27oo009oo`00:Woo00=Nm`008@P02Woo00=JeP00G_L01Goo00<YBQS6Mkd03Goo
00DHaP00000006mk00Moo`04@Q1F]EkgG_MROol00`00<Haoo`0BOol00e:D000YBP0LOol00ekg000Q
2005Ool2000TOol00aS6001W>@0AOol00c6<8@Qoo`02Ool002Yoo`03G_L0024800Yoo`0348@YBWoo
00Aoo`03G_L005kg00ioo`04>Lh0000048A^Ool00`00<Haoo`0;Ool016mk@Q1246mk0goo00=F]@00
>Lh077oo00=Nm`008@P01Goo0P0097oo00<icP00Mkd00Woo00=:DT8@E[D037oo00<aS248Ool00Woo
000ZOol00ekg000Q2009Ool00d8@001g_@05Ool00aS6:DYoo`0>Ool015:D0000036<KWoo00<0036<
Ool037oo00=:DVmkKg/017oo00<8@U:DOol06goo00=Nm`008@P01Goo0P0097oo00=BU248Ool00Woo
00=_NekgJeX037oo00<aS248Ool00Woo000ZOol00ekg000Q2008Ool00gNm24924005Ool00dYB001_
N`0?Ool016mk000003W>KWoo00<0036<Ool03Goo00=247ooOol00goo00<HaVmkOol06goo00=Nm`00
8@P01Goo0P0097oo00=_Nc6<Ool00goo00=W>EkgOol02goo00<aS248Ool00Woo000ZOol00ekg000Q
2008Ool00cW>6<Ig_@04Ool00gNm48@icP0AOol00a24001W>@1^Ool00`00<Haoo`0>Ool00dYBOomo
o`02Ool00dYBOomoo`0KOol00ekg000Q2005Ool2000UOol00f<HOomoo`03Ool00cF]Mkeoo`0:Ool0
0c6<8@Qoo`02Ool002Yoo`03G_L0024800Moo`03G_L005:D00Eoo`03@Q08@WNm015oo`03:DX006mk
06ioo`03000aS7oo00aoo`03G_M:DS6<00Aoo`03Mkeoogoo01]oo`03G_L0024800Eoo`8002Uoo`04
IcUBU2U:Kg/;Ool00c6<8@Qoo`02Ool002Yoo`03G_L0024800Ioo`03Mkd8@QS600Eoo`03Kg/8@TYB
019oo`03BU8@Q7oo06ioo`03000aS7oo00eoo`03G_Mg_Goo025oo`04<H`00000DY@4Ool2000ZOol0
0ekgMkeoo`0;Ool00c6<8@Qoo`02Ool002Yoo`03G_L0024800Ioo`03>Lh005kg00Eoo`03<H`HaWNm
019oo`03E[DYBWoo06ioo`03000aS7oo00aoo`9BU003:DYW>Goo01eoo`03DYA244YB00<00003249B
U5:D009BU08000EBU003G_Moogoo025oo`04G_MBU2U:BU8;Ool00c6<8@Qoo`02Ool002Yoo`03G_L0
024800Eoo`03Kg/003F]00Eoo`03IcT005:D01Aoo`03<Haoogoo06eoo`03000aS7oo00]oo`05Mkeo
ogooOom_N`0NOol2Kg/01FLi6<H00000<H`015kg0P001Ekg00=W>GooOol087oo00Ig_GooOomoofLi
Mkd:Ool00c6<8@Qoo`02Ool002Yoo`03G_L0024800Eoo`03:DX@Q7oo00Eoo`036<HQ27oo01Aoo`03
<Haoogoo06eoo`03000aS7oo00]oo`06IcU:DWooOom247Nm87oo00=g_EJeE[D01Goo0P00:7oo00IW
>E:DMkeoofLiDY@:Ool00c6<8@Qoo`02Ool002Yoo`03G_L0024800Aoo`03IcT005kg00Eoo`03F]H0
06Li01Eoo`03<Haoogoo06eoo`03000aS7oo00aoo`05DYA_NgooBU9W>@0XOol2000YOol01VmkBU9o
oe[FKg]g_@Uoo`03<H`Q27oo009oo`00:Woo00=Nm`008@P017oo00<HaRU:Ool017oo00=g_A24>Lh0
5Woo00<aS7ooOol0KGoo00<0036<Ool037oo00E_NdYBIcUg_Ekg02Qoo`8002Yoo`03>Liooekg009g
_@Uoo`03<H`Q27oo009oo`00:Woo00=Nm`008@P00goo00=BU0Q2IcT01Goo00=240Q2Mkd05Woo00<a
S7ooOol0KGoo00<0036<Ool03Goo00<icWooOol0:Goo0P00:Woo00<icWooOol02goo00<aS248Ool0
0Woo000ZOol00ekg000Q2002Ool00gNm248icP05Ool00gNm249:DP0GOol00d8@Oomoo`1]Ool00`00
<Haoo`0<Ool00gNm<HaW>@0ZOol2000ZOol00dHa?Nmoo`0;Ool00c6<8@Qoo`02Ool002Yoo`03G_L0
0248009oo`03@Q08@WNm00Eoo`03>LhHaWNm01Moo`03@Q1oogoo06eoo`03000aS7oo00eoo`03IcU:
DWNm02Uoo`8002]oo`03@Q1S67oo00Yoo`03<H`Q27oo009oo`00:Woo00MNm`008@Qoofmk249:DP05
Ool00fLi001BU00HOol00d8@Oomoo`1]Ool00`00<Haoo`0>Ool00gNmOomoo`0XOol2000[Ool2Mkd;
Ool00c6<8@Qoo`02Ool002Yoo`06G_L00248Oole[@Q21Woo00<Q20Q2Ool067oo00<e[GooOol0KGoo
00<002U:Ool0>Goo0P00>7oo00<YBR48Ool00Woo000ZOol01Ukg000Q27Nm001:DPEoo`03IcT8@U:D
01Uoo`03@Q1oogoo06eoo`03000aS7oo03Uoo`8003Qoo`03<H`Q27oo009oo`00:Woo00INm`008@PY
BQ24Mkd5Ool00b486<Ioo`0IOol00d8@Oomoo`1]Ool00`00<Haoo`0iOol2000hOol00c6<8@Qoo`02
Ool002Yoo`05G_L000Q2001JeP05Ool00eJe001Nm`0JOol00d8@Oomoo`1]Ool00`00<Haoo`0iOol2
000hOol00c6<8@Qoo`02Ool002Yoo`04G_L000008@P5Ool00gNm000YBP0KOol00dYBOomoo`1]Ool0
0`00<Haoo`0iOol2000hOol00c6<8@Qoo`02Ool002Yoo`04G_L00000IcT5Ool00bU:001_N`2;Ool0
0`00<Haoo`0iOol2000hOol00c6<8@Qoo`02Ool002Yoo`03G_L0024800Eoo`03G_L004YB01aoo`03
IcUoogoo06eoo`03000aS7oo03Uoo`8003Qoo`03<H`Q27oo009oo`00:Woo00=240008@P01Goo0R48
7Goo00=247ooOol0KGoo00<0036<Ool0>Goo0P00>7oo00<aS248Ool00Woo000YOol017Nm00000248
17oo00=BU000IcT07Goo00=:DWooOol0KGoo00<0036<Ool0>Goo0P00>7oo00<aS248Ool00Woo000Y
Ool012U:000002480goo00=g_AS6<H`0SWoo00<0036<Kg/086mk00=[FVmkKg/05Vmk0P0026mk00=g
_FmkKg/086mk00=[FVmkKg/02Vmk00<aS248Ool00Woo000XOol01Ekg000icP008@P00goo00=:DPQ2
Mkd07Woo00=W>GooOol0KGooM`0000<Q27ooOol00Goo000XOol01B486<INm`006<H00Woo00=g_@00
BU807goo00=247ooOol0KGoo=Ukg00AF]A24000HaP9Nm`80009Nm`04E[D8@P006<HcG_L00fLiOomo
o`01Ool002Moo`04DY@005Je48@200001CW>OolaS124Mkd07goo00=247ooOol0Y7oo00Eg_C6<000a
S7Nm00800005OomF]A24000icP0GOol2E[D00fLiOomoo`0LOol002Ioo`04MkdHaS6<G_L3000011S6
Kg/005[F87oo00=247ooOol0YWoo00<aS0006<H00P0000@YBP00000YBPABU003BU9BU5:D019BU008
:DX000Q28@PaS4YBG_M_NaQoo`009Woo00E:DPQ2Mkeooa2400800003DY@Q21S6025oo`03@Q1oogoo
0:Moo`03DY@0000002H0000448@Q24YBMkdDOol002Eoo`03Mkd004YB00=oo`05IcUg_E[F001Nm`0Q
Ool00d8@Oomoo`2XOol012U:000000001c6<00<YBS6<<H`04S6<00T8@P000008@QS6>Li245:DKg/0
5goo000UOol00c6<48Ag_@04Ool00gNm6<HYBP0ROol00d8@Oomoo`2XOol016Li<H`YBU[F6Woo00E_
Ne:DBU9F]GNm01eoo`0097oo00=W>@00F]H01Goo00=:DPQ2Kg/08Woo00=247ooOol0j7oo000TOol0
0b486<Ioo`04Ool00gNm248icP0SOol00d8@Oomoo`3XOol002=oo`03F]H005kg00Eoo`03>Lh@Q7Nm
02=oo`03@Q1oogoo0=9oo`03Kg]g_Fmk01=oo`008Woo00=g_AS6<H`01Goo00=_N`00BU8097oo00=2
47ooOol0dWoo00Ag_Fmk@Q1g_A9oo`008Woo00=:DPQ2Mkd01Goo00<YBQS6Ool097oo00=247ooOol0
cgoo00HaS7NmOomoofmkBU8COol0025oo`03Mkd8@TYB00Eoo`03F]H005kg02Eoo`03@Q1oogoo0<mo
o`05:DYg_GNmOomNm`02Kg/BOol0025oo`03<H`@Q7Nm00Aoo`03MkdHaRU:02Ioo`03@Q1oogoo0<mo
o`9:DP03DYAoogoo01Aoo`0087oo00=_N`00F]H01Goo00=BU000Kg/09Woo00=247ooOol0cgoo00A_
Nc6<Kg]g_AEoo`0087oo00<Q21S6Ool017oo00=g_A24>Lh09goo00=247ooOol0cgoo00Ag_BU:G_M2
41Eoo`007goo00=JeP00G_L01Goo00=240Q2Mkd09goo00=247ooOol0j7oo000NOol00gNm6<HYBP05
Ool00gNm001:DP0XOol00d8@Oomoo`3XOol001ioo`03BU88@Vmk00Eoo`03:DX@Q7Nm02Qoo`03@Q1o
ogoo0>Qoo`007Goo00=g_@Q2BU801Goo00=Nm`00F]H0:Goo00=247ooOol0j7oo000MOol00c6<48Ag
_@05Ool00b486<Ioo`0YOol00eJeOomoo`3XOol001aoo`03Kg/005[F00Eoo`03DY@005kg0?mooaIo
o`0077oo00<Q21S6Ool017oo00=g_AS6<H`0:goo00=NmgooOol0j7oo000KOol00ekg001F]@05Ool0
0eJe249g_@0[Ool00dYBOomoo`3XOol001]oo`03:DXHaWoo00Eoo`0348@aS7oo02]oo`03@Q1oogoo
0>Qoo`006Woo00=F]@00G_L00Woo0WNm00Aood8@249_NomooaQoo`006Woo00<@Q2U:Ool00goo00AB
U3W>249242eoo`03Mkeoogoo0>Qoo`006Goo00=:DPQ2IcT01Goo00@YBP008@QJeRaoo`03@Q1oogoo
0>Qoo`0067oo00=g_@Q2>Lh01Goo00=W>@00:DX00P0000<HaU[FOol0:Goo00=247ooOol0j7oo000H
Ool00cW>249g_@05Ool012U:6<Iooe:D0P0000<8@SW>IcT0:7oo00=247ooOol0j7oo000GOol00fLi
249BU005Ool00ekg001Nm`02Ool015:D000HaU:D:Goo00=247ooOol0j7oo000GOol00bU:6<Ioo`05
Ool00a24:DYoo`03Ool01E:D@Q1Nmc6<F]H09goo00=247ooOol0j7oo000FOol00ekg001Nm`05Ool0
0dYB249W>@05Ool01U:DMkeg_DYB>LiNmbEoo`03@Q1oogoo0>Qoo`005Woo00<@Q2U:Ool017oo00=g
_@Q2>Lh02Woo00Ag_DYB@Q1g_B=oo`03@Q1oogoo0>Qoo`005Goo00=BU0Q2IcT01Goo00<icPQ2Mkd0
37oo00Ag_CW>>Li_Nb5oo`03@Q1oogoo0>Qoo`0057oo00=g_@Q2<H`01Goo00=_N`Q2BU803goo00Ag
_D8@>LiJeQmoo`03@Q1oogoo0>Qoo`0057oo00<icPQ2Mkd01Goo00<YBQS6Ool04Goo00Ag_DYB:DYJ
eQeoo`03@Q1oogoo0>Qoo`004goo00=W>@Q2DY@01Goo00=Nm`00G_L05Goo00AW>CF]<HaNmaYoo`03
@Q1oogoo0>Qoo`004goo00<YBQS6Ool01Goo00<Q22U:Ool067oo00AF]BU:DYAW>AMoo`03@Q1oogoo
0>Qoo`004Woo00=Nm`00G_L01Goo00=BU0Q2IcT06goo00E_NdYB<HaBU5kg01Aoo`03@Q1oogoo0>Qo
o`004Woo00<@Q2U:Ool01Goo00<8@S6<Ool07Woo00I_Ne:D:DXicTYBMkd@Ool00d8@Oomoo`3XOol0
015oo`03@Q08@VLi00Eoo`03>Lh8@Vmk02=oo`06G_M:DS6<>Li:DUJe37oo00=247ooOol0j7oo000@
Ool00fLi000aS005Ool00gNm2492400XOol01FLiE[E2436<>Lh00T8@00ABU5JeKg]g_@=oo`03@Q1o
ogoo0>Qoo`0047oo00<HaPQ2Mkd01Goo00<aS0Q2Ool0;Woo00=_NekgE[D00U:D00@icS6<<H`ic^Yo
o`003goo00=JeP00G_L01Goo00=W>@00DY@067oo00=F]EkgOol077oo00=247ooOol0j7oo000>Ool0
0gNm48@icP06Ool00bU:8@Qoo`0GOol015JeDYAW>D8@77oo00=247ooOol0j7oo000>Ool00d8@249g
_@05Ool00eJe249Nm`0HOol014YBE[ENmbU:77oo00=247ooOol0j7oo000=Ool00gNm249:DP06Ool0
0a24<Haoo`0HOol014YBCW=W>BU:ogoo27oo000=Ool00c6<6<Ig_@05Ool00d8@249_N`0IOol017Nm
BU9NmeJe77oo00=W>GooOol0j7oo000<Ool00fLi001BU005Ool00gNm2492400KOol2Kg/MOol00c6<
Oomoo`3XOol000aoo`8HaPIoo`03>Lh8@Woo03Yoo`03@Q1oogoo0>Qoo`002goo00=JeP00G_L01Goo
00=W>@00DY@0ogoo9goo000;Ool00a24<Haoo`05Ool00bU:6<Ioo`0kOol00fLiOomoo`3XOol000Yo
o`03BU88@Vmk00Eoo`03G_L005kg03aoo`03<Haoogoo0>Qoo`002Goo00=g_@Q2@Q001Woo00<@Q2U:
Ool0?7oo00<aS7ooOol0j7oo0009Ool00c6<6<Ig_@05Ool00d8@249W>@0mOol00c6<Oomoo`3XOol0
00Qoo`03IcT005:D00Eoo`03IcT0036<03ioo`03<Haoogoo0>Qoo`0027oo00<Q20Q2Ool01Goo00<Q
2000Mkd0?Woo00<YBWooOol0j7oo0007Ool00fLi001BU005Ool00fLi001:DP0oOol00c6<Oomoo`3X
Ool000Moo`038@PHaWoo00Eoo`8Q241oo`03<Haoogoo0>Qoo`001Woo00=Nm`00G_L01Goo00=F]@00
G_L0@7oo00<aS7ooOol0j7oo0006Ool00a24:DYoo`05Ool00a24<Haoo`10Ool00c6<Oomoo`3XOol0
00Eoo`03BU88@Vmk00Eoo`03@Q08@Vmk045oo`03<Haoogoo0>Qoo`0017oo00=_N`Q2@Q001Goo00=_
N`Q2@Q00@Woo00<aS7ooOol0j7oo0004Ool00c6<249oo`05Ool00c6<249oo`12Ool00gNmOomoo`3X
Ool000=oo`03IcT8@U:D00Eoo`03IcT8@U:D0?moobmoo`000goo00<YBQ24Mkd01Goo00<aS1S6Ool0
ogoo;goo0003Ool01D8@000@Q5:DMkd00Woo00=Nm`00G_L0ogoo<7oo0004Ool027Nm>Lh001S6IcUo
oaS6:D[oOolaOol000Ioo`06Kg/HaP006<H006Liogoo<Goo0008Ool00e[F6<I2403oOolbOol00?mo
oceoo`00ogoo?Goo003oOolmOol00001\
\>"],
  CellTags->"2"],

Cell[TextData[{
  StyleBox["Figure 2.2. ",
    FontWeight->"Bold"],
  "Forces applied to the rod (a) and the cart (b) of the pendulum."
}], "Caption",
  CellTags->"2"],

Cell["\<\
Finally, for the cart we have (see Figure\[NonBreakingSpace]2.2b) 
\
\>", "Text",
  CellTags->"2"],

Cell[BoxData[
    \(TraditionalForm\`f\_x - F\_x = M \( X\&\[DoubleDot]\)\&\)], 
  "DisplayFormula",
  CellTags->"2"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f\_x\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " is the input force applied to the wheels. \nTranslating the model into ",
  StyleBox["Mathematica", "TI"],
  " is straightforward. "
}], "Text",
  CellTags->"2"],

Cell[TextData[{
  "This is the first equation. We will keep it as ",
  StyleBox["eq1", "MR"],
  " for future reference. "
}], "MathCaption",
  CellTags->"2"],

Cell["eq1 = Fx == m xc''[t]", "Input",
  CellLabel->"In[1]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{"Fx", "==", 
      RowBox[{"m", " ", 
        RowBox[{
          SuperscriptBox["xc", "\[DoublePrime]",
            MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
  CellLabel->"Out[1]=",
  CellTags->"2"],

Cell["Next equation translates almost verbatim as well. ", "MathCaption",
  CellTags->"2"],

Cell["eq2 = Fy - m g == m yc''[t]", "Input",
  CellLabel->"In[2]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{\(Fy - g\ m\), "==", 
      RowBox[{"m", " ", 
        RowBox[{
          SuperscriptBox["yc", "\[DoublePrime]",
            MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
  CellLabel->"Out[2]=",
  CellTags->"2"],

Cell["This is the dynamical equation. ", "MathCaption",
  CellTags->"2"],

Cell["\<\
eq3 =
 Fy L/2 Sin[theta[t]] -
 Fx L/2 Cos[theta[t]] == J theta''[t]\
\>", "Input",
  CellLabel->"In[3]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{
    \(\(-\(1\/2\)\)\ Fx\ L\ Cos[theta[t]] + 1\/2\ Fy\ L\ Sin[theta[t]]\), 
      "==", 
      RowBox[{"J", " ", 
        RowBox[{
          SuperscriptBox["theta", "\[DoublePrime]",
            MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
  CellLabel->"Out[3]=",
  CellTags->"2"],

Cell[TextData[{
  "This gives the definition for the moment of inertia ",
  StyleBox["J", "MR"],
  ". "
}], "MathCaption",
  CellTags->"2"],

Cell["J = m/12 L^2", "Input",
  CellLabel->"In[4]:=",
  CellTags->"2"],

Cell[BoxData[
    \(\(L\^2\ m\)\/12\)], "Output",
  CellLabel->"Out[4]=",
  CellTags->"2"],

Cell["Here is the last equation. ", "MathCaption",
  CellTags->"2"],

Cell["eq4 = fx - Fx == M X''[t]", "Input",
  CellLabel->"In[5]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{\(fx - Fx\), "==", 
      RowBox[{"M", " ", 
        RowBox[{
          SuperscriptBox["X", "\[DoublePrime]",
            MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
  CellLabel->"Out[5]=",
  CellTags->"2"],

Cell[TextData[{
  "We now define the horizontal displacement ",
  StyleBox["xc", "MR"],
  " of the pendulum through the displacement of the cart ",
  StyleBox["X", "MR"],
  " and the angle ",
  StyleBox["theta", "MR"],
  ". As the two depend on time ",
  StyleBox["t", "MR"],
  ", then so does ",
  StyleBox["xc", "MR"],
  ". The pattern notation ",
  StyleBox["t_", "MR"],
  " on the left\[Hyphen]hand side makes the formula work for ",
  StyleBox["any", "TI"],
  " expression ",
  StyleBox["t", "MR"],
  ". "
}], "MathCaption",
  CellTags->"2"],

Cell["xc[t_] = X[t] + L/2 Sin[theta[t]]", "Input",
  CellLabel->"In[6]:=",
  CellTags->"2"],

Cell[BoxData[
    \(1\/2\ L\ Sin[theta[t]] + X[t]\)], "Output",
  CellLabel->"Out[6]=",
  CellTags->"2"],

Cell[TextData[{
  "Here is the corresponding assignment to the vertical displacement ",
  StyleBox["yc", "MR"],
  ". "
}], "MathCaption",
  CellTags->"2"],

Cell["yc[t_] = L/2 Cos[theta[t]]", "Input",
  CellLabel->"In[7]:=",
  CellTags->"2"],

Cell[BoxData[
    \(1\/2\ L\ Cos[theta[t]]\)], "Output",
  CellLabel->"Out[7]=",
  CellTags->"2"],

Cell[TextData[{
  "Notice that we have defined ",
  StyleBox["eq1", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Ellipsis]\)\(\ \)\)\)], "InlineFormula",
    CellTags->"S0.0.1"],
  StyleBox["eq4", "MR"],
  " as logical ",
  StyleBox["equations", "TI"],
  " (using the double equation mark ",
  StyleBox["==", "MR"],
  ") and the expressions for ",
  StyleBox["xc", "MR"],
  " and ",
  StyleBox["yc", "MR"],
  " as ",
  StyleBox["assignments", "TI"],
  " to these symbols (using the single ",
  StyleBox["=", "MR"],
  "). We then have the benefit of not solving the ",
  StyleBox["differential", "TI"],
  " equation against ",
  StyleBox["X''[t]", "MR"],
  ", but simply eliminating it ",
  StyleBox["algebraically", "TI"],
  " along with the other variables we no longer need. "
}], "Text",
  CellTags->"2"],

Cell[TextData[{
  StyleBox["Eliminate", "MR"],
  " takes the list of equations and the list of variables to eliminate. The \
result is a nonlinear differential equation between the input force ",
  StyleBox["fx", "MR"],
  " and the angular displacement ",
  StyleBox["theta", "MR"],
  " and its first and second derivatives. It is solvable for ",
  StyleBox["theta''[t]", "MR"],
  ". "
}], "MathCaption",
  CellTags->"2"],

Cell["Eliminate[{eq1, eq2, eq3, eq4}, {Fx, Fy, X''[t]}]", "Input",
  CellLabel->"In[8]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{\(6\ fx\ L\ m\ Cos[theta[t]]\), "==", 
      RowBox[{"L", " ", "m", " ", 
        RowBox[{"(", 
          RowBox[{
          \(6\ g\ m\ Sin[theta[t]]\), "+", \(6\ g\ M\ Sin[theta[t]]\), "-", 
            RowBox[{
            "3", " ", "L", " ", "m", " ", \(Cos[theta[t]]\), " ", 
              \(Sin[theta[t]]\), " ", 
              SuperscriptBox[
                RowBox[{
                  SuperscriptBox["theta", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
            RowBox[{"L", " ", "m", " ", 
              RowBox[{
                SuperscriptBox["theta", "\[DoublePrime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "-", 
            RowBox[{"L", " ", "M", " ", 
              RowBox[{
                SuperscriptBox["theta", "\[DoublePrime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "-", 
            RowBox[{"3", " ", "L", " ", "M", " ", \(Cos[theta[t]]\^2\), " ", 
              RowBox[{
                SuperscriptBox["theta", "\[DoublePrime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "-", 
            RowBox[{"3", " ", "L", " ", "m", " ", \(Sin[theta[t]]\^2\), " ", 
              RowBox[{
                SuperscriptBox["theta", "\[DoublePrime]",
                  MultilineFunction->None], "[", "t", "]"}]}], "-", 
            RowBox[{"3", " ", "L", " ", "M", " ", \(Sin[theta[t]]\^2\), " ", 
              RowBox[{
                SuperscriptBox["theta", "\[DoublePrime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]], 
  "Output",
  CellLabel->"Out[8]=",
  CellTags->"2"],

Cell[TextData[{
  StyleBox["Solve", "MR"],
  " returns a list of rules that give generic solutions to the input \
equation. "
}], "MathCaption",
  CellTags->"2"],

Cell["Solve[%, theta''[t]]", "Input",
  CellLabel->"In[9]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            SuperscriptBox["theta", "\[DoublePrime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
          RowBox[{"-", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{"3", " ", 
                  RowBox[{"(", 
                    RowBox[{
                    \(2\ fx\ Cos[theta[t]]\), "-", 
                      \(2\ g\ m\ Sin[theta[t]]\), "-", 
                      \(2\ g\ M\ Sin[theta[t]]\), "+", 
                      RowBox[{
                      "L", " ", "m", " ", \(Cos[theta[t]]\), " ", 
                        \(Sin[theta[t]]\), " ", 
                        SuperscriptBox[
                          RowBox[{
                            SuperscriptBox["theta", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], "2"]}
                        ]}], ")"}]}], ")"}], "/", 
              \((L\ \((m + M + 3\ M\ Cos[theta[t]]\^2 + 
                      3\ m\ Sin[theta[t]]\^2 + 3\ M\ Sin[theta[t]]\^2)\))\)}]}
            ]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[9]=",
  CellTags->"2"],

Cell["\<\
We have, in fact, just a single rule and we extract it from the \
lists. \
\>", "MathCaption",
  CellTags->"2"],

Cell["sln = %[[1, 1]]", "Input",
  CellLabel->"In[10]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["theta", "\[DoublePrime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{"-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                RowBox[{
                \(2\ fx\ Cos[theta[t]]\), "-", \(2\ g\ m\ Sin[theta[t]]\), 
                  "-", \(2\ g\ M\ Sin[theta[t]]\), "+", 
                  RowBox[{
                  "L", " ", "m", " ", \(Cos[theta[t]]\), " ", 
                    \(Sin[theta[t]]\), " ", 
                    SuperscriptBox[
                      RowBox[{
                        SuperscriptBox["theta", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], "2"]}]}]
                  , ")"}]}], ")"}], "/", 
          \((L\ \((m + M + 3\ M\ Cos[theta[t]]\^2 + 3\ m\ Sin[theta[t]]\^2 + 
                  3\ M\ Sin[theta[t]]\^2)\))\)}]}]}]], "Output",
  CellLabel->"Out[10]=",
  CellTags->"2"],

Cell[TextData[{
  "As our next step, we create a state\[Hyphen]space model of the system and \
linearize it for small perturbations near the equilibrium position  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 0\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ". Then, based on the linearized model, we design the state feedback \
controller that attempts to keep the pendulum in equilibrium. Finally, we \
carry out several simulations of the actual nonlinear system governed by the \
controller and see what such a controller can and cannot do. \nThe nonlinear \
state\[Hyphen]space model of the system will be presented in the form   "
}], "Text",
  CellTags->"2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{
                OverscriptBox[
                  StyleBox["\<\"x\"\>",
                    "TB"], "."], "=", 
                StyleBox["\<\"f\"\>",
                  "TB"], 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["\<\"x\"\>",
                      "TB"], ",", 
                    StyleBox["\<\"u\"\>",
                      "TB"]}], ")"}]}],
              "InlineFormula"]},
          {
            StyleBox[
              RowBox[{
                StyleBox["\<\"y\"\>",
                  "TB"], "=", 
                StyleBox["\<\"h\"\>",
                  "TB"], 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["\<\"x\"\>",
                      "TB"], ",", 
                    StyleBox["\<\"u\"\>",
                      "TB"]}], ")"}]}],
              "InlineFormula"]}
          },
        ColumnAlignments->{Right}], TraditionalForm]], "DisplayFormula",
  CellTags->"2"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Theta]\& . \)\)\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " constitute the state vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"x\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f\_x\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " is the only component of the input vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"u\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " makes up the output vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"y\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ". "
}], "Text",
  CellTags->"2"],

Cell[TextData[{
  "This creates the state vector in ",
  StyleBox["Mathematica", "TI"],
  ". "
}], "MathCaption",
  CellTags->"2"],

Cell["x = {theta[t], theta'[t]};", "Input",
  CellLabel->"In[11]:=",
  CellTags->"2"],

Cell["This sets the input and output vectors. ", "MathCaption",
  CellTags->"2"],

Cell["u = {fx};  y = {theta[t]};", "Input",
  CellLabel->"In[12]:=",
  CellTags->"2"],

Cell[TextData[{
  "To obtain ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"f\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"h\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", we observe that their ",
  StyleBox["Mathematica", "TI"],
  " equivalents ",
  StyleBox["f", "MR"],
  " and ",
  StyleBox["h", "MR"],
  " are simply the derivative ",
  StyleBox["D[x,", "MR"],
  " ",
  StyleBox["t]", "MR"],
  " and the output vector ",
  StyleBox["y", "MR"],
  " expressed via the state and input variables. "
}], "Text",
  CellTags->"2"],

Cell[TextData[{
  "The expression for the derivative contains an undesirable variable, ",
  StyleBox["theta''[t]", "MR"],
  ", which is among neither state nor input variables. "
}], "MathCaption",
  CellTags->"2"],

Cell["D[x, t]", "Input",
  CellLabel->"In[13]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          SuperscriptBox["theta", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], ",", 
        RowBox[{
          SuperscriptBox["theta", "\[DoublePrime]",
            MultilineFunction->None], "[", "t", "]"}]}], "}"}]], "Output",
  CellLabel->"Out[13]=",
  CellTags->"2"],

Cell[TextData[{
  "The replacement rule stored as ",
  StyleBox["sln", "MR"],
  " helps to get rid of ",
  StyleBox["theta''[t]", "MR"],
  ". "
}], "MathCaption",
  CellTags->"2"],

Cell["f = % /. sln", "Input",
  CellLabel->"In[14]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          SuperscriptBox["theta", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], ",", 
        RowBox[{"-", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{"3", " ", 
                RowBox[{"(", 
                  RowBox[{
                  \(2\ fx\ Cos[theta[t]]\), "-", \(2\ g\ m\ Sin[theta[t]]\), 
                    "-", \(2\ g\ M\ Sin[theta[t]]\), "+", 
                    RowBox[{
                    "L", " ", "m", " ", \(Cos[theta[t]]\), " ", 
                      \(Sin[theta[t]]\), " ", 
                      SuperscriptBox[
                        RowBox[{
                          SuperscriptBox["theta", "\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], "2"]}]}
                    ], ")"}]}], ")"}], "/", 
            \((L\ \((m + M + 3\ M\ Cos[theta[t]]\^2 + 3\ m\ Sin[theta[t]]\^2 
                    + 3\ M\ Sin[theta[t]]\^2)\))\)}]}]}], "}"}]], "Output",
  CellLabel->"Out[14]=",
  CellTags->"2"],

Cell[TextData[{
  "The expression for function ",
  StyleBox["h", "MR"],
  " is trivial. "
}], "MathCaption",
  CellTags->"2"],

Cell["h = y", "Input",
  CellLabel->"In[15]:=",
  CellTags->"2"],

Cell[BoxData[
    \({theta[t]}\)], "Output",
  CellLabel->"Out[15]=",
  CellTags->"2"],

Cell[TextData[{
  "So far we have used the built\[Hyphen]in ",
  StyleBox["Mathematica", "TI"],
  " functions. Now it's time to make accessible the library of functions \
provided in ",
  StyleBox["Control System Professional", "TI"],
  ". "
}], "Text",
  CellTags->"2"],

Cell["This loads the application. ", "MathCaption",
  CellTags->"2"],

Cell["<<ControlSystems`", "Input",
  CellLabel->"In[16]:=",
  CellTags->"2"],

Cell[TextData[{
  "For most ",
  StyleBox["Control System Professional", "TI"],
  " functions, the input state\[Hyphen]space model must be linear. Therefore, \
our first task will be to linearize the model, that is, represent it in the \
form "
}], "Text",
  CellTags->"2"],

Cell[BoxData[
    FormBox[
      StyleBox[GridBox[{
            {
              StyleBox[
                RowBox[{
                  OverscriptBox[
                    StyleBox["\<\"x\"\>",
                      "TB"], "."], "=", 
                  RowBox[{
                    StyleBox["\<\"A\"\>",
                      "TB"], "x"}], "+", 
                  RowBox[{
                    StyleBox["\<\"B\"\>",
                      "TB"], "u"}]}],
                "InlineFormula"]},
            {
              StyleBox[
                RowBox[{
                  StyleBox["\<\"y\"\>",
                    "TB"], "=", 
                  RowBox[{
                    StyleBox["\<\"C\"\>",
                      "TB"], "x"}], "+", 
                  RowBox[{
                    StyleBox["\<\"D\"\>",
                      "TB"], "u"}]}],
                "InlineFormula"]}
            },
          ColumnAlignments->{Right}],
        "InlineFormula"], TraditionalForm]], "DisplayFormula",
  CellTags->"2"],

Cell[TextData[{
  "This is the purpose of the function ",
  StyleBox["Linearize", "MR"],
  ", which, given the nonlinear functions ",
  StyleBox["f", "MR"],
  " and ",
  StyleBox["h", "MR"],
  " and the lists of state and input variables, supplied together with values \
at the nominal point (the point in the vicinity of which the linearization \
will take place), returns the control object ",
  StyleBox["StateSpace[a,", "MR"],
  " ",
  StyleBox["b,", "MR"],
  " ",
  StyleBox["c,", "MR"],
  " ",
  StyleBox["d]", "MR"],
  ", where matrices ",
  StyleBox["a", "MR"],
  ", ",
  StyleBox["b", "MR"],
  ", ",
  StyleBox["c", "MR"],
  ", and ",
  StyleBox["d", "MR"],
  " are the coefficients ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"D\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " in the above system of equations.     "
}], "Text",
  CellTags->"2"],

Cell["This performs the linearization. ", "MathCaption",
  CellTags->"2"],

Cell["\<\
ss = Linearize[f, h,
 {{theta[t], 0}, {theta'[t], 0}},
 {{fx, 0}} ]\
\>", "Input",
  CellLabel->"In[17]:=",
  CellTags->"2"],

Cell[BoxData[
    \(StateSpace[
      {{0, 1}, {\(-\(\(3\ \((\(-2\)\ g\ m - 2\ g\ M)\)\)\/\(L\ \((m + 4\ M)
                    \)\)\)\), 0}}, 
      {{0}, {\(-\(6\/\(L\ \((m + 4\ M)\)\)\)\)}}, {{1, 0}}, {{0}}]\)], 
  "Output",
  CellLabel->"Out[17]=",
  CellTags->"2"],

Cell[TextData[{
  "Mapping the built\[Hyphen]in ",
  StyleBox["Mathematica", "TI"],
  " function ",
  StyleBox["Factor", "MR"],
  " onto components of the state\[Hyphen]space object simplifies the result \
somewhat. (Here ",
  StyleBox["/@", "MR"],
  " is a shortcut for the ",
  StyleBox["Map", "MR"],
  " command.) "
}], "MathCaption",
  CellTags->"2"],

Cell["Factor /@ %", "Input",
  CellLabel->"In[18]:=",
  CellTags->"2"],

Cell[BoxData[
    \(StateSpace[{{0, 1}, {\(6\ g\ \((m + M)\)\)\/\(L\ \((m + 4\ M)\)\), 0}}, 
      {{0}, {\(-\(6\/\(L\ \((m + 4\ M)\)\)\)\)}}, {{1, 0}}, {{0}}]\)], 
  "Output",
  CellLabel->"Out[18]=",
  CellTags->"2"],

Cell[TextData[{
  "The function ",
  StyleBox["ReviewForm", "MR"],
  " presents the result in a ",
  StyleBox["MatrixForm", "MR"],
  " fashion and labels the matrices. "
}], "MathCaption",
  CellTags->"2"],

Cell["%//ReviewForm", "Input",
  CellLabel->"In[19]:=",
  CellTags->"2"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "1"},
                  {\(\(6\ g\ \((m + M)\)\)\/\(L\ \((m + 4\ M)\)\)\), "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0"},
                  {\(-\(6\/\(L\ \((m + 4\ M)\)\)\)\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"1", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[19]//ReviewForm=",
  CellTags->"2"],

Cell[TextData[{
  "Now let us design a state feedback controller that will stabilize the \
pendulum in a vertical position near the nominal point. One way to do this is \
to place the poles of the closed\[Hyphen]loop system at some points ",
  Cell[BoxData[
      \(TraditionalForm\`p\_1\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`p\_2\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " on the left\[Hyphen]hand side of the complex plane. "
}], "Text",
  CellTags->"2"],

Cell["\<\
In this particular case, Ackermann's formula (see Section\
\[NonBreakingSpace]9.1) is used. The result is a matrix comprising the \
feedback gains. \
\>", "MathCaption",
  CellTags->"2"],

Cell["K = StateFeedbackGains[ss, {p1, p2}]", "Input",
  CellLabel->"In[20]:=",
  CellTags->"2"],

Cell[BoxData[
    \({{1\/6\ \((\(-6\)\ g\ m - 6\ g\ M - L\ m\ p1\ p2 - 4\ L\ M\ p1\ p2)\), 
        1\/6\ L\ \((m + 4\ M)\)\ \((p1 + p2)\)}}\)], "Output",
  CellLabel->"Out[20]=",
  CellTags->"2"],

Cell[TextData[{
  "Note that we were able to obtain a symbolic solution to this problem and \
thus see immediately that, for example, only the first gain depends on ",
  Cell[BoxData[
      \(TraditionalForm\`g\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " and so would be affected should our pendulum get sent to Mars (and the \
change would be linear in ",
  Cell[BoxData[
      \(TraditionalForm\`g\)], "InlineFormula",
    CellTags->"S0.0.1"],
  "). We also see that the first gain depends on the product of pole values, \
the second gain on their sum, and so on. \nTo check if the pole assignment \
has been performed correctly, we can find the poles of the \
closed\[Hyphen]loop system, that is, the eigenvalues of the matrix ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"A\"\>",
            "TB"], "-", 
          StyleBox["\<\"B\"\>",
            "TB"], 
          StyleBox["\<\"K\"\>",
            "TB"]}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ".  "
}], "Text",
  CellTags->"2"],

Cell[TextData[{
  "This extracts the matrices from their ",
  StyleBox["StateSpace", "MR"],
  " wrapper. "
}], "MathCaption",
  CellTags->"2"],

Cell["a = ss[[1]];  b = ss[[2]];", "Input",
  CellLabel->"In[21]:=",
  CellTags->"2"],

Cell["\<\
We see that the eigenvalues of the closed\[Hyphen]loop system are \
indeed as required. \
\>", "MathCaption",
  CellTags->"2"],

Cell["Eigenvalues[a - b.K]", "Input",
  CellLabel->"In[22]:=",
  CellTags->"2"],

Cell[BoxData[
    \({p1, p2}\)], "Output",
  CellLabel->"Out[22]=",
  CellTags->"2"],

Cell[TextData[{
  "With ",
  StyleBox["Control System Professional", "TI"],
  ", we can also design the state feedback using the optimal \
linear\[Hyphen]quadratic (LQ) regulator (see ",
  ButtonBox["Chapter 10",
    ButtonData:>{"Linear Quadratic Regulator"},
    ButtonStyle->"AddOnsLink"],
  "). This approach is more computationally intensive, so it is advisable to \
work with inexact numeric input. "
}], "Text",
  CellTags->"2"],

Cell["\<\
This is the particular set of numeric values (all in SI) we will \
use. \
\>", "MathCaption",
  CellTags->"2"],

Cell["\<\
numericValues = {
 m -> 2.,
 M -> 8.,
 L -> 1.,
 g -> 9.8,
 p1 -> -4.,
 p2 -> -5.
}\
\>", "Input",
  CellLabel->"In[23]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"m", "\[Rule]", 
          StyleBox["2.`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", 
        RowBox[{"M", "\[Rule]", 
          StyleBox["8.`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", 
        RowBox[{"L", "\[Rule]", 
          StyleBox["1.`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1]}], ",", 
        RowBox[{"g", "\[Rule]", 
          StyleBox["9.80000000000000071`",
            StyleBoxAutoDelete->True,
            PrintPrecision->2]}], ",", 
        RowBox[{"p1", "\[Rule]", 
          RowBox[{"-", 
            StyleBox["4.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}]}], ",", 
        RowBox[{"p2", "\[Rule]", 
          RowBox[{"-", 
            StyleBox["5.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->1]}]}]}], "}"}]], "Output",
  CellLabel->"Out[23]=",
  CellTags->"2"],

Cell["Here our system is numericalized. ", "MathCaption",
  CellTags->"2"],

Cell["nss = ss /. numericValues", "Input",
  CellLabel->"In[24]:=",
  CellTags->"2"],

Cell[BoxData[
    \(StateSpace[{{0, 1}, {17.2941176470588242`, 0}}, 
      {{0}, {\(-0.176470588235294112`\)}}, {{1, 0}}, {{0}}]\)], "Output",
  CellLabel->"Out[24]=",
  CellTags->"2"],

Cell[TextData[{
  "Let ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"Q\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"R\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  " be identity matrices. "
}], "MathCaption",
  CellTags->"2"],

Cell["Q = IdentityMatrix[2]", "Input",
  CellLabel->"In[25]:=",
  CellTags->"2"],

Cell[BoxData[
    \({{1, 0}, {0, 1}}\)], "Output",
  CellLabel->"Out[25]=",
  CellTags->"2"],

Cell["R = {{1}}", "Input",
  CellLabel->"In[26]:=",
  CellTags->"2"],

Cell[BoxData[
    \({{1}}\)], "Output",
  CellLabel->"Out[26]=",
  CellTags->"2"],

Cell[TextData[{
  StyleBox["LQRegulatorGains", "MR"],
  " solves the Riccati equations and returns the corresponding gain matrix. "
}], "MathCaption",
  CellTags->"2"],

Cell["LQRegulatorGains[nss, Q, R]", "Input",
  CellLabel->"In[27]:=",
  CellTags->"2"],

Cell[BoxData[
    \({{\(-196.005101908016658`\), \(-47.1422438472922245`\)}}\)], "Output",
  CellLabel->"Out[27]=",
  CellTags->"2"],

Cell["\<\
Here are the poles our system will possess when we close the loop. \
\
\>", "MathCaption",
  CellTags->"2"],

Cell["Eigenvalues[a - b.% /. numericValues]", "Input",
  CellLabel->"In[28]:=",
  CellTags->"2"],

Cell[BoxData[
    \({\(-4.24525611002133018`\), \(-4.07396339244200333`\)}\)], "Output",
  CellLabel->"Out[28]=",
  CellTags->"2"],

Cell[TextData[{
  "Let us make some simulations of the linearized system as well as the \
original, nonlinear system stabilized with one of the controllers we have \
designed\[LongDash]say the one obtained with Ackermann's formula. We start \
with the linearized system and compute the transient response of the system \
for the initial values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0)\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " of 0.5, 1, and 1.2, assuming in all cases that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\[Theta]\& . \)(0) = 0\)\)\)], 
    "InlineFormula",
    CellTags->"S0.0.1"],
  ". The same initial conditions will then be used for the nonlinear system, \
and the results will be compared. "
}], "Text",
  CellTags->"2"],

Cell[TextData[{
  "Here is the list of initial conditions for ",
  StyleBox["theta", "MR"],
  ". "
}], "MathCaption",
  CellTags->"2"],

Cell["theta0 = {.5, 1., 1.2}", "Input",
  CellLabel->"In[29]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        StyleBox["0.5`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], ",", 
        StyleBox["1.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->1], ",", 
        StyleBox["1.19999999999999996`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2]}], "}"}]], "Output",
  CellLabel->"Out[29]=",
  CellTags->"2"],

Cell[TextData[{
  "This is the linearized system after the closing state feedback. ",
  StyleBox["StateFeedbackConnect", "MR"],
  " is described in ",
  ButtonBox["Chapter 6",
    ButtonData:>{"State Feedback"},
    ButtonStyle->"AddOnsLink"],
  " together with other functions for interconnecting systems. "
}], "MathCaption",
  CellTags->"2"],

Cell["StateFeedbackConnect[ss, K]//Simplify", "Input",
  CellLabel->"In[30]:=",
  CellTags->"2"],

Cell[BoxData[
    \(StateSpace[{{0, 1}, {\(-p1\)\ p2, p1 + p2}}, 
      {{0}, {\(-\(6\/\(L\ \((m + 4\ M)\)\)\)\)}}, {{1, 0}}, {{0}}]\)], 
  "Output",
  CellLabel->"Out[30]=",
  CellTags->"2"],

Cell[TextData[{
  "To compute how the initial condition in ",
  StyleBox["theta", "MR"],
  " decays in the absence of an input signal, we can use ",
  StyleBox["OutputResponse", "MR"],
  ", which is one of the functions defined in ",
  ButtonBox["Chapter 4",
    ButtonData:>{"Symbolic Solution for Time-Domain Response"},
    ButtonStyle->"AddOnsLink"],
  ".  "
}], "Text",
  CellTags->"2"],

Cell[TextData[{
  "In this particular case, the input arguments to ",
  StyleBox["OutputResponse", "MR"],
  " are the system to be analyzed, the input signal (which is ",
  StyleBox["0", "MR"],
  " for all ",
  StyleBox["t", "MR"],
  "), the time variable ",
  StyleBox["t", "MR"],
  ", and the initial conditions for the state variables supplied as an \
option. The initial value for ",
  StyleBox["theta", "MR"],
  " is denoted as ",
  StyleBox["angle", "MR"],
  ". "
}], "MathCaption",
  CellTags->"2"],

Cell["\<\
OutputResponse[%, 0, t,
 InitialConditions -> {angle, 0}]\
\>", "Input",
  CellLabel->"In[31]:=",
  CellTags->"2"],

Cell[BoxData[
    \({\(angle\ \((E\^\(p2\ t\)\ p1 - E\^\(p1\ t\)\ p2)\)\)\/\(p1 - p2\)}\)], 
  "Output",
  CellLabel->"Out[31]=",
  CellTags->"2"],

Cell[TextData[{
  "Here is the plot of the previous function for the chosen values ",
  StyleBox["theta0", "MR"],
  ". We store it as ",
  StyleBox["plot", "MR"],
  " for future reference. "
}], "MathCaption",
  CellTags->"2"],

Cell["\<\
plot = Plot[
 Evaluate[% /. numericValues /. angle -> theta0],
 {t, 0, 4},
 PlotStyle -> RGBColor[1,0,0]
]\
\>", "Input",
  CellLabel->"In[32]:=",
  CellTags->"2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 0.490503 [
[.2619 .00222 -3 -9 ]
[.2619 .00222 3 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .11282 -18 -4.5 ]
[.01131 .11282 0 4.5 ]
[.01131 .21092 -18 -4.5 ]
[.01131 .21092 0 4.5 ]
[.01131 .30902 -18 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .40712 -18 -4.5 ]
[.01131 .40712 0 4.5 ]
[.01131 .50522 -6 -4.5 ]
[.01131 .50522 0 4.5 ]
[.01131 .60332 -18 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.2619 .01472 m
.2619 .02097 L
s
[(1)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(2)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(3)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(4)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11282 m
.03006 .11282 L
s
[(0.2)] .01131 .11282 1 0 Mshowa
.02381 .21092 m
.03006 .21092 L
s
[(0.4)] .01131 .21092 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(0.6)] .01131 .30902 1 0 Mshowa
.02381 .40712 m
.03006 .40712 L
s
[(0.8)] .01131 .40712 1 0 Mshowa
.02381 .50522 m
.03006 .50522 L
s
[(1)] .01131 .50522 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1.2)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .03924 m
.02756 .03924 L
s
.02381 .06377 m
.02756 .06377 L
s
.02381 .08829 m
.02756 .08829 L
s
.02381 .13734 m
.02756 .13734 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .18639 m
.02756 .18639 L
s
.02381 .23544 m
.02756 .23544 L
s
.02381 .25997 m
.02756 .25997 L
s
.02381 .28449 m
.02756 .28449 L
s
.02381 .33354 m
.02756 .33354 L
s
.02381 .35807 m
.02756 .35807 L
s
.02381 .38259 m
.02756 .38259 L
s
.02381 .43164 m
.02756 .43164 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .48069 m
.02756 .48069 L
s
.02381 .52974 m
.02756 .52974 L
s
.02381 .55427 m
.02756 .55427 L
s
.02381 .57879 m
.02756 .57879 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .25997 m
.02499 .25991 L
.02605 .25975 L
.02729 .25947 L
.02846 .25909 L
.03053 .25817 L
.03279 .25685 L
.0379 .25276 L
.04262 .24785 L
.06244 .21965 L
.10458 .15051 L
.1249 .1217 L
.14393 .09897 L
.16333 .07999 L
.18177 .06546 L
.20201 .0529 L
.22054 .04396 L
.24034 .03658 L
.25873 .03134 L
.27925 .0269 L
.29786 .02388 L
.31711 .02153 L
.33793 .01964 L
.35787 .01831 L
.37893 .01729 L
.39857 .0166 L
.4169 .01612 L
.43725 .01573 L
.45581 .01547 L
.4749 .01527 L
.49566 .01511 L
.51543 .015 L
.53644 .01492 L
.55591 .01486 L
.57419 .01482 L
.59437 .01479 L
.61288 .01477 L
.6318 .01476 L
.6525 .01475 L
.67211 .01474 L
.69306 .01473 L
.71441 .01473 L
.73456 .01472 L
.75457 .01472 L
.77302 .01472 L
.79179 .01472 L
.81243 .01472 L
.83188 .01472 L
.85277 .01472 L
.87394 .01472 L
Mistroke
.89404 .01472 L
.91389 .01472 L
.93229 .01472 L
.95285 .01472 L
.97147 .01472 L
.97619 .01472 L
Mfstroke
.02381 .50522 m
.02499 .5051 L
.02605 .50479 L
.02729 .50422 L
.02846 .50346 L
.03053 .50162 L
.03279 .49899 L
.0379 .49081 L
.04262 .48098 L
.06244 .42458 L
.10458 .28631 L
.1249 .22869 L
.14393 .18323 L
.16333 .14526 L
.18177 .11621 L
.20201 .09108 L
.22054 .0732 L
.24034 .05845 L
.25873 .04796 L
.27925 .03909 L
.29786 .03305 L
.31711 .02834 L
.33793 .02456 L
.35787 .02191 L
.37893 .01987 L
.39857 .01849 L
.4169 .01753 L
.43725 .01674 L
.45581 .01622 L
.4749 .01582 L
.49566 .0155 L
.51543 .01529 L
.53644 .01512 L
.55591 .01501 L
.57419 .01493 L
.59437 .01487 L
.61288 .01483 L
.6318 .0148 L
.6525 .01477 L
.67211 .01476 L
.69306 .01475 L
.71441 .01474 L
.73456 .01473 L
.75457 .01473 L
.77302 .01472 L
.79179 .01472 L
.81243 .01472 L
.83188 .01472 L
.85277 .01472 L
.87394 .01472 L
Mistroke
.89404 .01472 L
.91389 .01472 L
.93229 .01472 L
.95285 .01472 L
.97147 .01472 L
.97619 .01472 L
Mfstroke
.02381 .60332 m
.02499 .60318 L
.02605 .60281 L
.02729 .60212 L
.02846 .6012 L
.03053 .59901 L
.03279 .59584 L
.0379 .58603 L
.04262 .57423 L
.06244 .50655 L
.10458 .34063 L
.1249 .27148 L
.14393 .21694 L
.16333 .17137 L
.18177 .13651 L
.20201 .10635 L
.22054 .0849 L
.24034 .0672 L
.25873 .05461 L
.27925 .04397 L
.29786 .03672 L
.31711 .03106 L
.33793 .02653 L
.35787 .02335 L
.37893 .0209 L
.39857 .01924 L
.4169 .01809 L
.43725 .01715 L
.45581 .01652 L
.4749 .01604 L
.49566 .01566 L
.51543 .0154 L
.53644 .0152 L
.55591 .01507 L
.57419 .01498 L
.59437 .0149 L
.61288 .01485 L
.6318 .01482 L
.6525 .01479 L
.67211 .01477 L
.69306 .01475 L
.71441 .01474 L
.73456 .01473 L
.75457 .01473 L
.77302 .01472 L
.79179 .01472 L
.81243 .01472 L
.83188 .01472 L
.85277 .01472 L
.87394 .01472 L
Mistroke
.89404 .01472 L
.91389 .01472 L
.93229 .01472 L
.95285 .01472 L
.97147 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[32]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001COol5
000mOol3000nOol2000oOol30006Ool005Eoo`03001oogoo03eoo`03001oogoo041oo`03001oogoo
03eoo`03001oogoo00Eoo`00EGoo00<007ooOol0?Woo00<007ooOol0?Woo00<007ooOol0?7oo1000
1Woo001EOol00`00Oomoo`0nOol00`00Oomoo`0oOol00`00Oomoo`0kOol00`00Ool00007Ool005Eo
o`03001oogoo03eoo`03001oo`0003ioo`03001oo`0003ioo`8000Moo`00E7oo0P00@7oo00<007oo
Ool0?Woo00<007ooOol0?Woo00<007ooOol01Goo003oOolQOol001Eoo`03001oogoo0?moo`Uoo`00
5Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`00
3gooJP00X7`01P000Goo000EOol00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`02OolPO002Ool00`00Oomoo`09
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:
Ool00`00Oomoo`05Ool001Eoo`03001oogoo03ioo`03001oogoo00Eoo`Yl00Ioo`]l01eoo`03001o
ogoo03ioo`03001oogoo03ioo`03001oogoo00Eoo`005Goo00<007ooOol0@7oo1W`02Woo1W`0/Woo
000EOol00`00Oomoo`0lOol4O00;Ool5O02hOol001Eoo`03001oogoo03Yoo`9l00]oo`El0;aoo`00
5Goo00<007ooOol0=goo0g`02Woo1W`0_Woo000EOol2000eOol3O00:Ool6O031Ool001Eoo`03001o
ogoo035oo`=l00]oo`9l0003Ooml07`00<Aoo`005Goo00<007ooOol0;goo0W`037oo0W`000=oog`0
O000aWoo000EOol00`00Oomoo`0]Ool2O00<Ool2O0000gooO01l0038Ool001Eoo`03001oogoo02ao
o`03O01oogoo00Yoo`9l009oo`03O01oogoo0<Qoo`005Goo00<007ooOol0:Woo0W`037oo00=l07oo
Ool00W`0bgoo000EOol2000ZOol00g`0Oomoo`0:Ool2O0000gooO01l003=Ool001Eoo`03001oogoo
02Qoo`03O01oogoo00Yoo`04O01oogooO03?Ool001Eoo`03001oogoo02Moo`03O01oogoo00Uoo`9l
009oo`03O01oogoo0<ioo`005Goo00<007ooOol09Goo0W`02goo00El07ooOomoog`00=5oo`005Goo
00<007ooOol097oo00=l07ooOol02Woo00=l07ooOol00W`0dWoo000EOol00`00Oomoo`0SOol00g`0
Oomoo`0:Ool017`0Oomoog`0e7oo000EOol00`00Oomoo`0ROol00g`0Oomoo`0:Ool017`0Oomoog`0
eGoo000EOol2000ROol00g`0Oomoo`0:Ool017`0Oomoog`0eWoo000EOol00`00Oomoo`0POol00g`0
Oomoo`0:Ool017`0Oomoog`0egoo000EOol00`00Oomoo`0OOol00g`0Oomoo`0:Ool017`0Oomoog`0
f7oo000EOol00`00Oomoo`0NOol00g`0Oomoo`0;Ool017`0Oomoog`0f7oo000EOol00`00Oomoo`0M
Ool00g`0Oomoo`0;Ool017`0Oomoog`0fGoo0005Ool00`00Oomoo`02Ool01000Oomoogoo0`0017oo
00<007ooOol077oo00=l07ooOol02goo00Al07ooOoml0=Yoo`0017oo00<007oo00001goo00<007oo
Ool017oo00<007ooOol06goo00=l07ooOol02goo00Al07ooOoml0=]oo`0017oo00<007oo000027oo
00<007ooOol00goo0`006Woo00=l07ooOol037oo00Al07ooOoml0=]oo`0017oo00<007oo000027oo
00<007ooOol00goo00<007ooOol06Goo00=l07ooOol037oo00Al07ooOoml0=aoo`0017oo00<007oo
00001goo00<007oo000017oo00<007ooOol067oo00=l07ooOol037oo00Al07ooOoml0=eoo`001Goo
00<007ooOol01goo00<007ooOol00goo00<007ooOol05goo00=l07ooOol03Goo00Al07ooOoml0=eo
o`005Goo00<007ooOol05goo00=l07ooOol037oo00Al07ooOoml0=ioo`005Goo00<007ooOol05Woo
00=l07ooOol037oo00El07ooOomoog`00=ioo`005Goo0P005Woo00=l07ooOol037oo00El07ooOomo
og`00=moo`005Goo00<007ooOol05Goo00=l07ooOol037oo00Al07ooOoml0>1oo`005Goo00<007oo
Ool057oo00=l07ooOol037oo00El07ooOomoog`00>1oo`005Goo00<007ooOol057oo00=l07ooOol0
37oo00Al07ooOoml0>5oo`005Goo00<007ooOol04goo00=l07ooOol037oo00El07ooOomoog`00>5o
o`005Goo00<007ooOol04Woo00=l07ooOol03Goo00Al07ooOoml0>9oo`005Goo00<007ooOol04Woo
00=l07ooOol037oo00El07ooOomoog`00>9oo`005Goo0P004Woo00=l07ooOol03Goo00Al07ooOoml
0>=oo`005Goo00<007ooOol047oo00=l07ooOol03Goo00El07ooOomoog`00>=oo`005Goo00<007oo
Ool047oo00=l07ooOol03Goo00Al07ooOoml0>Aoo`005Goo00<007ooOol03goo00=l07ooOol03Goo
00El07ooOomoog`00>Aoo`005Goo00<007ooOol03goo00=l07ooOol03Goo00El07ooOomoog`00>Ao
o`005Goo00<007ooOol03Woo00=l07ooOol03Goo00El07ooOomoog`00>Eoo`005Goo00<007ooOol0
3Goo00=l07ooOol03Woo00El07ooOomoog`00>Eoo`005Goo0P003Woo00=l07ooOol03Goo00El07oo
Oomoog`00>Ioo`005Goo00<007ooOol037oo00=l07ooOol03Woo00El07ooOomoog`00>Ioo`005Goo
00<007ooOol02goo00=l07ooOol03Woo00El07ooOomoog`00>Moo`005Goo00<007ooOol02goo00=l
07ooOol03Woo00El07ooOomoog`00>Moo`001Goo00<007ooOol00Woo00<007ooOol00Woo0`000goo
00<007ooOol02Woo00=l07ooOol03Woo00=l07ooOol00Woo00=l07ooOol0iGoo0004Ool00`00Ool0
0009Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00g`0Oomoo`0>Ool01G`0OomoogooO000j7oo0004
Ool00`00Ool00007Ool40003Ool30009Ool00g`0Oomoo`0>Ool00g`0Oomoo`02Ool00g`0Oomoo`3V
Ool000Aoo`03001oo`0000Moo`03001oo`0000Aoo`03001oogoo00Qoo`03O01oogoo00moo`05O01o
ogooOoml003YOol000Aoo`03001oo`0000Qoo`8000Aoo`03001oogoo00Qoo`03O01oogoo00ioo`03
O01oogoo009oo`03O01oogoo0>Moo`001Goo00<007ooOol027oo00<007ooOol00Woo00<007ooOol0
1goo00=l07ooOol03goo00=l07ooOol00Woo00=l07ooOol0igoo000EOol00`00Oomoo`06Ool00g`0
Oomoo`0?Ool00g`0Oomoo`02Ool00g`0Oomoo`3XOol001Eoo`03001oogoo00Ioo`03O01oogoo00mo
o`03O01oogoo009oo`03O01oogoo0>Qoo`005Goo00<007ooOol01Goo00=l07ooOol047oo00El07oo
Oomoog`00>]oo`005Goo0P001Goo00=l07ooOol047oo00=l07ooOol00Woo00=l07ooOol0jGoo000E
Ool00`00Oomoo`03Ool00g`0Oomoo`0AOol00g`0Oomoo`02Ool00g`0Oomoo`3YOol001Eoo`03001o
ogoo00=oo`03O01oogoo015oo`05O01oogooOoml003/Ool001Eoo`03001oogoo009oo`03O01oogoo
015oo`03O01oogoo009oo`03O01oogoo0>Yoo`005Goo00D007ooOomoog`001Aoo`05O01oogooOoml
003]Ool001Eoo`05001oogooOoml000DOol01G`0OomoogooO000kGoo000EOol01000O01l07`057oo
00=l07ooOol00Woo00=l07ooOol0jgoo000EOol2O00FOol01G`0OomoogooO000kWoo000EOol00`00
Oomoo`0EOol01G`0OomoogooO000kWoo000EOol00`00Oomoo`0EOol017`0Oomoog`0kgoo000EOol0
0`00Oomoo`0DOol01G`0OomoogooO000kgoo000EOol00`00Oomoo`0DOol01G`0OomoogooO000kgoo
000EOol00`00Oomoo`0DOol017`0Oomoog`0l7oo000EOol2000DOol01G`0OomoogooO000l7oo000E
Ool00`00Oomoo`0COol01G`0OomoogooO000l7oo000EOol00`00Oomoo`0COol01G`0OomoogooO000
l7oo000EOol00`00Oomoo`0BOol01G`0OomoogooO000lGoo000EOol00`00Oomoo`0BOol01G`0Oomo
ogooO000lGoo0005Ool00`00Oomoo`02Ool01000Oomoogoo0P001Goo00<007ooOol04Woo00El07oo
Oomoog`00?5oo`0017oo00<007oo00001goo00<007oo000017oo00<007ooOol04Goo00=l07ooOol0
0Woo00=l07ooOol0kgoo0004Ool00`00Ool00007Ool00`00Ool00004Ool3000AOol01G`0Oomoogoo
O000lWoo0004Ool00`00Ool00007Ool20005Ool00`00Oomoo`0AOol01G`0OomoogooO000lWoo0004
Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool00g`0Oomoo`02Ool00g`0Oomoo`3`
Ool000Eoo`03001oogoo00Moo`8000Aoo`03001oogoo011oo`03O01oogoo009oo`03O01oogoo0?1o
o`005Goo00<007ooOol047oo00El07ooOomoog`00?=oo`005Goo00<007ooOol03goo00=l07ooOol0
0Woo00=l07ooOol0lGoo000EOol00`00Oomoo`0?Ool00g`0Oomoo`02Ool00g`0Oomoo`3aOol001Eo
o`80011oo`03O01oogoo009oo`03O01oogoo0?5oo`005Goo00<007ooOol03Woo00=l07ooOol00Woo
00=l07ooOol0lWoo000EOol00`00Oomoo`0>Ool00g`0Oomoo`02Ool00g`0Oomoo`3bOol001Eoo`03
001oogoo00ioo`03O01oogoo009oo`03O01oogoo0?9oo`005Goo00<007ooOol03Goo00=l07ooOol0
0Woo00=l07ooOol0lgoo000EOol00`00Oomoo`0=Ool00g`0Oomoo`02Ool00g`0Oomoo`3cOol001Eo
o`8000ioo`03O01oogoo009oo`03O01oogoo0?=oo`005Goo00<007ooOol03Goo00=l07ooOol00Woo
00=l07ooOol0lgoo000EOol00`00Oomoo`0<Ool00g`0Oomoo`02Ool00g`0Oomoo`3dOol001Eoo`03
001oogoo00aoo`03O01oogoo009oo`03O01oogoo0?Aoo`005Goo00<007ooOol037oo00=l07ooOol0
0Woo00=l07ooOol0m7oo000EOol00`00Oomoo`0;Ool00g`0Oomoo`03Ool00g`0Oomoo`3dOol001Eo
o`03001oogoo00]oo`03O01oogoo009oo`03O01oogoo0?Eoo`005Goo0P0037oo00=l07ooOol00Woo
00=l07ooOol0mGoo000EOol00`00Oomoo`0:Ool00g`0Oomoo`03Ool00g`0Oomoo`3eOol001Eoo`03
001oogoo00Yoo`03O01oogoo00=oo`03O01oogoo0?Eoo`005Goo00<007ooOol02Woo00=l07ooOol0
0Woo00=l07ooOol0mWoo000EOol00`00Oomoo`09Ool00g`0Oomoo`03Ool00g`0Oomoo`3fOol000Eo
o`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Uoo`03O01oogoo00=o
o`03O01oogoo0?Ioo`0017oo00<007oo00001goo00<007oo000017oo00<007ooOol02Goo00=l07oo
Ool00Woo00=l07ooOol0mgoo0004Ool00`00Ool00007Ool00`00Ool00004Ool30008Ool00g`0Oomo
o`03Ool00g`0Oomoo`3gOol000Aoo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo00Qoo`03
O01oogoo00=oo`03O01oogoo0?Moo`0017oo00<007oo00001goo00<007oo000017oo00<007ooOol0
27oo00=l07ooOol00goo00=l07ooOol0mgoo0005Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00
Oomoo`07Ool00g`0Oomoo`03Ool00g`0Oomoo`3hOol001Eoo`03001oogoo00Moo`03O01oogoo00=o
o`03O01oogoo0?Qoo`005Goo00<007ooOol01goo00=l07ooOol00goo00=l07ooOol0n7oo000EOol2
0007Ool00g`0Oomoo`04Ool00g`0Oomoo`3hOol001Eoo`03001oogoo00Ioo`03O01oogoo00=oo`03
O01oogoo0?Uoo`005Goo00<007ooOol01Woo00=l07ooOol00goo00=l07ooOol0nGoo000EOol00`00
Oomoo`05Ool00g`0Oomoo`04Ool00g`0Oomoo`3iOol001Eoo`03001oogoo00Eoo`03O01oogoo00Ao
o`03O01oogoo0?Uoo`005Goo00<007ooOol01Goo00=l07ooOol00goo00=l07ooOol0nWoo000EOol0
0`00Oomoo`04Ool00g`0Oomoo`04Ool00g`0Oomoo`3jOol001Eoo`8000Eoo`03O01oogoo00Aoo`03
O01oogoo0?Yoo`005Goo00<007ooOol017oo00=l07ooOol00goo00=l07ooOol0ngoo000EOol00`00
Oomoo`04Ool00g`0Oomoo`03Ool00g`0Oomoo`3kOol001Eoo`03001oogoo00=oo`03O01oogoo00Ao
o`03O01oogoo0?]oo`005Goo00<007ooOol00goo00=l07ooOol017oo00=l07ooOol0ngoo000EOol0
0`00Oomoo`03Ool00g`0Oomoo`03Ool00g`0Oomoo`3lOol001Eoo`03001oogoo009oo`03O01oogoo
00Aoo`03O01oogoo0?aoo`005Goo0P000goo00=l07ooOol017oo00=l07ooOol0o7oo000EOol01@00
OomoogooO0001goo00=l07ooOol0o7oo000EOol01@00OomoogooO0001Woo00=l07ooOol0oGoo000E
Ool01000Oomoog`01goo00=l07ooOol0oGoo000=Ool50003Ool01000Oomoog`01goo00=l07ooOol0
oGoo000?Ool00`00Oomoo`03Ool00`00Ooml0008Ool00g`0Oomoo`3mOol000moo`03001oogoo00=o
o`9l0003001oogoo00Eoo`03O01oogoo0?ioo`003goo00<007ooOol00goo00<007ooOol01goo00=l
07ooOol0oWoo000?Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00g`0Oomoo`3nOol000ioo`8000Eo
o`03001oogoo00Ioo`03O01oogoo0?moo`005Goo00<007ooOol01Woo00=l07ooOol0ogoo000EOol0
0`00Oomoo`06Ool00g`0Oomoo`3oOol001Eoo`03001oogoo00Ioo`03O01oogoo0?moo`005Goo0P00
1Woo00=l07ooOol0ogoo0Goo000EOol00`00Oomoo`05Ool00g`0Oomoo`3oOol1Ool001Eoo`03001o
ogoo00Eoo`03O01oogoo0?moo`5oo`005Goo00<007ooOol017oo00=l07ooOol0ogoo0Woo000EOol0
0`00Oomoo`04Ool00g`0Oomoo`3oOol2Ool001Eoo`03001oogoo00Aoo`03O01oogoo0?moo`9oo`00
5Goo00<007ooOol017oo00=l07ooOol0ogoo0Woo000EOol20004Ool00g`0Oomoo`3oOol3Ool001Eo
o`03001oogoo00=oo`03O01oogoo0?moo`=oo`005Goo00<007ooOol00goo00=l07ooOol0ogoo0goo
000EOol00`00Oomoo`03Ool00g`0Oomoo`3oOol3Ool001Eoo`03001oogoo009oo`03O01oogoo0?mo
o`Aoo`005Goo00<007ooOol00Woo00=l07ooOol0ogoo17oo000EOol20003Ool00g`0Oomoo`3oOol4
Ool001Eoo`05001oogooOoml003oOol7Ool001Eoo`05001oogooOoml003oOol7Ool001Eoo`04001o
ogooO03oOol8Ool001Eoo`04001oogooO03oOol8Ool000=oo`D0009oo`04001oogooOol30004Ool0
0`00Ooml003oOol9Ool000Eoo`03001oogoo00Ioo`03001oogoo00Aoo`03001l07`00?moo`Uoo`00
1Goo00<007ooOol01goo00<007ooOol00goo0W`000<007ooOol0ogoo1goo0005Ool00`00Oomoo`07
Ool00`00Oomoo`03Ool00`00Oomoo`3oOol9Ool000Eoo`03001oogoo00Ioo`03001oo`0000Aoo`03
001oogoo0?moo`Uoo`0017oo0P002Goo00<007ooOol00goo00<007ooOol0ogoo2Goo000EOol00`00
Oomoo`3oOol9Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.331941, -0.0929641, 
  0.0154472, 0.00749821}},
  CellTags->"2"],

Cell[TextData[{
  "The case of actual nonlinear system stabilized with the linear controller \
is more interesting, but requires some work on our part. We note that when \
the control loop is closed, the input variable\[LongDash]the force ",
  Cell[BoxData[
      \(TraditionalForm\`f\_x\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " applied by the motor of the cart\[LongDash]tracks changes in state \
variables ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](t)\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\[Theta]\& . \)(t)\)\)\)], 
    "InlineFormula",
    CellTags->"S0.0.1"],
  ". "
}], "Text",
  CellTags->"2"],

Cell["\<\
First we prepare the input rules. As we have only one input, there \
is only one rule in the list. \
\>", "MathCaption",
  CellTags->"2"],

Cell["feedbackRules = Thread[u -> - K.x] /. numericValues", "Input",
  CellLabel->"In[33]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"fx", "\[Rule]", 
        RowBox[{\(211.333333333333373`\ theta[t]\), "+", 
          RowBox[{"50.9999999999999964`", " ", 
            RowBox[{
              SuperscriptBox["theta", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]], 
  "Output",
  CellLabel->"Out[33]=",
  CellTags->"2"],

Cell[TextData[{
  "Recall that we store the description of our nonlinear system as ",
  StyleBox["sln", "MR"],
  ". "
}], "MathCaption",
  CellTags->"2"],

Cell["sln", "Input",
  CellLabel->"In[34]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["theta", "\[DoublePrime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{"-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"3", " ", 
              RowBox[{"(", 
                RowBox[{
                \(2\ fx\ Cos[theta[t]]\), "-", \(2\ g\ m\ Sin[theta[t]]\), 
                  "-", \(2\ g\ M\ Sin[theta[t]]\), "+", 
                  RowBox[{
                  "L", " ", "m", " ", \(Cos[theta[t]]\), " ", 
                    \(Sin[theta[t]]\), " ", 
                    SuperscriptBox[
                      RowBox[{
                        SuperscriptBox["theta", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], "2"]}]}]
                  , ")"}]}], ")"}], "/", 
          \((L\ \((m + M + 3\ M\ Cos[theta[t]]\^2 + 3\ m\ Sin[theta[t]]\^2 + 
                  3\ M\ Sin[theta[t]]\^2)\))\)}]}]}]], "Output",
  CellLabel->"Out[34]=",
  CellTags->"2"],

Cell[TextData[{
  "Now we numericalize the rule, substitute the feedback rules, and, to \
convert the rule to an equation, apply the head ",
  StyleBox["Equal", "MR"],
  " to it (",
  StyleBox["@@", "MR"],
  " is the shorthand form of the ",
  StyleBox["Apply", "MR"],
  " function). The resultant differential equation is labeled ",
  StyleBox["de", "MR"],
  ". "
}], "MathCaption",
  CellTags->"2"],

Cell["de = Equal @@ sln /. numericValues /. feedbackRules", "Input",
  CellLabel->"In[35]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["theta", "\[DoublePrime]",
          MultilineFunction->None], "[", "t", "]"}], "==", 
      RowBox[{"-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"3.`", " ", 
              RowBox[{"(", 
                RowBox[{\(\(-196.000000000000014`\)\ Sin[theta[t]]\), "+", 
                  RowBox[{
                  "2.`", " ", \(Cos[theta[t]]\), " ", \(Sin[theta[t]]\), 
                    " ", 
                    SuperscriptBox[
                      RowBox[{
                        SuperscriptBox["theta", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], "2"]}], 
                  "+", 
                  RowBox[{"2", " ", \(Cos[theta[t]]\), " ", 
                    RowBox[{"(", 
                      RowBox[{\(211.333333333333373`\ theta[t]\), "+", 
                        RowBox[{"50.9999999999999964`", " ", 
                          RowBox[{
                            SuperscriptBox["theta", "\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}]}]}], 
                      ")"}]}]}], ")"}]}], ")"}], "/", 
          \((\(\(10.`\)\(\[InvisibleSpace]\)\) + 
              24.0000000000000035`\ Cos[theta[t]]\^2 + 30.`\ Sin[theta[t]]\^2)
            \)}]}]}]], "Output",
  CellLabel->"Out[35]=",
  CellTags->"2"],

Cell[TextData[{
  "This solves the differential equation with the initial conditions for \
every value in the list ",
  StyleBox["theta0", "MR"],
  " one by one and returns a list of solutions. The time ",
  StyleBox["t", "MR"],
  " is assumed to vary from 0 to 4 seconds. "
}], "MathCaption",
  CellTags->"2"],

Cell["\<\
thetas = NDSolve[
 {de, theta[0]==#, theta'[0]==0},
 {theta},
 {t, 0, 4}
]& /@ theta0\
\>", "Input",
  CellLabel->"In[36]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"theta", "\[Rule]", 
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False]}], "}"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"theta", "\[Rule]", 
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False]}], "}"}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            RowBox[{"theta", "\[Rule]", 
              TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
                False,
                Editable->False]}], "}"}], "}"}]}], "}"}]], "Output",
  CellLabel->"Out[36]=",
  CellTags->"2"],

Cell[TextData[{
  "We are preparing to show the results for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0) = 0\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " as a solid line, for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0) = 1\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " as a dashed\[Hyphen]dotted one, and for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0) = 1.2\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " as a dashed line. Here is the ",
  StyleBox["PlotStyle", "MR"],
  " realization of this convention and a few other nonautomatic values of \
choice for plot options. "
}], "MathCaption",
  CellTags->"2"],

Cell["\<\
someOptions = {
 PlotStyle -> {
 \tThickness[.001],
\tDashing[{.025, .0075, .0075, .0075}],
\tDashing[{.01, .01}]
 },
 Frame -> {Automatic, Automatic, None, None},
 FrameLabel -> {\"Time (s)\", None}
}\
\>", "Input",
  CellLabel->"In[37]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"Thickness", "[", 
                StyleBox["0.001`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1], "]"}], ",", 
              RowBox[{"Dashing", "[", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox["0.025`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->2], ",", 
                    StyleBox["0.0075`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->2], ",", 
                    StyleBox["0.0075`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->2], ",", 
                    StyleBox["0.0075`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->2]}], "}"}], "]"}], ",", 
              RowBox[{"Dashing", "[", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox["0.01`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->1], ",", 
                    StyleBox["0.01`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->1]}], "}"}], "]"}]}], "}"}]}], ",", 
        \(Frame \[Rule] {Automatic, Automatic, None, None}\), ",", 
        \(FrameLabel \[Rule] {"Time (s)", None}\)}], "}"}]], "Output",
  CellLabel->"Out[37]=",
  CellTags->"2"],

Cell[TextData[{
  "The results for ",
  StyleBox["theta", "MR"],
  " are now presented graphically. We can see that the controller succeeds in \
driving the pendulum to its equilibrium position for all three initial \
displacements. The plot is stored as ",
  StyleBox["plot1", "MR"],
  ". "
}], "MathCaption",
  CellTags->"2"],

Cell["\<\
plot1 = Plot[Evaluate[theta[t] /. thetas],
 {t, 0, 4},
 PlotLabel -> \"Theta (radian)\",
 Evaluate[someOptions]
]\
\>", "Input",
  CellLabel->"In[38]:=",
  CellTags->"2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 0.490503 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -18 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -18 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -18 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -6 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(0.2)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(0.4)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.6)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(0.8)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(1)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1.2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03924 m
.00375 .03924 L
s
0 .06377 m
.00375 .06377 L
s
0 .08829 m
.00375 .08829 L
s
0 .13734 m
.00375 .13734 L
s
0 .16187 m
.00375 .16187 L
s
0 .18639 m
.00375 .18639 L
s
0 .23544 m
.00375 .23544 L
s
0 .25997 m
.00375 .25997 L
s
0 .28449 m
.00375 .28449 L
s
0 .33354 m
.00375 .33354 L
s
0 .35807 m
.00375 .35807 L
s
0 .38259 m
.00375 .38259 L
s
0 .43164 m
.00375 .43164 L
s
0 .45617 m
.00375 .45617 L
s
0 .48069 m
.00375 .48069 L
s
0 .52974 m
.00375 .52974 L
s
0 .55427 m
.00375 .55427 L
s
0 .57879 m
.00375 .57879 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Theta) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(radian) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .25997 m
.02499 .25992 L
.02605 .2598 L
.02729 .25957 L
.02846 .25928 L
.03053 .25855 L
.03279 .2575 L
.0379 .25421 L
.04262 .25019 L
.05224 .23967 L
.06244 .22606 L
.10458 .16106 L
.14241 .10983 L
.16345 .08761 L
.1827 .07117 L
.20281 .05752 L
.22147 .04757 L
.24046 .03968 L
.26118 .0331 L
.28171 .02823 L
.30031 .0249 L
.31956 .02229 L
.34038 .0202 L
.36032 .01873 L
.38138 .0176 L
.40102 .01682 L
.41935 .01629 L
.43971 .01585 L
.45826 .01556 L
.47735 .01533 L
.49811 .01516 L
.51788 .01504 L
.53889 .01494 L
.55836 .01488 L
.57664 .01484 L
.59682 .0148 L
.61533 .01478 L
.63425 .01476 L
.65495 .01475 L
.67456 .01474 L
.69551 .01473 L
.71686 .01473 L
.73701 .01472 L
.75702 .01472 L
.77548 .01472 L
.79424 .01472 L
.81488 .01472 L
.83433 .01472 L
.85522 .01472 L
.86535 .01472 L
Mistroke
.87639 .01472 L
.8965 .01472 L
.91621 .01472 L
.93719 .01472 L
.95729 .01472 L
.97619 .01472 L
Mfstroke
.5 Mabswid
[ .025 .0075 .0075 .0075 ] 0 setdash
.02381 .50522 m
.02499 .50519 L
.02605 .50511 L
.02729 .50496 L
.02846 .50477 L
.03053 .50428 L
.03279 .50357 L
.03527 .50257 L
.0379 .50127 L
.04262 .49834 L
.05205 .49036 L
.06244 .47857 L
.0842 .44503 L
.10458 .40458 L
.14335 .313 L
.18458 .21556 L
.20517 .17373 L
.22428 .1406 L
.26248 .09079 L
.283 .07187 L
.30161 .05851 L
.32085 .04777 L
.34167 .03897 L
.36161 .03267 L
.38268 .02772 L
.40231 .02432 L
.42065 .02193 L
.441 .01996 L
.45956 .01862 L
.47864 .0176 L
.4994 .01678 L
.51918 .01622 L
.54018 .01579 L
.55966 .0155 L
.57794 .0153 L
.59812 .01513 L
.61662 .01502 L
.63555 .01494 L
.65625 .01488 L
.67586 .01483 L
.69681 .0148 L
.71815 .01477 L
.73831 .01476 L
.75832 .01475 L
.77677 .01474 L
.79554 .01473 L
.81617 .01473 L
.83562 .01472 L
.85651 .01472 L
.86665 .01472 L
Mistroke
.87769 .01472 L
.88824 .01472 L
.89779 .01472 L
.9175 .01472 L
.92832 .01472 L
.93849 .01472 L
.95814 .01472 L
.97619 .01472 L
Mfstroke
[ .01 .01 ] 0 setdash
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60331 L
.02846 .60331 L
.03053 .6033 L
.03279 .60329 L
.03527 .60327 L
.0379 .60325 L
.04262 .6032 L
.05205 .60305 L
.06244 .60282 L
.07293 .60251 L
.0842 .60208 L
.10458 .60101 L
.11468 .6003 L
.12571 .59937 L
.1458 .59712 L
.16548 .594 L
.18645 .58927 L
.19674 .58626 L
.20786 .58237 L
.22803 .57322 L
.24797 .5608 L
.26904 .54296 L
.28867 .5209 L
.30701 .49479 L
.34592 .4207 L
.38728 .32108 L
.42712 .2247 L
.46545 .14928 L
.48523 .11923 L
.50623 .09358 L
.52593 .07471 L
.54398 .06109 L
.56333 .0497 L
.58419 .04039 L
.60311 .03402 L
.62381 .02879 L
.64342 .02512 L
.66437 .02222 L
.68572 .02008 L
.70587 .01862 L
.72588 .01755 L
.74434 .01683 L
.7631 .01628 L
.78374 .01584 L
.80319 .01553 L
.82408 .0153 L
.84525 .01513 L
Mistroke
.86536 .01501 L
.8852 .01493 L
.9036 .01487 L
.92416 .01483 L
.94278 .0148 L
.95884 .01478 L
.97619 .01476 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[38]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00:=oo`03001oogoo00Ioo`03001oogoo075oo`00XWoo00<007ooOol027oo00<007ooOol0L7oo
0022Ool30002Ool300001Woo001oo`00Ool0009oo`8000eoo`03001oogoo009oo`8000Ioo`03001o
ogoo06moo`00Pgoo00<007ooOol00Woo00X007ooOol007oo001oo`00Ool000moo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo06moo`00Pgoo00<007ooOol00Woo00T007ooOol007oo001oo`00
Ool00`003Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0Kgoo0023Ool01000Oomoogoo
0P000Woo0P0000Aoo`00Oomoo`<000eoo`03001oogoo00=oo`8000Eoo`03001oogoo06moo`00PGoo
00D007oo001oo`0001aoo`03001oogoo00Qoo`03001oogoo071oo`00PGoo1@000Woo00<007ooOol0
67oo00<007ooOol01Woo00<007ooOol0LGoo003oOolQOol00?moob5oo`00ogoo8Goo000_Ool00`00
Oomoo`0`Ool5000aOol3000bOol2000dOol3000JOol002ioo`03001oo`0003=oo`03001oogoo035o
o`03001oogoo03Aoo`03001oogoo039oo`03001oogoo01Uoo`00;Woo00<007oo0000<goo00<007oo
Ool0<Woo00<007ooOol0<Woo00<007ooOol0<Goo10006Woo000^Ool00`00Ool0000cOol00`00Oomo
o`0bOol00`00Oomoo`0cOol00`00Oomoo`0`Ool00`00Ool0000KOol002ioo`03001oo`0003=oo`03
001oogoo035oo`03001oo`00039oo`03001oo`0003=oo`8001]oo`00;goo00<007ooOol0<Goo0P00
=7oo00<007ooOol0<Woo00<007ooOol0<goo00<007ooOol06Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00:Woog`005goo000UOol00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`0JOol002Aoo`03001oo`0000=oo`03001oogoo0?=oo`0097oo00<007oo00000goo0`00
GGooNP0077oo000TOol00`00Ool00003Ool00`00Oomoo`17OolF0002Ool200000goo000000080000
0goo00000004000SOol300000goo0000000200001Goo00000000Ool00`000Woo0P00BGoo000TOol0
0`00Ool00003Ool00`00Oomoo`0oOol8000?Ool00`00Ool00005000_Ool30002Ool3001NOol002Eo
o`03001oogoo009oo`03001oogoo03Yoo`D0019oo`D003=oo`<006Moo`00:Woo00<007ooOol0=goo
0`004goo1000<goo1000Jgoo000ZOol00`00Oomoo`0eOol2000COol3000eOol00`00Oomoo`1^Ool0
02Yoo`8003=oo`<001=oo`03001oogoo03=oo`04001oo`00001aOol002Yoo`03001oogoo02moo`<0
01Aoo`8003Aoo`8007Eoo`00:Woo00<007ooOol0;Goo0P0057oo0`00=7oo00<007ooOol0MWoo000Z
Ool00`00Oomoo`0[Ool2000EOol00`00Oomoo`0cOol2001iOol002Yoo`03001oogoo02Yoo`03001o
ogoo01Aoo`03001oogoo039oo`03001oogoo07Yoo`00:Woo0P00:Woo00<007ooOol04goo00<007oo
Ool0<goo00<007ooOol0Ngoo000ZOol00`00Oomoo`0WOol2000DOol2000eOol00`00Oomoo`1lOol0
02Yoo`03001oogoo02Ioo`03001oogoo01=oo`03001oogoo03=oo`8007moo`00:Woo00<007ooOol0
9Goo00<007ooOol04goo00<007ooOol0<goo00<007ooOol0Ogoo000ZOol00`00Oomoo`0SOol2000E
Ool00`00Oomoo`0dOol00`00Oomoo`1oOol002Yoo`03001oogoo029oo`03001oogoo01=oo`8003Eo
o`03001oogoo085oo`00:Woo0P008Woo00<007ooOol0BWoo00<007ooOol0PWoo000ZOol00`00Oomo
o`0POol00`00Oomoo`0DOol00`00Oomoo`0dOol00`00Oomoo`22Ool002Yoo`03001oogoo01moo`03
001oogoo01Aoo`03001oogoo03=oo`03001oogoo08Aoo`006goo00<007ooOol00Woo00@007ooOomo
o`<000=oo`03001oogoo01ioo`03001oogoo01Aoo`03001oogoo03=oo`03001oogoo08Eoo`006Woo
00<007oo00001goo00<007ooOol00goo00<007ooOol07Goo00<007ooOol05Goo00<007ooOol0<goo
00<007ooOol0QGoo000JOol00`00Ool00008Ool00`00Oomoo`02Ool3000LOol00`00Oomoo`0EOol0
0`00Oomoo`2lOol001Yoo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo01aoo`03001oogoo
01Aoo`03001oogoo03=oo`8008Qoo`006Woo00<007oo00001goo00<007oo00000goo00<007ooOol0
6goo00<007ooOol057oo00<007ooOol0<goo00<007ooOol0R7oo000KOol00`00Oomoo`07Ool00`00
Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`0EOol00`00Oomoo`0cOol00`00Oomoo`28Ool002Yo
o`03001oogoo01Yoo`03001oogoo01Aoo`03001oogoo03=oo`03001oogoo08Uoo`00:Woo0P006Woo
00<007ooOol057oo00<007ooOol0<goo00<007ooOol0RWoo000ZOol00`00Oomoo`0HOol00`00Oomo
o`0DOol00`00Oomoo`0dOol00`00Oomoo`2:Ool002Yoo`03001oogoo01Qoo`03001oogoo01Aoo`03
001oogoo0<5oo`00:Woo00<007ooOol05goo00<007ooOol057oo00<007ooOol0=7oo00<007ooOol0
Rgoo000ZOol00`00Oomoo`0FOol00`00Oomoo`0EOol00`00Oomoo`0cOol00`00Oomoo`2<Ool002Yo
o`03001oogoo01Ioo`03001oogoo01Aoo`03001oogoo03Aoo`03001oogoo08aoo`00:Woo0P005Woo
00<007ooOol057oo00<007ooOol0a7oo000ZOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomo
o`0dOol00`00Oomoo`2=Ool002Yoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo03Aoo`03
001oogoo08ioo`00:Woo00<007ooOol04goo00<007ooOol05Goo00<007ooOol0=7oo00<007ooOol0
SWoo000ZOol00`00Oomoo`0BOol00`00Oomoo`0EOol00`00Oomoo`36Ool002Yoo`80019oo`03001o
ogoo01Ioo`03001oogoo03Aoo`03001oogoo08moo`00:Woo00<007ooOol04Goo00<007ooOol05Goo
00<007ooOol0=7oo00<007ooOol0T7oo000ZOol00`00Oomoo`0@Ool00`00Oomoo`0FOol00`00Oomo
o`0dOol00`00Oomoo`2@Ool002Yoo`03001oogoo00moo`03001oogoo01Ioo`03001oogoo0<Qoo`00
6goo00<007ooOol00Woo00<007ooOol00Woo0`000Woo00<007ooOol03goo00<007ooOol05Goo00<0
07ooOol0=Goo00<007ooOol0TGoo000JOol00`00Ool00009Ool01@00Oomoogoo000047oo00<007oo
Ool05Woo00<007ooOol0=7oo00<007ooOol0TWoo000JOol00`00Ool00007Ool40002Ool3000=Ool0
0`00Oomoo`0GOol00`00Oomoo`0dOol00`00Oomoo`2BOol001Yoo`03001oo`0000Moo`03001oo`00
00=oo`03001oogoo00aoo`03001oogoo01Moo`03001oogoo0<Yoo`006Woo00<007oo000027oo0P00
0goo00<007ooOol037oo00<007ooOol05goo00<007ooOol0=7oo00<007ooOol0Tgoo000KOol00`00
Oomoo`08Ool01@00Oomoogoo00003Goo00<007ooOol05goo00<007ooOol0=7oo00<007ooOol0U7oo
000ZOol00`00Oomoo`0:Ool00`00Oomoo`0HOol00`00Oomoo`0dOol00`00Oomoo`2DOol002Yoo`80
00]oo`03001oogoo01Moo`03001oogoo0<aoo`00:Woo00<007ooOol02Goo00<007ooOol067oo00<0
07ooOol0=7oo00<007ooOol0UGoo000ZOol00`00Oomoo`08Ool00`00Oomoo`0IOol00`00Oomoo`0c
Ool00`00Oomoo`2FOol002Yoo`03001oogoo00Moo`03001oogoo01Uoo`03001oogoo03Aoo`03001o
ogoo09Ioo`00:Woo00<007ooOol01Woo00<007ooOol06Woo00<007ooOol0cGoo000ZOol00`00Oomo
o`04Ool2000LOol00`00Oomoo`0dOol00`00Oomoo`2GOol002Yoo`8000Aoo`03001oogoo01aoo`03
001oogoo03=oo`03001oogoo09Qoo`00:Woo00<007ooOol08Goo00<007ooOol0=7oo00<007ooOol0
V7oo000ZOol00`00Oomoo`0QOol00`00Oomoo`3?Ool002Yoo`03001oogoo021oo`03001oogoo03Ao
o`03001oogoo09Uoo`00:Woo00<007ooOol087oo00<007ooOol0=7oo00<007ooOol0VGoo000ZOol2
001HOol00`00Oomoo`2IOol002Yoo`03001oogoo021oo`03001oogoo0=1oo`00:Woo00<007ooOol0
7goo00<007ooOol0=7oo00<007ooOol0VWoo000ZOol00`00Oomoo`1EOol00`00Oomoo`2KOol001]o
o`03001oogoo009oo`04001oogooOol20004Ool00`00Oomoo`0NOol00`00Oomoo`0dOol00`00Oomo
o`2KOol001Yoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo01eoo`03001oogoo0==oo`00
6Woo00<007oo00001goo00<007oo00000goo0`007Goo00<007ooOol0=7oo00<007ooOol0W7oo000J
Ool00`00Ool00007Ool20004Ool00`00Oomoo`0MOol00`00Oomoo`0cOol00`00Oomoo`2MOol001Yo
o`03001oo`0000Moo`03001oogoo00=oo`03001oogoo01aoo`03001oogoo03Aoo`03001oogoo09eo
o`006goo00<007ooOol01goo0P000goo00<007ooOol077oo00<007ooOol0=7oo00<007ooOol0WGoo
000ZOol00`00Oomoo`0KOol00`00Oomoo`3EOol002Yoo`8001aoo`03001oogoo03Aoo`03001oogoo
09ioo`00:Woo00<007ooOol06goo00<007ooOol0<goo00<007ooOol0Wgoo000ZOol00`00Oomoo`1A
Ool00`00Oomoo`2OOol002Yoo`03001oogoo01Yoo`03001oogoo0=Ioo`00:Woo00<007ooOol06Woo
00<007ooOol0=7oo00<007ooOol0Wgoo000ZOol2000JOol00`00Oomoo`0dOol00`00Oomoo`2POol0
02Yoo`03001oogoo01Uoo`03001oogoo03Aoo`03001oogoo0:1oo`00:Woo00<007ooOol067oo00<0
07ooOol0f7oo000ZOol00`00Oomoo`0HOol00`00Oomoo`0dOol00`00Oomoo`2QOol002Yoo`03001o
ogoo01Moo`03001oogoo03Aoo`03001oogoo0:9oo`00:Woo00<007ooOol05goo00<007ooOol0=7oo
00<007ooOol0XWoo000ZOol2000HOol00`00Oomoo`3IOol002Yoo`03001oogoo01Ioo`03001oogoo
03Aoo`03001oogoo0:=oo`00:Woo00<007ooOol05Woo00<007ooOol0<goo00<007ooOol0Y7oo000K
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`0d
Ool00`00Oomoo`2TOol001Yoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo01Eoo`03001o
ogoo0=]oo`006Woo00<007oo00001goo00<007oo00000goo0`005Goo00<007ooOol0=7oo00<007oo
Ool0Y7oo000JOol00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`0DOol00`00Oomoo`0dOol0
0`00Oomoo`2UOol001Yoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo04]oo`03001oogoo
0:Eoo`006goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol04goo00<007ooOol0gGoo000Z
Ool00`00Oomoo`0BOol00`00Oomoo`0eOol00`00Oomoo`2VOol002Yoo`03001oogoo04Uoo`03001o
ogoo0:Moo`00:Woo0P004goo00<007ooOol0=7oo00<007ooOol0Ygoo000ZOol00`00Oomoo`0AOol0
0`00Oomoo`3OOol002Yoo`03001oogoo015oo`03001oogoo03Aoo`03001oogoo0:Qoo`00:Woo00<0
07ooOol047oo00<007ooOol0=7oo00<007ooOol0ZGoo000ZOol00`00Oomoo`0?Ool00`00Oomoo`0e
Ool00`00Oomoo`2YOol002Yoo`80011oo`03001oogoo0>5oo`00:Woo00<007ooOol03Woo00<007oo
Ool0=Goo00<007ooOol0ZWoo000ZOol00`00Oomoo`0=Ool00`00Oomoo`0eOol00`00Oomoo`2[Ool0
02Yoo`03001oogoo04Eoo`03001oogoo0:]oo`00:Woo00<007ooOol037oo00<007ooOol0i7oo000Z
Ool00`00Oomoo`0;Ool00`00Oomoo`0fOol00`00Oomoo`2/Ool002Yoo`8000]oo`03001oogoo03Io
o`03001oogoo0:eoo`00:Woo00<007ooOol02Woo00<007ooOol0=Woo00<007ooOol0[Goo000ZOol0
0`00Oomoo`09Ool00`00Oomoo`3WOol002=oo`D0009oo`03001oogoo00Moo`03001oogoo03Qoo`03
001oogoo0:ioo`009Goo00<007ooOol00Woo00<007ooOol01Woo0P00>Goo00<007ooOol0[goo000U
Ool00`00Oomoo`02Ool30003Ool2000kOol00`00Oomoo`2`Ool002Eoo`03001oogoo009oo`03001o
ogoo03moo`03001oogoo0;5oo`009Goo00<007ooOol00Woo00<007ooOol0?Woo00<007ooOol0/Woo
000TOol20004Ool00`00Oomoo`0nOol00`00Oomoo`2bOol002Yoo`03001oogoo0?=oo`00:Woo00<0
07ooOol0?7oo00<007ooOol0]7oo000ZOol2000lOol00`00Oomoo`2eOol002Yoo`03001oogoo03]o
o`03001oogoo0;Eoo`00:Woo00<007ooOol0>Goo00<007ooOol0]goo000ZOol00`00Oomoo`0hOol0
0`00Oomoo`2hOol002Yoo`03001oogoo03Qoo`03001oogoo0;Qoo`00:Woo0P00=goo00<007ooOol0
^Woo000ZOol00`00Oomoo`0dOol2002mOol002Yoo`03001oogoo03Aoo`03001oogoo0;aoo`00:Woo
00<007ooOol0<Woo00<007ooOol0_Woo000ZOol00`00Oomoo`0`Ool20031Ool002Yoo`8002moo`03
001oogoo0<9oo`00:Woo00<007ooOol0;7oo0P00aGoo000ZOol00`00Oomoo`0XOol30038Ool002Yo
o`03001oogoo02Aoo`<00<aoo`006Goo1@000Woo00@007ooOomoo`<000=oo`03001oogoo021oo`<0
0=1oo`006goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol057oo0P0000Eoo`00000007oo
00<00=Eoo`006goo00<007ooOol01goo00<007ooOol00Woo0`000goo00<007oo00000P0000=oo`00
00000P0000Eoo`00000007oo00800=moo`006goo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool0lgoo000KOol00`00Oomoo`06Ool00`00Ool00003Ool00`00Oomoo`3cOol001Yoo`8000Uoo`03
001oogoo009oo`03001oogoo0?=oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool009Moo`03001oogoo02Aoo`03001oogoo05moo`00UWoo00<007ooOol09Woo00<007ooOol0GWoo
001`Ool300001Woo00000000Ool0009oo`8000=oo`80009oo`@000eoo`03001oogoo009oo`<0009o
o`@0009oo`<00004Ool000000002Ool60002Ool00`00Oomoo`07Ool00`00Oomoo`1MOol0075oo`05
001oogooOol00002Ool00`00Ool00004Ool01@00Oomoo`00Ool00`003Woo00<007ooOol00goo00@0
07ooOomoo`<0009oo`04001oogoo0002Ool01000Oomoogoo0`000Woo00@007ooOol000Uoo`03001o
ogoo05eoo`00LGoo00D007ooOomoo`00009oo`03001oo`000080009oo`03001oogoo00Aoo`03001o
ogoo00aoo`03001oogoo00=oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`001Goo00@0
07ooOol0009oo`03001oogoo00Moo`03001oogoo05eoo`00LGoo00@007ooOomoo`<0009oo`<00003
Ool00000008000=oo`8000ioo`03001oogoo009oo`@0009oo`8000=oo`<00003Ool0000000Aoo`80
0003Ool00000008000Yoo`03001oogoo05eoo`00Kgoo00L007oo001oo`00Ool00009Ool00`00Oomo
o`0DOol00`00Oomoo`0>Ool00`00Oomoo`0EOol00`00Oomoo`1NOol006moo`L0025oo`03001oogoo
00aoo`80009oo`03001oogoo015oo`03001oogoo05moo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.910206, -0.253428, 
  0.0189112, 0.00917968}},
  CellTags->"2"],

Cell[TextData[{
  "We can also see that, once the angle ",
  StyleBox["theta[t]", "MR"],
  " has come to zero, the derivative ",
  StyleBox["theta'[t]", "MR"],
  " vanishes as well. This means that the pendulum is not about to oscillate \
around its equilibrium position, at least not when driven from the \
displacements we are considering for now. "
}], "MathCaption",
  CellTags->"2"],

Cell["\<\
Plot[Evaluate[theta'[t] /. thetas],
 {t, 0, 4},
 PlotLabel -> \"Theta dot (radian/s)\",
 Evaluate[someOptions]
]\
\>", "Input",
  CellLabel->"In[39]:=",
  CellTags->"2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.603319 0.482489 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .02433 -24 -4.5 ]
[-0.0125 .02433 0 4.5 ]
[-0.0125 .12083 -12 -4.5 ]
[-0.0125 .12083 0 4.5 ]
[-0.0125 .21733 -24 -4.5 ]
[-0.0125 .21733 0 4.5 ]
[-0.0125 .31383 -24 -4.5 ]
[-0.0125 .31383 0 4.5 ]
[-0.0125 .41032 -24 -4.5 ]
[-0.0125 .41032 0 4.5 ]
[-0.0125 .50682 -24 -4.5 ]
[-0.0125 .50682 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[.5 .63053 -62 0 ]
[.5 .63053 62 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .02433 m
.00625 .02433 L
s
[(-1.2)] -0.0125 .02433 1 0 Mshowa
0 .12083 m
.00625 .12083 L
s
[(-1)] -0.0125 .12083 1 0 Mshowa
0 .21733 m
.00625 .21733 L
s
[(-0.8)] -0.0125 .21733 1 0 Mshowa
0 .31383 m
.00625 .31383 L
s
[(-0.6)] -0.0125 .31383 1 0 Mshowa
0 .41032 m
.00625 .41032 L
s
[(-0.4)] -0.0125 .41032 1 0 Mshowa
0 .50682 m
.00625 .50682 L
s
[(-0.2)] -0.0125 .50682 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .04846 m
.00375 .04846 L
s
0 .07258 m
.00375 .07258 L
s
0 .09671 m
.00375 .09671 L
s
0 .14495 m
.00375 .14495 L
s
0 .16908 m
.00375 .16908 L
s
0 .1932 m
.00375 .1932 L
s
0 .24145 m
.00375 .24145 L
s
0 .26558 m
.00375 .26558 L
s
0 .2897 m
.00375 .2897 L
s
0 .33795 m
.00375 .33795 L
s
0 .36207 m
.00375 .36207 L
s
0 .3862 m
.00375 .3862 L
s
0 .43445 m
.00375 .43445 L
s
0 .45857 m
.00375 .45857 L
s
0 .4827 m
.00375 .4827 L
s
0 .53095 m
.00375 .53095 L
s
0 .55507 m
.00375 .55507 L
s
0 .57919 m
.00375 .57919 L
s
0 .00021 m
.00375 .00021 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -123 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Theta) show
99.000000 12.812500 moveto
(dot) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(radian) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
165.000000 12.812500 moveto
(\\220) show
171.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
177.000000 12.812500 moveto
(L) show
183.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .60331 m
.03279 .48081 L
.04262 .38288 L
.04758 .34525 L
.05288 .3124 L
.05785 .28781 L
.06244 .26985 L
.06788 .25379 L
.07075 .2474 L
.07379 .24203 L
.07642 .23848 L
.07889 .23602 L
.0803 .23497 L
.08159 .23422 L
.08231 .23389 L
.08309 .23361 L
.08382 .2334 L
.08451 .23326 L
.08577 .23314 L
.08648 .23315 L
.08713 .2332 L
.08833 .23341 L
.0896 .23379 L
.09074 .23427 L
.0918 .23481 L
.09422 .23643 L
.09684 .23872 L
.09922 .24127 L
.10458 .2484 L
.11449 .26573 L
.12366 .28518 L
.14443 .33503 L
.18369 .42642 L
.22144 .493 L
.24079 .51823 L
.26165 .53963 L
.28169 .55548 L
.30279 .56817 L
.32253 .57711 L
.34089 .58345 L
.36135 .58878 L
.37994 .5924 L
.39912 .59522 L
.41992 .59748 L
.4398 .59905 L
.46084 .60026 L
.48041 .60108 L
.49873 .60166 L
.51901 .60212 L
.53755 .60243 L
Mistroke
.55657 .60267 L
.57731 .60285 L
.59702 .60298 L
.61801 .60308 L
.62832 .60312 L
.63946 .60315 L
.65964 .6032 L
.67962 .60323 L
.7007 .60326 L
.72038 .60327 L
.73872 .60329 L
.75912 .6033 L
.77768 .6033 L
.79681 .60331 L
.8076 .60331 L
.81758 .60331 L
.82735 .60331 L
.83787 .60331 L
.8569 .60331 L
.86652 .60332 L
.87663 .60332 L
.8947 .60332 L
.91448 .60332 L
.92331 .60332 L
.93286 .60332 L
.93553 .60332 L
.93836 .60332 L
.94077 .60332 L
.94213 .60332 L
.94341 .60332 L
.94608 .60332 L
.94861 .60332 L
.95089 .60332 L
.95336 .60332 L
.95562 .60332 L
.95802 .60332 L
.96233 .60332 L
.96347 .60332 L
.96469 .60332 L
.96585 .60332 L
.96691 .60332 L
.96808 .60332 L
.96937 .60332 L
.97002 .60332 L
.97071 .60332 L
.97196 .60332 L
.973 .60332 L
.97414 .60332 L
.9752 .60332 L
.97619 .60332 L
Mistroke
Mfstroke
.5 Mabswid
[ .025 .0075 .0075 .0075 ] 0 setdash
.02381 .60332 m
.04262 .43974 L
.06244 .30468 L
.08426 .1839 L
.0949 .13506 L
.10458 .09729 L
.1134 .0692 L
.12297 .04627 L
.12822 .03725 L
.13053 .03411 L
.13308 .03124 L
.13547 .02911 L
.13772 .02762 L
.13895 .027 L
.14009 .02656 L
.14139 .02621 L
.14264 .02602 L
.14388 .02598 L
.14458 .02602 L
.14522 .0261 L
.14641 .02634 L
.14766 .02674 L
.14879 .02722 L
.14984 .02777 L
.15222 .0294 L
.1548 .03172 L
.15715 .03433 L
.16244 .04186 L
.17188 .06053 L
.18083 .08348 L
.21916 .21354 L
.25994 .35157 L
.28019 .40711 L
.29921 .45013 L
.3176 .48391 L
.33696 .51223 L
.35714 .53513 L
.37564 .55132 L
.39539 .56456 L
.41375 .57395 L
.43421 .58184 L
.4528 .5872 L
.47198 .59136 L
.49278 .59469 L
.51266 .59702 L
.5337 .59881 L
.55327 .60002 L
.57159 .60086 L
.59187 .60155 L
.61041 .60201 L
Mistroke
.62943 .60236 L
.65017 .60263 L
.66988 .60282 L
.69087 .60297 L
.71232 .60307 L
.7325 .60314 L
.75262 .60319 L
.77111 .60322 L
.78997 .60325 L
.81065 .60327 L
.82069 .60328 L
.83019 .60328 L
.83544 .60329 L
.84115 .60329 L
.85112 .60329 L
.86048 .6033 L
.86573 .6033 L
.87055 .6033 L
.87593 .6033 L
.87864 .6033 L
.8816 .6033 L
.88419 .6033 L
.88697 .6033 L
.89196 .60331 L
.89443 .60331 L
.89705 .60331 L
.89992 .60331 L
.90257 .60331 L
.91257 .60331 L
.91687 .60331 L
.91811 .60331 L
.91928 .60331 L
.92035 .60331 L
.92148 .60331 L
.92274 .60331 L
.92391 .60331 L
.92655 .60331 L
.92879 .60331 L
.93128 .60331 L
.93656 .60331 L
.93913 .60331 L
.94148 .60331 L
.94396 .60331 L
.94661 .60331 L
.94803 .60331 L
.94953 .60331 L
.95081 .60332 L
.95154 .60332 L
.95222 .60332 L
.95342 .60332 L
Mistroke
.95451 .60332 L
.95577 .60332 L
.95696 .60332 L
.95826 .60332 L
.95896 .60332 L
.95963 .60332 L
.96093 .60331 L
.96211 .60331 L
.96323 .60331 L
.96425 .60332 L
.96538 .60332 L
.96657 .60332 L
.9677 .60332 L
.9689 .60332 L
.97022 .60332 L
.97145 .60332 L
.97272 .60332 L
.97393 .60332 L
.97501 .60332 L
.97619 .60332 L
Mfstroke
[ .01 .01 ] 0 setdash
.02381 .60332 m
.06244 .59727 L
.08255 .59367 L
.10458 .58847 L
.12507 .58173 L
.14415 .57304 L
.16457 .56013 L
.18314 .54396 L
.20229 .52147 L
.22307 .48844 L
.24291 .44655 L
.26394 .38938 L
.30178 .2546 L
.32281 .17032 L
.34206 .09878 L
.35157 .069 L
.35659 .0554 L
.36194 .04281 L
.36708 .03274 L
.37174 .02545 L
.37399 .02258 L
.37642 .01997 L
.37873 .01798 L
.38084 .01657 L
.38205 .01593 L
.38321 .01545 L
.38443 .01507 L
.38511 .01492 L
.38575 .01481 L
.38681 .01472 L
.38798 .01473 L
.3892 .01487 L
.39034 .01512 L
.39162 .01554 L
.39296 .01613 L
.39536 .01758 L
.39795 .0197 L
.40077 .02266 L
.40605 .02994 L
.41169 .04006 L
.42184 .06376 L
.44318 .13041 L
.46334 .20359 L
.5018 .33722 L
.52129 .39328 L
.54272 .44408 L
.56331 .4828 L
.58212 .51068 L
.60157 .53323 L
.62246 .55171 L
Mistroke
.64149 .56445 L
.66223 .57491 L
.68194 .58231 L
.70292 .58813 L
.72438 .59246 L
.74456 .59541 L
.76468 .59757 L
.78316 .59904 L
.80202 .60015 L
.8227 .60105 L
.84225 .60166 L
.86318 .60214 L
.88446 .60248 L
.90459 .60272 L
.92454 .60289 L
.94297 .603 L
.95877 .60307 L
.97619 .60313 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[39]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00:Ioo`03001oogoo00Ioo`03001oogoo06ioo`00YGoo00<007ooOol027oo00<007ooOol0KGoo
0025Ool30002Ool300001Woo001oo`00Ool0009oo`8000eoo`03001oogoo009oo`8000Ioo`03001o
ogoo06aoo`00QWoo00<007ooOol00Woo00X007ooOol007oo001oo`00Ool000moo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo06aoo`00QWoo00<007ooOol00Woo00T007ooOol007oo001oo`00
Ool00`003Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0K7oo0026Ool01000Oomoogoo
0P000Woo0P0000Aoo`00Oomoo`<000eoo`03001oogoo00=oo`8000Eoo`03001oogoo06aoo`00Q7oo
00D007oo001oo`0001aoo`03001oogoo00Qoo`03001oogoo06eoo`00Q7oo1@000Woo00<007ooOol0
67oo00<007ooOol01Woo00<007ooOol0KWoo003oOolQOol00?moob5oo`00ogoo8Goo000bOol00`00
Oomoo`0`Ool5000aOol3000bOol2000dOol3000GOol0035oo`03001oo`0003=oo`03001oogoo035o
o`03001oogoo03Aoo`03001oogoo039oo`03001oogoo01Ioo`00<Goo00<007oo0000<goo00<007oo
Ool0<Woo00<007ooOol0<Woo00<007ooOol0<Goo10005goo000aOol00`00Ool0000cOol00`00Oomo
o`0bOol00`00Oomoo`0cOol00`00Oomoo`0`Ool00`00Ool0000HOol0035oo`03001oo`0003=oo`03
001oogoo035oo`03001oo`00039oo`03001oo`0003=oo`8001Qoo`00<Woo00<007ooOol0<Goo0P00
=7oo00<007ooOol0<Woo00<007ooOol0<goo00<007ooOol05Woo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00;Goog`0057oo000]Ool00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0GOol0
02eoo`03001oogoo0?1oo`0077oo1@000Woo00@007ooOomoo`<000=oo`03001oogoo05Aoo`8009Yo
o`007Woo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0DGoo0P000Woo0P00VGoo000HOol3
0003Ool00`00Oomoo`07Ool00`00Oomoo`02Ool3001@Ool00`00Oomoo`03Ool00`00Oomoo`2GOol0
01ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo01]oo`800003Ool0000003Moo`03001o
ogoo09Ioo`007Woo00<007ooOol01Woo00<007oo00000goo00<007ooOol06Woo0P000goo00<007oo
Ool0;Goo00<007ooOol01Woo00<007ooOol0UGoo000MOol20009Ool00`00Oomoo`02Ool00`00Oomo
o`0JOol00`00Oomoo`03Ool00`00Oomoo`0[Ool00`00Oomoo`08Ool00`00Oomoo`2DOol002eoo`03
001oogoo01Uoo`03001oogoo00Eoo`03001oogoo02Yoo`03001oogoo09moo`00;Goo00<007ooOol0
6Goo00<007ooOol01Woo00<007ooOol0=7oo00<007ooOol0U7oo000]Ool2000IOol00`00Oomoo`07
Ool00`00Oomoo`0XOol00`00Oomoo`0:Ool00`00Oomoo`2COol002eoo`03001oogoo01Moo`03001o
ogoo00Uoo`03001oogoo02Moo`03001oogoo00Yoo`03001oogoo09=oo`00;Goo00<007ooOol05goo
00<007ooOol02Goo00<007ooOol09Woo00<007ooOol0XGoo000]Ool00`00Oomoo`0TOol00`00Oomo
o`0dOol00`00Oomoo`2BOol002eoo`03001oogoo01Moo`03001oogoo00Yoo`03001oogoo02Aoo`80
00ioo`03001oogoo099oo`00;Goo0P0067oo00<007ooOol02Woo00<007ooOol097oo00<007ooOol0
3Woo00<007ooOol0TGoo000]Ool00`00Oomoo`0FOol00`00Oomoo`0<Ool00`00Oomoo`0SOol00`00
Oomoo`0>Ool00`00Oomoo`2AOol002eoo`03001oogoo01Ioo`03001oogoo00eoo`03001oogoo0<Mo
o`00;Goo00<007ooOol05Goo00<007ooOol03Woo00<007ooOol08Goo00<007ooOol03goo00<007oo
Ool0TGoo000]Ool00`00Oomoo`0EOol00`00Oomoo`0>Ool00`00Oomoo`0QOol00`00Oomoo`0@Ool0
0`00Oomoo`2@Ool002eoo`8001Ioo`03001oogoo00moo`03001oogoo021oo`03001oogoo011oo`03
001oogoo091oo`00;Goo00<007ooOol05Goo00<007ooOol03goo00<007ooOol0aWoo000]Ool00`00
Oomoo`0DOol00`00Oomoo`0@Ool00`00Oomoo`0OOol00`00Oomoo`0BOol00`00Oomoo`2?Ool002eo
o`03001oogoo02Moo`03001oogoo01ioo`03001oogoo01Aoo`03001oogoo08ioo`009Woo1@000Woo
00<007ooOol057oo00<007ooOol04Goo00<007ooOol07Goo00<007ooOol057oo00<007ooOol0SWoo
000XOol00`00Oomoo`02Ool00`00Oomoo`0DOol00`00Oomoo`0AOol00`00Oomoo`35Ool0029oo`<0
00=oo`03001oogoo009oo`<001=oo`03001oogoo019oo`03001oogoo03Aoo`03001oogoo08ioo`00
:7oo00<007ooOol00Woo00<007ooOol04goo00<007ooOol04Woo00<007ooOol07Goo00<007ooOol0
5Goo00<007ooOol0SGoo000XOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`0DOol00`00
Oomoo`0KOol00`00Oomoo`0FOol00`00Oomoo`2=Ool002Moo`8000Aoo`03001oogoo019oo`03001o
ogoo01Aoo`03001oogoo01]oo`03001oogoo0:Ioo`00;Goo00<007ooOol0:Goo00<007ooOol0=7oo
00<007ooOol0SGoo000]Ool2000COol00`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomoo`0FOol0
0`00Oomoo`2=Ool002eoo`03001oogoo019oo`03001oogoo01Eoo`03001oogoo01Uoo`03001oogoo
01Qoo`03001oogoo08aoo`00;Goo00<007ooOol0:Woo00<007ooOol06Goo00<007ooOol067oo00<0
07ooOol0S7oo000]Ool00`00Oomoo`0AOol00`00Oomoo`0GOol00`00Oomoo`32Ool002eoo`03001o
ogoo015oo`03001oogoo01Moo`03001oogoo01Moo`03001oogoo01Yoo`03001oogoo08]oo`00;Goo
0P004Woo00<007ooOol0<Goo00<007ooOol06Woo00<007ooOol0Rgoo000]Ool00`00Oomoo`0@Ool0
0`00Oomoo`0HOol00`00Oomoo`0GOol00`00Oomoo`0JOol00`00Oomoo`2;Ool002eoo`03001oogoo
011oo`03001oogoo01Qoo`03001oogoo0<9oo`00;Goo00<007ooOol047oo00<007ooOol06Goo00<0
07ooOol05Goo00<007ooOol077oo00<007ooOol0RWoo000]Ool00`00Oomoo`0/Ool00`00Oomoo`0E
Ool00`00Oomoo`0LOol00`00Oomoo`2:Ool002eoo`03001oogoo011oo`03001oogoo01Yoo`03001o
ogoo01Aoo`03001oogoo01aoo`03001oogoo08Yoo`00;Goo0P0047oo00<007ooOol06goo00<007oo
Ool057oo00<007ooOol0ZGoo000]Ool00`00Oomoo`0?Ool00`00Oomoo`0KOol00`00Oomoo`0dOol0
0`00Oomoo`29Ool002eoo`03001oogoo00moo`03001oogoo01aoo`03001oogoo019oo`03001oogoo
01ioo`03001oogoo08Uoo`007Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol03goo00<007ooOol077oo00<007ooOol04Woo00<007ooOol07goo00<007ooOol0R7oo000M
Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0?Ool00`00Oomoo`0aOol00`00Oomoo`2Z
Ool001Qoo`<0009oo`03001oo`0000Moo`03001oo`0000=oo`<000ioo`03001oogoo01eoo`03001o
ogoo0;moo`007Goo00<007oo000027oo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol07Goo
00<007ooOol04Goo00<007ooOol087oo00<007ooOol0R7oo000MOol00`00Ool00007Ool00`00Ool0
0003Ool00`00Oomoo`0>Ool00`00Oomoo`0NOol00`00Oomoo`0@Ool00`00Oomoo`0QOol00`00Oomo
o`27Ool001ioo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00ioo`03001oogoo01ioo`03
001oogoo011oo`03001oogoo025oo`03001oogoo08Moo`00;Goo00<007ooOol03Woo1@007Goo00<0
07ooOol0_Goo000]Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`0>
Ool00`00Oomoo`0ROol00`00Oomoo`27Ool002eoo`8000moo`03001oogoo00=oo`03001oogoo02Yo
o`03001oogoo02=oo`03001oogoo08Ioo`00;Goo00<007ooOol03Goo00<007ooOol01Goo00<007oo
Ool067oo00<007ooOol03Woo00<007ooOol08goo00<007ooOol0QWoo000]Ool00`00Oomoo`0<Ool2
0008Ool00`00Oomoo`0HOol00`00Oomoo`0=Ool00`00Oomoo`2/Ool002eoo`03001oogoo00aoo`80
00Qoo`03001oogoo04moo`03001oogoo08Eoo`00;Goo00<007ooOol02goo00<007oo00002Goo00<0
07ooOol05goo00<007ooOol037oo00<007ooOol09Goo00<007ooOol0QGoo000]Ool2000<Ool2000:
Ool00`00Oomoo`0GOol00`00Oomoo`0;Ool00`00Oomoo`0VOol00`00Oomoo`25Ool002eoo`03001o
ogoo00]oo`8000]oo`03001oogoo01Moo`03001oogoo00Yoo`03001oogoo0:ioo`00;Goo00<007oo
Ool02goo0P002goo00<007ooOol05goo00<007ooOol0=7oo00<007ooOol0Q7oo000]Ool00`00Oomo
o`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0GOol00`00Oomoo`09Ool00`00Oomoo`0WOol00`00Oomo
o`24Ool002eoo`03001oogoo00Yoo`03001oo`0000aoo`03001oogoo01Moo`03001oogoo00Qoo`03
001oogoo02Qoo`03001oogoo08Aoo`00;Goo0P002goo00<007oo000037oo00<007ooOol08Woo00<0
07ooOol0:7oo00<007ooOol0Q7oo000]Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomoo`0F
Ool00`00Oomoo`2jOol002eoo`03001oogoo00Yoo`8000ioo`03001oogoo01Moo`03001oogoo00Mo
o`03001oogoo02Uoo`03001oogoo08=oo`00;Goo00<007ooOol02Goo00<007oo00003Woo00<007oo
Ool087oo00<007ooOol0:goo00<007ooOol0PWoo000NOol00`00Oomoo`02Ool01000Oomoogoo0P00
17oo00<007ooOol02Goo00<007oo00003goo00<007ooOol05Woo00<007ooOol01Woo00<007ooOol0
:goo00<007ooOol0PWoo000MOol00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`09Ool00`00
Ool0000?Ool00`00Oomoo`0FOol00`00Oomoo`2iOol001Qoo`<0009oo`03001oo`0000Moo`03001o
o`0000=oo`<000Uoo`03001oo`00011oo`03001oogoo01Ioo`03001oogoo00Aoo`03001oogoo02ao
o`03001oogoo089oo`007Goo00<007oo00001goo0P0017oo00<007ooOol02Goo00<007oo000047oo
00<007ooOol05Woo00<007ooOol017oo00<007ooOol0;Goo00<007ooOol0PGoo000MOol00`00Ool0
0007Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`0@Ool00`00Oomoo`0GOol00`00Oomo
o`03Ool00`00Oomoo`0]Ool00`00Oomoo`21Ool001ioo`03001oogoo00Moo`8000=oo`03001oogoo
00Qoo`03001oo`00019oo`03001oogoo01Ioo`03001oogoo00=oo`03001oogoo0;5oo`00;Goo00<0
07ooOol027oo00<007oo00004Woo00<007ooOol0CGoo00<007ooOol0P7oo000]Ool20009Ool00`00
Ool0000BOol00`00Oomoo`0FOol00`00Oomoo`02Ool00`00Oomoo`0_Ool00`00Oomoo`20Ool002eo
o`03001oogoo00Qoo`03001oo`0001=oo`03001oogoo01Ioo`05001oogooOol0000aOol00`00Oomo
o`20Ool002eoo`03001oogoo00Qoo`03001oo`0001=oo`03001oogoo01Yoo`03001oogoo0;9oo`00
;Goo00<007ooOol027oo00<007oo000057oo00<007ooOol05Goo00<007ooOol0=7oo00<007ooOol0
Ogoo000]Ool00`00Oomoo`08Ool2000EOol00`00Oomoo`0EOol01000Oomoo`00=7oo00<007ooOol0
OWoo000]Ool20009Ool2000FOol00`00Oomoo`0EOol2000eOol00`00Oomoo`1nOol002eoo`03001o
ogoo00Moo`03001oo`0001Ioo`03001oogoo01Eoo`800;Ioo`00;Goo00<007ooOol01goo00<007oo
00005Woo00<007ooOol05Woo00<007ooOol0]7oo000]Ool00`00Oomoo`07Ool00`00Oomoo`0GOol0
0`00Oomoo`0EOol00`00Oomoo`0cOol00`00Oomoo`1nOol002eoo`03001oogoo00Moo`03001oo`00
01Moo`03001oogoo01Aoo`03001oogoo03Eoo`03001oogoo07eoo`00;Goo00<007ooOol01goo00<0
07oo000067oo00<007ooOol04goo00<007oo0000=Goo00<007ooOol0OGoo000]Ool20008Ool00`00
Oomoo`0HOol00`00Oomoo`0EOol00`00Oomoo`2cOol002eoo`03001oogoo00Moo`8001Yoo`03001o
ogoo04]oo`03001oogoo07aoo`00;Goo00<007ooOol01goo0P006Woo00<007ooOol04Woo00@007oo
Ool003Ioo`03001oogoo07]oo`007Woo00<007ooOol00Woo00<007ooOol00Woo0`000Woo00<007oo
Ool01goo0P006Woo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol0<goo00<007ooOol0Ngoo
000MOol00`00Ool00009Ool01@00Oomoogoo00002Goo0P006goo00<007ooOol047oo00<007ooOol0
0Woo00<007ooOol0/Goo000HOol30002Ool00`00Ool00007Ool40002Ool30006Ool00`00Ool0000K
Ool00`00Oomoo`0EOol00`00Oomoo`0dOol00`00Oomoo`1jOol001eoo`03001oo`0000Moo`03001o
o`0000=oo`03001oogoo00Ioo`03001oo`0001aoo`03001oogoo00ioo`03001oogoo00Aoo`03001o
ogoo03=oo`03001oogoo07Yoo`007Goo00<007oo000027oo0P000goo00<007ooOol01Woo00<007oo
Ool077oo00<007ooOol03Goo00<007ooOol01Goo00<007ooOol0<goo00<007ooOol0NWoo000NOol0
0`00Oomoo`08Ool01@00Oomoogoo000027oo0P007Woo00<007ooOol037oo00<007ooOol0^7oo000]
Ool00`00Oomoo`06Ool2000NOol00`00Oomoo`0DOol00`00Oomoo`0dOol00`00Oomoo`1iOol002eo
o`8000Moo`8001moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo03Aoo`03001oogoo07Qo
o`00;Goo00<007ooOol01Woo0P007goo00<007ooOol02Woo00<007ooOol0?Woo00<007ooOol0N7oo
000]Ool00`00Oomoo`06Ool2000POol00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`2^Ool0
02eoo`03001oogoo00Ioo`80025oo`03001oogoo01Aoo`03001oogoo03=oo`03001oogoo07Moo`00
;Goo00<007ooOol01Woo0P008Goo00<007ooOol01goo00<007ooOol02Woo00<007ooOol0=7oo00<0
07ooOol0MWoo000]Ool00`00Oomoo`06Ool00`00Oomoo`0QOol00`00Oomoo`05Ool00`00Oomoo`0;
Ool00`00Oomoo`0dOol00`00Oomoo`1fOol002eoo`8000Ioo`8002Aoo`03001oogoo00Aoo`03001o
ogoo00aoo`03001oogoo0:aoo`00;Goo00<007ooOol01Goo0P0097oo00<007ooOol04goo00<007oo
Ool0=7oo00<007ooOol0MGoo000]Ool00`00Oomoo`05Ool2000UOol00`00Oomoo`02Ool00`00Oomo
o`0>Ool00`00Oomoo`0dOol00`00Oomoo`1dOol002eoo`03001oogoo00Eoo`8002Eoo`05001oogoo
Ool0000BOol00`00Oomoo`0cOol00`00Oomoo`1dOol002eoo`03001oogoo00Eoo`8002Ioo`04001o
ogoo000BOol00`00Oomoo`2ZOol002eoo`8000Ioo`03001oogoo02Ioo`03001oogoo01=oo`03001o
ogoo03=oo`03001oogoo07=oo`00;Goo00<007ooOol01Goo0P009goo0P005Goo00<007ooOol0<goo
00<007ooOol0LWoo000]Ool00`00Oomoo`05Ool2000WOol2000EOol00`00Oomoo`0cOol00`00Oomo
o`1bOol001ioo`03001oogoo009oo`04001oogooOol30003Ool00`00Oomoo`05Ool2000WOol00`00
Ool0000EOol00`00Oomoo`2WOol001eoo`03001oo`0000Moo`03001oogoo00=oo`03001oogoo00Eo
o`03001oogoo02Qoo`03001oogoo01=oo`03001oogoo03Aoo`03001oogoo071oo`0067oo0`000Woo
00<007oo000027oo00<007ooOol00Woo0`001Goo00<007ooOol09Goo00D007ooOomoo`0001Eoo`03
001oogoo03Aoo`03001oogoo06moo`007Goo00<007oo000027oo00<007ooOol00Woo00<007ooOol0
1Goo00<007ooOol097oo00<007ooOol00goo00<007ooOol04goo00<007ooOol0YGoo000MOol00`00
Ool00007Ool00`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`0UOol00`00Oomoo`03Ool00`00
Oomoo`0COol2000eOol00`00Oomoo`1^Ool001ioo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo00Aoo`8002eoo`03001oogoo04Yoo`03001oogoo06eoo`00;Goo00<007ooOol017oo0P0097oo
00<007ooOol01goo00<007ooOol04goo00<007ooOol0=7oo00<007ooOol0K7oo000]Ool00`00Oomo
o`04Ool2000SOol00`00Oomoo`09Ool00`00Oomoo`0COol00`00Oomoo`2ROol002eoo`8000Eoo`03
001oogoo02ioo`03001oogoo01Aoo`03001oogoo03=oo`8006aoo`00;Goo00<007ooOol017oo00<0
07ooOol087oo00<007ooOol037oo00<007ooOol057oo00<007ooOol0=7oo00<007ooOol0JGoo000]
Ool00`00Oomoo`04Ool00`00Oomoo`0OOol00`00Oomoo`0>Ool00`00Oomoo`0DOol00`00Oomoo`2O
Ool002eoo`03001oogoo00Aoo`03001oogoo01moo`03001oogoo00moo`8001Eoo`03001oogoo03=o
o`03001oogoo06Qoo`00;Goo00<007ooOol017oo00<007ooOol07Goo00<007ooOol04goo0P0057oo
00<007ooOol0<goo0`00Igoo000]Ool20005Ool00`00Oomoo`0LOol00`00Oomoo`0FOol00`00Oomo
o`0BOol00`00Oomoo`0dOol00`00Oomoo`1UOol002eoo`03001oogoo00Aoo`03001oogoo01aoo`03
001oogoo01Moo`8001=oo`8003Ioo`03001oogoo06=oo`00;Goo00<007ooOol017oo00<007ooOol0
6Woo00<007ooOol06goo0P004goo0P00=Goo0P00Hgoo000]Ool00`00Oomoo`03Ool2000JOol2000P
Ool00`00Oomoo`0BOol00`00Oomoo`0eOol00`00Oomoo`1OOol002eoo`03001oogoo00=oo`8001Qo
o`03001oogoo029oo`8001Aoo`8003Eoo`8005moo`00;Goo00<007ooOol00goo00<007ooOol05Goo
0P009goo0`0057oo0P00=Goo00<007ooOol0Fgoo000]Ool20004Ool00`00Oomoo`0COol00`00Oomo
o`0[Ool4000BOol2000dOol2001KOol002eoo`03001oogoo00=oo`03001oogoo015oo`80039oo`80
019oo`@003=oo`<005Moo`00;Goo00<007ooOol00goo00<007ooOol03Goo0`00=goo1`003goo00<0
07oo00000P00<Woo1000DWoo000XOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`06Ool0
0`00Ool000030012Ool5000?Ool3000017oo000007oo0`00;Goo0`0000Aoo`00000004Yoo`009goo
00<007oo00000goo00<007ooOol00goo00<007ooOol00`0000=oo`000000CGoo4@0027oo1`0000=o
o`0000001000:7oo0`0000Eoo`00000007oo00@00003Ool007oo03Uoo`009goo00<007oo00000goo
0`000goo00<007ooOol0I7ooK@006Goo000WOol00`00Ool00003Ool00`00Oomoo`3`Ool002Moo`03
001oo`0000=oo`03001oogoo0?1oo`00:7oo00<007ooOol00Woo00<007ooOol0l7oo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00X7oo00<007ooOol0<7oo00<007ooOol0BWoo
002OOol00`00Oomoo`0UOol00`00Oomoo`0:Ool00`00Oomoo`19Ool0065oo`<00006Ool00000001o
o`000Woo0P000goo0P000Woo10003Goo0`000Woo0P000goo0P0037oo00<007ooOol00Woo0`000Woo
10000Woo0`0000Aoo`000000009oo`H0009oo`03001oogoo00Ioo`03001oogoo009oo`8000Ioo`03
001oogoo04Qoo`00HWoo00D007ooOomoo`00009oo`03001oo`0000Aoo`05001oogoo001oo`03000=
Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo00Uoo`03001oogoo00=oo`04001o
ogooOol30002Ool01000Oomoo`000Woo00@007ooOomoo`<0009oo`04001oogoo0008Ool00`00Oomo
o`04Ool00`00Oomoo`03Ool00`00Oomoo`18Ool0069oo`05001oogooOol00002Ool00`00Ool00002
0002Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool01P00Oomoo`00Ool0009oo`03001oo`0000ioo`03
001oogoo00=oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0009o
o`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo04Qoo`00HWoo00@007oo
Oomoo`<0009oo`<00003Ool00000008000=oo`8000ioo`<0009oo`800003Ool00000008000aoo`03
001oogoo009oo`@0009oo`8000=oo`<00003Ool0000000Aoo`800003Ool00000008000Yoo`03001o
ogoo009oo`8000Eoo`03001oogoo04Qoo`00H7oo00L007oo001oo`00Ool00009Ool00`00Oomoo`0E
Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0FOol00`00Oomoo`08
Ool00`00Oomoo`19Ool0061oo`L0021oo`8001Moo`03001oogoo00aoo`80009oo`03001oogoo01Ao
o`03001oogoo00Ioo`03001oogoo04Yoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.96694, -1.47757, 0.0189112
  , 0.00933215}},
  CellTags->"2"],

Cell["Here is the plot of input force versus time. ", "MathCaption",
  CellTags->"2"],

Cell["\<\
Plot[Evaluate[fx /. feedbackRules /. thetas],
 {t, 0, 4},
 PlotLabel -> \"Input Force (Newton)\",
 Evaluate[someOptions],
 PlotRange -> All
]\
\>", "Input",
  CellLabel->"In[40]:=",
  CellTags->"2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147152 0.00232099 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .13076 -12 -4.5 ]
[-0.0125 .13076 0 4.5 ]
[-0.0125 .24681 -18 -4.5 ]
[-0.0125 .24681 0 4.5 ]
[-0.0125 .36286 -18 -4.5 ]
[-0.0125 .36286 0 4.5 ]
[-0.0125 .47891 -18 -4.5 ]
[-0.0125 .47891 0 4.5 ]
[-0.0125 .59496 -18 -4.5 ]
[-0.0125 .59496 0 4.5 ]
[ 0 0 -0.125 0 ]
[.5 .63053 -62 0 ]
[.5 .63053 62 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .13076 m
.00625 .13076 L
s
[(50)] -0.0125 .13076 1 0 Mshowa
0 .24681 m
.00625 .24681 L
s
[(100)] -0.0125 .24681 1 0 Mshowa
0 .36286 m
.00625 .36286 L
s
[(150)] -0.0125 .36286 1 0 Mshowa
0 .47891 m
.00625 .47891 L
s
[(200)] -0.0125 .47891 1 0 Mshowa
0 .59496 m
.00625 .59496 L
s
[(250)] -0.0125 .59496 1 0 Mshowa
.125 Mabswid
0 .03793 m
.00375 .03793 L
s
0 .06114 m
.00375 .06114 L
s
0 .08434 m
.00375 .08434 L
s
0 .10755 m
.00375 .10755 L
s
0 .15397 m
.00375 .15397 L
s
0 .17718 m
.00375 .17718 L
s
0 .20039 m
.00375 .20039 L
s
0 .2236 m
.00375 .2236 L
s
0 .27002 m
.00375 .27002 L
s
0 .29323 m
.00375 .29323 L
s
0 .31644 m
.00375 .31644 L
s
0 .33965 m
.00375 .33965 L
s
0 .38607 m
.00375 .38607 L
s
0 .40928 m
.00375 .40928 L
s
0 .43249 m
.00375 .43249 L
s
0 .4557 m
.00375 .4557 L
s
0 .50212 m
.00375 .50212 L
s
0 .52533 m
.00375 .52533 L
s
0 .54854 m
.00375 .54854 L
s
0 .57175 m
.00375 .57175 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -123 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Input) show
99.000000 12.812500 moveto
(Force) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
135.000000 12.812500 moveto
(H) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Newton) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
177.000000 12.812500 moveto
(L) show
183.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.001 w
.02381 .25997 m
.04262 .19611 L
.06244 .14425 L
.08255 .10479 L
.09409 .08722 L
.10458 .07398 L
.12415 .05509 L
.13491 .04732 L
.14509 .04133 L
.15478 .03664 L
.16506 .03257 L
.1835 .02706 L
.19291 .02495 L
.20304 .02308 L
.22134 .02054 L
.23144 .01948 L
.24247 .01855 L
.25301 .01783 L
.26256 .0173 L
.28224 .01648 L
.29303 .01614 L
.30321 .01589 L
.31297 .01569 L
.32329 .01551 L
.34176 .01527 L
.35124 .01518 L
.3614 .0151 L
.37973 .01498 L
.3899 .01494 L
.40097 .0149 L
.41053 .01487 L
.42109 .01484 L
.44087 .0148 L
.4517 .01478 L
.46187 .01477 L
.4717 .01476 L
.48206 .01475 L
.49089 .01475 L
.4959 .01475 L
.50056 .01474 L
.50966 .01474 L
.51425 .01474 L
.5193 .01473 L
.52986 .01473 L
.53961 .01473 L
.55063 .01473 L
.56095 .01472 L
.5811 .01472 L
.59151 .01472 L
.60139 .01472 L
Mistroke
.61993 .01472 L
.62954 .01472 L
.63481 .01472 L
.63607 .01472 L
.6374 .01472 L
.63853 .01472 L
.63977 .01472 L
.64093 .01472 L
.64217 .01472 L
.64325 .01472 L
.64441 .01472 L
.64576 .01472 L
.64704 .01472 L
.64943 .01472 L
.65817 .01472 L
.67799 .01472 L
.68811 .01472 L
.69901 .01472 L
.71852 .01472 L
.728 .01472 L
.73681 .01472 L
.74641 .01472 L
.7519 .01472 L
.75689 .01472 L
.75812 .01472 L
.75941 .01472 L
.76009 .01472 L
.76084 .01472 L
.76215 .01472 L
.76338 .01472 L
.76408 .01472 L
.76471 .01472 L
.76594 .01472 L
.7671 .01472 L
.778 .01472 L
.7962 .01472 L
.80118 .01472 L
.8038 .01472 L
.80523 .01472 L
.80656 .01472 L
.80773 .01472 L
.80899 .01472 L
.8097 .01472 L
.81038 .01472 L
.81164 .01472 L
.81386 .01472 L
.81512 .01472 L
.8163 .01472 L
.81745 .01472 L
.81869 .01472 L
Mistroke
.81937 .01472 L
.82002 .01472 L
.82123 .01472 L
.82235 .01472 L
.8234 .01472 L
.82577 .01472 L
.82712 .01472 L
.82838 .01472 L
.82952 .01472 L
.83075 .01472 L
.83139 .01472 L
.83209 .01472 L
.83351 .01472 L
.83605 .01472 L
.84129 .01472 L
.8428 .01472 L
.84355 .01472 L
.84423 .01472 L
.84552 .01472 L
.84619 .01472 L
.84691 .01472 L
.84811 .01472 L
.8494 .01472 L
.85062 .01472 L
.85173 .01472 L
.85238 .01472 L
.85307 .01472 L
.85432 .01472 L
.85563 .01472 L
.85637 .01472 L
.85705 .01472 L
.87787 .01472 L
.89705 .01472 L
.91575 .01472 L
.91808 .01472 L
.92029 .01472 L
.92152 .01472 L
.92221 .01472 L
.92285 .01472 L
.92397 .01472 L
.92517 .01472 L
.92587 .01472 L
.92662 .01472 L
.92799 .01472 L
.93053 .01472 L
.93295 .01472 L
.93428 .01472 L
.93554 .01472 L
.93676 .01472 L
.93746 .01472 L
Mistroke
.9381 .01472 L
.93923 .01472 L
.94042 .01472 L
.94154 .01472 L
.94259 .01472 L
.94498 .01472 L
.94753 .01472 L
.94996 .01472 L
.9513 .01472 L
.95206 .01472 L
.95276 .01472 L
.954 .01472 L
.95532 .01472 L
.95601 .01472 L
.95673 .01472 L
.95803 .01472 L
.95875 .01472 L
.95943 .01472 L
.96096 .01472 L
.96227 .01472 L
.96352 .01472 L
.96421 .01472 L
.96496 .01472 L
.96627 .01472 L
.96745 .01472 L
.96876 .01472 L
.97142 .01472 L
.9726 .01472 L
.97388 .01472 L
.97509 .01472 L
.97619 .01472 L
Mfstroke
.5 Mabswid
[ .025 .0075 .0075 .0075 ] 0 setdash
.02381 .50522 m
.06244 .40531 L
.10458 .28043 L
.14415 .16939 L
.16408 .1254 L
.18221 .09417 L
.20178 .06919 L
.21254 .05875 L
.22272 .05065 L
.23241 .04429 L
.24269 .03877 L
.26113 .03131 L
.27054 .02845 L
.28067 .02593 L
.29897 .02251 L
.30907 .02109 L
.3201 .01985 L
.33064 .01888 L
.34019 .01817 L
.35986 .01707 L
.37066 .01662 L
.38084 .01628 L
.3906 .01601 L
.40091 .01578 L
.41939 .01546 L
.42886 .01534 L
.43902 .01523 L
.45736 .01508 L
.46753 .01501 L
.4786 .01496 L
.48816 .01492 L
.49872 .01488 L
.51849 .01483 L
.52933 .01481 L
.5395 .01479 L
.54933 .01478 L
.55968 .01477 L
.57819 .01475 L
.58773 .01475 L
.59793 .01474 L
.60755 .01474 L
.6163 .01473 L
.62562 .01473 L
.63071 .01473 L
.63548 .01473 L
.64063 .01473 L
.6463 .01473 L
.65628 .01472 L
.66669 .01472 L
.67657 .01472 L
Mistroke
.6951 .01472 L
.71495 .01472 L
.72379 .01472 L
.72622 .01472 L
.72744 .01472 L
.72813 .01472 L
.72877 .01472 L
.72993 .01472 L
.73098 .01472 L
.73213 .01472 L
.73335 .01472 L
.7347 .01472 L
.73596 .01472 L
.73879 .01472 L
.74394 .01472 L
.75391 .01472 L
.77253 .01472 L
.77711 .01472 L
.77961 .01472 L
.78082 .01472 L
.78193 .01472 L
.78315 .01472 L
.78445 .01472 L
.78513 .01472 L
.78587 .01472 L
.78721 .01472 L
.79204 .01472 L
.81033 .01472 L
.81975 .01472 L
.82494 .01472 L
.82749 .01472 L
.82986 .01472 L
.8312 .01472 L
.83263 .01472 L
.83407 .01472 L
.83565 .01472 L
.84094 .01472 L
.8422 .01472 L
.84351 .01472 L
.8442 .01472 L
.84496 .01472 L
.84565 .01472 L
.84629 .01472 L
.84756 .01472 L
.84871 .01472 L
.84935 .01472 L
.85004 .01472 L
.8513 .01472 L
.85378 .01472 L
.85645 .01472 L
Mistroke
.85774 .01472 L
.85897 .01472 L
.86007 .01472 L
.86127 .01472 L
.86253 .01472 L
.86323 .01472 L
.86387 .01472 L
.86512 .01472 L
.86629 .01472 L
.86697 .01472 L
.86768 .01472 L
.86895 .01472 L
.87045 .01472 L
.87182 .01472 L
.87298 .01472 L
.87408 .01472 L
.87524 .01472 L
.87649 .01472 L
.87876 .01472 L
.88085 .01472 L
.88195 .01472 L
.88314 .01472 L
.88444 .01472 L
.88566 .01472 L
.88695 .01472 L
.88761 .01472 L
.88832 .01472 L
.88958 .01472 L
.89076 .01472 L
.89322 .01472 L
.89445 .01472 L
.89516 .01472 L
.89581 .01472 L
.89653 .01472 L
.89719 .01472 L
.89795 .01472 L
.89867 .01472 L
.89992 .01472 L
.90063 .01472 L
.90129 .01472 L
.90377 .01472 L
.90499 .01472 L
.90611 .01472 L
.9074 .01472 L
.90808 .01472 L
.9088 .01472 L
.90996 .01472 L
.91123 .01472 L
.91362 .01472 L
.91588 .01472 L
Mistroke
.91713 .01472 L
.91783 .01472 L
.91849 .01472 L
.91964 .01472 L
.92086 .01472 L
.92192 .01472 L
.92306 .01472 L
.92512 .01472 L
.92639 .01472 L
.92759 .01472 L
.92875 .01472 L
.92982 .01472 L
.93104 .01472 L
.93236 .01472 L
.93506 .01472 L
.93627 .01472 L
.93757 .01472 L
.9388 .01472 L
.93992 .01472 L
.94123 .01472 L
.94248 .01472 L
.94318 .01472 L
.94382 .01472 L
.94528 .01472 L
.94821 .01472 L
.9489 .01472 L
.94964 .01472 L
.95095 .01472 L
.95201 .01472 L
.95318 .01472 L
.95442 .01472 L
.95558 .01472 L
.95825 .01472 L
.96069 .01472 L
.96192 .01472 L
.96262 .01472 L
.96326 .01472 L
.96444 .01472 L
.96569 .01472 L
.96701 .01472 L
.96824 .01472 L
.96894 .01472 L
.96959 .01472 L
.97033 .01472 L
.97104 .01472 L
.97233 .01472 L
.97306 .01472 L
.97371 .01472 L
.97499 .01472 L
.97619 .01472 L
Mistroke
Mfstroke
[ .01 .01 ] 0 setdash
.02381 .60332 m
.04262 .60246 L
.06244 .60133 L
.08255 .59978 L
.09409 .59863 L
.10458 .59737 L
.12415 .5943 L
.14509 .58966 L
.16424 .58369 L
.18502 .57462 L
.20486 .56254 L
.22588 .54486 L
.24542 .52265 L
.26372 .49566 L
.30249 .4155 L
.34372 .30039 L
.38342 .18652 L
.40346 .13907 L
.42162 .1047 L
.44129 .07665 L
.45209 .06483 L
.46226 .05566 L
.47203 .04838 L
.48234 .04208 L
.50081 .03358 L
.51029 .03031 L
.52045 .02743 L
.53879 .02353 L
.54896 .02192 L
.56003 .0205 L
.56959 .01951 L
.58015 .01861 L
.59992 .01736 L
.61076 .01686 L
.62093 .01647 L
.63076 .01617 L
.64111 .01591 L
.65962 .01555 L
.66916 .01541 L
.67936 .01529 L
.69772 .01512 L
.70797 .01505 L
.71907 .01498 L
.72867 .01494 L
.73922 .0149 L
.7591 .01484 L
.76997 .01482 L
.78014 .0148 L
.79055 .01479 L
.80043 .01477 L
Mistroke
.81897 .01476 L
.82858 .01475 L
.83881 .01474 L
.85721 .01474 L
.86752 .01473 L
.87866 .01473 L
.88829 .01473 L
.89884 .01472 L
.91882 .01472 L
.92973 .01472 L
.9399 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[40]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00:=oo`03001oogoo00Ioo`03001oogoo075oo`00XWoo00<007ooOol027oo00<007ooOol0L7oo
0022Ool30002Ool300001Woo001oo`00Ool0009oo`8000eoo`03001oogoo009oo`8000Ioo`03001o
ogoo06moo`00Pgoo00<007ooOol00Woo00X007ooOol007oo001oo`00Ool000moo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo06moo`00Pgoo00<007ooOol00Woo00T007ooOol007oo001oo`00
Ool00`003Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0Kgoo0023Ool01000Oomoogoo
0P000Woo0P0000Aoo`00Oomoo`<000eoo`03001oogoo00=oo`8000Eoo`03001oogoo06moo`00PGoo
00D007oo001oo`0001aoo`03001oogoo00Qoo`03001oogoo071oo`00PGoo1@000Woo00<007ooOol0
67oo00<007ooOol01Woo00<007ooOol0LGoo003oOolQOol00?moob5oo`00ogoo8Goo000_Ool00`00
Oomoo`0`Ool5000aOol3000bOol2000dOol3000JOol002ioo`03001oo`0003=oo`03001oogoo035o
o`03001oogoo03Aoo`03001oogoo039oo`03001oogoo01Uoo`00;Woo00<007oo0000<goo00<007oo
Ool0<Woo00<007ooOol0<Woo00<007ooOol0<Goo10006Woo000^Ool00`00Ool0000cOol00`00Oomo
o`0bOol00`00Oomoo`0cOol00`00Oomoo`0`Ool00`00Ool0000KOol002ioo`03001oo`0003=oo`03
001oogoo035oo`03001oo`00039oo`03001oo`0003=oo`8001]oo`00;goo00<007ooOol0<Goo0P00
=7oo00<007ooOol0<Woo00<007ooOol0<goo00<007ooOol06Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00:Woog`005goo000UOol00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`0JOol002Aoo`03001oo`0000=oo`03001oogoo0?=oo`0097oo00<007oo00000goo0`00
?WooV@0077oo000TOol00`00Ool00003Ool00`00Oomoo`0]OolA0005Ool00`00Ool0000>000VOol3
000017oo000000000Woo0`0000=oo`000000JWoo000TOol00`00Ool00003Ool00`00Oomoo`0XOol5
000BOol200000goo001oo`0aOol4001jOol002Eoo`03001oogoo009oo`03001oogoo02Eoo`<0015o
o`03001oo`0000<0039oo`<007moo`00:Woo00<007ooOol08Woo0`004Goo0`00=7oo0`00Pgoo000Z
Ool2000QOol2000BOol2000eOol00`00Oomoo`25Ool002Yoo`03001oogoo01eoo`<001=oo`03001o
ogoo03=oo`8008Qoo`00:Woo00<007ooOol06goo0P0057oo0P00=7oo00<007ooOol0RGoo000ZOol0
0`00Oomoo`0JOol00`00Oomoo`0BOol00`00Oomoo`0dOol00`00Oomoo`2:Ool002Yoo`03001oogoo
01Uoo`03001oogoo019oo`03001oogoo03Aoo`03001oogoo08]oo`00:Woo0P006Goo00<007ooOol0
4Woo00<007ooOol0<goo00<007ooOol0SGoo000ZOol00`00Oomoo`0GOol00`00Oomoo`0AOol2000e
Ool00`00Oomoo`2>Ool002Yoo`03001oogoo01Ioo`03001oogoo015oo`03001oogoo0<Ioo`00:Woo
00<007ooOol05Goo00<007ooOol04Goo00<007ooOol0=7oo00<007ooOol0T7oo000ZOol00`00Oomo
o`0DOol00`00Oomoo`0BOol00`00Oomoo`0cOol00`00Oomoo`2AOol002Yoo`03001oogoo01=oo`03
001oogoo019oo`03001oogoo03Aoo`03001oogoo095oo`00:Woo0P004goo00<007ooOol04Woo00<0
07ooOol0bGoo000ZOol00`00Oomoo`0AOol00`00Oomoo`19Ool00`00Oomoo`2COol002Yoo`03001o
ogoo015oo`03001oogoo019oo`03001oogoo03=oo`03001oogoo09Aoo`00:Woo00<007ooOol047oo
00<007ooOol04Woo00<007ooOol0bgoo000ZOol00`00Oomoo`0@Ool00`00Oomoo`0BOol00`00Oomo
o`0cOol00`00Oomoo`2EOol002Yoo`80011oo`03001oogoo019oo`03001oogoo03=oo`03001oogoo
09Ioo`00:Woo00<007ooOol03goo00<007ooOol04Woo00<007ooOol0<goo00<007ooOol0UWoo000Z
Ool00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`3=Ool0021oo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo00ioo`03001oogoo015oo`03001oogoo03Aoo`03001oogoo09Moo`007goo
00<007oo00000Woo00<007oo00000goo00<007ooOol03Goo00<007ooOol04Goo0P00=Goo00<007oo
Ool0V7oo000QOol01P00Oomoo`00Ool000=oo`<000eoo`03001oogoo04Qoo`03001oogoo09Qoo`00
7goo0P000goo00<007oo00000goo00<007ooOol037oo00<007ooOol04Woo00<007ooOol0cgoo000O
Ool00`00Oomoo`02Ool00`00Ool00003Ool00`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`0d
Ool00`00Oomoo`2IOol001moo`<000=oo`03001oogoo009oo`03001oogoo00]oo`03001oogoo019o
o`03001oogoo03=oo`03001oogoo09Yoo`00:Woo00<007ooOol02goo00<007ooOol04Goo00<007oo
Ool0=7oo00<007ooOol0VWoo000ZOol2000;Ool00`00Oomoo`0BOol00`00Oomoo`3AOol002Yoo`03
001oogoo00Yoo`03001oogoo015oo`03001oogoo03Aoo`03001oogoo09]oo`00:Woo00<007ooOol0
2Woo00<007ooOol0Agoo00<007ooOol0W7oo000ZOol00`00Oomoo`09Ool00`00Oomoo`0BOol00`00
Oomoo`0cOol00`00Oomoo`2LOol002Yoo`03001oogoo00Uoo`03001oogoo015oo`03001oogoo0==o
o`00:Woo0P002Goo00<007ooOol0B7oo00<007ooOol0WGoo000ZOol00`00Oomoo`08Ool00`00Oomo
o`0BOol00`00Oomoo`0bOol00`00Oomoo`2NOol002Yoo`03001oogoo00Qoo`03001oogoo019oo`03
001oogoo039oo`03001oogoo09ioo`00:Woo00<007ooOol01goo00<007ooOol04Woo00<007ooOol0
e7oo000ZOol00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0cOol00`00Oomoo`2NOol002Yo
o`8000Qoo`03001oogoo015oo`03001oogoo03=oo`03001oogoo09moo`00:Woo00<007ooOol01Woo
00<007ooOol04Woo00<007ooOol0<goo00<007ooOol0Wgoo000ZOol00`00Oomoo`06Ool00`00Oomo
o`0AOol00`00Oomoo`3FOol002Yoo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo0=Ioo`00
:Woo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol0<goo00<007ooOol0X7oo000ZOol00`00
Oomoo`05Ool00`00Oomoo`18Ool00`00Oomoo`2POol002Yoo`8000Ioo`03001oogoo015oo`03001o
ogoo03Aoo`03001oogoo0:1oo`00:Woo00<007ooOol01Goo00<007ooOol04Goo00<007ooOol0egoo
000ZOol00`00Oomoo`05Ool00`00Oomoo`0@Ool00`00Oomoo`0dOol00`00Oomoo`2QOol001Uoo`D0
009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo
03=oo`03001oogoo0:9oo`006goo00L007ooOomoo`00Ool00002Ool00`00Ool00003Ool00`00Oomo
o`04Ool00`00Oomoo`0@Ool00`00Oomoo`0dOol00`00Oomoo`2ROol001]oo`07001oogooOol007oo
00000Woo00<007oo00000goo0`0017oo00<007ooOol047oo00<007ooOol0fGoo000KOol01`00Oomo
ogoo001oo`00009oo`03001oo`0000=oo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo03=o
o`03001oogoo0:=oo`006goo00L007ooOomoo`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`03
Ool00`00Oomoo`0@Ool00`00Oomoo`0dOol00`00Oomoo`2SOol001Yoo`8000Aoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00=oo`03001oogoo011oo`03001oogoo03Aoo`03001oogoo0:=o
o`00:Woo00<007ooOol0lgoo000ZOol2000GOol00`00Oomoo`0cOol00`00Oomoo`2TOol002Yoo`03
001oogoo01Eoo`03001oogoo03=oo`03001oogoo0:Eoo`00:Woo00<007ooOol05Goo00<007ooOol0
<goo00<007ooOol0YGoo000ZOol00`00Oomoo`0EOol00`00Oomoo`3KOol002Yoo`03001oogoo01Ao
o`03001oogoo03=oo`03001oogoo0:Ioo`00:Woo0P005Goo00<007ooOol0<goo00<007ooOol0YWoo
000ZOol00`00Oomoo`0COol00`00Oomoo`0dOol00`00Oomoo`2VOol002Yoo`03001oogoo01=oo`03
001oogoo0=eoo`00:Woo00<007ooOol04goo00<007ooOol0gGoo000ZOol00`00Oomoo`0BOol00`00
Oomoo`0dOol00`00Oomoo`2WOol002Yoo`8001=oo`03001oogoo03=oo`03001oogoo0:Qoo`00:Woo
00<007ooOol04Goo00<007ooOol0=7oo00<007ooOol0Z7oo000ZOol00`00Oomoo`0AOol00`00Oomo
o`3OOol002Yoo`03001oogoo015oo`03001oogoo03=oo`03001oogoo0:Uoo`00:Woo00<007ooOol0
47oo00<007ooOol0=7oo00<007ooOol0ZGoo000ZOol2000AOol00`00Oomoo`0dOol00`00Oomoo`2Y
Ool002Yoo`03001oogoo011oo`03001oogoo0>1oo`00:Woo00<007ooOol03goo00<007ooOol0=7oo
00<007ooOol0ZWoo000IOol50002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool0
0`00Oomoo`0cOol00`00Oomoo`2[Ool001]oo`07001oogooOol007oo00000Woo00<007oo00000goo
00<007ooOol03goo00<007ooOol0<goo00<007ooOol0Zgoo000KOol00`00Oomoo`03Ool01P00Oomo
o`00Ool000=oo`<000moo`03001oogoo0>5oo`006goo00@007ooOomoo`8000=oo`03001oo`0000=o
o`03001oogoo00ioo`03001oogoo03=oo`03001oogoo0:aoo`006goo00D007ooOomoo`0000Aoo`03
001oo`0000=oo`03001oogoo00ioo`03001oogoo03=oo`03001oogoo0:aoo`006Woo0P000goo0`00
0goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol0<goo00<007ooOol0[7oo000ZOol00`00
Oomoo`0=Ool00`00Oomoo`3SOol002Yoo`03001oogoo00eoo`03001oogoo03=oo`03001oogoo0:eo
o`00:Woo0P003Goo00<007ooOol0<goo00<007ooOol0[Woo000ZOol00`00Oomoo`0<Ool00`00Oomo
o`0cOol00`00Oomoo`2^Ool002Yoo`03001oogoo00aoo`03001oogoo0>Aoo`00:Woo00<007ooOol0
2goo00<007ooOol0<goo00<007ooOol0[goo000ZOol00`00Oomoo`0;Ool00`00Oomoo`0cOol00`00
Oomoo`2_Ool002Yoo`8000aoo`03001oogoo03=oo`03001oogoo0:moo`00:Woo00<007ooOol02Woo
00<007ooOol0=7oo00<007ooOol0[goo000ZOol00`00Oomoo`0:Ool00`00Oomoo`3VOol002Yoo`03
001oogoo00Uoo`03001oogoo03Aoo`03001oogoo0;1oo`00:Woo00<007ooOol02Goo00<007ooOol0
<goo00<007ooOol0/Goo000ZOol2000:Ool00`00Oomoo`0cOol00`00Oomoo`2aOol002Yoo`03001o
ogoo00Qoo`03001oogoo0>Qoo`00:Woo00<007ooOol027oo00<007ooOol0<goo00<007ooOol0/Woo
000ZOol00`00Oomoo`08Ool00`00Oomoo`0bOol00`00Oomoo`2cOol002Yoo`03001oogoo00Qoo`03
001oogoo039oo`03001oogoo0;=oo`00:Woo0P0027oo00<007ooOol0jGoo000ZOol00`00Oomoo`07
Ool00`00Oomoo`0bOol00`00Oomoo`2dOol002Yoo`03001oogoo00Moo`03001oogoo035oo`03001o
ogoo0;Eoo`006Woo0`000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool0<Woo00<007ooOol0]Goo000JOol00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool00003Ool0
0`00Oomoo`06Ool00`00Oomoo`3ZOol001]oo`07001oogooOol007oo00000Woo00<007oo00000goo
0`001Goo00<007ooOol0<Woo00<007ooOol0]Woo000KOol01`00Oomoogoo001oo`00009oo`03001o
o`0000=oo`03001oogoo00Aoo`03001oogoo039oo`03001oogoo0;Moo`006Woo00<007oo00000Woo
00<007oo00000Woo00<007oo00000goo00<007ooOol017oo00<007ooOol0<Woo00<007ooOol0]goo
000KOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomo
o`3/Ool002Yoo`03001oogoo00Aoo`03001oogoo035oo`03001oogoo0;Qoo`00:Woo0P0017oo00<0
07ooOol0<Goo00<007ooOol0^Goo000ZOol00`00Oomoo`03Ool00`00Oomoo`3]Ool002Yoo`03001o
ogoo03Ioo`03001oogoo0;Yoo`00:Woo00<007ooOol0=Goo00<007ooOol0^goo000ZOol00`00Oomo
o`0dOol00`00Oomoo`2lOol002Yoo`03001oogoo0?=oo`00:Woo0P00=7oo00<007ooOol0_Goo000Z
Ool00`00Oomoo`0bOol00`00Oomoo`2nOol002Yoo`03001oogoo039oo`03001oogoo0;ioo`00:Woo
00<007ooOol0<7oo00<007ooOol0`7oo000ZOol00`00Oomoo`0`Ool00`00Oomoo`30Ool002Yoo`80
031oo`03001oogoo0<5oo`00:Woo00<007ooOol0;Goo00<007ooOol0`goo000ZOol00`00Oomoo`0/
Ool00`00Oomoo`34Ool002Yoo`03001oogoo02]oo`03001oogoo0<Eoo`00:Woo00<007ooOol0:Goo
00<007ooOol0agoo000ZOol2000XOol2003:Ool002Yoo`03001oogoo02Eoo`03001oogoo0<]oo`00
:Woo00<007ooOol08goo0P00cWoo000JOol30003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`0OOol3003AOol001Yoo`03001oogoo009oo`03001oo`00009oo`03001oo`0000=oo`03001o
ogoo01]oo`<00=Eoo`006goo00<007ooOol00goo00H007ooOol007oo0003Ool3000GOol3003IOol0
01]oo`04001oogooOol20003Ool00`00Ool00003Ool00`00Oomoo`0;Ool200001Goo00000000Ool0
0`00gWoo000JOol00`00Ool00002Ool00`00Oomoo`02Ool00`00Ool00003Ool00`00Oomoo`03Ool0
0`00Ool0000200000goo0000003XOol001]oo`04001oogooOol30003Ool00`00Oomoo`02Ool00`00
Oomoo`3cOol002Yoo`03001oogoo0?=oo`00:Woo00<007ooOol0lgoo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00Igoo0`00?goo00<007ooOol097oo00<007ooOol0CGoo001X
Ool00`00Oomoo`0mOol00`00Oomoo`0VOol00`00Oomoo`1<Ool005ioo`<00003Ool00000009oo`03
001oo`00008000=oo`<0009oo`8000aoo`<000Aoo`80009oo`<0009oo`<000=oo`8000ioo`04001o
ogooOol3000017oo001oogoo0P000Woo00<007oo00000goo0P000goo0P0000=oo`0000000Woo00<0
07ooOol01goo00<007ooOol0Bgoo001OOol01@00Oomoogoo00000Woo00<007oo00000Woo00<007oo
00000Woo00<007oo00000Woo00<007ooOol02Woo00<007ooOol00Woo00@007ooOol0009oo`05001o
ogooOol00004Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool01P00Ool00000Ool000=oo`07001oo`00
Ool007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007ooOol01goo00<007ooOol0Bgoo
001OOol01@00Oomoogoo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00003goo00<0
07ooOol00Woo00@007ooOol0009oo`05001oogooOol00004Ool3000>Ool00`00Oomoo`02Ool01@00
Ool00000Ool00`0000Qoo`00Ool007oo001oo`0017oo00H007ooOol007oo0002Ool00`00Oomoo`07
Ool00`00Oomoo`1;Ool005moo`03001oogoo00@00003Ool0000000800004Ool00000Ool6000=Ool2
0004Ool20002Ool4000017oo000000000Woo0`003Woo00<007ooOol00Woo0P0000=oo`00Ool00`00
00Aoo`00001oo`H000=oo`800003Ool00000008000Yoo`03001oogoo04]oo`00Ggoo00<007ooOol0
47oo00<007ooOol03Goo00@007ooOol0029oo`04001oogooOol200000goo001oo`0:Ool00`00Oomo
o`0COol00`00Oomoo`1<Ool005ioo`<0021oo`D002=oo`05001oo`00001oo`02000POol00`00Oomo
o`1=Ool00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.910206, -53.5578, 
  0.0189112, 1.93997}},
  CellTags->"2"],

Cell[TextData[{
  "Finally, we compare the graphs of ",
  StyleBox["theta", "MR"],
  " for the nonlinear and linear systems and see that the only case of \
smallest initial displacement is treated adequately by the linear model. "
}], "MathCaption",
  CellTags->"2"],

Cell["Show[plot1, plot]", "Input",
  CellLabel->"In[41]:=",
  CellTags->"2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.0147151 0.490503 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .01472 -6 -4.5 ]
[-0.0125 .01472 0 4.5 ]
[-0.0125 .11282 -18 -4.5 ]
[-0.0125 .11282 0 4.5 ]
[-0.0125 .21092 -18 -4.5 ]
[-0.0125 .21092 0 4.5 ]
[-0.0125 .30902 -18 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .40712 -18 -4.5 ]
[-0.0125 .40712 0 4.5 ]
[-0.0125 .50522 -6 -4.5 ]
[-0.0125 .50522 0 4.5 ]
[-0.0125 .60332 -18 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .01472 m
.00625 .01472 L
s
[(0)] -0.0125 .01472 1 0 Mshowa
0 .11282 m
.00625 .11282 L
s
[(0.2)] -0.0125 .11282 1 0 Mshowa
0 .21092 m
.00625 .21092 L
s
[(0.4)] -0.0125 .21092 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(0.6)] -0.0125 .30902 1 0 Mshowa
0 .40712 m
.00625 .40712 L
s
[(0.8)] -0.0125 .40712 1 0 Mshowa
0 .50522 m
.00625 .50522 L
s
[(1)] -0.0125 .50522 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(1.2)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03924 m
.00375 .03924 L
s
0 .06377 m
.00375 .06377 L
s
0 .08829 m
.00375 .08829 L
s
0 .13734 m
.00375 .13734 L
s
0 .16187 m
.00375 .16187 L
s
0 .18639 m
.00375 .18639 L
s
0 .23544 m
.00375 .23544 L
s
0 .25997 m
.00375 .25997 L
s
0 .28449 m
.00375 .28449 L
s
0 .33354 m
.00375 .33354 L
s
0 .35807 m
.00375 .35807 L
s
0 .38259 m
.00375 .38259 L
s
0 .43164 m
.00375 .43164 L
s
0 .45617 m
.00375 .45617 L
s
0 .48069 m
.00375 .48069 L
s
0 .52974 m
.00375 .52974 L
s
0 .55427 m
.00375 .55427 L
s
0 .57879 m
.00375 .57879 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Theta) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(radian) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .25997 m
.02499 .25992 L
.02605 .2598 L
.02729 .25957 L
.02846 .25928 L
.03053 .25855 L
.03279 .2575 L
.0379 .25421 L
.04262 .25019 L
.05224 .23967 L
.06244 .22606 L
.10458 .16106 L
.14241 .10983 L
.16345 .08761 L
.1827 .07117 L
.20281 .05752 L
.22147 .04757 L
.24046 .03968 L
.26118 .0331 L
.28171 .02823 L
.30031 .0249 L
.31956 .02229 L
.34038 .0202 L
.36032 .01873 L
.38138 .0176 L
.40102 .01682 L
.41935 .01629 L
.43971 .01585 L
.45826 .01556 L
.47735 .01533 L
.49811 .01516 L
.51788 .01504 L
.53889 .01494 L
.55836 .01488 L
.57664 .01484 L
.59682 .0148 L
.61533 .01478 L
.63425 .01476 L
.65495 .01475 L
.67456 .01474 L
.69551 .01473 L
.71686 .01473 L
.73701 .01472 L
.75702 .01472 L
.77548 .01472 L
.79424 .01472 L
.81488 .01472 L
.83433 .01472 L
.85522 .01472 L
.86535 .01472 L
Mistroke
.87639 .01472 L
.8965 .01472 L
.91621 .01472 L
.93719 .01472 L
.95729 .01472 L
.97619 .01472 L
Mfstroke
.5 Mabswid
[ .025 .0075 .0075 .0075 ] 0 setdash
.02381 .50522 m
.02499 .50519 L
.02605 .50511 L
.02729 .50496 L
.02846 .50477 L
.03053 .50428 L
.03279 .50357 L
.03527 .50257 L
.0379 .50127 L
.04262 .49834 L
.05205 .49036 L
.06244 .47857 L
.0842 .44503 L
.10458 .40458 L
.14335 .313 L
.18458 .21556 L
.20517 .17373 L
.22428 .1406 L
.26248 .09079 L
.283 .07187 L
.30161 .05851 L
.32085 .04777 L
.34167 .03897 L
.36161 .03267 L
.38268 .02772 L
.40231 .02432 L
.42065 .02193 L
.441 .01996 L
.45956 .01862 L
.47864 .0176 L
.4994 .01678 L
.51918 .01622 L
.54018 .01579 L
.55966 .0155 L
.57794 .0153 L
.59812 .01513 L
.61662 .01502 L
.63555 .01494 L
.65625 .01488 L
.67586 .01483 L
.69681 .0148 L
.71815 .01477 L
.73831 .01476 L
.75832 .01475 L
.77677 .01474 L
.79554 .01473 L
.81617 .01473 L
.83562 .01472 L
.85651 .01472 L
.86665 .01472 L
Mistroke
.87769 .01472 L
.88824 .01472 L
.89779 .01472 L
.9175 .01472 L
.92832 .01472 L
.93849 .01472 L
.95814 .01472 L
.97619 .01472 L
Mfstroke
[ .01 .01 ] 0 setdash
.02381 .60332 m
.02499 .60332 L
.02605 .60332 L
.02729 .60331 L
.02846 .60331 L
.03053 .6033 L
.03279 .60329 L
.03527 .60327 L
.0379 .60325 L
.04262 .6032 L
.05205 .60305 L
.06244 .60282 L
.07293 .60251 L
.0842 .60208 L
.10458 .60101 L
.11468 .6003 L
.12571 .59937 L
.1458 .59712 L
.16548 .594 L
.18645 .58927 L
.19674 .58626 L
.20786 .58237 L
.22803 .57322 L
.24797 .5608 L
.26904 .54296 L
.28867 .5209 L
.30701 .49479 L
.34592 .4207 L
.38728 .32108 L
.42712 .2247 L
.46545 .14928 L
.48523 .11923 L
.50623 .09358 L
.52593 .07471 L
.54398 .06109 L
.56333 .0497 L
.58419 .04039 L
.60311 .03402 L
.62381 .02879 L
.64342 .02512 L
.66437 .02222 L
.68572 .02008 L
.70587 .01862 L
.72588 .01755 L
.74434 .01683 L
.7631 .01628 L
.78374 .01584 L
.80319 .01553 L
.82408 .0153 L
.84525 .01513 L
Mistroke
.86536 .01501 L
.8852 .01493 L
.9036 .01487 L
.92416 .01483 L
.94278 .0148 L
.95884 .01478 L
.97619 .01476 L
Mfstroke
1 0 0 r
[ ] 0 setdash
.02381 .25997 m
.02499 .25991 L
.02605 .25975 L
.02729 .25947 L
.02846 .25909 L
.03053 .25817 L
.03279 .25685 L
.0379 .25276 L
.04262 .24785 L
.06244 .21965 L
.10458 .15051 L
.1249 .1217 L
.14393 .09897 L
.16333 .07999 L
.18177 .06546 L
.20201 .0529 L
.22054 .04396 L
.24034 .03658 L
.25873 .03134 L
.27925 .0269 L
.29786 .02388 L
.31711 .02153 L
.33793 .01964 L
.35787 .01831 L
.37893 .01729 L
.39857 .0166 L
.4169 .01612 L
.43725 .01573 L
.45581 .01547 L
.4749 .01527 L
.49566 .01511 L
.51543 .015 L
.53644 .01492 L
.55591 .01486 L
.57419 .01482 L
.59437 .01479 L
.61288 .01477 L
.6318 .01476 L
.6525 .01475 L
.67211 .01474 L
.69306 .01473 L
.71441 .01473 L
.73456 .01472 L
.75457 .01472 L
.77302 .01472 L
.79179 .01472 L
.81243 .01472 L
.83188 .01472 L
.85277 .01472 L
.87394 .01472 L
Mistroke
.89404 .01472 L
.91389 .01472 L
.93229 .01472 L
.95285 .01472 L
.97147 .01472 L
.97619 .01472 L
Mfstroke
.02381 .50522 m
.02499 .5051 L
.02605 .50479 L
.02729 .50422 L
.02846 .50346 L
.03053 .50162 L
.03279 .49899 L
.0379 .49081 L
.04262 .48098 L
.06244 .42458 L
.10458 .28631 L
.1249 .22869 L
.14393 .18323 L
.16333 .14526 L
.18177 .11621 L
.20201 .09108 L
.22054 .0732 L
.24034 .05845 L
.25873 .04796 L
.27925 .03909 L
.29786 .03305 L
.31711 .02834 L
.33793 .02456 L
.35787 .02191 L
.37893 .01987 L
.39857 .01849 L
.4169 .01753 L
.43725 .01674 L
.45581 .01622 L
.4749 .01582 L
.49566 .0155 L
.51543 .01529 L
.53644 .01512 L
.55591 .01501 L
.57419 .01493 L
.59437 .01487 L
.61288 .01483 L
.6318 .0148 L
.6525 .01477 L
.67211 .01476 L
.69306 .01475 L
.71441 .01474 L
.73456 .01473 L
.75457 .01473 L
.77302 .01472 L
.79179 .01472 L
.81243 .01472 L
.83188 .01472 L
.85277 .01472 L
.87394 .01472 L
Mistroke
.89404 .01472 L
.91389 .01472 L
.93229 .01472 L
.95285 .01472 L
.97147 .01472 L
.97619 .01472 L
Mfstroke
.02381 .60332 m
.02499 .60318 L
.02605 .60281 L
.02729 .60212 L
.02846 .6012 L
.03053 .59901 L
.03279 .59584 L
.0379 .58603 L
.04262 .57423 L
.06244 .50655 L
.10458 .34063 L
.1249 .27148 L
.14393 .21694 L
.16333 .17137 L
.18177 .13651 L
.20201 .10635 L
.22054 .0849 L
.24034 .0672 L
.25873 .05461 L
.27925 .04397 L
.29786 .03672 L
.31711 .03106 L
.33793 .02653 L
.35787 .02335 L
.37893 .0209 L
.39857 .01924 L
.4169 .01809 L
.43725 .01715 L
.45581 .01652 L
.4749 .01604 L
.49566 .01566 L
.51543 .0154 L
.53644 .0152 L
.55591 .01507 L
.57419 .01498 L
.59437 .0149 L
.61288 .01485 L
.6318 .01482 L
.6525 .01479 L
.67211 .01477 L
.69306 .01475 L
.71441 .01474 L
.73456 .01473 L
.75457 .01473 L
.77302 .01472 L
.79179 .01472 L
.81243 .01472 L
.83188 .01472 L
.85277 .01472 L
.87394 .01472 L
Mistroke
.89404 .01472 L
.91389 .01472 L
.93229 .01472 L
.95285 .01472 L
.97147 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[41]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00:=oo`03001oogoo00Ioo`03001oogoo075oo`00XWoo00<007ooOol027oo00<007ooOol0L7oo
0022Ool30002Ool300001Woo001oo`00Ool0009oo`8000eoo`03001oogoo009oo`8000Ioo`03001o
ogoo06moo`00Pgoo00<007ooOol00Woo00X007ooOol007oo001oo`00Ool000moo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo06moo`00Pgoo00<007ooOol00Woo00T007ooOol007oo001oo`00
Ool00`003Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0Kgoo0023Ool01000Oomoogoo
0P000Woo0P0000Aoo`00Oomoo`<000eoo`03001oogoo00=oo`8000Eoo`03001oogoo06moo`00PGoo
00D007oo001oo`0001aoo`03001oogoo00Qoo`03001oogoo071oo`00PGoo1@000Woo00<007ooOol0
67oo00<007ooOol01Woo00<007ooOol0LGoo003oOolQOol00?moob5oo`00ogoo8Goo000_Ool00`00
Oomoo`0`Ool5000aOol3000bOol2000dOol3000JOol002ioo`03001oo`0003=oo`03001oogoo035o
o`03001oogoo03Aoo`03001oogoo039oo`03001oogoo01Uoo`00;Woo00<007oo0000<goo00<007oo
Ool0<Woo00<007ooOol0<Woo00<007ooOol0<Goo10006Woo000^Ool00`00Ool0000cOol00`00Oomo
o`0bOol00`00Oomoo`0cOol00`00Oomoo`0`Ool00`00Ool0000KOol002ioo`03001oo`0003=oo`03
001oogoo035oo`03001oo`00039oo`03001oo`0003=oo`8001]oo`00;goo00<007ooOol0<Goo0P00
=7oo00<007ooOol0<Woo00<007ooOol0<goo00<007ooOol06Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00:Woog`005goo000UOol00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`0JOol002Aoo`03001oo`0000=oo`03001oogoo0?=oo`0097oo00<007oo00000goo0`00
FGooOW`077oo000TOol00`00Ool00003Ool00`00Oomoo`17OolOO00600000goo00000004000SOol3
00000goo0000000200001Goo00000000Ool00`000Woo0P00BGoo000TOol00`00Ool00003Ool00`00
Oomoo`0nOolGO0000goo001oo`06000_Ool30002Ool3001NOol002Eoo`03001oogoo009oo`03001o
ogoo03Yoo`Al0004001oogooOol9O006Ool5000cOol3001WOol002Yoo`03001oogoo03Ioo`Al00Eo
o`Ql00Ioo`@003=oo`@006]oo`00:Woo00<007ooOol0<Woo17`000<007ooOol017oo1G`027oo0`00
=Goo00<007ooOol0KWoo000ZOol2000aOol2O0030006Ool4O009Ool00`00Oomoo`0cOol01000Ool0
0000LGoo000ZOol00`00Oomoo`0^Ool2O0020007Ool4O009Ool2000dOol2001eOol002Yoo`03001o
ogoo02aoo`9l0003001oogoo00Ioo`Al00Qoo`<003Aoo`03001oogoo07Ioo`00:Woo00<007ooOol0
:Woo0W`000<007ooOol01Woo17`02Goo00<007ooOol0<goo0P00NGoo000ZOol00`00Oomoo`0XOol2
O0000`00Oomoo`06Ool2O0000gooO01oo`09Ool00`00Oomoo`0bOol00`00Oomoo`1jOol002Yoo`80
02Moo`9l0003Ool007oo00Ioo`9l0003Ooml07`000Uoo`03001oogoo03=oo`03001oogoo07]oo`00
:Woo00<007ooOol09Goo00Al07oo000000Ioo`9l009oo`03O01oogoo00Moo`8003Eoo`03001oogoo
07aoo`00:Woo00<007ooOol097oo00=l07oo00001goo00El07ooOomoog`000Uoo`03001oogoo03=o
o`8007moo`00:Woo00<007ooOol08goo00=l07oo00001goo00=l07ooOol00W`02Goo00<007ooOol0
<goo00<007ooOol0Ogoo000ZOol00`00Oomoo`0ROol00g`000000007Ool017`0Oomoog`02Woo00<0
07ooOol0=7oo00<007ooOol0Ogoo000ZOol00`00Oomoo`0QOol00g`0001oo`07Ool017`0Oomoog`0
2Goo0P00=Goo00<007ooOol0PGoo000ZOol2000POol2O0000`00Oomoo`06Ool017`0Oomoog`0@7oo
00<007ooOol0PWoo000ZOol00`00Oomoo`0NOol00g`0Ool00008Ool017`0Oomoog`02Woo00<007oo
Ool0=7oo00<007ooOol0PWoo000ZOol00`00Oomoo`0MOol00g`0Ool00009Ool017`0Oomoog`02Goo
00<007ooOol0<goo00<007ooOol0Q7oo000KOol00`00Oomoo`02Ool01000Oomoogoo0`000goo00<0
07ooOol077oo00=l07oo00002Goo00Al07ooOoml00Uoo`03001oogoo03=oo`03001oogoo08Eoo`00
6Woo00<007oo00001goo00<007ooOol00goo00<007ooOol06goo00=l07oo00002Goo00Al07ooOoml
00Yoo`03001oogoo03=oo`03001oogoo08Eoo`006Woo00<007oo000027oo00<007ooOol00Woo0`00
6goo00=l0000Ool02Goo00=l07ooO0002Woo00<007ooOol0_7oo000JOol00`00Ool00008Ool00`00
Oomoo`02Ool00`00Oomoo`0JOol00g`0Ool00009Ool017`0Oomoog`02Goo00<007ooOol0<goo0P00
R7oo000JOol00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0IOol00g`0Ool00009Ool017`0
Oomoog`02Goo00<007ooOol0<goo00<007ooOol0R7oo000KOol00`00Oomoo`07Ool00`00Oomoo`02
Ool00`00Oomoo`0HOol00g`0Ool0000:Ool00g`0Ooml000:Ool00`00Oomoo`0cOol00`00Oomoo`28
Ool002Yoo`03001oogoo01Qoo`03O01oo`0000Uoo`04O01oogooO009Ool00`00Oomoo`0cOol00`00
Oomoo`29Ool002Yoo`8001Qoo`03O01oo`0000Uoo`04O01oogooO009Ool00`00Oomoo`0cOol00`00
Oomoo`2:Ool002Yoo`03001oogoo01Ioo`03O01oo`0000Yoo`03O01oog`000Uoo`03001oogoo03Ao
o`03001oogoo08Yoo`00:Woo00<007ooOol05Woo00=l07oo00002Goo00Al07ooOoml00Uoo`03001o
ogoo0<5oo`00:Woo00<007ooOol05Goo00=l07oo00002Goo00Al07ooOoml00Uoo`03001oogoo03Ao
o`03001oogoo08]oo`00:Woo00<007ooOol057oo00=l07oo00002Woo00Al07ooOoml00Uoo`03001o
ogoo03=oo`03001oogoo08aoo`00:Woo00<007ooOol057oo00=l07oo00002Goo00Al07ooOoml00Uo
o`03001oogoo03Aoo`03001oogoo08aoo`00:Woo0P0057oo00=l07oo00002Woo00Al07ooOoml00Qo
o`03001oogoo0<Aoo`00:Woo00<007ooOol04Woo00=l07oo00002Woo00Al07ooOoml00Uoo`03001o
ogoo03Aoo`03001oogoo08eoo`00:Woo00<007ooOol04Woo00=l07oo00002Woo00Al07ooOoml00Qo
o`03001oogoo03Aoo`03001oogoo08ioo`00:Woo00<007ooOol04Goo00=l07oo00002Woo00Al07oo
Ooml00Uoo`03001oogoo03Aoo`03001oogoo08ioo`00:Woo00<007ooOol04Goo00=l0000Ool02Woo
00Al07ooOoml00Qoo`03001oogoo0<Ioo`00:Woo0P004Goo00=l0000Ool02Woo00Al07ooOoml00Uo
o`03001oogoo03Aoo`03001oogoo08moo`00:Woo00<007ooOol03goo00=l07oo00002goo00Al07oo
Ooml00Qoo`03001oogoo03Aoo`03001oogoo091oo`00:Woo00<007ooOol03goo00=l0000Ool02Woo
00Al07ooOoml00Uoo`03001oogoo03Aoo`03001oogoo091oo`00:Woo00<007ooOol03Woo00=l0000
Ool02goo00Al07ooOoml00Qoo`03001oogoo0<Qoo`006goo00<007ooOol00Woo00<007ooOol00Woo
0`000Woo00<007ooOol03Goo00=l07oo00002goo00Al07ooOoml00Qoo`03001oogoo03Eoo`03001o
ogoo095oo`006Woo00<007oo00002Goo00D007ooOomoo`0000moo`03O00007oo00]oo`04O01oogoo
O008Ool00`00Oomoo`0dOol00`00Oomoo`2BOol001Yoo`03001oo`0000Moo`@0009oo`<000aoo`03
O00007oo00aoo`03O01oog`000Uoo`03001oogoo03Aoo`03001oogoo099oo`006Woo00<007oo0000
1goo00<007oo00000goo00<007ooOol037oo00=l07ooOol02goo00Al07ooOoml00Qoo`03001oogoo
0<Yoo`006Woo00<007oo000027oo0P000goo00<007ooOol02goo00=l0000Ool037oo00Al07ooOoml
00Qoo`03001oogoo03Aoo`03001oogoo09=oo`006goo00<007ooOol027oo00D007ooOomoo`0000ao
o`03O00007oo00aoo`04O01oogooO008Ool00`00Oomoo`0dOol00`00Oomoo`2DOol002Yoo`03001o
ogoo00Yoo`03O01oogoo00aoo`04O01oogooO008Ool00`00Oomoo`0dOol00`00Oomoo`2DOol002Yo
o`8000Yoo`03O00007oo00eoo`04O01oogooO007Ool00`00Oomoo`3<Ool002Yoo`03001oogoo00Qo
o`03O00007oo00eoo`04O01oogooO008Ool00`00Oomoo`0dOol00`00Oomoo`2EOol002Yoo`03001o
ogoo00Qoo`03O01oogoo00eoo`04O01oogooO008Ool00`00Oomoo`0cOol00`00Oomoo`2FOol002Yo
o`03001oogoo00Moo`03O01oogoo00ioo`04O01oogooO007Ool00`00Oomoo`0dOol00`00Oomoo`2F
Ool002Yoo`03001oogoo00Ioo`03O01oogoo00ioo`04O01oogooO008Ool00`00Oomoo`3=Ool002Yo
o`03001oogoo00Aoo`9l015oo`04O01oogooO007Ool00`00Oomoo`0dOol00`00Oomoo`2GOol002Yo
o`8000Aoo`03O01oogoo015oo`04O01oogooO007Ool00`00Oomoo`0cOol00`00Oomoo`2HOol002Yo
o`03001oogoo01Ioo`04O01oogooO007Ool00`00Oomoo`0dOol00`00Oomoo`2HOol002Yoo`03001o
ogoo01Ioo`04O01oogooO007Ool00`00Oomoo`3?Ool002Yoo`03001oogoo01Ioo`04O01oogooO006
Ool00`00Oomoo`0dOol00`00Oomoo`2IOol002Yoo`03001oogoo01Eoo`04O01oogooO007Ool00`00
Oomoo`0dOol00`00Oomoo`2IOol002Yoo`8001Ioo`04O01oogooO00nOol00`00Oomoo`2IOol002Yo
o`03001oogoo01Eoo`04O01oogooO007Ool00`00Oomoo`3@Ool002Yoo`03001oogoo01Aoo`05O01o
ogooOoml0006Ool00`00Oomoo`0dOol00`00Oomoo`2JOol002Yoo`03001oogoo01Aoo`04O01oogoo
O00mOol00`00Oomoo`2KOol001]oo`03001oogoo009oo`04001oogooOol20004Ool00`00Oomoo`0D
Ool017`0Oomoog`01Woo00<007ooOol0=7oo00<007ooOol0Vgoo000JOol00`00Ool00007Ool00`00
Ool00003Ool00`00Oomoo`0COol01G`0OomoogooO0001Goo00<007ooOol0dgoo000JOol00`00Ool0
0007Ool00`00Ool00003Ool3000COol01G`0OomoogooO0001Goo00<007ooOol0=7oo00<007ooOol0
W7oo000JOol00`00Ool00007Ool20004Ool00`00Oomoo`0COol017`0Oomoog`01Woo00<007ooOol0
<goo00<007ooOol0WGoo000JOol00`00Ool00007Ool00`00Oomoo`03Ool00`00Oomoo`0BOol01G`0
OomoogooO0001Goo00<007ooOol0=7oo00<007ooOol0WGoo000KOol00`00Oomoo`07Ool20003Ool0
0`00Oomoo`0BOol01G`0OomoogooO0001Goo00<007ooOol0=7oo00<007ooOol0WGoo000ZOol00`00
Oomoo`0BOol01G`0OomoogooO00017oo00<007ooOol0eGoo000ZOol2000BOol01G`0OomoogooO000
1Goo00<007ooOol0=7oo00<007ooOol0WWoo000ZOol00`00Oomoo`0AOol01G`0OomoogooO0001Goo
00<007ooOol0<goo00<007ooOol0Wgoo000ZOol00`00Oomoo`0AOol01G`0OomoogooO000>goo00<0
07ooOol0Wgoo000ZOol00`00Oomoo`0@Ool00g`0Oomoo`02Ool00g`0Oomoo`02Ool00`00Oomoo`3F
Ool002Yoo`03001oogoo011oo`05O01oogooOoml0005Ool00`00Oomoo`0dOol00`00Oomoo`2OOol0
02Yoo`80015oo`05O01oogooOoml0004Ool00`00Oomoo`0dOol00`00Oomoo`2POol002Yoo`03001o
ogoo011oo`05O01oogooOoml0004Ool00`00Oomoo`0dOol00`00Oomoo`2POol002Yoo`03001oogoo
00moo`03O01oogoo009oo`05O01oogooOol0003JOol002Yoo`03001oogoo00moo`05O01oogooOoml
0004Ool00`00Oomoo`0dOol00`00Oomoo`2QOol002Yoo`03001oogoo00moo`05O01oogooOoml0003
Ool00`00Oomoo`0dOol00`00Oomoo`2ROol002Yoo`03001oogoo00ioo`03O01oogoo009oo`05O01o
ogooOol0000fOol00`00Oomoo`2ROol002Yoo`8000moo`05O01oogooOoml0004Ool00`00Oomoo`3I
Ool002Yoo`03001oogoo00ioo`05O01oogooOoml0003Ool00`00Oomoo`0dOol00`00Oomoo`2SOol0
02Yoo`03001oogoo00eoo`03O01oogoo009oo`05O01oogooOol0000eOol00`00Oomoo`2TOol001]o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00eoo`03O01oogoo009o
o`04O01oogoo000fOol00`00Oomoo`2TOol001Yoo`03001oo`0000Moo`03001oo`0000=oo`03001o
ogoo00eoo`05O01oogooOoml0003Ool00`00Oomoo`3KOol001Yoo`03001oo`0000Moo`03001oo`00
00=oo`<000aoo`03O01oogoo009oo`05O01oogooOol0000fOol00`00Oomoo`2TOol001Yoo`03001o
o`0000Qoo`03001oogoo009oo`03001oogoo00aoo`03O01oogoo009oo`04O01oogoo000fOol00`00
Oomoo`2UOol001Yoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo00aoo`03O01oogoo009o
o`03O01oogoo03Moo`03001oogoo0:Eoo`006goo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool02goo00=l07ooOol00Woo00Al07ooOol00=moo`00:Woo00<007ooOol02goo00=l07ooOol00Woo
00=l07oo0000=goo00<007ooOol0YWoo000ZOol00`00Oomoo`0;Ool00g`0Oomoo`02Ool00g`0Oomo
o`0fOol00`00Oomoo`2WOol002Yoo`8000]oo`03O01oogoo009oo`04O01oogoo000fOol00`00Oomo
o`2WOol002Yoo`03001oogoo00Yoo`03O01oogoo009oo`03O01oo`000>5oo`00:Woo00<007ooOol0
2Woo00=l07ooOol00Woo00=l07oo0000=Woo00<007ooOol0Z7oo000ZOol00`00Oomoo`09Ool00g`0
Oomoo`03Ool00g`0001oo`0eOol00`00Oomoo`2YOol002Yoo`03001oogoo00Uoo`03O01oogoo009o
o`03O00007oo03Ioo`03001oogoo0:Uoo`00:Woo0P002Woo00=l07ooOol00Woo00=l0000Ool0hWoo
000ZOol00`00Oomoo`09Ool00g`0Oomoo`02Ool00g`0Oomoo`0eOol00`00Oomoo`2ZOol002Yoo`03
001oogoo00Qoo`03O01oogoo009oo`03O01oogoo03Eoo`03001oogoo0:]oo`00:Woo00<007ooOol0
27oo00=l07ooOol00Woo00=l07ooOol0=Goo00<007ooOol0Zgoo000ZOol00`00Oomoo`08Ool01W`0
Oomoogoo001l0>Eoo`00:Woo00<007ooOol01goo00Ml07ooOomoo`00Ooml000fOol00`00Oomoo`2/
Ool002Yoo`8000Qoo`06O01oogoo001oog`0=Woo00<007ooOol0[Goo000ZOol00`00Oomoo`06Ool0
1g`0Oomoogoo001oog`003Ioo`03001oogoo0:eoo`00:Woo00<007ooOol01Woo00Al07ooOol0009o
o`03O01oogoo0>Aoo`008goo1@000Woo00<007ooOol01Goo00=l07oo000017oo00=l07ooOol0<goo
00<007ooOol0[Woo000UOol00`00Oomoo`02Ool00`00Oomoo`04Ool2O0020003Ool00g`0Oomoo`0c
Ool00`00Oomoo`2_Ool002Eoo`03001oogoo009oo`<000=oo`9l00Ioo`03O01oogoo039oo`03001o
ogoo0;1oo`009Goo00<007ooOol00Woo00<007ooOol02goo00=l07ooOol0<Goo00<007ooOol0/Goo
000UOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00g`0Oomoo`0aOol00`00Oomoo`2bOol002Aoo`80
00Aoo`03001oogoo00Yoo`03O01oogoo035oo`03001oogoo0;9oo`00:Woo00<007ooOol02Woo00=l
07ooOol0iWoo000ZOol00`00Oomoo`0:Ool00g`0Oomoo`0_Ool00`00Oomoo`2dOol002Yoo`8000Yo
o`03O01oogoo02moo`03001oogoo0;Eoo`00:Woo00<007ooOol02Goo00=l07ooOol0;goo00<007oo
Ool0]Goo000ZOol00`00Oomoo`09Ool00g`0Oomoo`0]Ool00`00Oomoo`2gOol002Yoo`03001oogoo
00Uoo`03O01oogoo02aoo`03001oogoo0;Qoo`00:Woo00<007ooOol027oo00=l07ooOol0;Goo00<0
07ooOol0^7oo000ZOol20009Ool00g`0Oomoo`0[Ool00`00Oomoo`2jOol002Yoo`03001oogoo00Qo
o`03O01oogoo02Uoo`800;eoo`00:Woo00<007ooOol027oo00=l07ooOol0:Goo00<007ooOol0_7oo
000ZOol00`00Oomoo`07Ool00g`0Oomoo`0XOol00`00Oomoo`2nOol002Yoo`03001oogoo00Moo`03
O01oogoo02Ioo`800<5oo`00:Woo0P0027oo00=l07ooOol097oo00<007ooOol0`Woo000ZOol00`00
Oomoo`06Ool00g`0Oomoo`0SOol20035Ool002Yoo`03001oogoo00Ioo`03O01oogoo01moo`<00<Qo
o`00:Woo00<007ooOol01Goo00=l07ooOol077oo0`00c7oo000IOol50002Ool01000Oomoogoo0`00
0goo00<007ooOol01Goo00=l07ooOol067oo0`00d7oo000KOol00`00Oomoo`06Ool00`00Oomoo`03
Ool00`00Oomoo`04Ool00g`0Oomoo`0=Ool200001Goo00000000Ool00`00eGoo000KOol00`00Oomo
o`07Ool00`00Oomoo`02Ool30003Ool00g`0Ool0000200000goo0000000200001Goo00000000Ool0
0P00ggoo000KOol00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`3cOol001]oo`03001oogoo
00Ioo`03001oo`0000=oo`03001oogoo0?=oo`006Woo0P002Goo00<007ooOol00Woo00<007ooOol0
lgoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00Ugoo00<007ooOol097oo
00<007ooOol0Ggoo002FOol00`00Oomoo`0VOol00`00Oomoo`1NOol0071oo`<00006Ool00000001o
o`000Woo0P000goo0P000Woo10003Goo00<007ooOol00Woo0`000Woo10000Woo0`0000Aoo`000000
009oo`H0009oo`03001oogoo00Moo`03001oogoo05eoo`00LGoo00D007ooOomoo`00009oo`03001o
o`0000Aoo`05001oogoo001oo`03000>Ool00`00Oomoo`03Ool01000Oomoogoo0`000Woo00@007oo
Ool0009oo`04001oogooOol30002Ool01000Oomoo`002Goo00<007ooOol0GGoo001aOol01@00Oomo
ogoo00000Woo00<007oo00000P000Woo00<007ooOol017oo00<007ooOol037oo00<007ooOol00goo
00<007ooOol00goo00@007ooOol0009oo`04001oogoo0005Ool01000Oomoo`000Woo00<007ooOol0
1goo00<007ooOol0GGoo001aOol01000Oomoogoo0`000Woo0`0000=oo`0000000P000goo0P003Woo
00<007ooOol00Woo10000Woo0P000goo0`0000=oo`00000017oo0P0000=oo`0000000P002Woo00<0
07ooOol0GGoo001_Ool01`00Ool007oo001oo`0000Uoo`03001oogoo01Aoo`03001oogoo00ioo`03
001oogoo01Eoo`03001oogoo05ioo`00Kgoo1`008Goo00<007ooOol037oo0P000Woo00<007ooOol0
4Goo00<007ooOol0Ggoo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.910206, -0.253428, 
  0.0189112, 0.00917968}},
  CellTags->"2"],

Cell[TextData[{
  "The transient responses suggest that our linear feedback is not \
sufficiently prompt in reacting to moderate and large initial displacements ",
  
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0)\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ", and that may cause problems for still larger angles. The case ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0) = \(\(1.2\)\(\ \)\)\)], "InlineFormula",
    CellTags->"S0.0.1"],
  "rad is almost critical. Indeed, for a slightly larger displacement, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0) = \(\(1.25\)\(\ \)\)\)], 
    "InlineFormula",
    CellTags->"S0.0.1"],
  " rad, the system becomes hard to control. "
}], "Text",
  CellTags->"2"],

Cell["\<\
We solve the same equation for another set of initial conditions. \
\
\>", "MathCaption",
  CellTags->"2"],

Cell["\<\
thetaBig = NDSolve[
 {de, theta[0]==1.25, theta'[0]==0},
 {theta}, {t, 0, 4},
 MaxSteps -> 1000
]\
\>", "Input",
  CellLabel->"In[42]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"theta", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[42]=",
  CellTags->"2"],

Cell[TextData[{
  "In the following graphs, we will plot the results for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0) = 1.25\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " as a solid line and one of our previous curves (namely, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0) = 1.2\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ") as a dashed line. Here are our new options. "
}], "MathCaption",
  CellTags->"2"],

Cell["\<\
newOptions = {
 PlotStyle -> {
 \tThickness[.001],
\tDashing[{.01, .01}]
 },
 Frame -> {Automatic, Automatic, None, None},
 FrameLabel -> {\"Time (s)\", None}
}\
\>", "Input",
  CellLabel->"In[43]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"PlotStyle", "\[Rule]", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"Thickness", "[", 
                StyleBox["0.001`",
                  StyleBoxAutoDelete->True,
                  PrintPrecision->1], "]"}], ",", 
              RowBox[{"Dashing", "[", 
                RowBox[{"{", 
                  RowBox[{
                    StyleBox["0.01`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->1], ",", 
                    StyleBox["0.01`",
                      StyleBoxAutoDelete->True,
                      PrintPrecision->1]}], "}"}], "]"}]}], "}"}]}], ",", 
        \(Frame \[Rule] {Automatic, Automatic, None, None}\), ",", 
        \(FrameLabel \[Rule] {"Time (s)", None}\)}], "}"}]], "Output",
  CellLabel->"Out[43]=",
  CellTags->"2"],

Cell[TextData[{
  "We find that the pendulum still could be driven from ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0) = 1.25\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 0\)], "InlineFormula",
    CellTags->"S0.0.1"],
  ", but now it oscillates badly around the equilibrium point. "
}], "MathCaption",
  CellTags->"2"],

Cell["\<\
Plot[Evaluate[theta[t] /. {thetaBig, thetas[[3]]}],
 {t, 0, 4},
 PlotLabel -> \"Theta (radian)\",
 Evaluate[newOptions]
]\
\>", "Input",
  CellLabel->"In[44]:=",
  CellTags->"2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.309138 0.0428153 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .05225 -12 -4.5 ]
[-0.0125 .05225 0 4.5 ]
[-0.0125 .13788 -12 -4.5 ]
[-0.0125 .13788 0 4.5 ]
[-0.0125 .22351 -12 -4.5 ]
[-0.0125 .22351 0 4.5 ]
[-0.0125 .30914 -6 -4.5 ]
[-0.0125 .30914 0 4.5 ]
[-0.0125 .39477 -6 -4.5 ]
[-0.0125 .39477 0 4.5 ]
[-0.0125 .4804 -6 -4.5 ]
[-0.0125 .4804 0 4.5 ]
[-0.0125 .56603 -6 -4.5 ]
[-0.0125 .56603 0 4.5 ]
[ 0 0 -0.125 0 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .05225 m
.00625 .05225 L
s
[(-6)] -0.0125 .05225 1 0 Mshowa
0 .13788 m
.00625 .13788 L
s
[(-4)] -0.0125 .13788 1 0 Mshowa
0 .22351 m
.00625 .22351 L
s
[(-2)] -0.0125 .22351 1 0 Mshowa
0 .30914 m
.00625 .30914 L
s
[(0)] -0.0125 .30914 1 0 Mshowa
0 .39477 m
.00625 .39477 L
s
[(2)] -0.0125 .39477 1 0 Mshowa
0 .4804 m
.00625 .4804 L
s
[(4)] -0.0125 .4804 1 0 Mshowa
0 .56603 m
.00625 .56603 L
s
[(6)] -0.0125 .56603 1 0 Mshowa
.125 Mabswid
0 .07365 m
.00375 .07365 L
s
0 .09506 m
.00375 .09506 L
s
0 .11647 m
.00375 .11647 L
s
0 .15928 m
.00375 .15928 L
s
0 .18069 m
.00375 .18069 L
s
0 .2021 m
.00375 .2021 L
s
0 .24492 m
.00375 .24492 L
s
0 .26632 m
.00375 .26632 L
s
0 .28773 m
.00375 .28773 L
s
0 .33055 m
.00375 .33055 L
s
0 .35195 m
.00375 .35195 L
s
0 .37336 m
.00375 .37336 L
s
0 .41618 m
.00375 .41618 L
s
0 .43758 m
.00375 .43758 L
s
0 .45899 m
.00375 .45899 L
s
0 .50181 m
.00375 .50181 L
s
0 .52321 m
.00375 .52321 L
s
0 .54462 m
.00375 .54462 L
s
0 .03084 m
.00375 .03084 L
s
0 .00943 m
.00375 .00943 L
s
0 .58744 m
.00375 .58744 L
s
0 .60885 m
.00375 .60885 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .30914 m
1 .30914 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Theta) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(radian) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .36266 m
.02499 .36266 L
.02605 .36266 L
.02729 .36266 L
.02846 .36267 L
.03053 .36268 L
.03279 .3627 L
.03527 .36273 L
.0379 .36276 L
.04262 .36285 L
.05205 .36308 L
.05742 .36325 L
.06244 .36344 L
.07285 .36394 L
.08274 .36455 L
.09415 .36545 L
.10458 .36651 L
.11417 .36773 L
.12439 .36938 L
.13403 .37138 L
.14277 .37367 L
.1528 .3771 L
.16202 .38131 L
.17214 .38774 L
.17724 .39205 L
.18284 .39798 L
.18808 .40514 L
.19304 .41403 L
.1975 .42455 L
.20235 .43992 L
.20762 .46261 L
.21321 .49265 L
.21846 .52282 L
.22326 .54894 L
.22783 .56936 L
.23012 .57737 L
.23263 .58436 L
.23516 .58969 L
.23658 .59199 L
.23787 .59369 L
.23907 .59496 L
.24037 .59602 L
.2416 .59673 L
.24273 .59715 L
.24379 .59734 L
.24492 .59734 L
.24599 .59716 L
.24696 .59684 L
.2481 .59629 L
.24935 .59548 L
Mistroke
.25161 .59345 L
.25398 .59061 L
.25649 .58683 L
.26101 .57821 L
.27133 .55213 L
.28247 .51954 L
.30265 .45507 L
.32223 .37798 L
.3326 .33719 L
.33831 .31752 L
.3437 .30199 L
.35441 .27933 L
.36417 .26477 L
.38324 .24245 L
.39292 .23052 L
.39822 .22272 L
.40319 .21391 L
.40777 .2038 L
.41196 .19201 L
.41661 .17484 L
.42163 .15055 L
.4308 .09658 L
.43584 .06784 L
.44059 .04575 L
.44329 .0362 L
.44622 .02831 L
.44888 .02307 L
.45014 .02115 L
.45132 .01966 L
.45253 .01842 L
.45364 .01753 L
.45486 .01679 L
.45617 .01627 L
.45743 .01602 L
.45815 .01599 L
.45881 .01603 L
.46002 .01627 L
.4613 .01675 L
.46244 .01736 L
.46368 .01822 L
.46618 .02057 L
.4685 .02344 L
.47066 .0267 L
.47553 .03598 L
.48075 .04845 L
.49902 .10196 L
.51891 .1677 L
.54049 .25579 L
.55057 .29479 L
.55609 .31234 L
Mistroke
.56126 .32575 L
.57039 .34382 L
.58044 .35875 L
.59899 .38237 L
.60407 .38959 L
.60949 .39851 L
.61417 .40787 L
.61923 .42076 L
.62494 .44075 L
.63032 .46662 L
.64038 .5263 L
.64547 .555 L
.64825 .56822 L
.65085 .57845 L
.65325 .58606 L
.65544 .59155 L
.65787 .59624 L
.65921 .59826 L
.66047 .59981 L
.66167 .601 L
.66276 .60186 L
.66397 .60258 L
.66528 .60308 L
.66647 .60331 L
.66777 .60332 L
.66843 .60323 L
.66913 .60307 L
.67039 .60261 L
.67158 .60198 L
.67287 .60108 L
.6752 .59892 L
.67748 .59617 L
.67957 .59309 L
.68438 .58414 L
.68966 .57168 L
.70034 .54131 L
.7407 .40066 L
.75929 .32536 L
.76438 .30863 L
.7698 .294 L
.77954 .27427 L
.79066 .25772 L
.80073 .24481 L
.81121 .23069 L
.8158 .22345 L
.82084 .21406 L
.8257 .20272 L
.83023 .18902 L
.83502 .16981 L
.84014 .1432 L
Mistroke
.85097 .07837 L
.85573 .05354 L
.85844 .04222 L
.86098 .03369 L
.86336 .02738 L
.86593 .02224 L
.86734 .02007 L
.86867 .01838 L
.86999 .01706 L
.87119 .01613 L
.87252 .01538 L
.87325 .01509 L
.87393 .01489 L
.87516 .01472 L
.87585 .01472 L
.87649 .01478 L
.87718 .01491 L
.87783 .01509 L
.87854 .01536 L
.8793 .01572 L
.88085 .01669 L
.88227 .01785 L
.88484 .0206 L
.88722 .02386 L
.89261 .03363 L
.90241 .05827 L
.94166 .18685 L
.97619 .31932 L
Mfstroke
.5 Mabswid
[ .01 .01 ] 0 setdash
.02381 .36052 m
.02499 .36052 L
.02605 .36052 L
.02729 .36052 L
.02846 .36052 L
.03053 .36051 L
.03279 .36051 L
.03527 .36051 L
.0379 .36051 L
.04262 .36051 L
.05205 .36049 L
.06244 .36047 L
.07293 .36045 L
.0842 .36041 L
.10458 .36031 L
.11468 .36025 L
.12571 .36017 L
.1458 .35998 L
.16548 .3597 L
.18645 .35929 L
.19674 .35903 L
.20786 .35869 L
.22803 .35789 L
.24797 .35681 L
.26904 .35525 L
.28867 .35332 L
.30701 .35104 L
.34592 .34458 L
.38728 .33588 L
.42712 .32747 L
.46545 .32088 L
.48523 .31826 L
.50623 .31602 L
.52593 .31437 L
.54398 .31319 L
.56333 .31219 L
.58419 .31138 L
.60311 .31082 L
.62381 .31037 L
.64342 .31005 L
.66437 .30979 L
.68572 .30961 L
.70587 .30948 L
.72588 .30939 L
.74434 .30932 L
.7631 .30927 L
.78374 .30924 L
.80319 .30921 L
.82408 .30919 L
.84525 .30917 L
Mistroke
.86536 .30916 L
.8852 .30916 L
.9036 .30915 L
.92416 .30915 L
.94278 .30915 L
.95884 .30914 L
.97619 .30914 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[44]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00:1oo`03001oogoo00Ioo`03001oogoo07Aoo`00Wgoo00<007ooOol027oo00<007ooOol0Lgoo
001oOol30002Ool300001Woo001oo`00Ool0009oo`8000eoo`03001oogoo009oo`8000Ioo`03001o
ogoo079oo`00P7oo00<007ooOol00Woo00X007ooOol007oo001oo`00Ool000moo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo079oo`00P7oo00<007ooOol00Woo00T007ooOol007oo001oo`00
Ool00`003Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0LWoo0020Ool01000Oomoogoo
0P000Woo0P0000Aoo`00Oomoo`<000eoo`03001oogoo00=oo`8000Eoo`03001oogoo079oo`00OWoo
00D007oo001oo`0001aoo`03001oogoo00Qoo`03001oogoo07=oo`00OWoo1@000Woo00<007ooOol0
67oo00<007ooOol01Woo00<007ooOol0M7oo003oOolQOol00?moob5oo`00ogoo8Goo000/Ool00`00
Oomoo`0`Ool5000aOol3000bOol2000dOol3000MOol002]oo`03001oo`0003=oo`03001oogoo035o
o`03001oogoo03Aoo`03001oogoo039oo`03001oogoo01aoo`00:goo00<007oo0000<goo00<007oo
Ool0<Woo00<007ooOol0<Woo00<007ooOol0<Goo10007Goo000[Ool00`00Ool0000cOol00`00Oomo
o`0bOol00`00Oomoo`0cOol00`00Oomoo`0`Ool00`00Ool0000NOol002]oo`03001oo`0003=oo`03
001oogoo035oo`03001oo`00039oo`03001oo`0003=oo`8001ioo`00;7oo00<007ooOol0<Goo0P00
=7oo00<007ooOol0<Woo00<007ooOol0<goo00<007ooOol077oo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`009goog`006Woo000WOol00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0MOol0
02Moo`800?Moo`009goo00<007ooOol0Hgoo00<007ooOol0FGoo0`00=7oo000WOol00`00Oomoo`1R
Ool4001HOol200000goo0000000cOol002Moo`03001oogoo065oo`05001oogooOol0001HOol01@00
Oomoogoo0000<goo000WOol00`00Oomoo`1POol00`00Oomoo`03Ool00`00Oomoo`1DOol00`00Oomo
o`03Ool00`00Oomoo`0`Ool002Moo`80065oo`03001oogoo00Aoo`03001oogoo05=oo`03001oogoo
00Aoo`03001oogoo02moo`009goo00<007ooOol0H7oo00<007ooOol017oo00<007ooOol0DWoo00<0
07ooOol01Goo00<007ooOol0;goo000WOol00`00Oomoo`1OOol00`00Oomoo`05Ool00`00Oomoo`1B
Ool00`00Oomoo`06Ool00`00Oomoo`0^Ool0025oo`8000Aoo`03001oogoo05moo`03001oogoo00Io
o`03001oogoo055oo`03001oogoo00Ioo`03001oogoo02ioo`008Goo00<007oo00000goo00<007oo
Ool0Ggoo00<007ooOol01Woo00<007ooOol0D7oo00<007ooOol01goo00<007ooOol0;Woo000LOol3
0002Ool00`00Ool00003Ool3001OOol00`00Oomoo`06Ool00`00Oomoo`1@Ool00`00Oomoo`08Ool0
0`00Oomoo`0]Ool0025oo`8000Aoo`03001oogoo05ioo`03001oogoo00Qoo`03001oogoo04moo`03
001oogoo00Qoo`03001oogoo02eoo`008Goo00<007ooOol00goo00<007ooOol0GWoo00<007ooOol0
27oo00<007ooOol0Cgoo00<007ooOol027oo00<007ooOol0;Goo000ROol20003Ool00`00Oomoo`1N
Ool00`00Oomoo`08Ool00`00Oomoo`1>Ool00`00Oomoo`0:Ool00`00Oomoo`0/Ool002Moo`8005mo
o`03001oogoo00Uoo`03001oogoo04eoo`03001oogoo00Yoo`03001oogoo02aoo`009goo00<007oo
Ool0GWoo00<007ooOol02Goo00<007ooOol0CGoo00<007ooOol02Woo00<007ooOol0;7oo000WOol0
0`00Oomoo`1MOol00`00Oomoo`0:Ool00`00Oomoo`1=Ool00`00Oomoo`0:Ool00`00Oomoo`0/Ool0
02Moo`03001oogoo05eoo`03001oogoo00]oo`03001oogoo04aoo`03001oogoo00]oo`03001oogoo
02]oo`009goo00<007ooOol0GGoo00<007ooOol02goo00<007ooOol0C7oo00<007ooOol02goo00<0
07ooOol0:goo000WOol2001NOol00`00Oomoo`0;Ool00`00Oomoo`1;Ool00`00Oomoo`0<Ool00`00
Oomoo`0[Ool002Moo`03001oogoo05eoo`03001oogoo00aoo`03001oogoo04Yoo`03001oogoo00eo
o`03001oogoo02Yoo`009goo00<007ooOol0GGoo00<007ooOol037oo00<007ooOol0BWoo00<007oo
Ool03Goo00<007ooOol0:Woo000WOol00`00Oomoo`1LOol00`00Oomoo`0=Ool00`00Oomoo`1:Ool0
0`00Oomoo`0=Ool00`00Oomoo`0ZOol002Moo`03001oogoo05aoo`03001oogoo00ioo`03001oogoo
04Uoo`03001oogoo00eoo`03001oogoo02Yoo`009goo0P00GGoo00<007ooOol03Woo00<007ooOol0
BGoo00<007ooOol03Woo00<007ooOol0:Goo000WOol00`00Oomoo`1LOol00`00Oomoo`0>Ool00`00
Oomoo`19Ool00`00Oomoo`0>Ool00`00Oomoo`0YOol002Moo`03001oogoo05aoo`03001oogoo00mo
o`03001oogoo04Qoo`03001oogoo00ioo`03001oogoo02Uoo`008Woo0`000Woo00<007ooOol0G7oo
00<007ooOol03goo00<007ooOol0Agoo00<007ooOol047oo00<007ooOol0:7oo000SOol01@00Oomo
ogoo0000GGoo00<007ooOol04Goo00<007ooOol0AWoo00<007ooOol047oo00<007ooOol0:7oo000L
Ool30002Ool40002Ool3001KOol00`00Oomoo`0AOol00`00Oomoo`16Ool00`00Oomoo`0@Ool00`00
Oomoo`0XOol0025oo`03001oo`0000=oo`03001oogoo05]oo`03001oogoo015oo`03001oogoo04Io
o`03001oogoo011oo`03001oogoo02Qoo`008Woo0P000goo00<007ooOol0Fgoo00<007ooOol04Woo
00<007ooOol0AGoo00<007ooOol04Goo00<007ooOol09goo000SOol01@00Oomoogoo0000GGoo00<0
07ooOol04Woo00<007ooOol0AGoo00<007ooOol04Goo00<007ooOol09goo000WOol2001LOol00`00
Oomoo`0BOol00`00Oomoo`14Ool00`00Oomoo`0BOol00`00Oomoo`0WOol002Moo`03001oogoo05Yo
o`03001oogoo01Aoo`03001oogoo04=oo`03001oogoo01=oo`03001oogoo02Ioo`009goo00<007oo
Ool0FWoo00<007ooOol057oo00<007ooOol0@goo00<007ooOol04goo00<007ooOol09Woo000WOol0
0`00Oomoo`1JOol00`00Oomoo`0DOol00`00Oomoo`13Ool00`00Oomoo`0COol00`00Oomoo`0VOol0
02Moo`03001oogoo05Yoo`03001oogoo01Aoo`03001oogoo04=oo`03001oogoo01=oo`03001oogoo
02Ioo`009goo0P00Fgoo00<007ooOol05Goo00<007ooOol0@Goo00<007ooOol05Goo00<007ooOol0
9Goo000WOol00`00Oomoo`1IOol00`00Oomoo`0FOol00`00Oomoo`11Ool00`00Oomoo`0EOol00`00
Oomoo`0UOol002Moo`03001oogoo05Uoo`03001oogoo01Ioo`03001oogoo045oo`03001oogoo01Eo
o`03001oogoo02Eoo`009goo00<007ooOol0FGoo00<007ooOol05Woo00<007ooOol0@Goo00<007oo
Ool05Woo00<007ooOol097oo000WOol00`00Oomoo`1HOol00`00Oomoo`0GOol00`00Oomoo`10Ool0
0`00Oomoo`0GOol00`00Oomoo`0TOol002Moo`8005Uoo`03001oogoo01Qoo`03001oogoo03moo`03
001oogoo01Moo`03001oogoo02Aoo`009goo00<007ooOol0Egoo00<007ooOol06Goo00<007ooOol0
?Woo00<007ooOol067oo00<007ooOol097oo000WOol00`00Oomoo`1GOol00`00Oomoo`0IOol00`00
Oomoo`0nOol00`00Oomoo`0IOol00`00Oomoo`0SOol0025oo`<000=oo`03001oogoo05Ioo`03001o
ogoo01Yoo`03001oogoo03ioo`03001oogoo01Uoo`03001oogoo02=oo`008Goo00<007ooOol00goo
00<007ooOol0EWoo00<007ooOol06Woo00<007ooOol0?Goo00<007ooOol06Woo00<007ooOol08goo
000LOol30003Ool00`00Oomoo`02Ool3001EOol00`00Oomoo`0LOol00`00Oomoo`0lOol00`00Oomo
o`0JOol00`00Oomoo`0SOol0029oo`03001oogoo009oo`03001oogoo05Eoo`03001oogoo01aoo`03
001oogoo03]oo`03001oogoo01aoo`03001oogoo029oo`008Goo00<007oo00000goo00<007ooOol0
E7oo00<007ooOol07Goo00<007ooOol0>Woo00<007ooOol07Goo00<007ooOol08Woo000ROol00`00
Oomoo`02Ool00`00Oomoo`1COol00`00Oomoo`0NOol00`00Oomoo`0iOol00`00Oomoo`0NOol00`00
Oomoo`0ROol002Moo`8005=oo`03001oogoo01moo`03001oogoo03Qoo`03001oogoo01moo`03001o
ogoo029oo`009goo00<007ooOol0DGoo00<007ooOol08Goo00<007ooOol0=Woo00<007ooOol08Goo
00<007ooOol08Goo000WOol00`00Oomoo`1@Ool00`00Oomoo`0ROol00`00Oomoo`0fOol00`00Oomo
o`0QOol00`00Oomoo`0QOol002Moo`03001oogoo051oo`03001oogoo029oo`03001oogoo03Eoo`03
001oogoo029oo`03001oogoo025oo`009goo00<007ooOol0Cgoo00<007ooOol08goo00<007ooOol0
=7oo00<007ooOol097oo00<007ooOol087oo000WOol2001?Ool00`00Oomoo`0UOol00`00Oomoo`0b
Ool00`00Oomoo`0UOol00`00Oomoo`0POol002Moo`03001oogoo04eoo`03001oogoo02Ioo`03001o
ogoo039oo`03001oogoo02Eoo`03001oogoo021oo`009goo00<007ooOol0CGoo00<007ooOol09goo
00<007ooOol0<7oo00<007ooOol09Woo00<007ooOol087oo000WOol00`00Oomoo`1<Ool00`00Oomo
o`0XOol00`00Oomoo`0_Ool00`00Oomoo`0XOol00`00Oomoo`0OOol002Moo`03001oogoo04aoo`03
001oogoo02Qoo`03001oogoo02moo`03001oogoo02Qoo`03001oogoo01moo`009goo0P00C7oo00<0
07ooOol0:Woo00<007ooOol0;Goo00<007ooOol0:Goo00<007ooOol07goo000WOol00`00Oomoo`1;
Ool00`00Oomoo`0ZOol00`00Oomoo`0]Ool00`00Oomoo`0YOol00`00Oomoo`0OOol002Moo`03001o
ogoo04Yoo`03001oogoo02]oo`03001oogoo02eoo`03001oogoo02Yoo`03001oogoo01ioo`008Woo
00<007ooOol00Woo00<007ooOol0BWoo00<007ooOol0;7oo00<007ooOol0:goo00<007ooOol0:goo
00<007ooOol07Woo000QOol00`00Ool00003Ool00`00Oomoo`19Ool00`00Oomoo`0]Ool00`00Oomo
o`0[Ool00`00Oomoo`0[Ool00`00Oomoo`0NOol0025oo`03001oo`0000=ooml001Yoo`008Goo00<0
07oo00000goo00<007ooOol0B7oo00<007ooOol07Woo00<007oo00000`0000Eoo`00000007oo0080
00=oo`03001oogoo02Yoo`03001oogoo02eoo`03001oogoo01eoo`008Goo00<007oo00000goo00<0
07ooOol0B7oo00<007ooOol06Woo00<007oo00000P0047oo00<007ooOol0:Goo00<007ooOol0;Goo
00<007ooOol07Goo000ROol00`00Oomoo`02Ool00`00Oomoo`18Ool00`00Oomoo`0COol30002Ool2
000EOol00`00Oomoo`0YOol00`00Oomoo`1=Ool002Moo`8004Qoo`03001oogoo011oo`<001ioo`03
001oogoo02Qoo`03001oogoo04eoo`009goo00<007ooOol0Agoo00<007ooOol02goo10008Woo00<0
07ooOol0:7oo00<007ooOol0CGoo000WOol00`00Oomoo`17Ool00`00Oomoo`05Ool00`00Ool00002
000XOol00`00Oomoo`0VOol00`00Oomoo`1>Ool002Moo`03001oogoo04Moo`03001oogoo00800003
Ool0000002eoo`03001oogoo02Ioo`03001oogoo04ioo`009goo00<007ooOol0A7oo1P00<goo00<0
07ooOol09Goo00<007ooOol0CWoo000WOol2000nOol00`00Oomoo`030003Ool00`00Oomoo`0dOol0
0`00Oomoo`0UOol00`00Oomoo`1>Ool002Moo`03001oogoo02ioo`<00003Ool0000000800005Ool0
0000001oo`020009Ool00`00Oomoo`0eOol00`00Oomoo`0SOol00`00Oomoo`1?Ool002Moo`03001o
ogoo00=oo`H00003Ool0000000800005Ool00000001oo`030002Ool3000017oo000000000Woo0`00
00Eoo`00000007oo00@001Uoo`03001oogoo03Eoo`03001oogoo02=oo`03001oogoo04moo`009goo
00<007ooOol027oo3P00<7oo00<007ooOol0=Woo00<007ooOol08Woo00<007ooOol0Cgoo000WOol0
0`00Oomoo`0FOol6000YOol00`00Oomoo`0hOol00`00Oomoo`0QOol00`00Oomoo`1?Ool002Moo`80
01eoo`8002Moo`03001oogoo03Qoo`03001oogoo021oo`03001oogoo051oo`009goo00<007ooOol0
7Woo0P009Goo00<007ooOol0>Goo00<007ooOol07goo00<007ooOol0D7oo000WOol00`00Oomoo`0P
Ool3000ROol00`00Oomoo`0jOol00`00Oomoo`0NOol00`00Oomoo`1@Ool0025oo`<000=oo`03001o
ogoo02=oo`80021oo`03001oogoo03]oo`8001ioo`03001oogoo051oo`008Goo00<007ooOol00goo
00<007ooOol09Goo00<007ooOol077oo00<007ooOol0?Woo00<007ooOol06Woo00<007ooOol0DGoo
000ROol00`00Oomoo`02Ool3000VOol00`00Oomoo`0KOol00`00Oomoo`0nOol00`00Oomoo`0JOol0
0`00Oomoo`1AOol0029oo`03001oogoo009oo`03001oogoo02Moo`03001oogoo01Yoo`03001oogoo
03moo`03001oogoo01Uoo`03001oogoo055oo`008Goo00<007oo00000goo00<007ooOol09goo00<0
07ooOol06Woo00<007ooOol0?goo00<007ooOol06Goo00<007ooOol0DGoo000ROol00`00Oomoo`02
Ool00`00Oomoo`0XOol00`00Oomoo`0HOol00`00Oomoo`10Ool00`00Oomoo`0HOol00`00Oomoo`1B
Ool002Moo`8002Uoo`03001oogoo01Qoo`03001oogoo045oo`03001oogoo01Moo`03001oogoo059o
o`009goo00<007ooOol0:Goo00<007ooOol05goo00<007ooOol0@Goo00<007ooOol05goo00<007oo
Ool0DWoo000WOol00`00Oomoo`0YOol00`00Oomoo`0GOol00`00Oomoo`11Ool00`00Oomoo`0GOol0
0`00Oomoo`1BOol002Moo`03001oogoo02Uoo`03001oogoo01Ioo`03001oogoo049oo`03001oogoo
01Ioo`03001oogoo05=oo`009goo00<007ooOol0:Woo00<007ooOol05Goo00<007ooOol0@goo00<0
07ooOol05Goo00<007ooOol0Dgoo000WOol2000[Ool00`00Oomoo`0EOol00`00Oomoo`13Ool00`00
Oomoo`0EOol00`00Oomoo`1COol002Moo`03001oogoo02Yoo`03001oogoo01Eoo`03001oogoo04=o
o`03001oogoo01Aoo`03001oogoo05Aoo`009goo00<007ooOol0:Woo00<007ooOol057oo00<007oo
Ool0A7oo00<007ooOol057oo00<007ooOol0E7oo000WOol00`00Oomoo`0ZOol00`00Oomoo`0DOol0
0`00Oomoo`14Ool00`00Oomoo`0DOol00`00Oomoo`1DOol002Moo`03001oogoo02]oo`03001oogoo
01=oo`03001oogoo04Eoo`03001oogoo01=oo`03001oogoo05Aoo`009goo0P00;7oo00<007ooOol0
4goo00<007ooOol0AGoo00<007ooOol04Woo00<007ooOol0EGoo000WOol00`00Oomoo`0[Ool00`00
Oomoo`0BOol00`00Oomoo`16Ool00`00Oomoo`0BOol00`00Oomoo`1EOol002Moo`03001oogoo02]o
o`03001oogoo019oo`03001oogoo04Ioo`03001oogoo019oo`03001oogoo05Eoo`008Woo0`000Woo
00<007ooOol0;7oo00<007ooOol04Goo00<007ooOol0AWoo00<007ooOol04Goo00<007ooOol0EWoo
000SOol01@00Oomoogoo0000;Woo00<007ooOol047oo00<007ooOol0Agoo00<007ooOol04Goo00<0
07ooOol0EWoo000QOol40002Ool3000/Ool00`00Oomoo`0@Ool00`00Oomoo`18Ool00`00Oomoo`0@
Ool00`00Oomoo`1FOol0025oo`03001oo`0000=oo`03001oogoo02eoo`03001oogoo00ioo`03001o
ogoo04Uoo`03001oogoo00moo`03001oogoo05Moo`008Woo0P000goo00<007ooOol0;Goo00<007oo
Ool03Woo00<007ooOol0BGoo00<007ooOol03goo00<007ooOol0Egoo000SOol01@00Oomoogoo0000
;goo00<007ooOol03Woo00<007ooOol0BGoo00<007ooOol03goo00<007ooOol0Egoo000WOol2000^
Ool00`00Oomoo`0=Ool00`00Oomoo`1;Ool00`00Oomoo`0>Ool00`00Oomoo`1GOol002Moo`03001o
ogoo02eoo`03001oogoo00eoo`03001oogoo04]oo`03001oogoo00eoo`03001oogoo05Qoo`009goo
00<007ooOol0;Woo00<007ooOol037oo00<007ooOol0Bgoo00<007ooOol03Goo00<007ooOol0F7oo
000WOol00`00Oomoo`0^Ool00`00Oomoo`0;Ool00`00Oomoo`1<Ool00`00Oomoo`0=Ool00`00Oomo
o`1HOol002Moo`03001oogoo02ioo`03001oogoo00]oo`03001oogoo04eoo`03001oogoo00]oo`03
001oogoo05Uoo`009goo0P00;goo00<007ooOol02goo00<007ooOol0CGoo00<007ooOol02goo00<0
07ooOol0FGoo000WOol00`00Oomoo`0^Ool00`00Oomoo`0:Ool00`00Oomoo`1>Ool00`00Oomoo`0;
Ool00`00Oomoo`1IOol002Moo`03001oogoo02ioo`03001oogoo00Yoo`03001oogoo04ioo`03001o
ogoo00]oo`03001oogoo05Uoo`009goo00<007ooOol0;goo00<007ooOol02Goo00<007ooOol0CWoo
00<007ooOol02Woo00<007ooOol0FWoo000WOol00`00Oomoo`0_Ool00`00Oomoo`09Ool00`00Oomo
o`1?Ool00`00Oomoo`09Ool00`00Oomoo`1JOol002Moo`80031oo`03001oogoo00Qoo`03001oogoo
051oo`03001oogoo00Uoo`03001oogoo05Yoo`009goo00<007ooOol0;goo00<007ooOol027oo00<0
07ooOol0D7oo00<007ooOol027oo00<007ooOol0Fgoo000WOol00`00Oomoo`0_Ool00`00Oomoo`08
Ool00`00Oomoo`1@Ool00`00Oomoo`08Ool00`00Oomoo`1KOol0025oo`8000Aoo`03001oogoo031o
o`03001oogoo00Ioo`03001oogoo055oo`03001oogoo00Qoo`03001oogoo05]oo`008Goo00<007oo
00000goo00<007ooOol0<7oo00<007ooOol01Woo00<007ooOol0DGoo00<007ooOol027oo00<007oo
Ool0Fgoo000QOol00`00Ool00003Ool3000`Ool00`00Oomoo`05Ool00`00Oomoo`1BOol00`00Oomo
o`07Ool00`00Oomoo`1LOol0025oo`8000Aoo`03001oogoo031oo`03001oogoo00Eoo`03001oogoo
05=oo`03001oogoo00Ioo`03001oogoo05aoo`008Goo00<007ooOol00goo00<007ooOol0<7oo00<0
07ooOol017oo00<007ooOol0E7oo00<007ooOol01Goo00<007ooOol0GGoo000ROol20003Ool00`00
Oomoo`0aOol00`00Oomoo`02Ool00`00Oomoo`1EOol00`00Oomoo`05Ool00`00Oomoo`1MOol002Mo
o`80039oo`03001oogoo009oo`03001oogoo05Eoo`03001oogoo00Aoo`03001oogoo05ioo`009goo
00<007ooOol0<Woo00D007ooOomoo`0005Qoo`03001oogoo009oo`03001oogoo05moo`009goo00<0
07ooOol0<Woo1000FGoo00<007ooOol00Woo00<007ooOol0Ggoo000WOol00`00Oomoo`0cOol2001K
Ool01000Oomoo`00HWoo000WOol00`00Oomoo`2AOol2001SOol002Moo`800?Moo`009goo00<007oo
Ool0mWoo000WOol00`00Oomoo`3fOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo002DOol00`00Oomoo`0TOol00`00Oomoo`1ROol009=oo`03001oogoo02Ioo`03001oogoo065o
o`00KGoo0`0000Ioo`00000007oo0002Ool20003Ool20002Ool4000=Ool00`00Oomoo`02Ool30002
Ool40002Ool3000017oo000000000Woo1P000Woo00<007ooOol01goo00<007ooOol0H7oo001^Ool0
1@00Oomoogoo00000Woo00<007oo000017oo00D007ooOol007oo00<000ioo`03001oogoo00=oo`04
001oogooOol30002Ool01000Oomoo`000Woo00@007ooOomoo`<0009oo`04001oogoo0009Ool00`00
Oomoo`1POol006ioo`05001oogooOol00002Ool00`00Ool000020002Ool00`00Oomoo`04Ool00`00
Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol000Eoo`04
001oogoo0002Ool00`00Oomoo`07Ool00`00Oomoo`1POol006ioo`04001oogooOol30002Ool30000
0goo000000020003Ool2000>Ool00`00Oomoo`02Ool40002Ool20003Ool300000goo00000004Ool2
00000goo00000002000:Ool00`00Oomoo`1POol006aoo`07001oo`00Ool007oo00002Goo00<007oo
Ool057oo00<007ooOol03Woo00<007ooOol05Goo00<007ooOol0HGoo001/Ool7000QOol00`00Oomo
o`0<Ool20002Ool00`00Oomoo`0AOol00`00Oomoo`1ROol00?moob5oo`00ogoo8Goo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.853472, -9.77991, 
  0.0189112, 0.105165}},
  CellTags->"2"],

Cell["\<\
Of course, the cart in our particular model of the pendulum (as \
shown in Figure 2.1) would not allow the pendulum to rotate in circles, but, \
for the sake of argument, we will assume that it would. \
\>", "Text",
  CellTags->"2"],

Cell[TextData[{
  "The variations in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Theta]\& . \)\)\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " become more complex and far more intense. "
}], "MathCaption",
  CellTags->"2"],

Cell["\<\
Plot[Evaluate[theta'[t] /. {thetaBig, thetas[[3]]}],
 {t, 0, 4},
 PlotLabel -> \"Theta dot (radian/s)\",
 Evaluate[newOptions]
]\
\>", "Input",
  CellLabel->"In[45]:=",
  CellTags->"2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.309289 0.00866511 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .04934 -18 -4.5 ]
[-0.0125 .04934 0 4.5 ]
[-0.0125 .13599 -18 -4.5 ]
[-0.0125 .13599 0 4.5 ]
[-0.0125 .22264 -18 -4.5 ]
[-0.0125 .22264 0 4.5 ]
[-0.0125 .30929 -6 -4.5 ]
[-0.0125 .30929 0 4.5 ]
[-0.0125 .39594 -12 -4.5 ]
[-0.0125 .39594 0 4.5 ]
[-0.0125 .48259 -12 -4.5 ]
[-0.0125 .48259 0 4.5 ]
[-0.0125 .56924 -12 -4.5 ]
[-0.0125 .56924 0 4.5 ]
[ 0 0 -0.125 0 ]
[.5 .63053 -62 0 ]
[.5 .63053 62 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .04934 m
.00625 .04934 L
s
[(-30)] -0.0125 .04934 1 0 Mshowa
0 .13599 m
.00625 .13599 L
s
[(-20)] -0.0125 .13599 1 0 Mshowa
0 .22264 m
.00625 .22264 L
s
[(-10)] -0.0125 .22264 1 0 Mshowa
0 .30929 m
.00625 .30929 L
s
[(0)] -0.0125 .30929 1 0 Mshowa
0 .39594 m
.00625 .39594 L
s
[(10)] -0.0125 .39594 1 0 Mshowa
0 .48259 m
.00625 .48259 L
s
[(20)] -0.0125 .48259 1 0 Mshowa
0 .56924 m
.00625 .56924 L
s
[(30)] -0.0125 .56924 1 0 Mshowa
.125 Mabswid
0 .06667 m
.00375 .06667 L
s
0 .084 m
.00375 .084 L
s
0 .10133 m
.00375 .10133 L
s
0 .11866 m
.00375 .11866 L
s
0 .15332 m
.00375 .15332 L
s
0 .17065 m
.00375 .17065 L
s
0 .18798 m
.00375 .18798 L
s
0 .20531 m
.00375 .20531 L
s
0 .23997 m
.00375 .23997 L
s
0 .2573 m
.00375 .2573 L
s
0 .27463 m
.00375 .27463 L
s
0 .29196 m
.00375 .29196 L
s
0 .32662 m
.00375 .32662 L
s
0 .34395 m
.00375 .34395 L
s
0 .36128 m
.00375 .36128 L
s
0 .37861 m
.00375 .37861 L
s
0 .41327 m
.00375 .41327 L
s
0 .4306 m
.00375 .4306 L
s
0 .44793 m
.00375 .44793 L
s
0 .46526 m
.00375 .46526 L
s
0 .49992 m
.00375 .49992 L
s
0 .51725 m
.00375 .51725 L
s
0 .53458 m
.00375 .53458 L
s
0 .55191 m
.00375 .55191 L
s
0 .03201 m
.00375 .03201 L
s
0 .01468 m
.00375 .01468 L
s
0 .58657 m
.00375 .58657 L
s
0 .6039 m
.00375 .6039 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .30929 m
1 .30929 L
s
gsave
.5 .63053 -123 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Theta) show
99.000000 12.812500 moveto
(dot) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(radian) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
165.000000 12.812500 moveto
(\\220) show
171.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
177.000000 12.812500 moveto
(L) show
183.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.001 w
.02381 .30929 m
.04262 .31024 L
.06244 .31127 L
.08255 .3126 L
.09396 .3136 L
.10458 .31479 L
.11508 .31632 L
.125 .31823 L
.1339 .32049 L
.14357 .32382 L
.15301 .32841 L
.15838 .3319 L
.16341 .336 L
.1687 .3415 L
.17354 .34803 L
.17913 .35815 L
.18186 .36453 L
.18444 .3717 L
.18685 .37971 L
.18947 .39013 L
.19403 .41427 L
.19661 .43243 L
.19935 .45598 L
.20424 .50856 L
.20848 .55399 L
.20969 .56432 L
.21085 .57242 L
.21188 .57821 L
.21301 .58293 L
.21426 .58632 L
.2149 .58732 L
.2156 .58788 L
.21683 .58746 L
.21799 .58541 L
.21915 .5816 L
.22022 .57645 L
.2214 .56884 L
.22263 .55852 L
.2329 .42317 L
.23795 .36548 L
.2426 .32336 L
.2513 .26077 L
.26074 .20749 L
.26528 .18899 L
.26785 .18123 L
.27027 .17578 L
.27157 .17349 L
.27281 .1717 L
.27513 .16916 L
.27642 .16811 L
Mistroke
.27763 .16732 L
.28035 .16591 L
.28286 .16481 L
.28558 .16349 L
.28814 .16185 L
.2905 .15983 L
.29326 .15662 L
.29617 .15207 L
.3013 .14101 L
.30618 .12849 L
.30859 .12288 L
.3108 .11867 L
.31202 .11685 L
.31336 .11525 L
.3147 .11406 L
.31544 .11358 L
.31613 .11322 L
.31735 .11279 L
.31847 .11262 L
.31969 .11265 L
.32098 .1129 L
.32213 .11333 L
.32318 .11389 L
.32439 .11478 L
.32552 .11588 L
.32755 .11863 L
.32869 .1207 L
.32975 .123 L
.33197 .1292 L
.3344 .1382 L
.33933 .16181 L
.34411 .18646 L
.34933 .2094 L
.35425 .22583 L
.35881 .23698 L
.36133 .24174 L
.36411 .24603 L
.36701 .24953 L
.36974 .252 L
.37096 .25287 L
.37224 .25363 L
.37335 .25417 L
.37454 .25462 L
.37582 .25496 L
.37701 .25515 L
.37774 .2552 L
.37843 .2552 L
.37972 .25509 L
.38087 .25486 L
.3821 .25448 L
Mistroke
.38327 .25398 L
.38434 .2534 L
.38695 .25147 L
.38942 .2489 L
.39197 .24539 L
.39434 .24122 L
.39694 .23543 L
.39971 .22755 L
.4021 .21897 L
.40469 .20735 L
.40697 .19459 L
.40938 .17796 L
.41395 .13573 L
.41815 .08658 L
.4207 .05787 L
.42196 .04593 L
.42312 .03669 L
.42415 .03007 L
.42528 .0245 L
.42643 .02065 L
.42764 .0184 L
.42896 .01797 L
.43016 .01944 L
.4308 .02096 L
.43149 .02325 L
.43221 .02637 L
.43288 .02998 L
.43413 .03863 L
.43526 .04875 L
.4378 .07869 L
.44671 .20472 L
.45121 .25316 L
.45614 .29507 L
.46614 .36184 L
.47534 .41243 L
.48053 .43374 L
.48344 .44226 L
.48481 .4454 L
.48609 .44782 L
.48856 .45132 L
.48986 .45266 L
.49125 .45377 L
.49382 .45524 L
.49615 .45621 L
.49868 .45721 L
.50104 .45834 L
.50351 .45997 L
.50621 .46248 L
.50854 .46548 L
.51067 .46891 L
Mistroke
.51544 .4794 L
.52058 .49345 L
.52329 .50036 L
.52477 .50355 L
.52616 .50605 L
.52746 .50793 L
.52866 .50926 L
.52999 .51033 L
.53072 .51076 L
.53142 .51106 L
.53263 .51137 L
.53375 .51144 L
.53497 .51131 L
.53628 .51091 L
.53752 .5103 L
.53823 .50983 L
.53889 .50931 L
.54021 .50797 L
.54164 .50604 L
.54296 .50369 L
.54421 .50089 L
.54656 .49394 L
.54933 .48285 L
.55189 .47027 L
.55769 .43914 L
.56273 .41556 L
.56746 .39866 L
.5724 .38598 L
.57502 .38095 L
.57785 .37665 L
.58025 .37383 L
.58157 .37258 L
.58281 .37158 L
.58397 .3708 L
.58522 .37012 L
.58637 .36965 L
.58742 .36935 L
.58867 .36913 L
.58984 .36908 L
.59112 .3692 L
.59184 .36935 L
.5925 .36953 L
.59382 .37005 L
.59526 .37085 L
.59662 .37183 L
.59789 .37297 L
.60065 .37624 L
.60325 .38044 L
.60558 .38532 L
.6081 .39201 L
Mistroke
.61086 .4014 L
.61377 .41432 L
.61626 .42849 L
.61898 .4482 L
.62379 .49561 L
.62633 .52589 L
.62902 .55745 L
.63137 .57991 L
.6327 .58941 L
.63396 .596 L
.6351 .60012 L
.63615 .60239 L
.63731 .60332 L
.63852 .60255 L
.63983 .59961 L
.64057 .59693 L
.64123 .59381 L
.64253 .58569 L
.64375 .57544 L
.6465 .54367 L
.64947 .50029 L
.65463 .42651 L
.65945 .37244 L
.66893 .29717 L
.67935 .23368 L
.68456 .2064 L
.68951 .18565 L
.69223 .1772 L
.69367 .17367 L
.6952 .17058 L
.69649 .16848 L
.6979 .16662 L
.7004 .1643 L
.70527 .16183 L
.70765 .16093 L
.70981 .15997 L
.71209 .15862 L
.71454 .15661 L
.7172 .15356 L
.71972 .14966 L
.72493 .13821 L
.73059 .12254 L
.73311 .11623 L
.73448 .11335 L
.73577 .1111 L
.73696 .10943 L
.73805 .10822 L
.73926 .10723 L
.74056 .10652 L
.74185 .10615 L
Mistroke
.74306 .10605 L
.74415 .10616 L
.74533 .10647 L
.74662 .10706 L
.74727 .10746 L
.74798 .10799 L
.74924 .10919 L
.75041 .11066 L
.7516 .11254 L
.75272 .11476 L
.75482 .12023 L
.75709 .12819 L
.75955 .13917 L
.76941 .19092 L
.77211 .20285 L
.77501 .21379 L
.77753 .2217 L
.78028 .22888 L
.78531 .23863 L
.78805 .24238 L
.7906 .245 L
.79183 .24599 L
.793 .24676 L
.79405 .24733 L
.79517 .24779 L
.79639 .24815 L
.79752 .24833 L
.79873 .24836 L
.79942 .24831 L
.80006 .24822 L
.80136 .24788 L
.80209 .2476 L
.80277 .24728 L
.80402 .24656 L
.80535 .24556 L
.80789 .24299 L
.81019 .23981 L
.81288 .23487 L
.8158 .22778 L
.81854 .21899 L
.82107 .20864 L
.82579 .18136 L
.82843 .16013 L
.83083 .13644 L
.83557 .08077 L
.83764 .05703 L
.83994 .03593 L
.84121 .0273 L
.84241 .02134 L
.84367 .01717 L
Mistroke
.84438 .01574 L
.84503 .01497 L
.84573 .01472 L
.84639 .01502 L
.8471 .01596 L
.84787 .0177 L
.84859 .02009 L
.84928 .02306 L
.85056 .03059 L
.85179 .04033 L
.85308 .05338 L
.85539 .08292 L
.86062 .16064 L
.86548 .22244 L
.87008 .26742 L
.87539 .30852 L
.88024 .34052 L
.88894 .3916 L
.89357 .41515 L
.89617 .4265 L
.89856 .43528 L
.90098 .44242 L
.9023 .44555 L
.90353 .44801 L
.90576 .45144 L
.90694 .4528 L
.9082 .45396 L
.90953 .45492 L
.91097 .45573 L
.91357 .45684 L
.9159 .45771 L
.91845 .45885 L
.92086 .46033 L
.9231 .46224 L
.92548 .46497 L
.92803 .46888 L
.93265 .47875 L
.93687 .49029 L
.94159 .50274 L
.94295 .50556 L
.94423 .50778 L
.9454 .50941 L
.94662 .51074 L
.9477 .5116 L
.94889 .51225 L
.94997 .5126 L
.95097 .51274 L
.95216 .5127 L
.95324 .51248 L
.95449 .51201 L
Mistroke
.95568 .51133 L
.95685 .51039 L
.95815 .509 L
.95951 .50707 L
.96078 .50473 L
.96306 .49903 L
.96551 .49048 L
.97108 .46313 L
.97619 .43562 L
Mfstroke
.5 Mabswid
[ .01 .01 ] 0 setdash
.02381 .30929 m
.06244 .30918 L
.08255 .30912 L
.10458 .30902 L
.12507 .3089 L
.14415 .30875 L
.16457 .30851 L
.18314 .30822 L
.20229 .30782 L
.22307 .30723 L
.24291 .30647 L
.26394 .30545 L
.30178 .30303 L
.32281 .30151 L
.34206 .30023 L
.35157 .29969 L
.35659 .29945 L
.36194 .29922 L
.36708 .29904 L
.37174 .29891 L
.37399 .29886 L
.37642 .29881 L
.37873 .29878 L
.38084 .29875 L
.38205 .29874 L
.38321 .29873 L
.38443 .29872 L
.38511 .29872 L
.38575 .29872 L
.38681 .29872 L
.38798 .29872 L
.3892 .29872 L
.39034 .29873 L
.39162 .29873 L
.39296 .29874 L
.39536 .29877 L
.39795 .29881 L
.40077 .29886 L
.40605 .29899 L
.41169 .29917 L
.42184 .2996 L
.44318 .3008 L
.46334 .30211 L
.5018 .30451 L
.52129 .30552 L
.54272 .30643 L
.56331 .30712 L
.58212 .30763 L
.60157 .30803 L
.62246 .30836 L
Mistroke
.64149 .30859 L
.66223 .30878 L
.68194 .30891 L
.70292 .30902 L
.72438 .30909 L
.74456 .30915 L
.76468 .30919 L
.78316 .30921 L
.80202 .30923 L
.8227 .30925 L
.84225 .30926 L
.86318 .30927 L
.88446 .30927 L
.90459 .30928 L
.92454 .30928 L
.94297 .30928 L
.95877 .30928 L
.97619 .30929 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[45]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00:=oo`03001oogoo00Ioo`03001oogoo075oo`00XWoo00<007ooOol027oo00<007ooOol0L7oo
0022Ool30002Ool300001Woo001oo`00Ool0009oo`8000eoo`03001oogoo009oo`8000Ioo`03001o
ogoo06moo`00Pgoo00<007ooOol00Woo00X007ooOol007oo001oo`00Ool000moo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo06moo`00Pgoo00<007ooOol00Woo00T007ooOol007oo001oo`00
Ool00`003Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0Kgoo0023Ool01000Oomoogoo
0P000Woo0P0000Aoo`00Oomoo`<000eoo`03001oogoo00=oo`8000Eoo`03001oogoo06moo`00PGoo
00D007oo001oo`0001aoo`03001oogoo00Qoo`03001oogoo071oo`00PGoo1@000Woo00<007ooOol0
67oo00<007ooOol01Woo00<007ooOol0LGoo003oOolQOol00?moob5oo`00ogoo8Goo000_Ool00`00
Oomoo`0`Ool5000aOol3000bOol2000dOol3000JOol002ioo`03001oo`0003=oo`03001oogoo035o
o`03001oogoo03Aoo`03001oogoo039oo`03001oogoo01Uoo`00;Woo00<007oo0000<goo00<007oo
Ool0<Woo00<007ooOol0<Woo00<007ooOol0<Goo10006Woo000^Ool00`00Ool0000cOol00`00Oomo
o`0bOol00`00Oomoo`0cOol00`00Oomoo`0`Ool00`00Ool0000KOol002ioo`03001oo`0003=oo`03
001oogoo035oo`03001oo`00039oo`03001oo`0003=oo`8001]oo`00;goo00<007ooOol0<Goo0P00
=7oo00<007ooOol0<Woo00<007ooOol0<goo00<007ooOol06Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00:Woog`005goo000ZOol00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0JOol0
02Yoo`03001oogoo0?=oo`00:Woo0P00^Woo00<007ooOol0=goo000ZOol00`00Oomoo`1LOol2001K
Ool2000hOol002Yoo`03001oogoo05aoo`8005Yoo`03001oo`0003Qoo`00:Woo00<007ooOol0G7oo
0P00FWoo00<007oo0000>7oo000ZOol2001MOol2001JOol00`00Ool0000hOol002Yoo`03001oogoo
05]oo`04001oogoo001IOol01000Oomoo`00=goo000OOol20004Ool00`00Oomoo`02Ool00`00Oomo
o`1KOol01000Oomoo`00FGoo00@007ooOol003Moo`008Goo00H007ooOol007oo0003Ool00`00Oomo
o`1KOol01000Oomoo`00FGoo00@007ooOol003Moo`006Woo0`000goo00L007ooOomoo`00Ool00003
Ool3001KOol01000Oomoo`00F7oo00D007ooOomoo`0003Moo`008Goo00H007ooOol007oo0003Ool0
0`00Oomoo`1KOol01000Oomoo`00F7oo00D007ooOomoo`0003Moo`007goo00<007oo00000Woo00<0
07oo00000goo00<007ooOol0Fgoo00@007ooOol005Qoo`05001oogooOol0000gOol0021oo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo05]oo`05001oogooOol0001GOol01@00Oomoogoo0000
=goo000ZOol2001LOol01@00Oomoogoo0000Egoo00D007ooOomoo`0003Moo`00:Woo00<007ooOol0
FWoo00<007ooOol00Woo00<007ooOol0EGoo00D007ooOomoo`0003Moo`00:Woo00<007ooOol0FWoo
00<007ooOol00Woo00<007ooOol0EGoo00D007ooOomoo`0003Moo`00:Woo00<007ooOol0FWoo00<0
07ooOol00Woo00<007ooOol0EGoo00D007ooOomoo`0003Moo`00:Woo0P00Fgoo00<007ooOol00Woo
00<007ooOol0EGoo00D007ooOomoo`0003Moo`00:Woo00<007ooOol0FWoo00<007ooOol00Woo00<0
07ooOol0EGoo00D007ooOomoo`0003Moo`00:Woo00<007ooOol0FWoo00<007ooOol00Woo00<007oo
Ool0EGoo00D007ooOomoo`0003Moo`00:Woo0P00Fgoo00<007ooOol00Woo00<007ooOol0EGoo00D0
07ooOomoo`0003Moo`00:Woo00<007ooOol0FWoo00<007ooOol00Woo00<007ooOol0@7oo0P004goo
00D007ooOomoo`0003Moo`00:Woo00<007ooOol0FWoo00<007ooOol00goo00<007ooOol0?Woo1000
4Goo00<007ooOol00Woo00<007ooOol0=Goo000ZOol00`00Oomoo`13Ool3000COol00`00Oomoo`04
Ool00`00Oomoo`0mOol20002Ool2000@Ool00`00Oomoo`02Ool00`00Oomoo`0eOol002Yoo`8004=o
o`80009oo`03001oogoo011oo`03001oogoo00Aoo`03001oogoo03eoo`03001oogoo009oo`03001o
ogoo00ioo`03001oogoo009oo`03001oogoo03Eoo`00:Woo00<007ooOol0@Woo00@007ooOomoo`80
015oo`03001oogoo00Aoo`03001oogoo03eoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo
00=oo`03001oogoo03Aoo`007goo0`000goo00<007ooOol00Woo00<007ooOol0@Goo00<007ooOol0
0goo00<007ooOol03goo00<007ooOol017oo00<007ooOol0?7oo00<007ooOol00goo00<007ooOol0
3Woo00<007ooOol00goo00<007ooOol0=7oo000OOol00`00Oomoo`02Ool00`00Ool00003Ool00`00
Oomoo`11Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomoo`0lOol00`00
Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0dOol001Yoo`<000=oo`07001o
ogooOol007oo00000goo0`00@7oo00<007ooOol01Goo00<007ooOol03Woo00<007ooOol017oo00<0
07ooOol0>goo00<007ooOol01Goo00<007ooOol03Goo00<007ooOol00goo00<007ooOol0=7oo000P
Ool01`00Oomoogoo001oo`0000=oo`03001oogoo041oo`03001oogoo00Eoo`03001oogoo00ioo`03
001oogoo00Aoo`03001oogoo03]oo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo00=oo`03
001oogoo03Aoo`007goo00<007oo00000Woo00<007oo00000goo00<007ooOol0@7oo00<007ooOol0
1Goo00<007ooOol03Woo00<007ooOol017oo00<007ooOol0>Woo00<007ooOol01Woo00<007ooOol0
3Goo00<007ooOol00goo00<007ooOol0=7oo000POol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`0oOol00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`0jOol00`00
Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`0dOol002Yoo`80041oo`03001o
ogoo00Moo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo03Yoo`03001oogoo00Moo`03001o
ogoo00]oo`03001oogoo00Aoo`03001oogoo03Aoo`00:Woo00<007ooOol0?Woo00<007ooOol027oo
00<007ooOol037oo00<007ooOol01Goo00<007ooOol0>7oo0P002Woo00<007ooOol02goo00<007oo
Ool017oo00<007ooOol0=7oo000ZOol00`00Oomoo`0mOol00`00Oomoo`09Ool00`00Oomoo`0<Ool0
0`00Oomoo`05Ool00`00Oomoo`0fOol3000;Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomo
o`0dOol002Yoo`03001oogoo03Yoo`<000aoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo
03Eoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo03Aoo`00:Woo0P00
>goo00<007ooOol037oo00<007ooOol037oo00<007ooOol01Woo00<007ooOol0<goo0P003Woo00<0
07ooOol02goo00<007ooOol017oo00<007ooOol0=7oo000ZOol00`00Oomoo`0iOol00`00Oomoo`0>
Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0cOol00`00Oomoo`0=Ool00`00Oomoo`0;
Ool00`00Oomoo`04Ool00`00Oomoo`0dOol002Yoo`03001oogoo03Uoo`03001oogoo00ioo`03001o
ogoo00]oo`03001oogoo00Ioo`03001oogoo039oo`03001oogoo00moo`03001oogoo00Yoo`03001o
ogoo00Eoo`03001oogoo03=oo`00:Woo00<007ooOol0>7oo00<007ooOol03goo00<007ooOol02goo
00<007ooOol01Woo00<007ooOol0<Woo00<007ooOol03goo00<007ooOol02Woo00<007ooOol01Goo
00<007ooOol0<goo000ZOol2000iOol00`00Oomoo`0?Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool0
0`00Oomoo`0bOol00`00Oomoo`0?Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0cOol0
02Yoo`03001oogoo03Qoo`03001oogoo00moo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo
039oo`03001oogoo00moo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo03=oo`00:Woo00<0
07ooOol0=goo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol0<Goo00<0
07ooOol04Goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0<goo000ZOol2000hOol00`00
Oomoo`0AOol00`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`0aOol00`00Oomoo`0AOol00`00
Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`0cOol002Yoo`03001oogoo03Moo`03001oogoo015o
o`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo035oo`03001oogoo015oo`03001oogoo00Qo
o`03001oogoo00Moo`03001oogoo039oo`007Woo1@000Woo00<007ooOol00Woo00<007ooOol0=goo
00<007ooOol04Goo00<007ooOol02Goo00<007ooOol01goo00<007ooOol0<Goo00<007ooOol04Goo
00<007ooOol027oo00<007ooOol01goo00<007ooOol0<Woo000POol01`00Oomoogoo001oo`0000=o
o`03001oogoo03Moo`03001oogoo019oo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo035o
o`03001oogoo019oo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo039oo`006Woo0`000goo
00L007ooOomoo`00Ool00003Ool3000fOol00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`07
Ool00`00Oomoo`0`Ool00`00Oomoo`0COol00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0b
Ool0021oo`07001oogooOol007oo00000goo00<007ooOol0=Woo00<007ooOol04goo00<007ooOol0
1goo00<007ooOol027oo00<007ooOol0<7oo00<007ooOol057oo00<007ooOol01Goo00<007ooOol0
27oo00<007ooOol0<Woo000POol01`00Oomoogoo001oo`0000=oo`03001oogoo03Ioo`03001oogoo
01=oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo02moo`03001oogoo01Aoo`03001oogoo
00Aoo`03001oogoo00Uoo`03001oogoo039oo`007goo0P0017oo00<007ooOol00Woo00<007ooOol0
=Woo00<007ooOol057oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0;goo00<007ooOol0
5Goo00<007ooOol00goo00<007ooOol02Goo00<007ooOol0<Woo000ZOol2000gOol00`00Oomoo`0D
Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0_Ool00`00Oomoo`0EOol00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`0bOol002Yoo`03001oogoo03Ioo`03001oogoo01Eoo`03001o
ogoo00=oo`03001oogoo00]oo`03001oogoo02moo`03001oogoo01Eoo`80009oo`8000eoo`03001o
ogoo035oo`00:Woo00<007ooOol0=Goo00<007ooOol05Woo0P0017oo00<007ooOol02goo00<007oo
Ool0;goo00<007ooOol05Woo10003Woo00<007ooOol0<Goo000ZOol00`00Oomoo`0eOol00`00Oomo
o`0GOol5000>Ool00`00Oomoo`0^Ool00`00Oomoo`0YOol00`00Oomoo`0aOol002Yoo`8003Ioo`03
001oogoo01Uoo`8000moo`03001oogoo02ioo`03001oogoo02Uoo`03001oogoo035oo`00:Woo00<0
07ooOol0=Goo00<007ooOol0:Woo00<007ooOol0;Woo00<007ooOol0:Goo00<007ooOol0<Goo000Z
Ool00`00Oomoo`0eOol00`00Oomoo`0ZOol00`00Oomoo`0^Ool00`00Oomoo`0YOol00`00Oomoo`0a
Ool002Yoo`03001oogoo03Eoo`03001oogoo02Yoo`03001oogoo02ioo`03001oogoo02Uoo`03001o
ogoo035oo`00:Woo0P00=Woo00<007ooOol0:goo00<007ooOol0;Goo00<007ooOol0:Goo00<007oo
Ool0<Goo000ZOol00`00Oomoo`0dOol00`00Oomoo`0/Ool00`00Oomoo`0]Ool00`00Oomoo`0YOol0
0`00Oomoo`0aOol002Yoo`03001oogoo03Aoo`03001oogoo02aoo`03001oogoo02aoo`03001oogoo
02Yoo`03001oogoo035oo`00:Woo00<007ooOol0=7oo00<007ooOol0;7oo00<007ooOol0;7oo00<0
07ooOol0:goo00<007ooOol0<7oo000ZOol2000eOol00`00Oomoo`0/Ool00`00Oomoo`0/Ool00`00
Oomoo`0[Ool00`00Oomoo`0`Ool002Yoo`03001oogoo03Aoo`03001oogoo01Aoo`800004Ool00000
0002Ool3000017oo000000002Goo00<007ooOol0;7oo00<007ooOol0:goo00<007ooOol0<7oo000U
Ool00`00Oomoo`02Ool00`00Oomoo`0dOol00`00Oomoo`06Ool300001Goo00000000Ool0100000=o
o`00Ool047oo0`0000=oo`0000001P0000Aoo`00000002Ioo`03001oogoo02]oo`03001oogoo031o
o`0097oo00<007oo00000goo00<007ooOol07Goo100000Eoo`00000007oo00@00005Ool00000001o
o`030002Ool3000017oo00000000:7oo00<007ooOol01goo100000Eoo`00000007oo00<0009oo`<0
0004Ool000000002Ool300001Goo00000000Ool00`000goo00<007ooOol0:goo00<007ooOol0<7oo
000TOol00`00Ool00003OooO000GOol002Aoo`03001oo`0000=oo`03001oogoo015oo`L001]oo`03
001oogoo02ioo`03001oogoo02]oo`03001oogoo02]oo`03001oogoo031oo`0097oo00<007oo0000
0goo00<007ooOol067oo10005goo00<007ooOol0;Woo00<007ooOol0:Woo00<007ooOol0;7oo00<0
07ooOol0<7oo000UOol00`00Oomoo`02Ool2000MOol2000EOol00`00Oomoo`0^Ool00`00Oomoo`0Z
Ool00`00Oomoo`0]Ool00`00Oomoo`0_Ool002Yoo`03001oogoo01ioo`8001=oo`03001oogoo02io
o`03001oogoo02Yoo`03001oogoo02eoo`03001oogoo02moo`00:Woo00<007ooOol087oo0P004Goo
00<007ooOol0;Woo00<007ooOol0:Woo00<007ooOol0;Goo00<007ooOol0;goo000ZOol00`00Oomo
o`0ROol00`00Oomoo`0>Ool00`00Oomoo`0^Ool00`00Oomoo`0ZOol00`00Oomoo`0]Ool00`00Oomo
o`0_Ool002Yoo`8002Aoo`03001oogoo00eoo`03001oogoo02ioo`03001oogoo02Yoo`03001oogoo
02eoo`03001oogoo02moo`00:Woo00<007ooOol097oo00<007ooOol02goo00<007ooOol0<7oo00<0
07ooOol0:Goo00<007ooOol0;Goo00<007ooOol0;goo000ZOol00`00Oomoo`0UOol00`00Oomoo`0:
Ool00`00Oomoo`0`Ool00`00Oomoo`0YOol00`00Oomoo`0]Ool00`00Oomoo`0_Ool002Yoo`03001o
ogoo02Eoo`03001oogoo00Yoo`03001oogoo031oo`03001oogoo02Qoo`03001oogoo02moo`03001o
ogoo02ioo`00:Woo0P009goo00<007ooOol02Goo00<007ooOol0<7oo00<007ooOol0:7oo00<007oo
Ool0;goo00<007ooOol0;Woo000ZOol00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0`Ool0
0`00Oomoo`0XOol00`00Oomoo`0_Ool00`00Oomoo`0^Ool002Yoo`03001oogoo02Ioo`03001oogoo
00Uoo`03001oogoo031oo`03001oogoo01Moo`@000eoo`03001oogoo02moo`03001oogoo02ioo`00
:Woo00<007ooOol09goo00<007ooOol027oo00<007ooOol0<Goo00<007ooOol05Goo0P000Woo0P00
37oo00<007ooOol0;goo00<007ooOol0;Woo000ZOol2000XOol00`00Oomoo`08Ool00`00Oomoo`0a
Ool00`00Oomoo`0EOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0_Ool00`00Oomoo`0^
Ool002Yoo`03001oogoo02Moo`03001oogoo00Qoo`03001oogoo035oo`03001oogoo01Aoo`03001o
ogoo00Aoo`03001oogoo00Uoo`03001oogoo031oo`03001oogoo02eoo`007Woo1@000Woo00<007oo
Ool00Woo00<007ooOol09goo00<007ooOol027oo00<007ooOol0<Goo00<007ooOol04goo00<007oo
Ool01Goo00<007ooOol02Goo00<007ooOol0<7oo00<007ooOol0;Goo000POol01`00Oomoogoo001o
o`0000=oo`03001oogoo02Moo`03001oogoo00Qoo`03001oogoo035oo`03001oogoo019oo`03001o
ogoo00Ioo`03001oogoo00Uoo`03001oogoo031oo`03001oogoo02eoo`0087oo00L007ooOomoo`00
Ool00003Ool3000WOol00`00Oomoo`07Ool00`00Oomoo`0bOol00`00Oomoo`0BOol00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`0`Ool00`00Oomoo`0]Ool0021oo`07001oogooOol007oo0000
0goo00<007ooOol09goo00<007ooOol01goo00<007ooOol0<goo00<007ooOol04Goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol0<Goo00<007ooOol0;Goo000POol01`00Oomoogoo001oo`00
00=oo`03001oogoo02Qoo`03001oogoo00Ioo`03001oogoo03=oo`03001oogoo011oo`03001oogoo
00Qoo`03001oogoo00Moo`03001oogoo039oo`03001oogoo02aoo`007goo0P0017oo00<007ooOol0
0Woo00<007ooOol0:7oo00<007ooOol01Woo00<007ooOol0<goo00<007ooOol047oo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol0<Woo00<007ooOol0;7oo000ZOol2000YOol00`00Oomoo`06
Ool00`00Oomoo`0cOol00`00Oomoo`0@Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`0b
Ool00`00Oomoo`0/Ool002Yoo`03001oogoo02Qoo`03001oogoo00Ioo`03001oogoo03=oo`03001o
ogoo011oo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo039oo`03001oogoo02aoo`00:Woo
00<007ooOol0:Goo00<007ooOol01Goo00<007ooOol0=7oo00<007ooOol03goo00<007ooOol02Goo
00<007ooOol01Woo00<007ooOol0<Woo00<007ooOol0;7oo000ZOol00`00Oomoo`0YOol00`00Oomo
o`05Ool00`00Oomoo`0dOol00`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomo
o`0bOol00`00Oomoo`0/Ool002Yoo`8002Yoo`03001oogoo00Eoo`03001oogoo03Aoo`03001oogoo
00ioo`03001oogoo00Yoo`03001oogoo00Ioo`03001oogoo03=oo`03001oogoo02]oo`00:Woo00<0
07ooOol0:Goo00<007ooOol01Goo00<007ooOol0=Goo00<007ooOol03Goo00<007ooOol02goo00<0
07ooOol01Goo00<007ooOol0<goo00<007ooOol03Woo00<007ooOol06Woo000ZOol00`00Oomoo`0Y
Ool00`00Oomoo`05Ool00`00Oomoo`0eOol00`00Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`05
Ool00`00Oomoo`0cOol00`00Oomoo`0>Ool00`00Oomoo`0JOol002Yoo`8002]oo`03001oogoo00Ao
o`03001oogoo03Eoo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo03Ao
o`03001oogoo00eoo`03001oogoo01Yoo`00:Woo00<007ooOol0:Woo00<007ooOol017oo00<007oo
Ool0=Woo00<007ooOol037oo00<007ooOol02goo00<007ooOol01Goo00<007ooOol0=Goo00<007oo
Ool02goo00<007ooOol06goo000ZOol00`00Oomoo`0ZOol00`00Oomoo`04Ool00`00Oomoo`0fOol3
000;Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0eOol2000<Ool00`00Oomoo`0KOol0
02Yoo`03001oogoo02Yoo`03001oogoo00=oo`03001oogoo03Yoo`03001oogoo00Qoo`03001oogoo
00aoo`03001oogoo00Eoo`03001oogoo03Moo`8000Yoo`03001oogoo01]oo`00:Woo0P00:goo00<0
07ooOol00goo00<007ooOol0>goo00<007ooOol01goo00<007ooOol037oo00<007ooOol017oo00<0
07ooOol0>Goo0P002Goo00<007ooOol06goo000ZOol00`00Oomoo`0ZOol00`00Oomoo`03Ool00`00
Oomoo`0lOol00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`0jOol00`00
Oomoo`07Ool00`00Oomoo`0KOol001moo`<000=oo`03001oogoo009oo`03001oogoo02Yoo`03001o
ogoo00=oo`03001oogoo03eoo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo00=oo`03001o
ogoo03]oo`03001oogoo00Ioo`03001oogoo01]oo`007goo00<007ooOol00Woo00<007oo00000goo
00<007ooOol0:Woo00<007ooOol00goo00<007ooOol0?Goo00<007ooOol017oo00<007ooOol03Woo
00<007ooOol00goo00<007ooOol0>goo00<007ooOol01Goo00<007ooOol077oo000POol01`00Oomo
ogoo001oo`0000=oo`<002]oo`03001oogoo009oo`03001oogoo03eoo`03001oogoo00Aoo`03001o
ogoo00ioo`03001oogoo00=oo`03001oogoo03]oo`03001oogoo00Eoo`03001oogoo01aoo`0087oo
00L007ooOomoo`00Ool00003Ool00`00Oomoo`0[Ool00`00Oomoo`02Ool00`00Oomoo`0nOol00`00
Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0lOol00`00Oomoo`04Ool00`00
Oomoo`0LOol001moo`03001oo`00009oo`03001oo`0000=oo`03001oogoo02]oo`03001oogoo009o
o`03001oogoo03ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo03ao
o`03001oogoo00Aoo`03001oogoo01aoo`0087oo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool0:goo00<007ooOol00Woo00<007ooOol0?goo00<007ooOol00Woo00<007ooOol03Woo00<007oo
Ool00goo00<007ooOol0?7oo00<007ooOol00goo00<007ooOol07Goo000ZOol2000/Ool00`00Oomo
o`02Ool00`00Oomoo`0oOol01@00Oomoogoo00004Goo00<007ooOol00goo00<007ooOol0?Goo00<0
07ooOol00Woo00<007ooOol07Goo000ZOol00`00Oomoo`0[Ool00`00Oomoo`02Ool00`00Oomoo`0o
Ool01@00Oomoogoo00004Goo00<007ooOol00goo00<007ooOol0?Goo0P000goo00<007ooOol07Goo
000ZOol00`00Oomoo`0[Ool00`00Oomoo`02Ool00`00Oomoo`0oOol4000BOol00`00Oomoo`03Ool0
0`00Oomoo`0nOol200000goo001oo`0OOol002Yoo`03001oogoo02]oo`03001oogoo009oo`03001o
ogoo05Eoo`03001oogoo00=oo`03001oogoo03moo`80025oo`00:Woo0P00;7oo00<007ooOol00Woo
00<007ooOol0EGoo00<007ooOol00goo00<007ooOol0HWoo000ZOol00`00Oomoo`0[Ool00`00Oomo
o`02Ool00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomoo`1SOol002Yoo`03001oogoo02]oo`05
001oogooOol0001HOol00`00Oomoo`02Ool00`00Oomoo`1SOol002Yoo`03001oogoo02aoo`04001o
ogoo001HOol00`00Oomoo`02Ool00`00Oomoo`1SOol002Yoo`8002eoo`04001oogoo001HOol00`00
Oomoo`02Ool00`00Oomoo`1SOol002Yoo`03001oogoo02aoo`04001oogoo001HOol00`00Oomoo`02
Ool00`00Oomoo`1SOol002Yoo`03001oogoo02aoo`04001oogoo001IOol01@00Oomoogoo0000IGoo
000ZOol2000]Ool01000Oomoo`00FGoo00D007ooOomoo`0006Eoo`00:Woo00<007ooOol0;7oo00@0
07ooOol005Uoo`05001oogooOol0001UOol001moo`8000Aoo`03001oogoo009oo`03001oogoo02ao
o`04001oogoo001IOol01@00Oomoogoo0000IGoo000QOol01P00Oomoo`00Ool000=oo`03001oogoo
02aoo`04001oogoo001IOol01000Oomoo`00IWoo000POol01`00Oomoogoo001oo`0000=oo`<002ao
o`04001oogoo001IOol01000Oomoo`00IWoo000QOol01P00Oomoo`00Ool000=oo`03001oogoo02ao
o`03001oo`0005]oo`03001oo`0006Ioo`007goo00<007oo00000Woo00<007oo00000goo00<007oo
Ool0;7oo00<007oo0000Fgoo00<007oo0000IWoo000POol00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`0]Ool2001KOol00`00Ool0001VOol002Yoo`8002ioo`8005]oo`03001oo`0006Ioo`00
:Woo00<007ooOol0RWoo00<007oo0000IWoo000ZOol00`00Oomoo`2:Ool00`00Ool0001VOol002Yo
o`03001oogoo08Yoo`8006Moo`00:Woo0P00S7oo00<007ooOol0IGoo000ZOol00`00Oomoo`3cOol0
02Yoo`03001oogoo0?=oo`00:Woo00<007ooOol0lgoo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00WGoo00<007ooOol0<7oo00<007ooOol0CGoo002LOol00`00Oomoo`0UOol0
0`00Oomoo`0:Ool00`00Oomoo`1<Ool005ioo`<00006Ool00000001oo`000Woo0P000goo0P000Woo
10003Goo0`000Woo0P000goo0P0037oo00<007ooOol00Woo0`000Woo10000Woo0`0000Aoo`000000
009oo`H0009oo`03001oogoo00Ioo`03001oogoo009oo`8000Ioo`03001oogoo04]oo`00Ggoo00D0
07ooOomoo`00009oo`03001oo`0000Aoo`05001oogoo001oo`03000=Ool01P00Oomoo`00Ool0009o
o`03001oo`00009oo`03001oogoo00Uoo`03001oogoo00=oo`04001oogooOol30002Ool01000Oomo
o`000Woo00@007ooOomoo`<0009oo`04001oogoo0008Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`1;Ool005moo`05001oogooOol00002Ool00`00Ool000020002Ool00`00Oomoo`04Ool0
0`00Oomoo`0;Ool01P00Oomoo`00Ool0009oo`03001oo`0000ioo`03001oogoo00=oo`03001oogoo
00=oo`04001oogoo0002Ool01000Oomoo`001Goo00@007ooOol0009oo`03001oogoo00Ioo`03001o
ogoo00=oo`03001oogoo00Aoo`03001oogoo04]oo`00Ggoo00@007ooOomoo`<0009oo`<00003Ool0
0000008000=oo`8000ioo`<0009oo`800003Ool00000008000aoo`03001oogoo009oo`@0009oo`80
00=oo`<00003Ool0000000Aoo`800003Ool00000008000Yoo`03001oogoo009oo`8000Eoo`03001o
ogoo04]oo`00GGoo00L007oo001oo`00Ool00009Ool00`00Oomoo`0EOol00`00Oomoo`04Ool00`00
Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0FOol00`00Oomoo`08Ool00`00Oomoo`1<Ool005eo
o`L0021oo`8001Moo`03001oogoo00aoo`80009oo`03001oogoo01Aoo`03001oogoo00Ioo`03001o
ogoo04eoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.910206, -48.3411, 
  0.0189112, 0.519631}},
  CellTags->"2"],

Cell["\<\
This is the force the motor must exert to maintain the process. \
\
\>", "MathCaption",
  CellTags->"2"],

Cell["\<\
Plot[Evaluate[fx /. feedbackRules /.
 {thetaBig, thetas[[3]]}],
 {t, 0, 4},
 PlotLabel -> \"Input Force (Newton)\",
 Evaluate[newOptions],
 PlotRange -> All
]\
\>", "Input",
  CellLabel->"In[46]:=",
  CellTags->"2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.309181 0.000106128 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .09692 -30 -4.5 ]
[-0.0125 .09692 0 4.5 ]
[-0.0125 .20305 -30 -4.5 ]
[-0.0125 .20305 0 4.5 ]
[-0.0125 .30918 -6 -4.5 ]
[-0.0125 .30918 0 4.5 ]
[-0.0125 .41531 -24 -4.5 ]
[-0.0125 .41531 0 4.5 ]
[-0.0125 .52144 -24 -4.5 ]
[-0.0125 .52144 0 4.5 ]
[ 0 0 -0.125 0 ]
[.5 .63053 -62 0 ]
[.5 .63053 62 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .09692 m
.00625 .09692 L
s
[(-2000)] -0.0125 .09692 1 0 Mshowa
0 .20305 m
.00625 .20305 L
s
[(-1000)] -0.0125 .20305 1 0 Mshowa
0 .30918 m
.00625 .30918 L
s
[(0)] -0.0125 .30918 1 0 Mshowa
0 .41531 m
.00625 .41531 L
s
[(1000)] -0.0125 .41531 1 0 Mshowa
0 .52144 m
.00625 .52144 L
s
[(2000)] -0.0125 .52144 1 0 Mshowa
.125 Mabswid
0 .11815 m
.00375 .11815 L
s
0 .13938 m
.00375 .13938 L
s
0 .1606 m
.00375 .1606 L
s
0 .18183 m
.00375 .18183 L
s
0 .22428 m
.00375 .22428 L
s
0 .2455 m
.00375 .2455 L
s
0 .26673 m
.00375 .26673 L
s
0 .28796 m
.00375 .28796 L
s
0 .33041 m
.00375 .33041 L
s
0 .35163 m
.00375 .35163 L
s
0 .37286 m
.00375 .37286 L
s
0 .39408 m
.00375 .39408 L
s
0 .43654 m
.00375 .43654 L
s
0 .45776 m
.00375 .45776 L
s
0 .47899 m
.00375 .47899 L
s
0 .50021 m
.00375 .50021 L
s
0 .0757 m
.00375 .0757 L
s
0 .05447 m
.00375 .05447 L
s
0 .03325 m
.00375 .03325 L
s
0 .01202 m
.00375 .01202 L
s
0 .54266 m
.00375 .54266 L
s
0 .56389 m
.00375 .56389 L
s
0 .58512 m
.00375 .58512 L
s
0 .60634 m
.00375 .60634 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .30918 m
1 .30918 L
s
gsave
.5 .63053 -123 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Input) show
99.000000 12.812500 moveto
(Force) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
135.000000 12.812500 moveto
(H) show
141.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Newton) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
177.000000 12.812500 moveto
(L) show
183.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.001 w
.02381 .33722 m
.04262 .33791 L
.06244 .33887 L
.07286 .33952 L
.08255 .34027 L
.0932 .34128 L
.10458 .34267 L
.1148 .34428 L
.12589 .3466 L
.13636 .34954 L
.14603 .35324 L
.15068 .3555 L
.15569 .35838 L
.16475 .36526 L
.17027 .37097 L
.17552 .378 L
.18023 .38622 L
.18538 .39824 L
.18793 .40586 L
.19069 .41578 L
.19312 .42635 L
.19569 .43984 L
.20057 .47356 L
.20505 .5136 L
.20987 .5558 L
.21126 .5655 L
.21258 .57335 L
.21378 .57936 L
.21505 .5846 L
.21572 .5869 L
.21646 .58906 L
.21777 .59185 L
.2185 .59282 L
.21929 .59334 L
.22004 .5933 L
.22072 .59279 L
.22196 .59065 L
.22265 .58872 L
.2233 .58648 L
.22462 .58065 L
.22602 .57278 L
.24593 .45273 L
.25716 .40188 L
.26251 .37986 L
.26752 .36249 L
.27198 .35029 L
.27677 .33992 L
.28694 .32075 L
.29768 .29456 L
.3075 .26131 L
Mistroke
.31228 .246 L
.31737 .23289 L
.32177 .22373 L
.32408 .21966 L
.32652 .21613 L
.32792 .21457 L
.32866 .21391 L
.32945 .21335 L
.33017 .21297 L
.33084 .21274 L
.33213 .21264 L
.33343 .21301 L
.33417 .21343 L
.33484 .21394 L
.33609 .21517 L
.33741 .21685 L
.34255 .22541 L
.34726 .23328 L
.35184 .23923 L
.35414 .24148 L
.35666 .24343 L
.35919 .24489 L
.36061 .2455 L
.3619 .24595 L
.3631 .24627 L
.36441 .24651 L
.36564 .24665 L
.36677 .24671 L
.36783 .2467 L
.36896 .24662 L
.37003 .24648 L
.37101 .2463 L
.37215 .24603 L
.3734 .24566 L
.37566 .24477 L
.37803 .24355 L
.38055 .24191 L
.38506 .23794 L
.38994 .23192 L
.39442 .22429 L
.39933 .21264 L
.40181 .20499 L
.40451 .19478 L
.40908 .1716 L
.41164 .15439 L
.41397 .13568 L
.41817 .096 L
.42278 .05403 L
.42528 .03732 L
.42762 .02618 L
Mistroke
.42891 .02181 L
.43009 .01892 L
.43074 .01782 L
.43145 .01703 L
.43275 .01685 L
.43396 .01827 L
.43506 .02098 L
.43633 .02581 L
.43752 .03189 L
.44194 .0624 L
.46273 .17607 L
.47251 .2184 L
.47784 .24025 L
.48283 .25761 L
.49164 .2793 L
.5013 .29754 L
.50632 .30834 L
.51177 .32289 L
.52167 .35745 L
.52628 .37326 L
.53125 .38702 L
.53563 .39673 L
.53801 .40123 L
.54023 .40478 L
.54146 .4064 L
.54258 .4076 L
.54382 .4086 L
.5445 .40897 L
.54514 .40921 L
.54627 .40933 L
.5473 .40911 L
.54844 .4085 L
.54964 .40746 L
.55087 .40601 L
.5522 .4041 L
.55459 .40001 L
.56002 .39019 L
.56272 .38602 L
.56566 .38231 L
.56843 .3796 L
.56976 .37857 L
.571 .37775 L
.57223 .37706 L
.57355 .37646 L
.57476 .37603 L
.57586 .37573 L
.57706 .3755 L
.57838 .37536 L
.57904 .37533 L
.57975 .37533 L
Mistroke
.58103 .37542 L
.58226 .3756 L
.58296 .37574 L
.58361 .3759 L
.58493 .37631 L
.58634 .37686 L
.5889 .37819 L
.59124 .37978 L
.59396 .38212 L
.59693 .38534 L
.59976 .38918 L
.60233 .39342 L
.60738 .40445 L
.61016 .41253 L
.61277 .42192 L
.61743 .44442 L
.62005 .46142 L
.62247 .48036 L
.62713 .52455 L
.63155 .56516 L
.63399 .58182 L
.63536 .58909 L
.63664 .5945 L
.63771 .5981 L
.63889 .60105 L
.64012 .60288 L
.64128 .60332 L
.64259 .60212 L
.64325 .6008 L
.64396 .59877 L
.64524 .59373 L
.64642 .58751 L
.65197 .54822 L
.66194 .48737 L
.68239 .39785 L
.70098 .33898 L
.71107 .31987 L
.72177 .29332 L
.73167 .2581 L
.73652 .24179 L
.74095 .22983 L
.74517 .22053 L
.7474 .21633 L
.74977 .21257 L
.75109 .21088 L
.75229 .20968 L
.7535 .20883 L
.75463 .20839 L
.75579 .20834 L
.75685 .20865 L
Mistroke
.75802 .20938 L
.75925 .21057 L
.76051 .21217 L
.76165 .2139 L
.76423 .21841 L
.76886 .2269 L
.77146 .23104 L
.77428 .23478 L
.77694 .23754 L
.7794 .23948 L
.78058 .24022 L
.78182 .24086 L
.7829 .24132 L
.78404 .2417 L
.78528 .24201 L
.78643 .2422 L
.78714 .24227 L
.7878 .2423 L
.78905 .24229 L
.79014 .24219 L
.79131 .24201 L
.7923 .24178 L
.79339 .24145 L
.79582 .24046 L
.79809 .23918 L
.80076 .23722 L
.80329 .23486 L
.80803 .22893 L
.81069 .22458 L
.81314 .21972 L
.81604 .21273 L
.81871 .20481 L
.82332 .18642 L
.82575 .1736 L
.82831 .15702 L
.83734 .07474 L
.8398 .0532 L
.84115 .04329 L
.84243 .03533 L
.84362 .0291 L
.84491 .02358 L
.84608 .01966 L
.84716 .01699 L
.84845 .01509 L
.84965 .01472 L
.85097 .01606 L
.85171 .01768 L
.85239 .01973 L
.85375 .02539 L
.85523 .03369 L
Mistroke
.85793 .05252 L
.87761 .16405 L
.88853 .21083 L
.89858 .25102 L
.90358 .26623 L
.90887 .27839 L
.92 .29958 L
.92962 .32339 L
.93507 .34176 L
.94017 .36072 L
.94481 .37636 L
.94985 .38988 L
.95461 .40002 L
.95688 .40401 L
.95901 .40707 L
.95994 .40813 L
.96092 .40903 L
.96199 .40974 L
.96297 .41011 L
.96405 .41018 L
.96506 .40993 L
.96616 .40931 L
.96734 .40825 L
.96849 .40689 L
.96973 .40509 L
.97198 .40123 L
.97619 .39343 L
Mfstroke
.5 Mabswid
[ .01 .01 ] 0 setdash
.02381 .3361 m
.04262 .33606 L
.06244 .336 L
.08255 .33593 L
.09409 .33588 L
.10458 .33582 L
.12415 .33568 L
.14509 .33547 L
.16424 .3352 L
.18502 .33478 L
.20486 .33423 L
.22588 .33342 L
.24542 .33241 L
.26372 .33117 L
.30249 .32751 L
.34372 .32224 L
.38342 .31704 L
.40346 .31487 L
.42162 .3133 L
.44129 .31201 L
.45209 .31147 L
.46226 .31105 L
.47203 .31072 L
.48234 .31043 L
.50081 .31004 L
.51029 .30989 L
.52045 .30976 L
.53879 .30958 L
.54896 .30951 L
.56003 .30945 L
.56959 .3094 L
.58015 .30936 L
.59992 .3093 L
.61076 .30928 L
.62093 .30926 L
.63076 .30925 L
.64111 .30924 L
.65962 .30922 L
.66916 .30921 L
.67936 .30921 L
.69772 .3092 L
.70797 .3092 L
.71907 .30919 L
.72867 .30919 L
.73922 .30919 L
.7591 .30919 L
.76997 .30919 L
.78014 .30919 L
.79055 .30918 L
.80043 .30918 L
Mistroke
.81897 .30918 L
.82858 .30918 L
.83881 .30918 L
.85721 .30918 L
.86752 .30918 L
.87866 .30918 L
.88829 .30918 L
.89884 .30918 L
.91882 .30918 L
.92973 .30918 L
.9399 .30918 L
.97619 .30918 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[46]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00:Uoo`03001oogoo00Ioo`03001oogoo06]oo`00Z7oo00<007ooOol027oo00<007ooOol0JWoo
0028Ool30002Ool300001Woo001oo`00Ool0009oo`8000eoo`03001oogoo009oo`8000Ioo`03001o
ogoo06Uoo`00RGoo00<007ooOol00Woo00X007ooOol007oo001oo`00Ool000moo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo06Uoo`00RGoo00<007ooOol00Woo00T007ooOol007oo001oo`00
Ool00`003Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0JGoo0029Ool01000Oomoogoo
0P000Woo0P0000Aoo`00Oomoo`<000eoo`03001oogoo00=oo`8000Eoo`03001oogoo06Uoo`00Qgoo
00D007oo001oo`0001aoo`03001oogoo00Qoo`03001oogoo06Yoo`00Qgoo1@000Woo00<007ooOol0
67oo00<007ooOol01Woo00<007ooOol0Jgoo003oOolQOol00?moob5oo`00ogoo8Goo000eOol00`00
Oomoo`0`Ool5000aOol3000bOol2000dOol3000DOol003Aoo`03001oo`0003=oo`03001oogoo035o
o`03001oogoo03Aoo`03001oogoo039oo`03001oogoo01=oo`00=7oo00<007oo0000<goo00<007oo
Ool0<Woo00<007ooOol0<Woo00<007ooOol0<Goo100057oo000dOol00`00Ool0000cOol00`00Oomo
o`0bOol00`00Oomoo`0cOol00`00Oomoo`0`Ool00`00Ool0000EOol003Aoo`03001oo`0003=oo`03
001oogoo035oo`03001oo`00039oo`03001oo`0003=oo`8001Eoo`00=Goo00<007ooOol0<Goo0P00
=7oo00<007ooOol0<Woo00<007ooOol0<goo00<007ooOol04goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00<7oog`004Goo000`Ool00`00Oomoo`03Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0DOol0
031oo`03001oogoo0>eoo`00<7oo0P00^goo00<007ooOol0<7oo000`Ool00`00Oomoo`1MOol2001J
Ool00`00Ool0000aOol0031oo`03001oogoo05eoo`8005Yoo`03001oo`00035oo`00<7oo00<007oo
Ool0G7oo00<007oo0000FWoo00<007oo0000<Goo000`Ool2001MOol01000Oomoo`00F7oo00@007oo
Ool0035oo`00<7oo00<007ooOol0G7oo00@007ooOol005Qoo`04001oogoo000aOol0031oo`03001o
ogoo05aoo`04001oogoo001HOol01000Oomoo`00<Goo000`Ool00`00Oomoo`1KOol01@00Oomoogoo
0000F7oo00D007ooOomoo`00031oo`00<7oo00<007ooOol0Fgoo00D007ooOomoo`0005Qoo`05001o
ogooOol0000`Ool0031oo`8005aoo`05001oogooOol0001HOol01@00Oomoogoo0000<7oo000`Ool0
0`00Oomoo`1KOol01@00Oomoogoo0000F7oo00D007ooOomoo`00031oo`00<7oo00<007ooOol0Fgoo
00D007ooOomoo`0005Moo`03001oogoo009oo`03001oogoo02ioo`00<7oo00<007ooOol0Fgoo00D0
07ooOomoo`0005Moo`03001oogoo00=oo`03001oogoo02eoo`00<7oo00<007ooOol0Fgoo00D007oo
Oomoo`0005Moo`03001oogoo00=oo`03001oogoo02eoo`00<7oo0P00Fgoo00<007ooOol00goo00<0
07ooOol0E7oo00<007ooOol00goo00<007ooOol0;Goo000`Ool00`00Oomoo`1JOol00`00Oomoo`03
Ool00`00Oomoo`1DOol00`00Oomoo`03Ool00`00Oomoo`0]Ool001]oo`<000=oo`03001oogoo009o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo05Yoo`03001oogoo00=oo`03001oogoo05Ao
o`03001oogoo00=oo`03001oogoo02eoo`006goo00<007ooOol00Woo00<007oo00000Woo00<007oo
00000Woo00<007oo00000goo00<007ooOol0FWoo00<007ooOol00goo00<007ooOol0E7oo00<007oo
Ool00goo00<007ooOol0;Goo000FOol30003Ool01`00Oomoogoo001oo`00009oo`03001oo`00009o
o`03001oo`0000=oo`<005Yoo`03001oogoo00=oo`03001oogoo05=oo`03001oogoo00Eoo`03001o
ogoo02aoo`0077oo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool00`00
Oomoo`1JOol00`00Oomoo`04Ool00`00Oomoo`1BOol00`00Oomoo`05Ool00`00Oomoo`0/Ool001]o
o`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oo`0000=oo`03001oogoo05Yo
o`03001oogoo00Aoo`03001oogoo059oo`03001oogoo00Eoo`03001oogoo02aoo`0077oo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0FWoo00<007oo
Ool017oo00<007ooOol0DWoo00<007ooOol01Goo00<007ooOol0;7oo000`Ool00`00Oomoo`1JOol0
0`00Oomoo`04Ool00`00Oomoo`1BOol00`00Oomoo`05Ool00`00Oomoo`0/Ool0031oo`8005Yoo`03
001oogoo00Eoo`03001oogoo059oo`03001oogoo00Eoo`03001oogoo02aoo`00<7oo00<007ooOol0
FGoo00<007ooOol01Woo00<007ooOol0DGoo00<007ooOol01Woo00<007ooOol0:goo000`Ool00`00
Oomoo`1IOol00`00Oomoo`06Ool00`00Oomoo`1AOol00`00Oomoo`06Ool00`00Oomoo`0[Ool0031o
o`03001oogoo05Uoo`03001oogoo00Ioo`03001oogoo055oo`03001oogoo00Ioo`03001oogoo02]o
o`00<7oo00<007ooOol0FGoo00<007ooOol01Woo00<007ooOol0DGoo00<007ooOol01Woo00<007oo
Ool0:goo000`Ool2001JOol00`00Oomoo`06Ool00`00Oomoo`1@Ool00`00Oomoo`07Ool00`00Oomo
o`0[Ool0031oo`03001oogoo05Uoo`03001oogoo00Moo`03001oogoo04moo`03001oogoo00Moo`03
001oogoo02]oo`00<7oo00<007ooOol0FGoo00<007ooOol01goo00<007ooOol0Cgoo00<007ooOol0
27oo00<007ooOol0:Woo000`Ool00`00Oomoo`1IOol00`00Oomoo`07Ool00`00Oomoo`1?Ool00`00
Oomoo`08Ool00`00Oomoo`0ZOol0031oo`03001oogoo05Uoo`03001oogoo00Moo`03001oogoo04mo
o`03001oogoo00Qoo`03001oogoo02Yoo`00<7oo0P00FGoo00<007ooOol027oo00<007ooOol0Cgoo
00<007ooOol027oo00<007ooOol0:Woo000`Ool00`00Oomoo`1HOol00`00Oomoo`09Ool00`00Oomo
o`1>Ool00`00Oomoo`08Ool00`00Oomoo`0ZOol0031oo`03001oogoo05Qoo`03001oogoo00Uoo`03
001oogoo04ioo`03001oogoo00Uoo`03001oogoo02Uoo`00<7oo00<007ooOol0F7oo00<007ooOol0
2Goo00<007ooOol0CWoo00<007ooOol02Goo00<007ooOol0:Goo000`Ool2001IOol00`00Oomoo`09
Ool00`00Oomoo`1=Ool00`00Oomoo`0:Ool00`00Oomoo`0YOol0031oo`03001oogoo05Moo`03001o
ogoo00Yoo`03001oogoo04eoo`03001oogoo00Yoo`03001oogoo02Uoo`00<7oo00<007ooOol0Egoo
00<007ooOol02goo00<007ooOol0C7oo00<007ooOol02goo00<007ooOol0:7oo000JOol50002Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`1GOol00`00Oomoo`0;Ool0
0`00Oomoo`1;Ool00`00Oomoo`0<Ool00`00Oomoo`0XOol001aoo`07001oogooOol007oo00000Woo
00<007oo00000Woo00<007oo00000goo00<007ooOol0Egoo00<007ooOol02goo00<007ooOol0Bgoo
00<007ooOol037oo00<007ooOol0:7oo000FOol30003Ool01`00Oomoogoo001oo`00009oo`03001o
o`00009oo`03001oo`0000=oo`<005Moo`03001oogoo00]oo`03001oogoo04]oo`03001oogoo00ao
o`03001oogoo02Qoo`0077oo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool00003
Ool00`00Oomoo`1FOol00`00Oomoo`0=Ool00`00Oomoo`0kOol3000<Ool00`00Oomoo`0=Ool00`00
Oomoo`0WOol001aoo`07001oogooOol007oo00000Woo00<007oo00000Woo00<007oo00000goo00<0
07ooOol0AWoo0`003Goo00<007ooOol03Goo00<007ooOol0>goo00@007oo000000]oo`03001oogoo
00eoo`03001oogoo02Moo`006goo0P0017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol0AWoo00<007oo00003Goo00<007ooOol03Goo00<007ooOol0>Woo00D007ooOomo
o`0000Yoo`03001oogoo00ioo`03001oogoo02Moo`00<7oo00<007ooOol0AGoo00D007ooOomoo`00
00]oo`03001oogoo00ioo`03001oogoo03Yoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo
00ioo`03001oogoo02Moo`00<7oo0P00AWoo00D007ooOomoo`0000]oo`03001oogoo00ioo`03001o
ogoo03Uoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo011oo`03001oogoo02Ioo`00<7oo
00<007ooOol0A7oo00<007ooOol00goo00<007ooOol01goo00<007ooOol047oo00<007ooOol0>7oo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol047oo00<007ooOol09Woo000`Ool00`00Oomo
o`14Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`0hOol00`00Oomo
o`04Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`0VOol0031oo`03001oogoo04Aoo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo015oo`03001oogoo03Moo`03001oogoo00Ioo`80
009oo`8001Aoo`03001oogoo02Ioo`00<7oo0P00A7oo00<007ooOol01Woo0P000Woo0`005Goo00<0
07ooOol0=Woo00<007ooOol01goo10005Woo00<007ooOol09Goo000`Ool00`00Oomoo`13Ool00`00
Oomoo`08Ool3000GOol00`00Oomoo`0fOol00`00Oomoo`0QOol00`00Oomoo`0UOol0031oo`03001o
ogoo04=oo`03001oogoo02=oo`03001oogoo03Aoo`03001oogoo029oo`03001oogoo02Eoo`00<7oo
00<007ooOol0@Woo00<007ooOol097oo00<007ooOol0=7oo00<007ooOol08Woo00<007ooOol09Goo
000`Ool00`00Oomoo`12Ool00`00Oomoo`0TOol00`00Oomoo`0dOol00`00Oomoo`0SOol00`00Oomo
o`0TOol0031oo`8004=oo`03001oogoo02Eoo`03001oogoo039oo`03001oogoo02Aoo`03001oogoo
02Aoo`00<7oo00<007ooOol0@Goo00<007ooOol09Woo00<007ooOol0<Woo00<007ooOol097oo00<0
07ooOol097oo000`Ool00`00Oomoo`11Ool00`00Oomoo`0WOol00`00Oomoo`0aOol00`00Oomoo`0U
Ool00`00Oomoo`0SOol0031oo`03001oogoo041oo`03001oogoo02Qoo`03001oogoo035oo`03001o
ogoo02Eoo`03001oogoo02=oo`00<7oo00<007ooOol0@7oo00<007ooOol0:Goo00<007ooOol0;goo
00<007ooOol09goo00<007ooOol08Woo000`Ool20010Ool00`00Oomoo`0ZOol00`00Oomoo`0_Ool0
0`00Oomoo`0XOol00`00Oomoo`0QOol0031oo`03001oogoo03moo`03001oogoo02]oo`03001oogoo
02ioo`03001oogoo02Qoo`03001oogoo025oo`00<7oo00<007ooOol0?goo00<007ooOol0:goo00<0
07ooOol0;Goo00<007ooOol0:Woo00<007ooOol087oo000[Ool00`00Oomoo`02Ool00`00Oomoo`0n
Ool00`00Oomoo`0]Ool00`00Oomoo`0/Ool00`00Oomoo`0ZOol00`00Oomoo`0POol002Yoo`03001o
o`0000=oo`03001oogoo03ioo`03001oogoo02eoo`03001oogoo02]oo`03001oogoo02aoo`03001o
ogoo01moo`00:Woo00<007oo00000goog`004Goo000ZOol00`00Ool00003Ool00`00Oomoo`0mOol0
0`00Oomoo`0COol300000goo00000002000DOol00`00Oomoo`0YOol00`00Oomoo`0]Ool00`00Oomo
o`0OOol002Yoo`03001oo`0000=oo`03001oogoo03eoo`03001oogoo00Yoo`<00003Ool000000080
01eoo`03001oogoo02Uoo`03001oogoo02ioo`03001oogoo01ioo`00:goo00<007ooOol00Woo00<0
07ooOol0?7oo00<007ooOol017oo00<007ooOol00`009Woo00<007ooOol0:7oo00<007ooOol0;goo
00<007ooOol07Woo000`Ool2000iOol800000goo0000000/Ool00`00Oomoo`0XOol00`00Oomoo`0_
Ool00`00Oomoo`0NOol0031oo`03001oogoo019oo`800005Ool00000001oo`0400001Goo00000000
Ool00`000Woo0`0000Aoo`000000009oo`<00004Ool000000004Ool00`00Oomoo`0bOol00`00Oomo
o`0VOol00`00Oomoo`0aOol00`00Oomoo`0MOol0031oo`03001oogoo00=oo`l002Uoo`03001oogoo
039oo`03001oogoo02Ioo`03001oogoo035oo`03001oogoo01eoo`00<7oo00<007ooOol04Goo1`00
8goo00<007ooOol0<Woo00<007ooOol09Woo00<007ooOol0<Goo00<007ooOol07Goo000`Ool00`00
Oomoo`0HOol3000OOol00`00Oomoo`0cOol00`00Oomoo`0UOol00`00Oomoo`0bOol00`00Oomoo`0M
Ool0031oo`8001aoo`@001]oo`03001oogoo03Aoo`03001oogoo02Aoo`03001oogoo03=oo`03001o
ogoo01aoo`00<7oo00<007ooOol07goo0P0067oo00<007ooOol0=Goo00<007ooOol097oo00<007oo
Ool0<goo00<007ooOol077oo000`Ool00`00Oomoo`0QOol00`00Oomoo`0EOol00`00Oomoo`0eOol0
0`00Oomoo`0SOol00`00Oomoo`0dOol00`00Oomoo`0LOol0031oo`03001oogoo029oo`03001oogoo
01Aoo`03001oogoo03Ioo`03001oogoo029oo`03001oogoo03Aoo`03001oogoo01aoo`00<7oo00<0
07ooOol08goo00<007ooOol04Woo00<007ooOol0=goo00<007ooOol08Woo00<007ooOol0=Goo00<0
07ooOol06goo000`Ool2000UOol00`00Oomoo`0AOol00`00Oomoo`0gOol00`00Oomoo`08Ool3000G
Ool00`00Oomoo`0eOol00`00Oomoo`0KOol0031oo`03001oogoo02Aoo`03001oogoo015oo`03001o
ogoo03Moo`03001oogoo00Moo`80009oo`8001Aoo`03001oogoo03Ioo`03001oogoo01]oo`00<7oo
00<007ooOol09Goo00<007ooOol047oo00<007ooOol0>7oo00<007ooOol01Goo00<007ooOol00goo
0P004goo00<007ooOol0=goo00<007ooOol06Woo000`Ool00`00Oomoo`0UOol00`00Oomoo`0?Ool0
0`00Oomoo`0iOol00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0@Ool00`00Oomoo`0gOol0
0`00Oomoo`0JOol0031oo`8002Moo`03001oogoo00ioo`03001oogoo03Yoo`03001oogoo00=oo`03
001oogoo00Ioo`03001oogoo00moo`03001oogoo03Qoo`03001oogoo00=oo`03001oogoo01Aoo`00
<7oo00<007ooOol09goo00<007ooOol037oo00<007ooOol0>goo00<007ooOol00Woo00<007ooOol0
1goo00<007ooOol03goo00<007ooOol0>Goo00D007ooOomoo`0001Moo`00<7oo00<007ooOol09goo
00<007ooOol037oo00<007ooOol0?7oo00D007ooOomoo`0000Yoo`03001oogoo00ioo`03001oogoo
03Uoo`05001oogooOol0000GOol001Yoo`D0009oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo02Moo`03001oogoo00aoo`03001oogoo03aoo`@000]oo`03001oogoo00eo
o`03001oogoo03]oo`04001oo`00000GOol001aoo`07001oogooOol007oo00000Woo00<007oo0000
0Woo00<007oo00000goo00<007ooOol0:7oo00<007ooOol02goo00<007ooOol0?Goo0P003Goo00<0
07ooOol037oo00<007ooOol0?7oo0P0067oo000LOol01`00Oomoogoo001oo`00009oo`03001oo`00
009oo`03001oo`0000=oo`<002Qoo`03001oogoo00Yoo`03001oogoo04eoo`03001oogoo00aoo`03
001oogoo05Ioo`0077oo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool0
0`00Oomoo`0XOol00`00Oomoo`0:Ool00`00Oomoo`1=Ool00`00Oomoo`0<Ool00`00Oomoo`1FOol0
01aoo`07001oogooOol007oo00000Woo00<007oo00000Woo00<007oo00000goo00<007ooOol0:7oo
00<007ooOol02Woo00<007ooOol0CGoo00<007ooOol02goo00<007ooOol0Egoo000KOol20004Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0XOol00`00Oomoo`0:Ool0
0`00Oomoo`1=Ool00`00Oomoo`0;Ool00`00Oomoo`1GOol0031oo`03001oogoo02Qoo`03001oogoo
00Yoo`03001oogoo04eoo`03001oogoo00]oo`03001oogoo05Moo`00<7oo0P00:Woo00<007ooOol0
2Goo00<007ooOol0CWoo00<007ooOol02Woo00<007ooOol0Egoo000`Ool00`00Oomoo`0YOol00`00
Oomoo`08Ool00`00Oomoo`1?Ool00`00Oomoo`09Ool00`00Oomoo`1HOol0031oo`03001oogoo02Uo
o`03001oogoo00Qoo`03001oogoo04moo`03001oogoo00Uoo`03001oogoo05Qoo`00<7oo00<007oo
Ool0:Goo00<007ooOol027oo00<007ooOol0Cgoo00<007ooOol02Goo00<007ooOol0F7oo000`Ool0
0`00Oomoo`0YOol00`00Oomoo`08Ool00`00Oomoo`1@Ool00`00Oomoo`08Ool00`00Oomoo`1HOol0
031oo`8002]oo`03001oogoo00Moo`03001oogoo051oo`03001oogoo00Moo`03001oogoo05Uoo`00
<7oo00<007ooOol0:Woo00<007ooOol01goo00<007ooOol0D7oo00<007ooOol01goo00<007ooOol0
FGoo000`Ool00`00Oomoo`0ZOol00`00Oomoo`06Ool00`00Oomoo`1AOol00`00Oomoo`07Ool00`00
Oomoo`1IOol0031oo`03001oogoo02Yoo`03001oogoo00Ioo`03001oogoo059oo`03001oogoo00Io
o`03001oogoo05Uoo`00<7oo0P00:goo00<007ooOol01Woo00<007ooOol0DWoo00<007ooOol01Goo
00<007ooOol0FWoo000`Ool00`00Oomoo`0ZOol00`00Oomoo`06Ool00`00Oomoo`1BOol00`00Oomo
o`05Ool00`00Oomoo`1JOol0031oo`03001oogoo02Yoo`03001oogoo00Ioo`03001oogoo059oo`03
001oogoo00Eoo`03001oogoo05Yoo`00<7oo00<007ooOol0:Woo00<007ooOol01Woo00<007ooOol0
DWoo00<007ooOol01Goo00<007ooOol0FWoo000`Ool00`00Oomoo`0[Ool00`00Oomoo`05Ool00`00
Oomoo`1BOol00`00Oomoo`05Ool00`00Oomoo`1JOol0031oo`8002aoo`03001oogoo00Aoo`03001o
ogoo05=oo`03001oogoo00Eoo`03001oogoo05Yoo`00<7oo00<007ooOol0:goo00<007ooOol017oo
00<007ooOol0E7oo00<007ooOol00goo00<007ooOol0Fgoo000`Ool00`00Oomoo`0[Ool00`00Oomo
o`04Ool00`00Oomoo`1DOol00`00Oomoo`03Ool00`00Oomoo`1KOol001]oo`<000=oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo02]oo`03001oogoo00Aoo`03001oogoo
05Aoo`03001oogoo00=oo`03001oogoo05]oo`006goo00<007ooOol00Woo00<007oo00000Woo00<0
07oo00000Woo00<007oo00000goo00<007ooOol0:goo00<007ooOol017oo00<007ooOol0E7oo00<0
07ooOol00goo00<007ooOol0Fgoo000LOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03
001oo`0000=oo`<002]oo`03001oogoo00Aoo`03001oogoo05Aoo`03001oogoo00=oo`03001oogoo
05]oo`0077oo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomo
o`0[Ool00`00Oomoo`03Ool00`00Oomoo`1EOol00`00Oomoo`03Ool00`00Oomoo`1KOol001]oo`03
001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oo`0000=oo`03001oogoo02]oo`03
001oogoo00=oo`03001oogoo05Eoo`03001oogoo00=oo`03001oogoo05]oo`0077oo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0;7oo00<007ooOol0
0Woo00<007ooOol0EGoo00<007ooOol00Woo00<007ooOol0G7oo000`Ool2000]Ool00`00Oomoo`02
Ool00`00Oomoo`1EOol00`00Oomoo`02Ool00`00Oomoo`1LOol0031oo`03001oogoo02aoo`03001o
ogoo009oo`03001oogoo05Ioo`05001oogooOol0001NOol0031oo`03001oogoo02aoo`03001oogoo
009oo`03001oogoo05Ioo`05001oogooOol0001NOol0031oo`03001oogoo02aoo`03001oogoo009o
o`03001oogoo05Ioo`05001oogooOol0001NOol0031oo`03001oogoo02aoo`05001oogooOol0001I
Ool01@00Oomoogoo0000GWoo000`Ool2000]Ool01@00Oomoogoo0000FGoo00D007ooOomoo`0005io
o`00<7oo00<007ooOol0;Goo00@007ooOol005Uoo`04001oogoo001OOol0031oo`03001oogoo02eo
o`04001oogoo001IOol01000Oomoo`00Ggoo000`Ool00`00Oomoo`0]Ool00`00Ool0001JOol01000
Oomoo`00Ggoo000`Ool00`00Oomoo`0]Ool00`00Ool0001JOol01000Oomoo`00Ggoo000`Ool2000^
Ool00`00Ool0001JOol01000Oomoo`00Ggoo000`Ool00`00Oomoo`0]Ool3001JOol01000Oomoo`00
Ggoo000`Ool00`00Oomoo`0^Ool00`00Oomoo`1JOol00`00Ool0001OOol0031oo`03001oogoo08]o
o`80061oo`00<7oo00<007ooOol0S7oo00<007ooOol0GWoo000`Ool2003^Ool0031oo`03001oogoo
0>eoo`00<7oo00<007ooOol0kGoo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00KGoo0`00?goo00<007ooOol097oo00<007ooOol0Agoo001^Ool00`00Oomoo`0mOol00`00Oomo
o`0VOol00`00Oomoo`16Ool006Aoo`<00003Ool00000009oo`03001oo`00008000=oo`<0009oo`80
00aoo`<000Aoo`80009oo`<0009oo`<000=oo`8000ioo`04001oogooOol3000017oo001oogoo0P00
0Woo00<007oo00000goo0P000goo0P0000=oo`0000000Woo00<007ooOol01goo00<007ooOol0AGoo
001UOol01@00Oomoogoo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<0
07ooOol02Woo00<007ooOol00Woo00@007ooOol0009oo`05001oogooOol00004Ool00`00Oomoo`0>
Ool00`00Oomoo`02Ool01P00Ool00000Ool000=oo`07001oo`00Ool007oo00000Woo00<007oo0000
0Woo00<007oo00000Woo00<007ooOol01goo00<007ooOol0AGoo001UOol01@00Oomoogoo00000Woo
00<007oo00000Woo00<007oo00000Woo00<007oo00003goo00<007ooOol00Woo00@007ooOol0009o
o`05001oogooOol00004Ool3000>Ool00`00Oomoo`02Ool01@00Ool00000Ool00`0000Qoo`00Ool0
07oo001oo`0017oo00H007ooOol007oo0002Ool00`00Oomoo`07Ool00`00Oomoo`15Ool006Eoo`03
001oogoo00@00003Ool0000000800004Ool00000Ool6000=Ool20004Ool20002Ool4000017oo0000
00000Woo0`003Woo00<007ooOol00Woo0P0000=oo`00Ool00`0000Aoo`00001oo`H000=oo`800003
Ool00000008000Yoo`03001oogoo04Eoo`00IGoo00<007ooOol047oo00<007ooOol03Goo00@007oo
Ool0029oo`04001oogooOol200000goo001oo`0:Ool00`00Oomoo`0COol00`00Oomoo`16Ool006Ao
o`<0021oo`D002=oo`05001oo`00001oo`02000POol00`00Oomoo`17Ool00?moob5oo`00ogoo8Goo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.02367, -3945.92, 0.0189112
  , 42.4267}},
  CellTags->"2"],

Cell[TextData[{
  "The real actuator may not be up to the task. If the maximum force the \
motor can provide is, say, ",
  Cell[BoxData[
      \(TraditionalForm\`1000\)], "InlineFormula",
    CellTags->"S0.0.1"],
  "\[NonBreakingSpace]N, and the feedback saturates at that limit, the \
controller fails to balance the pendulum. "
}], "Text",
  CellTags->"2"],

Cell["To model this situation, we create a clip function. ", "MathCaption",
  CellTags->"2"],

Cell["clip = If[Abs[#] <= 1000., #, Sign[#] 1000.]&", "Input",
  CellLabel->"In[47]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{
      RowBox[{"If", "[", 
        RowBox[{
          RowBox[{\(Abs[#1]\), "\[LessEqual]", 
            StyleBox["1000.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}], ",", "#1", ",", 
          RowBox[{\(Sign[#1]\), " ", 
            StyleBox["1000.`",
              StyleBoxAutoDelete->True,
              PrintPrecision->4]}]}], "]"}], "&"}]], "Output",
  CellLabel->"Out[47]=",
  CellTags->"2"],

Cell[TextData[{
  "Here is how it works: everything beyond the interval from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1000\)\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`1000\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " gets cut off. "
}], "MathCaption",
  CellTags->"2"],

Cell["clip /@ {-1001, -999, 999, 1001}", "Input",
  CellLabel->"In[48]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(-1000.`\), ",", \(-999\), ",", "999", ",", 
        StyleBox["1000.`",
          StyleBoxAutoDelete->True,
          PrintPrecision->4]}], "}"}]], "Output",
  CellLabel->"Out[48]=",
  CellTags->"2"],

Cell[TextData[{
  "We use ",
  StyleBox["clip", "MR"],
  " to saturate the feedback. "
}], "MathCaption",
  CellTags->"2"],

Cell["feedbackLtd = MapAt[clip, feedbackRules, {1, 2}]", "Input",
  CellLabel->"In[49]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"fx", "\[Rule]", 
        RowBox[{"If", "[", 
          RowBox[{
            RowBox[{
              RowBox[{"Abs", "[", 
                RowBox[{\(211.333333333333373`\ theta[t]\), "+", 
                  RowBox[{"50.9999999999999964`", " ", 
                    RowBox[{
                      SuperscriptBox["theta", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], 
              "\[LessEqual]", 
              StyleBox["1000.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4]}], ",", 
            RowBox[{\(211.333333333333373`\ theta[t]\), "+", 
              RowBox[{"50.9999999999999964`", " ", 
                RowBox[{
                  SuperscriptBox["theta", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
            RowBox[{
              RowBox[{"Sign", "[", 
                RowBox[{\(211.333333333333373`\ theta[t]\), "+", 
                  RowBox[{"50.9999999999999964`", " ", 
                    RowBox[{
                      SuperscriptBox["theta", "\[Prime]",
                        MultilineFunction->None], "[", "t", "]"}]}]}], "]"}], 
              " ", 
              StyleBox["1000.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->4]}]}], "]"}]}], "}"}]], "Output",
  CellLabel->"Out[49]=",
  CellTags->"2"],

Cell[TextData[{
  "This is the new differential equation for ",
  StyleBox["theta", "MR"],
  " under the saturated feedback. "
}], "MathCaption",
  CellTags->"2"],

Cell["de1 = Equal @@ sln /. numericValues /. feedbackLtd", "Input",
  CellLabel->"In[50]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["theta", "\[DoublePrime]",
          MultilineFunction->None], "[", "t", "]"}], "==", 
      RowBox[{"-", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{"3.`", " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", \(Cos[theta[t]]\), " ", 
                    RowBox[{"If", "[", 
                      RowBox[{
                        RowBox[{
                          RowBox[{"Abs", "[", 
                            RowBox[{\(211.333333333333373`\ theta[t]\), "+", 
                              RowBox[{"50.9999999999999964`", " ", 
                                RowBox[{
                                  SuperscriptBox["theta", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}]}
                                ]}], "]"}], "\[LessEqual]", 
                          StyleBox["1000.`",
                            StyleBoxAutoDelete->True,
                            PrintPrecision->4]}], ",", 
                        RowBox[{\(211.333333333333373`\ theta[t]\), "+", 
                          RowBox[{"50.9999999999999964`", " ", 
                            RowBox[{
                              SuperscriptBox["theta", "\[Prime]",
                                MultilineFunction->None], "[", "t", "]"}]}]}]
                          , ",", 
                        RowBox[{
                          RowBox[{"Sign", "[", 
                            RowBox[{\(211.333333333333373`\ theta[t]\), "+", 
                              RowBox[{"50.9999999999999964`", " ", 
                                RowBox[{
                                  SuperscriptBox["theta", "\[Prime]",
                                    MultilineFunction->None], "[", "t", "]"}]}
                                ]}], "]"}], " ", 
                          StyleBox["1000.`",
                            StyleBoxAutoDelete->True,
                            PrintPrecision->4]}]}], "]"}]}], "-", 
                  \(196.000000000000014`\ Sin[theta[t]]\), "+", 
                  RowBox[{
                  "2.`", " ", \(Cos[theta[t]]\), " ", \(Sin[theta[t]]\), 
                    " ", 
                    SuperscriptBox[
                      RowBox[{
                        SuperscriptBox["theta", "\[Prime]",
                          MultilineFunction->None], "[", "t", "]"}], "2"]}]}]
                  , ")"}]}], ")"}], "/", 
          \((\(\(10.`\)\(\[InvisibleSpace]\)\) + 
              24.0000000000000035`\ Cos[theta[t]]\^2 + 30.`\ Sin[theta[t]]\^2)
            \)}]}]}]], "Output",
  CellLabel->"Out[50]=",
  CellTags->"2"],

Cell["This solves it. ", "MathCaption",
  CellTags->"2"],

Cell["\<\
thetaBig1 = NDSolve[
 {de1, theta[0]==1.25, theta'[0]==0},
 {theta}, {t, 0, 4},
 MaxSteps -> 1000
]\
\>", "Input",
  CellLabel->"In[51]:=",
  CellTags->"2"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"theta", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 4.`}}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[51]=",
  CellTags->"2"],

Cell[TextData[{
  "Finally, we plot the state response\[LongDash]for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " as a solid line and for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Theta]\& . \)\)\)], "InlineFormula",
    CellTags->"S0.0.1"],
  " as a dashed one. It is clear that the controller fails to return the \
pendulum to its equilibrium position. "
}], "MathCaption",
  CellTags->"2"],

Cell["\<\
Plot[Evaluate[{theta[t], theta'[t]} /. thetaBig1],
 {t, 0, 4},
 PlotStyle -> {
 Thickness[.001],
 {Dashing[{.05, .01}], Thickness[.001]} },
 PlotRange -> All,
 PlotLabel -> \"State Response\",
 Frame -> {Automatic, Automatic, None, None},
 FrameLabel -> {\"Time (s)\", None}
]\
\>", "Input",
  CellLabel->"In[52]:=",
  CellTags->"2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.238095 0.380603 0.00917037 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.2619 -0.0125 -3 -9 ]
[.2619 -0.0125 3 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -26 -21.5625 ]
[.5 -0.0125 26 -9 ]
[-0.0125 .01379 -18 -4.5 ]
[-0.0125 .01379 0 4.5 ]
[-0.0125 .10549 -18 -4.5 ]
[-0.0125 .10549 0 4.5 ]
[-0.0125 .1972 -18 -4.5 ]
[-0.0125 .1972 0 4.5 ]
[-0.0125 .2889 -18 -4.5 ]
[-0.0125 .2889 0 4.5 ]
[-0.0125 .3806 -6 -4.5 ]
[-0.0125 .3806 0 4.5 ]
[-0.0125 .47231 -12 -4.5 ]
[-0.0125 .47231 0 4.5 ]
[-0.0125 .56401 -12 -4.5 ]
[-0.0125 .56401 0 4.5 ]
[ 0 0 -0.125 0 ]
[.5 .63053 -44 0 ]
[.5 .63053 44 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(1)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(2)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(3)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(4)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -87 -25.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Time) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
93.000000 12.812500 moveto
(H) show
99.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(s) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
105.000000 12.812500 moveto
(L) show
111.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .01379 m
.00625 .01379 L
s
[(-40)] -0.0125 .01379 1 0 Mshowa
0 .10549 m
.00625 .10549 L
s
[(-30)] -0.0125 .10549 1 0 Mshowa
0 .1972 m
.00625 .1972 L
s
[(-20)] -0.0125 .1972 1 0 Mshowa
0 .2889 m
.00625 .2889 L
s
[(-10)] -0.0125 .2889 1 0 Mshowa
0 .3806 m
.00625 .3806 L
s
[(0)] -0.0125 .3806 1 0 Mshowa
0 .47231 m
.00625 .47231 L
s
[(10)] -0.0125 .47231 1 0 Mshowa
0 .56401 m
.00625 .56401 L
s
[(20)] -0.0125 .56401 1 0 Mshowa
.125 Mabswid
0 .03213 m
.00375 .03213 L
s
0 .05047 m
.00375 .05047 L
s
0 .06881 m
.00375 .06881 L
s
0 .08715 m
.00375 .08715 L
s
0 .12383 m
.00375 .12383 L
s
0 .14217 m
.00375 .14217 L
s
0 .16051 m
.00375 .16051 L
s
0 .17886 m
.00375 .17886 L
s
0 .21554 m
.00375 .21554 L
s
0 .23388 m
.00375 .23388 L
s
0 .25222 m
.00375 .25222 L
s
0 .27056 m
.00375 .27056 L
s
0 .30724 m
.00375 .30724 L
s
0 .32558 m
.00375 .32558 L
s
0 .34392 m
.00375 .34392 L
s
0 .36226 m
.00375 .36226 L
s
0 .39894 m
.00375 .39894 L
s
0 .41728 m
.00375 .41728 L
s
0 .43563 m
.00375 .43563 L
s
0 .45397 m
.00375 .45397 L
s
0 .49065 m
.00375 .49065 L
s
0 .50899 m
.00375 .50899 L
s
0 .52733 m
.00375 .52733 L
s
0 .54567 m
.00375 .54567 L
s
0 .58235 m
.00375 .58235 L
s
0 .60069 m
.00375 .60069 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 .3806 m
1 .3806 L
s
gsave
.5 .63053 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(State) show
99.000000 12.812500 moveto
(Response) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.02381 .39207 m
.02499 .39207 L
.02605 .39207 L
.02729 .39207 L
.02846 .39207 L
.03053 .39207 L
.03279 .39208 L
.03527 .39208 L
.0379 .39209 L
.04262 .39211 L
.05205 .39216 L
.05742 .39219 L
.06244 .39224 L
.07285 .39234 L
.08274 .39247 L
.09415 .39266 L
.10458 .39289 L
.11417 .39315 L
.12439 .39351 L
.13403 .39393 L
.14277 .39443 L
.1528 .39516 L
.16202 .39606 L
.17214 .39744 L
.17724 .39836 L
.18284 .39963 L
.18808 .40117 L
.19304 .40307 L
.1975 .40527 L
.20235 .4083 L
.22326 .42667 L
.23346 .43547 L
.23846 .439 L
.24304 .44161 L
.24784 .44375 L
.25302 .4455 L
.25839 .44682 L
.26109 .44733 L
.26405 .44779 L
.26658 .44811 L
.26933 .44838 L
.27193 .44857 L
.27316 .44865 L
.27432 .4487 L
.27545 .44875 L
.27648 .44878 L
.27762 .44881 L
.27886 .44882 L
.28003 .44883 L
.28132 .44882 L
Mistroke
.28253 .4488 L
.28366 .44877 L
.28498 .44873 L
.2864 .44866 L
.28898 .4485 L
.29149 .44829 L
.2938 .44804 L
.29906 .44727 L
.30171 .44676 L
.30461 .44609 L
.30986 .44453 L
.31484 .44256 L
.32415 .43754 L
.34508 .42328 L
.38346 .39009 L
.39369 .38131 L
.40328 .37535 L
.40809 .37308 L
.41328 .37097 L
.4243 .36708 L
.43471 .36336 L
.44438 .35892 L
.44926 .35594 L
.45447 .35199 L
.46549 .34156 L
.47519 .33189 L
.48544 .32276 L
.4908 .31904 L
.49669 .31583 L
.50704 .3116 L
.51779 .30794 L
.52797 .30402 L
.53712 .29915 L
.54229 .29544 L
.54708 .2913 L
.56656 .27211 L
.57175 .26742 L
.57734 .26311 L
.58227 .26004 L
.58747 .25743 L
.59719 .25362 L
.60611 .25059 L
.61606 .24685 L
.62153 .24427 L
.6267 .24123 L
.63703 .23291 L
.64642 .22362 L
.65516 .21499 L
.66478 .2067 L
.67448 .20081 L
Mistroke
.67979 .19844 L
.68477 .19655 L
.70321 .19005 L
.70818 .18788 L
.7136 .185 L
.72347 .17773 L
.742 .15957 L
.75214 .15042 L
.76169 .14417 L
.76698 .14163 L
.7727 .13936 L
.78267 .13592 L
.79299 .13217 L
.80262 .12744 L
.80747 .12425 L
.81267 .12004 L
.82369 .10936 L
.86507 .08058 L
.87512 .07717 L
.88062 .07514 L
.88579 .07295 L
.89489 .06783 L
.89973 .06419 L
.90494 .05953 L
.92362 .04109 L
.92855 .03668 L
.93381 .03264 L
.94329 .02726 L
.95152 .02391 L
.95901 .02133 L
.97619 .01472 L
Mfstroke
[ .05 .01 ] 0 setdash
.02381 .3806 m
.04262 .38161 L
.06244 .3827 L
.08255 .3841 L
.09396 .38516 L
.10458 .38643 L
.11508 .38804 L
.125 .39006 L
.1339 .39246 L
.14357 .39598 L
.15301 .40084 L
.15838 .40453 L
.16341 .40887 L
.1687 .41469 L
.17354 .4216 L
.17913 .43232 L
.18186 .43907 L
.18444 .44666 L
.18947 .46616 L
.19403 .49052 L
.19935 .5253 L
.20424 .55975 L
.20647 .57373 L
.20854 .58459 L
.2107 .59313 L
.21185 .59646 L
.21308 .5992 L
.21431 .60115 L
.215 .60194 L
.21564 .6025 L
.21682 .60313 L
.21808 .60332 L
.21919 .60312 L
.22024 .60265 L
.22139 .60182 L
.22263 .60056 L
.22389 .59884 L
.22503 .59685 L
.22626 .59419 L
.22759 .59059 L
.22996 .58211 L
.2322 .5715 L
.24267 .50368 L
.24801 .47258 L
.25365 .44673 L
.25847 .4295 L
.26377 .41429 L
.30411 .32232 L
.34294 .21374 L
.34415 .21316 L
Mistroke
.34546 .21234 L
.3467 .21134 L
.34784 .21021 L
.35058 .20652 L
.35307 .20182 L
.35586 .19485 L
.3588 .18569 L
.36411 .16731 L
.36651 .16034 L
.36783 .15728 L
.36907 .15498 L
.37023 .15332 L
.3715 .15203 L
.37264 .15125 L
.3737 .15083 L
.37495 .15064 L
.37613 .15073 L
.37741 .1511 L
.37814 .15144 L
.3788 .15184 L
.38006 .15285 L
.38144 .15442 L
.38288 .15667 L
.38421 .15942 L
.38549 .16275 L
.38685 .16713 L
.38928 .17738 L
.39476 .21001 L
.39991 .24155 L
.40471 .26472 L
.40899 .27957 L
.41138 .28582 L
.41357 .29038 L
.41597 .29423 L
.41723 .29583 L
.41857 .2972 L
.41974 .29813 L
.42103 .29888 L
.42221 .29931 L
.42331 .2995 L
.42448 .29947 L
.42574 .29917 L
.42692 .29861 L
.428 .29788 L
.42926 .29674 L
.43063 .29511 L
.43313 .29108 L
.43574 .28512 L
.4385 .27648 L
.44347 .25472 L
Mistroke
.45313 .19108 L
.45736 .16364 L
.45851 .15781 L
.45975 .15265 L
.46081 .14907 L
.46197 .14608 L
.46327 .14369 L
.4645 .14226 L
.4657 .14149 L
.4668 .14122 L
.46786 .14128 L
.46903 .14164 L
.47025 .14233 L
.47139 .14326 L
.4727 .14469 L
.47394 .14649 L
.47506 .14855 L
.47628 .15137 L
.4776 .15523 L
.479 .16036 L
.48151 .1724 L
.49107 .23516 L
.49525 .25882 L
.49762 .26969 L
.49982 .27815 L
.50222 .28567 L
.50439 .29108 L
.50672 .29546 L
.50799 .29728 L
.5092 .29864 L
.51043 .29967 L
.51172 .30037 L
.51283 .30066 L
.51405 .30065 L
.51536 .30027 L
.5161 .29988 L
.51677 .29942 L
.51807 .29823 L
.51931 .29673 L
.52151 .29314 L
.52385 .28798 L
.52806 .27492 L
.53064 .26426 L
.53306 .25224 L
.53759 .2245 L
.54266 .18814 L
.54514 .17147 L
.54739 .15898 L
.54853 .15396 L
.54977 .14957 L
Mistroke
.55108 .14609 L
.55232 .1438 L
.55297 .14293 L
.55368 .14221 L
.55443 .14168 L
.55513 .14138 L
.55638 .14121 L
.55708 .14129 L
.55772 .14147 L
.55886 .14201 L
.56007 .14287 L
.56122 .14398 L
.56225 .14526 L
.56348 .14719 L
.5648 .1499 L
.56595 .15285 L
.5672 .15686 L
.56948 .16642 L
.57189 .17966 L
.57621 .20848 L
.58145 .24286 L
.58403 .25708 L
.58641 .26829 L
.59087 .28432 L
.59322 .29041 L
.59452 .29314 L
.59571 .29525 L
.59689 .29698 L
.59818 .29849 L
.59948 .29961 L
.60018 .30005 L
.60084 .30036 L
.60206 .30067 L
.60317 .30065 L
.60444 .30028 L
.60565 .29959 L
.60629 .2991 L
.60698 .29844 L
.60839 .29677 L
.61092 .29257 L
.61387 .28562 L
.61663 .27693 L
.62562 .2318 L
.63055 .19707 L
.63519 .16592 L
.63648 .15913 L
.63784 .15322 L
.63933 .14828 L
.63999 .14657 L
.6407 .14506 L
Mistroke
.64194 .14312 L
.64308 .14199 L
.64379 .14156 L
.64445 .14132 L
.6457 .14122 L
.64687 .14148 L
.64812 .14209 L
.64919 .14286 L
.65036 .144 L
.65162 .14561 L
.65298 .1479 L
.65426 .15071 L
.65544 .15394 L
.65799 .16355 L
.66037 .1758 L
.66575 .21137 L
.67144 .24789 L
.67392 .2609 L
.6766 .2727 L
.67921 .28194 L
.68161 .28867 L
.6839 .29362 L
.68633 .29738 L
.68756 .29874 L
.68824 .29934 L
.68888 .2998 L
.69013 .30042 L
.69127 .30067 L
.69192 .30069 L
.69262 .30059 L
.69387 .30014 L
.69456 .29974 L
.69521 .29926 L
.6967 .29779 L
.69787 .29627 L
.69913 .29427 L
.70138 .28969 L
.70407 .28247 L
.70651 .27413 L
.71183 .24938 L
.71685 .21746 L
.72116 .18638 L
.72351 .17066 L
.72572 .15857 L
.72696 .15322 L
.7281 .1493 L
.72937 .146 L
.73006 .14462 L
.73072 .14356 L
.73187 .14225 L
Mistroke
.73293 .14155 L
.7341 .14122 L
.73534 .1413 L
.73659 .14173 L
.73729 .14212 L
.73795 .14258 L
.73928 .14378 L
.7407 .14555 L
.74203 .14776 L
.74328 .15046 L
.74563 .15754 L
.74698 .16294 L
.7484 .16983 L
.75096 .18481 L
.75676 .22427 L
.76138 .25239 L
.76635 .27511 L
.7692 .28458 L
.77181 .29118 L
.77431 .2958 L
.77556 .29753 L
.77623 .29829 L
.77693 .29898 L
.77825 .29995 L
.77947 .30049 L
.78078 .30069 L
.78153 .30063 L
.78222 .30046 L
.78348 .29987 L
.78463 .29901 L
.78595 .29764 L
.78721 .29595 L
.78953 .29182 L
.79168 .28677 L
.79655 .27052 L
.7993 .25809 L
.80188 .24408 L
.8067 .21228 L
.81185 .17561 L
.81327 .16689 L
.81478 .15887 L
.81608 .15322 L
.8175 .14848 L
.81817 .14674 L
.81887 .1452 L
.82014 .14317 L
.82132 .14199 L
.82263 .14133 L
.82379 .14121 L
.82504 .14145 L
Mistroke
.82622 .142 L
.8273 .14275 L
.82861 .144 L
.82983 .14555 L
.83116 .14778 L
.83259 .15092 L
.83395 .15478 L
.83523 .15933 L
.83763 .17036 L
.84644 .22794 L
.85111 .2556 L
.85611 .27746 L
.85875 .28579 L
.86115 .29166 L
.86231 .29393 L
.86357 .29602 L
.86475 .29761 L
.86586 .2988 L
.8671 .29978 L
.86775 .30015 L
.86846 .30045 L
.86916 .30062 L
.8699 .30069 L
.87122 .30049 L
.87244 .29996 L
.87358 .29915 L
.87483 .29791 L
.87617 .29618 L
.87856 .29201 L
.88115 .28584 L
.88359 .27832 L
.88585 .2698 L
.89012 .24912 L
.89464 .22062 L
.89947 .18584 L
.90185 .17004 L
.90406 .15808 L
.90529 .15289 L
.9066 .14856 L
.90734 .14661 L
.90804 .1451 L
.90936 .14304 L
.91057 .1419 L
.91168 .14135 L
.9129 .14121 L
.91419 .14147 L
.91534 .142 L
.91638 .14272 L
.91758 .14384 L
.91871 .14522 L
Mistroke
.92073 .14867 L
.92187 .15133 L
.92293 .15433 L
.92513 .16258 L
.92757 .17489 L
.9325 .20711 L
.93743 .2398 L
.94011 .25501 L
.94261 .26703 L
.94703 .28337 L
.94937 .28964 L
.95187 .2947 L
.95327 .29684 L
.95457 .29839 L
.95599 .29963 L
.95671 .30007 L
.9575 .30042 L
.95819 .30061 L
.95882 .30068 L
.95955 .30066 L
.96024 .30052 L
.96147 .30001 L
.96216 .29957 L
.9628 .29906 L
.96411 .29774 L
.96533 .29612 L
.96761 .29214 L
.97008 .28635 L
.97273 .27824 L
.97619 .26449 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[52]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00:=oo`03001oogoo00Ioo`03001oogoo075oo`00XWoo00<007ooOol027oo00<007ooOol0L7oo
0022Ool30002Ool300001Woo001oo`00Ool0009oo`8000eoo`03001oogoo009oo`8000Ioo`03001o
ogoo06moo`00Pgoo00<007ooOol00Woo00X007ooOol007oo001oo`00Ool000moo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo06moo`00Pgoo00<007ooOol00Woo00T007ooOol007oo001oo`00
Ool00`003Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0Kgoo0023Ool01000Oomoogoo
0P000Woo0P0000Aoo`00Oomoo`<000eoo`03001oogoo00=oo`8000Eoo`03001oogoo06moo`00PGoo
00D007oo001oo`0001aoo`03001oogoo00Qoo`03001oogoo071oo`00PGoo1@000Woo00<007ooOol0
67oo00<007ooOol01Woo00<007ooOol0LGoo003oOolQOol00?moob5oo`00ogoo8Goo000_Ool00`00
Oomoo`0`Ool5000aOol3000bOol2000dOol3000JOol002ioo`03001oo`0003=oo`03001oogoo035o
o`03001oogoo03Aoo`03001oogoo039oo`03001oogoo01Uoo`00;Woo00<007oo0000<goo00<007oo
Ool0<Woo00<007ooOol0<Woo00<007ooOol0<Goo10006Woo000^Ool00`00Ool0000cOol00`00Oomo
o`0bOol00`00Oomoo`0cOol00`00Oomoo`0`Ool00`00Ool0000KOol002ioo`03001oo`0003=oo`03
001oogoo035oo`03001oo`00039oo`03001oo`0003=oo`8001]oo`00;goo00<007ooOol0<Goo0P00
=7oo00<007ooOol0<Woo00<007ooOol0<goo00<007ooOol06Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00:Woog`005goo000POol30002Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`0JOol0025oo`06001oogoo001oo`000goo00<007ooOol0lgoo000JOol30002
Ool4000017oo001oo`000goo0`00eWoo00<007ooOol06Woo000OOol00`00Ool00002Ool00`00Ool0
0003Ool00`00Oomoo`3DOol2000MOol0021oo`80009oo`03001oo`0000=oo`03001oogoo0=5oo`<0
01moo`008Goo00D007ooOomoo`0000Aoo`03001oogoo0<moo`80029oo`00:Woo0P00cWoo0P0097oo
000ZOol00`00Oomoo`3<Ool00`00Oomoo`0TOol002Yoo`03001oogoo0<Yoo`8002Moo`00:Woo00<0
07ooOol0bGoo00<007ooOol09goo000ZOol20039Ool00`00Oomoo`0XOol002Yoo`03001oogoo0<Mo
o`03001oogoo02Uoo`00:Woo00<007ooOol0aWoo00<007ooOol0:Woo000ZOol00`00Oomoo`35Ool0
0`00Oomoo`0[Ool002Yoo`800<Eoo`03001oogoo02aoo`00:Woo00<007ooOol0`Woo0P00;goo000Z
Ool00`00Oomoo`2oOol3000aOol002Yoo`03001oogoo0;eoo`8003Aoo`00:Woo0P00_7oo0P00=Woo
000ZOol00`00Oomoo`2jOol00`00Oomoo`0fOol001moo`8000Aoo`03001oogoo009oo`03001oogoo
0;Qoo`8003Uoo`008Goo00H007ooOol007oo0003Ool00`00Oomoo`2gOol00`00Oomoo`0iOol001Yo
o`<000=oo`07001oogooOol007oo00000goo0`00]Goo0P00?7oo000QOol01P00Oomoo`00Ool000=o
o`03001oogoo0;Aoo`03001oogoo03aoo`007goo00<007oo00000Woo00<007oo00000goo00<007oo
Ool0/goo00<007ooOol0?Goo000POol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`2cOol0
0`00Oomoo`0mOol002Yoo`800;9oo`80041oo`00:Woo00<007ooOol0[goo0P00@Woo000ZOol00`00
Oomoo`2]Ool20014Ool002Yoo`03001oogoo0:]oo`8004Ioo`00:Woo0P00Ngoo00<007ooOol03goo
0P004Woo0P001Woo0`002Woo00<007ooOol047oo0P00:Goo000ZOol00`00Oomoo`1TOol01000Ool0
000047oo00<007oo000047oo0P0000=oo`00Ool03goo10000goo0P002goo00@007oo0000011oo`04
001oo`00000XOol002Yoo`03001oogoo051oo`80019oo`04001oogoo000?Ool00`00Oomoo`02000?
Ool00`00Oomoo`02000?Ool01@00Oomoo`00Ool00P003Goo00@007ooOol0011oo`04001oogoo000X
Ool002Yoo`03001oogoo04moo`@0011oo`05001oogooOol0000?Ool01@00Oomoogoo00003goo00D0
07ooOomoo`0000moo`05001oogooOol0000?Ool01@00Oomoogoo00003Woo00D007ooOomoo`0002Qo
o`00:Woo00<007ooOol0Cgoo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol037oo00D007oo
Oomoo`0000moo`03001oogoo01Aoo`8000ioo`03001oogoo009oo`03001oogoo00aoo`03001oogoo
009oo`03001oogoo02Eoo`00:Woo0P00D7oo00D007ooOomoo`0000moo`03001oogoo009oo`03001o
ogoo00aoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo009oo`03001oogoo00aoo`06001o
ogoo001oo`003Woo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol09Goo
000ZOol00`00Oomoo`1>Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomo
o`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Ool0
0003Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomo
o`0UOol002Yoo`03001oogoo04ioo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`80
00Aoo`03001oogoo00]oo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo
02Eoo`00:Woo00<007ooOol0CGoo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<0
07ooOol02goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol02goo00<007ooOol04Goo00<0
07ooOol00Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol09Goo000ZOol2001>Ool00`00
Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00
Oomoo`03Ool00`00Oomoo`0:Ool20005Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0@
Ool00`00Oomoo`0UOol002Yoo`03001oogoo04eoo`03001oogoo00Aoo`03001oogoo00]oo`03001o
ogoo00Aoo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001o
ogoo00Uoo`03001oo`0000Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001o
ogoo00Aoo`03001oogoo02Aoo`007goo0`000goo00<007ooOol00Woo00<007ooOol0CGoo00<007oo
Ool017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007oo
Ool02Goo00<007ooOol017oo00<007ooOol01Woo0`000Woo00<007ooOol00goo00<007ooOol02Woo
00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol097oo000OOol00`00Oomo
o`02Ool00`00Ool00003Ool00`00Oomoo`1EOol00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomo
o`04Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`03Ool0
0`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0TOol001Yoo`<000=oo`07
001oogooOol007oo00000goo0`00C7oo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol02Woo
00<007ooOol047oo00<007ooOol01Goo00<007oo00000`001Woo00<007ooOol017oo00<007ooOol0
4Goo00<007ooOol02Woo00<007ooOol0:goo000POol01`00Oomoogoo001oo`0000=oo`03001oogoo
04aoo`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo
00Aoo`03001oogoo00Uoo`03001oogoo00Eoo`8000Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03
001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo02Aoo`007goo00<007oo0000
0Woo00<007oo00000goo00<007ooOol0Bgoo00<007ooOol01goo00<007ooOol02Woo00<007ooOol0
17oo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol017oo00<007ooOol02Goo00<007ooOol0
1Goo00<007ooOol097oo000POol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`1:Ool20009
Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09
Ool00`00Oomoo`04Ool2000;Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00
Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0TOol002Yoo`8004Yoo`03001oogoo01Eoo`03001o
ogoo00Ioo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00Aoo`03001o
ogoo01=oo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00Ioo`03001o
ogoo02=oo`00:Woo00<007ooOol0BGoo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol01Woo
00<007ooOol027oo00<007ooOol01Goo00<007ooOol027oo00<007ooOol00goo00D007ooOomoo`00
00Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo
00Ioo`03001oogoo02=oo`00:Woo00<007ooOol0B7oo00<007ooOol02Woo00<007ooOol02Goo00<0
07ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol01goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol01goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<0
07ooOol027oo00<007ooOol01Woo00<007ooOol08goo000ZOol00`00Oomoo`18Ool00`00Oomoo`0:
Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool01@00Oomoogoo00001Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol08goo000ZOol20018Ool00`00Oomo
o`0<Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomo
o`0:Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`06Ool00`00Oomo
o`08Ool00`00Oomoo`07Ool00`00Oomoo`0ROol002Yoo`03001oogoo04Moo`03001oogoo00aoo`03
001oogoo00Qoo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo00Qoo`8000Moo`03001oogoo
00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo015oo`03001oogoo
029oo`00:Woo00<007ooOol0EWoo00<007ooOol01goo00<007ooOol027oo00<007ooOol01Woo00<0
07ooOol01goo00<007ooOol01Woo0P002Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
1Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol08Woo000ZOol00`00
Oomoo`1FOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00
Oomoo`04Ool00`00Ool00009Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00
Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0ROol002Yoo`8004Qoo`03001o
ogoo00aoo`03001oogoo00Moo`03001oogoo015oo`03001oogoo00Qoo`03001oogoo00@00003Ool0
07oo00Uoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo015oo`03001o
ogoo00Qoo`03001oogoo029oo`00:Woo00<007ooOol0Agoo00<007ooOol03Goo00<007ooOol01Woo
00<007ooOol04Goo00<007ooOol02Goo0P001Goo00<007ooOol02Goo00<007ooOol01Goo00<007oo
Ool027oo00<007ooOol04Goo00<007ooOol01Woo00<007ooOol0;Goo000ZOol00`00Oomoo`16Ool0
0`00Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`08Ool2
0007Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomo
o`08Ool00`00Oomoo`05Ool00`00Oomoo`0^Ool002Yoo`03001oogoo04Ioo`03001oogoo00ioo`03
001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Ioo`80009oo`03001oogoo
00Aoo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo01Yoo`00:Woo0P00
AWoo00<007ooOol047oo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol0
2goo00<007ooOol00goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol0
17oo00<007ooOol06Woo000ZOol00`00Oomoo`15Ool00`00Oomoo`0TOol00`00Oomoo`04Ool00`00
Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0OOol00`00Oomoo`03Ool00`00
Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0KOol001io
o`D0009oo`03001oogoo009oo`03001oogoo04Eoo`03001oogoo011oo`03001oogoo00=oo`03001o
ogoo00]oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo009oo`03001oogoo00]oo`03001o
ogoo00Aoo`03001oogoo00]oo`03001oogoo009oo`03001oogoo01]oo`0087oo00L007ooOomoo`00
Ool00003Ool00`00Oomoo`14Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool00`00
Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00
Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0KOol001Yoo`<000=oo`07001oogooOol007oo0000
0goo0`00A7oo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<0
07ooOol00goo00<007ooOol01Woo00D007ooOomoo`0000moo`05001oogooOol0000?Ool01@00Oomo
ogoo00003goo00@007ooOol000moo`03001oogoo009oo`03001oogoo01]oo`0087oo00L007ooOomo
o`00Ool00003Ool00`00Oomoo`13Ool00`00Oomoo`0DOol00`00Oomoo`02000>Ool01@00Oomoogoo
00001Goo00<007ooOol01goo0P004Woo00D007ooOomoo`0001=oo`03001oogoo00eoo`04001oogoo
000@Ool00`00Oomoo`0OOol0021oo`07001oogooOol007oo00000goo00<007ooOol0@goo00<007oo
Ool057oo100047oo0`0017oo0P002goo00<007oo00004Goo00<007oo00004Goo0`0047oo0P004Woo
10007Woo000OOol20004Ool00`00Oomoo`02Ool00`00Oomoo`1_Ool2000017oo000000003Woo0P00
4Woo00<007ooOol047oo0P004Woo0P004Woo0P007goo000ZOol20013Ool00`00Oomoo`0[Ool20021
Ool002Yoo`03001oogoo049oo`03001oogoo02Uoo`8008=oo`00:Woo00<007ooOol0@Goo00<007oo
Ool0:7oo0P00QGoo000ZOol00`00Oomoo`11Ool00`00Oomoo`0VOol20027Ool002Yoo`80049oo`03
001oogoo02Eoo`03001oogoo08Moo`00:Woo00<007ooOol0@7oo00<007ooOol09Goo00<007ooOol0
R7oo000ZOol00`00Oomoo`10Ool00`00Oomoo`0TOol00`00Oomoo`29Ool002Yoo`03001oogoo03mo
o`03001oogoo02Aoo`03001oogoo08Yoo`00:Woo0P00@7oo00<007ooOol08goo00<007ooOol0Rgoo
000ZOol00`00Oomoo`0nOol00`00Oomoo`0ROol2002>Ool002Yoo`03001oogoo03ioo`03001oogoo
025oo`03001oogoo08ioo`00:Woo00<007ooOol0HGoo00<007ooOol0Sgoo000ZOol2000nOol00`00
Oomoo`0POol00`00Oomoo`2@Ool002Yoo`03001oogoo03eoo`03001oogoo01]oo`D009=oo`009Goo
00<007ooOol00Woo00<007ooOol0?7oo00<007ooOol06Woo0P00V7oo000TOol00`00Ool00003Ool0
0`00Oomoo`0lOol00`00Oomoo`0HOol2002JOol002Aoo`03001oo`0000=ooml001Moo`0097oo00<0
07oo00000goo00<007ooOol017oo00<007oo00002`00:Goo00<007ooOol05goo00<007ooOol0Vgoo
000TOol00`00Ool00003Ool00`00Oomoo`0COol5000ROol00`00Oomoo`0GOol00`00Oomoo`2LOol0
02Eoo`03001oogoo009oo`03001oogoo00=ooa/001aoo`03001oogoo01Ioo`03001oogoo09eoo`00
:Woo00<007ooOol077oo2P004goo00<007ooOol05Woo00<007ooOol0WWoo000ZOol2000QOol00`00
Oomoo`03Ool3000@Ool00`00Oomoo`0DOol2002QOol002Yoo`03001oogoo025oo`03001oogoo00Eo
o`03001oogoo00aoo`03001oogoo01Aoo`03001oogoo0:5oo`00:Woo00<007ooOol08Woo00<007oo
Ool01Goo00<007ooOol02goo00<007ooOol04goo00<007ooOol0XWoo000ZOol00`00Oomoo`0SOol0
0`00Oomoo`05Ool00`00Oomoo`0NOol2002UOol002Yoo`8002Eoo`03001oogoo00Eoo`8000Yoo`03
001oogoo011oo`03001oogoo0:Eoo`00:Woo00<007ooOol097oo00<007ooOol01goo00<007ooOol0
1Woo00<007ooOol047oo00<007ooOol0YWoo000ZOol00`00Oomoo`0UOol00`00Oomoo`07Ool00`00
Oomoo`05Ool00`00Oomoo`0>Ool2002YOol002Yoo`03001oogoo02Eoo`03001oogoo00Qoo`03001o
ogoo00Aoo`03001oogoo00aoo`800:]oo`00:Woo0P009goo00<007ooOol027oo0P000goo00<007oo
Ool037oo00<007ooOol0Zgoo000ZOol00`00Oomoo`0VOol00`00Oomoo`0:Ool200000goo001oo`0;
Ool2002^Ool002Yoo`03001oogoo03Eoo`D000Aoo`D00;1oo`00:Woo00<007ooOol09goo00<007oo
Ool037oo00@007ooOomoo`D00;Aoo`00:Woo0P00:7oo00<007ooOol02goo00<007ooOol0^goo000Z
Ool00`00Oomoo`0WOol00`00Oomoo`0;Ool00`00Oomoo`2kOol001ioo`D0009oo`03001oogoo009o
o`03001oogoo02Moo`03001oogoo00]oo`03001oogoo0;]oo`0087oo00L007ooOomoo`00Ool00003
Ool00`00Oomoo`0WOol00`00Oomoo`39Ool0021oo`07001oogooOol007oo00000goo0`009goo00<0
07ooOol02Woo00<007ooOol0_7oo000POol01`00Oomoogoo001oo`0000=oo`03001oogoo02Qoo`03
001oogoo00Uoo`03001oogoo0;aoo`0087oo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0XOol0
0`00Oomoo`09Ool00`00Oomoo`2lOol001moo`8000Aoo`03001oogoo009oo`03001oogoo02Qoo`03
001oogoo00Uoo`03001oogoo0;aoo`00:Woo0P00:Goo00<007ooOol027oo00<007ooOol0_Goo000Z
Ool00`00Oomoo`0YOol00`00Oomoo`07Ool00`00Oomoo`2mOol002Yoo`03001oogoo02Uoo`03001o
ogoo00Moo`03001oogoo0;eoo`00:Woo00<007ooOol0<goo00<007ooOol0_Goo000ZOol2000dOol0
0`00Oomoo`2mOol002Yoo`03001oogoo02Uoo`03001oogoo00Ioo`03001oogoo0;ioo`00:Woo00<0
07ooOol0:Goo00<007ooOol01Woo00<007ooOol0_Woo000ZOol00`00Oomoo`0ZOol00`00Oomoo`05
Ool00`00Oomoo`2nOol002Yoo`8002]oo`03001oogoo0<Ioo`00:Woo00<007ooOol0:Woo00<007oo
Ool0aWoo000ZOol00`00Oomoo`0ZOol00`00Oomoo`05Ool00`00Oomoo`2nOol002Yoo`03001oogoo
02Yoo`03001oogoo00Eoo`03001oogoo0;ioo`00:Woo0P00;7oo00<007ooOol017oo00<007ooOol0
_Woo000ZOol00`00Oomoo`0[Ool00`00Oomoo`04Ool00`00Oomoo`2nOol001moo`<000=oo`03001o
ogoo009oo`03001oogoo02]oo`03001oogoo00=oo`03001oogoo0;moo`007goo00<007ooOol00Woo
00<007oo00000goo00<007ooOol0:goo00<007ooOol00goo00<007ooOol0_goo000POol01`00Oomo
ogoo001oo`0000=oo`<002]oo`03001oogoo00=oo`03001oogoo0;moo`0087oo00L007ooOomoo`00
Ool00003Ool00`00Oomoo`0aOol00`00Oomoo`2oOol001moo`03001oo`00009oo`03001oo`0000=o
o`03001oogoo02]oo`03001oogoo00=oo`03001oogoo0;moo`0087oo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol0`7oo000ZOol2000]Ool01@00Oomo
ogoo0000`Woo000ZOol00`00Oomoo`0/Ool01@00Oomoogoo0000`Woo000ZOol00`00Oomoo`0/Ool0
0`00Oomoo`34Ool002Yoo`03001oogoo02aoo`03001oogoo00800<9oo`00:Woo0P00;Woo00<007oo
0000`goo000ZOol00`00Oomoo`0]Ool30033Ool002Yoo`03001oogoo0?=oo`00:Woo00<007ooOol0
lgoo000ZOol00`00Oomoo`3cOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
002ROol3001kOol00:=oo`03001oogoo07Yoo`00L7oo0`000goo0P000Woo10000Woo0P000goo0P00
37oo0`0000Aoo`00Oomoo`80009oo`8000=oo`<000=oo`800003Ool00000009oo`04001oo`000004
Ool2001VOol0071oo`03001oo`00009oo`05001oogoo001oo`030002Ool01P00Oomoo`00Ool000mo
o`06001oogoo001oo`001Woo00@007ooOol0009oo`03001oo`00009oo`03001oo`00009oo`05001o
ogooOol00002Ool00`00Oomoo`1VOol0079oo`04001oogoo0006Ool01000Oomoo`0017oo0`003Goo
0`000Woo0`000goo00D007ooOomoo`00009oo`03001oo`00009oo`03001oo`00009oo`04001oogoo
0003Ool3001VOol0075oo`03001oogoo00@000=oo`800003Ool000000080009oo`<000eoo`05001o
ogoo001oo`030003Ool200000goo000000020003Ool200000goo000000020003Ool20002Ool3001V
Ool0071oo`03001oo`00009oo`03001oogoo00Moo`03001oogoo019oo`04001oogoo0028Ool0071o
o`<0021oo`@008Uoo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.910206, -53.4542, 
  0.0189112, 0.491001}},
  CellTags->"2"]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{484, 284},
WindowMargins->{{5, Automatic}, {Automatic, 5}},
StyleDefinitions -> "Manual.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "2"->{
    Cell[1717, 49, 145, 5, 90, "Section",
      CellTags->"2"],
    Cell[1865, 56, 1176, 21, 221, "Text",
      CellTags->"2"],
    Cell[3044, 79, 171235, 3222, 207, 153611, 2999, "GraphicsData", 
    "PostScript", "Picture",
      Evaluatable->False,
      CellTags->"2"],
    Cell[174282, 3303, 122, 5, 27, "Caption",
      CellTags->"2"],
    Cell[174407, 3310, 777, 22, 90, "Text",
      CellTags->"2"],
    Cell[175187, 3334, 395, 12, 78, "DisplayFormula",
      CellTags->"2"],
    Cell[175585, 3348, 1013, 29, 131, "Text",
      CellTags->"2"],
    Cell[176601, 3379, 204, 5, 58, "DisplayFormula",
      CellTags->"2"],
    Cell[176808, 3386, 247, 8, 59, "Text",
      CellTags->"2"],
    Cell[177058, 3396, 228643, 4207, 187, 212715, 4005, "GraphicsData", 
    "PostScript", "Picture",
      Evaluatable->False,
      CellTags->"2"],
    Cell[405704, 7605, 167, 5, 27, "Caption",
      CellTags->"2"],
    Cell[405874, 7612, 108, 4, 67, "Text",
      CellTags->"2"],
    Cell[405985, 7618, 117, 3, 51, "DisplayFormula",
      CellTags->"2"],
    Cell[406105, 7623, 285, 9, 67, "Text",
      CellTags->"2"],
    Cell[406393, 7634, 157, 5, 41, "MathCaption",
      CellTags->"2"],
    Cell[406553, 7641, 79, 2, 39, "Input",
      CellTags->"2"],
    Cell[406635, 7645, 240, 7, 26, "Output",
      CellTags->"2"],
    Cell[406878, 7654, 90, 1, 40, "MathCaption",
      CellTags->"2"],
    Cell[406971, 7657, 85, 2, 39, "Input",
      CellTags->"2"],
    Cell[407059, 7661, 249, 7, 26, "Output",
      CellTags->"2"],
    Cell[407311, 7670, 72, 1, 40, "MathCaption",
      CellTags->"2"],
    Cell[407386, 7673, 133, 6, 69, "Input",
      CellTags->"2"],
    Cell[407522, 7681, 319, 9, 42, "Output",
      CellTags->"2"],
    Cell[407844, 7692, 139, 5, 41, "MathCaption",
      CellTags->"2"],
    Cell[407986, 7699, 70, 2, 39, "Input",
      CellTags->"2"],
    Cell[408059, 7703, 90, 3, 44, "Output",
      CellTags->"2"],
    Cell[408152, 7708, 67, 1, 40, "MathCaption",
      CellTags->"2"],
    Cell[408222, 7711, 83, 2, 39, "Input",
      CellTags->"2"],
    Cell[408308, 7715, 246, 7, 26, "Output",
      CellTags->"2"],
    Cell[408557, 7724, 546, 19, 87, "MathCaption",
      CellTags->"2"],
    Cell[409106, 7745, 91, 2, 39, "Input",
      CellTags->"2"],
    Cell[409200, 7749, 104, 3, 42, "Output",
      CellTags->"2"],
    Cell[409307, 7754, 154, 5, 41, "MathCaption",
      CellTags->"2"],
    Cell[409464, 7761, 84, 2, 39, "Input",
      CellTags->"2"],
    Cell[409551, 7765, 97, 3, 42, "Output",
      CellTags->"2"],
    Cell[409651, 7770, 823, 28, 98, "Text",
      CellTags->"2"],
    Cell[410477, 7800, 421, 11, 86, "MathCaption",
      CellTags->"2"],
    Cell[410901, 7813, 107, 2, 54, "Input",
      CellTags->"2"],
    Cell[411011, 7817, 1658, 35, 109, "Output",
      CellTags->"2"],
    Cell[412672, 7854, 161, 5, 41, "MathCaption",
      CellTags->"2"],
    Cell[412836, 7861, 78, 2, 39, "Input",
      CellTags->"2"],
    Cell[412917, 7865, 1178, 28, 94, "Output",
      CellTags->"2"],
    Cell[414098, 7895, 121, 4, 40, "MathCaption",
      CellTags->"2"],
    Cell[414222, 7901, 74, 2, 39, "Input",
      CellTags->"2"],
    Cell[414299, 7905, 1001, 24, 94, "Output",
      CellTags->"2"],
    Cell[415303, 7931, 675, 12, 131, "Text",
      CellTags->"2"],
    Cell[415981, 7945, 1056, 33, 60, "DisplayFormula",
      CellTags->"2"],
    Cell[417040, 7980, 1028, 37, 59, "Text",
      CellTags->"2"],
    Cell[418071, 8019, 130, 5, 31, "MathCaption",
      CellTags->"2"],
    Cell[418204, 8026, 85, 2, 30, "Input",
      CellTags->"2"],
    Cell[418292, 8030, 80, 1, 31, "MathCaption",
      CellTags->"2"],
    Cell[418375, 8033, 85, 2, 30, "Input",
      CellTags->"2"],
    Cell[418463, 8037, 681, 27, 52, "Text",
      CellTags->"2"],
    Cell[419147, 8066, 214, 5, 48, "MathCaption",
      CellTags->"2"],
    Cell[419364, 8073, 66, 2, 30, "Input",
      CellTags->"2"],
    Cell[419433, 8077, 356, 10, 29, "Output",
      CellTags->"2"],
    Cell[419792, 8089, 179, 7, 31, "MathCaption",
      CellTags->"2"],
    Cell[419974, 8098, 71, 2, 30, "Input",
      CellTags->"2"],
    Cell[420048, 8102, 1058, 25, 106, "Output",
      CellTags->"2"],
    Cell[421109, 8129, 126, 5, 31, "MathCaption",
      CellTags->"2"],
    Cell[421238, 8136, 64, 2, 30, "Input",
      CellTags->"2"],
    Cell[421305, 8140, 86, 3, 29, "Output",
      CellTags->"2"],
    Cell[421394, 8145, 270, 8, 52, "Text",
      CellTags->"2"],
    Cell[421667, 8155, 68, 1, 31, "MathCaption",
      CellTags->"2"],
    Cell[421738, 8158, 76, 2, 30, "Input",
      CellTags->"2"],
    Cell[421817, 8162, 273, 7, 52, "Text",
      CellTags->"2"],
    Cell[422093, 8171, 1004, 31, 46, "DisplayFormula",
      CellTags->"2"],
    Cell[423100, 8204, 1351, 51, 109, "Text",
      CellTags->"2"],
    Cell[424454, 8257, 73, 1, 31, "MathCaption",
      CellTags->"2"],
    Cell[424530, 8260, 134, 6, 66, "Input",
      CellTags->"2"],
    Cell[424667, 8268, 269, 7, 80, "Output",
      CellTags->"2"],
    Cell[424939, 8277, 354, 12, 65, "MathCaption",
      CellTags->"2"],
    Cell[425296, 8291, 70, 2, 30, "Input",
      CellTags->"2"],
    Cell[425369, 8295, 218, 5, 70, "Output",
      CellTags->"2"],
    Cell[425590, 8302, 205, 7, 55, "MathCaption",
      CellTags->"2"],
    Cell[425798, 8311, 72, 2, 39, "Input",
      CellTags->"2"],
    Cell[425873, 8315, 1768, 55, 159, "Output",
      CellTags->"2"],
    Cell[427644, 8372, 523, 13, 74, "Text",
      CellTags->"2"],
    Cell[428170, 8387, 196, 5, 48, "MathCaption",
      CellTags->"2"],
    Cell[428369, 8394, 95, 2, 30, "Input",
      CellTags->"2"],
    Cell[428467, 8398, 196, 4, 76, "Output",
      CellTags->"2"],
    Cell[428666, 8404, 1046, 27, 139, "Text",
      CellTags->"2"],
    Cell[429715, 8433, 142, 5, 31, "MathCaption",
      CellTags->"2"],
    Cell[429860, 8440, 85, 2, 50, "Input",
      CellTags->"2"],
    Cell[429948, 8444, 136, 4, 92, "MathCaption",
      CellTags->"2"],
    Cell[430087, 8450, 79, 2, 50, "Input",
      CellTags->"2"],
    Cell[430169, 8454, 84, 3, 78, "Output",
      CellTags->"2"],
    Cell[430256, 8459, 435, 11, 176, "Text",
      CellTags->"2"],
    Cell[430694, 8472, 120, 4, 31, "MathCaption",
      CellTags->"2"],
    Cell[430817, 8478, 150, 11, 156, "Input",
      CellTags->"2"],
    Cell[430970, 8491, 1007, 30, 29, "Output",
      CellTags->"2"],
    Cell[431980, 8523, 74, 1, 31, "MathCaption",
      CellTags->"2"],
    Cell[432057, 8526, 84, 2, 39, "Input",
      CellTags->"2"],
    Cell[432144, 8530, 184, 4, 41, "Output",
      CellTags->"2"],
    Cell[432331, 8536, 378, 15, 40, "MathCaption",
      CellTags->"2"],
    Cell[432712, 8553, 80, 2, 39, "Input",
      CellTags->"2"],
    Cell[432795, 8557, 92, 3, 26, "Output",
      CellTags->"2"],
    Cell[432890, 8562, 68, 2, 39, "Input",
      CellTags->"2"],
    Cell[432961, 8566, 81, 3, 26, "Output",
      CellTags->"2"],
    Cell[433045, 8571, 167, 4, 55, "MathCaption",
      CellTags->"2"],
    Cell[433215, 8577, 86, 2, 30, "Input",
      CellTags->"2"],
    Cell[433304, 8581, 132, 3, 29, "Output",
      CellTags->"2"],
    Cell[433439, 8586, 117, 4, 31, "MathCaption",
      CellTags->"2"],
    Cell[433559, 8592, 96, 2, 30, "Input",
      CellTags->"2"],
    Cell[433658, 8596, 130, 3, 29, "Output",
      CellTags->"2"],
    Cell[433791, 8601, 777, 17, 112, "Text",
      CellTags->"2"],
    Cell[434571, 8620, 134, 5, 29, "MathCaption",
      CellTags->"2"],
    Cell[434708, 8627, 81, 2, 27, "Input",
      CellTags->"2"],
    Cell[434792, 8631, 408, 13, 26, "Output",
      CellTags->"2"],
    Cell[435203, 8646, 344, 9, 58, "MathCaption",
      CellTags->"2"],
    Cell[435550, 8657, 96, 2, 27, "Input",
      CellTags->"2"],
    Cell[435649, 8661, 191, 5, 70, "Output",
      CellTags->"2"],
    Cell[435843, 8668, 391, 11, 48, "Text",
      CellTags->"2"],
    Cell[436237, 8681, 505, 16, 74, "MathCaption",
      CellTags->"2"],
    Cell[436745, 8699, 124, 5, 54, "Input",
      CellTags->"2"],
    Cell[436872, 8706, 146, 4, 46, "Output",
      CellTags->"2"],
    Cell[437021, 8712, 226, 7, 56, "MathCaption",
      CellTags->"2"],
    Cell[437250, 8721, 173, 8, 114, "Input",
      CellTags->"2"],
    Cell[437426, 8731, 16217, 522, 186, 5698, 386, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2"],
    Cell[453646, 9255, 692, 19, 91, "Text",
      CellTags->"2"],
    Cell[454341, 9276, 147, 4, 54, "MathCaption",
      CellTags->"2"],
    Cell[454491, 9282, 110, 2, 54, "Input",
      CellTags->"2"],
    Cell[454604, 9286, 368, 10, 26, "Output",
      CellTags->"2"],
    Cell[454975, 9298, 153, 5, 41, "MathCaption",
      CellTags->"2"],
    Cell[455131, 9305, 62, 2, 39, "Input",
      CellTags->"2"],
    Cell[455196, 9309, 1001, 24, 94, "Output",
      CellTags->"2"],
    Cell[456200, 9335, 400, 12, 65, "MathCaption",
      CellTags->"2"],
    Cell[456603, 9349, 110, 2, 54, "Input",
      CellTags->"2"],
    Cell[456716, 9353, 1370, 31, 79, "Output",
      CellTags->"2"],
    Cell[458089, 9386, 310, 8, 69, "MathCaption",
      CellTags->"2"],
    Cell[458402, 9396, 152, 8, 99, "Input",
      CellTags->"2"],
    Cell[458557, 9406, 804, 22, 56, "Output",
      CellTags->"2"],
    Cell[459364, 9430, 655, 18, 84, "MathCaption",
      CellTags->"2"],
    Cell[460022, 9450, 268, 12, 159, "Input",
      CellTags->"2"],
    Cell[460293, 9464, 1530, 37, 86, "Output",
      CellTags->"2"],
    Cell[461826, 9503, 327, 9, 70, "MathCaption",
      CellTags->"2"],
    Cell[462156, 9514, 180, 8, 99, "Input",
      CellTags->"2"],
    Cell[462339, 9524, 20778, 694, 186, 9641, 551, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2"],
    Cell[483120, 10220, 387, 9, 84, "MathCaption",
      CellTags->"2"],
    Cell[483510, 10231, 179, 8, 99, "Input",
      CellTags->"2"],
    Cell[483692, 10241, 27088, 881, 186, 11996, 689, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2"],
    Cell[510783, 11124, 85, 1, 40, "MathCaption",
      CellTags->"2"],
    Cell[510871, 11127, 208, 9, 114, "Input",
      CellTags->"2"],
    Cell[511082, 11138, 25589, 979, 186, 14010, 830, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2"],
    Cell[536674, 12119, 266, 6, 69, "MathCaption",
      CellTags->"2"],
    Cell[536943, 12127, 76, 2, 39, "Input",
      CellTags->"2"],
    Cell[537022, 12131, 25828, 899, 186, 12370, 727, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2"],
    Cell[562853, 13032, 729, 18, 90, "Text",
      CellTags->"2"],
    Cell[563585, 13052, 116, 4, 40, "MathCaption",
      CellTags->"2"],
    Cell[563704, 13058, 164, 8, 99, "Input",
      CellTags->"2"],
    Cell[563871, 13068, 270, 8, 26, "Output",
      CellTags->"2"],
    Cell[564144, 13078, 436, 11, 68, "MathCaption",
      CellTags->"2"],
    Cell[564583, 13091, 227, 11, 144, "Input",
      CellTags->"2"],
    Cell[564813, 13104, 875, 22, 56, "Output",
      CellTags->"2"],
    Cell[565691, 13128, 391, 11, 54, "MathCaption",
      CellTags->"2"],
    Cell[566085, 13141, 188, 8, 114, "Input",
      CellTags->"2"],
    Cell[566276, 13151, 25455, 816, 186, 10757, 629, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2"],
    Cell[591734, 13969, 242, 5, 74, "Text",
      CellTags->"2"],
    Cell[591979, 13976, 238, 7, 42, "MathCaption",
      CellTags->"2"],
    Cell[592220, 13985, 195, 8, 114, "Input",
      CellTags->"2"],
    Cell[592418, 13995, 33069, 1095, 186, 14438, 859, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2"],
    Cell[625490, 15092, 114, 4, 40, "MathCaption",
      CellTags->"2"],
    Cell[625607, 15098, 225, 10, 129, "Input",
      CellTags->"2"],
    Cell[625835, 15110, 28701, 940, 186, 12291, 731, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2"],
    Cell[654539, 16052, 358, 9, 74, "Text",
      CellTags->"2"],
    Cell[654900, 16063, 92, 1, 40, "MathCaption",
      CellTags->"2"],
    Cell[654995, 16066, 104, 2, 39, "Input",
      CellTags->"2"],
    Cell[655102, 16070, 455, 13, 26, "Output",
      CellTags->"2"],
    Cell[655560, 16085, 334, 11, 54, "MathCaption",
      CellTags->"2"],
    Cell[655897, 16098, 91, 2, 39, "Input",
      CellTags->"2"],
    Cell[655991, 16102, 246, 7, 26, "Output",
      CellTags->"2"],
    Cell[656240, 16111, 122, 5, 41, "MathCaption",
      CellTags->"2"],
    Cell[656365, 16118, 107, 2, 39, "Input",
      CellTags->"2"],
    Cell[656475, 16122, 1419, 33, 56, "Output",
      CellTags->"2"],
    Cell[657897, 16157, 162, 5, 41, "MathCaption",
      CellTags->"2"],
    Cell[658062, 16164, 109, 2, 54, "Input",
      CellTags->"2"],
    Cell[658174, 16168, 2691, 55, 122, "Output",
      CellTags->"2"],
    Cell[660868, 16225, 56, 1, 40, "MathCaption",
      CellTags->"2"],
    Cell[660927, 16228, 166, 8, 87, "Input",
      CellTags->"2"],
    Cell[661096, 16238, 270, 8, 26, "Output",
      CellTags->"2"],
    Cell[661369, 16248, 464, 12, 58, "MathCaption",
      CellTags->"2"],
    Cell[661836, 16262, 343, 13, 177, "Input",
      CellTags->"2"],
    Cell[662182, 16277, 30910, 1106, 186, 14620, 899, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"2"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"2", 693969, 17408}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 145, 5, 90, "Section",
  CellTags->"2"],
Cell[1865, 56, 1176, 21, 221, "Text",
  CellTags->"2"],
Cell[3044, 79, 171235, 3222, 207, 153611, 2999, "GraphicsData", 
"PostScript", "Picture",
  Evaluatable->False,
  CellTags->"2"],
Cell[174282, 3303, 122, 5, 27, "Caption",
  CellTags->"2"],
Cell[174407, 3310, 777, 22, 90, "Text",
  CellTags->"2"],
Cell[175187, 3334, 395, 12, 78, "DisplayFormula",
  CellTags->"2"],
Cell[175585, 3348, 1013, 29, 131, "Text",
  CellTags->"2"],
Cell[176601, 3379, 204, 5, 58, "DisplayFormula",
  CellTags->"2"],
Cell[176808, 3386, 247, 8, 59, "Text",
  CellTags->"2"],
Cell[177058, 3396, 228643, 4207, 187, 212715, 4005, "GraphicsData", 
"PostScript", "Picture",
  Evaluatable->False,
  CellTags->"2"],
Cell[405704, 7605, 167, 5, 27, "Caption",
  CellTags->"2"],
Cell[405874, 7612, 108, 4, 67, "Text",
  CellTags->"2"],
Cell[405985, 7618, 117, 3, 51, "DisplayFormula",
  CellTags->"2"],
Cell[406105, 7623, 285, 9, 67, "Text",
  CellTags->"2"],
Cell[406393, 7634, 157, 5, 41, "MathCaption",
  CellTags->"2"],
Cell[406553, 7641, 79, 2, 39, "Input",
  CellTags->"2"],
Cell[406635, 7645, 240, 7, 26, "Output",
  CellTags->"2"],
Cell[406878, 7654, 90, 1, 40, "MathCaption",
  CellTags->"2"],
Cell[406971, 7657, 85, 2, 39, "Input",
  CellTags->"2"],
Cell[407059, 7661, 249, 7, 26, "Output",
  CellTags->"2"],
Cell[407311, 7670, 72, 1, 40, "MathCaption",
  CellTags->"2"],
Cell[407386, 7673, 133, 6, 69, "Input",
  CellTags->"2"],
Cell[407522, 7681, 319, 9, 42, "Output",
  CellTags->"2"],
Cell[407844, 7692, 139, 5, 41, "MathCaption",
  CellTags->"2"],
Cell[407986, 7699, 70, 2, 39, "Input",
  CellTags->"2"],
Cell[408059, 7703, 90, 3, 44, "Output",
  CellTags->"2"],
Cell[408152, 7708, 67, 1, 40, "MathCaption",
  CellTags->"2"],
Cell[408222, 7711, 83, 2, 39, "Input",
  CellTags->"2"],
Cell[408308, 7715, 246, 7, 26, "Output",
  CellTags->"2"],
Cell[408557, 7724, 546, 19, 87, "MathCaption",
  CellTags->"2"],
Cell[409106, 7745, 91, 2, 39, "Input",
  CellTags->"2"],
Cell[409200, 7749, 104, 3, 42, "Output",
  CellTags->"2"],
Cell[409307, 7754, 154, 5, 41, "MathCaption",
  CellTags->"2"],
Cell[409464, 7761, 84, 2, 39, "Input",
  CellTags->"2"],
Cell[409551, 7765, 97, 3, 42, "Output",
  CellTags->"2"],
Cell[409651, 7770, 823, 28, 98, "Text",
  CellTags->"2"],
Cell[410477, 7800, 421, 11, 86, "MathCaption",
  CellTags->"2"],
Cell[410901, 7813, 107, 2, 54, "Input",
  CellTags->"2"],
Cell[411011, 7817, 1658, 35, 109, "Output",
  CellTags->"2"],
Cell[412672, 7854, 161, 5, 41, "MathCaption",
  CellTags->"2"],
Cell[412836, 7861, 78, 2, 39, "Input",
  CellTags->"2"],
Cell[412917, 7865, 1178, 28, 94, "Output",
  CellTags->"2"],
Cell[414098, 7895, 121, 4, 40, "MathCaption",
  CellTags->"2"],
Cell[414222, 7901, 74, 2, 39, "Input",
  CellTags->"2"],
Cell[414299, 7905, 1001, 24, 94, "Output",
  CellTags->"2"],
Cell[415303, 7931, 675, 12, 131, "Text",
  CellTags->"2"],
Cell[415981, 7945, 1056, 33, 60, "DisplayFormula",
  CellTags->"2"],
Cell[417040, 7980, 1028, 37, 59, "Text",
  CellTags->"2"],
Cell[418071, 8019, 130, 5, 31, "MathCaption",
  CellTags->"2"],
Cell[418204, 8026, 85, 2, 30, "Input",
  CellTags->"2"],
Cell[418292, 8030, 80, 1, 31, "MathCaption",
  CellTags->"2"],
Cell[418375, 8033, 85, 2, 30, "Input",
  CellTags->"2"],
Cell[418463, 8037, 681, 27, 52, "Text",
  CellTags->"2"],
Cell[419147, 8066, 214, 5, 48, "MathCaption",
  CellTags->"2"],
Cell[419364, 8073, 66, 2, 30, "Input",
  CellTags->"2"],
Cell[419433, 8077, 356, 10, 29, "Output",
  CellTags->"2"],
Cell[419792, 8089, 179, 7, 31, "MathCaption",
  CellTags->"2"],
Cell[419974, 8098, 71, 2, 30, "Input",
  CellTags->"2"],
Cell[420048, 8102, 1058, 25, 106, "Output",
  CellTags->"2"],
Cell[421109, 8129, 126, 5, 31, "MathCaption",
  CellTags->"2"],
Cell[421238, 8136, 64, 2, 30, "Input",
  CellTags->"2"],
Cell[421305, 8140, 86, 3, 29, "Output",
  CellTags->"2"],
Cell[421394, 8145, 270, 8, 52, "Text",
  CellTags->"2"],
Cell[421667, 8155, 68, 1, 31, "MathCaption",
  CellTags->"2"],
Cell[421738, 8158, 76, 2, 30, "Input",
  CellTags->"2"],
Cell[421817, 8162, 273, 7, 52, "Text",
  CellTags->"2"],
Cell[422093, 8171, 1004, 31, 46, "DisplayFormula",
  CellTags->"2"],
Cell[423100, 8204, 1351, 51, 109, "Text",
  CellTags->"2"],
Cell[424454, 8257, 73, 1, 31, "MathCaption",
  CellTags->"2"],
Cell[424530, 8260, 134, 6, 66, "Input",
  CellTags->"2"],
Cell[424667, 8268, 269, 7, 80, "Output",
  CellTags->"2"],
Cell[424939, 8277, 354, 12, 65, "MathCaption",
  CellTags->"2"],
Cell[425296, 8291, 70, 2, 30, "Input",
  CellTags->"2"],
Cell[425369, 8295, 218, 5, 70, "Output",
  CellTags->"2"],
Cell[425590, 8302, 205, 7, 55, "MathCaption",
  CellTags->"2"],
Cell[425798, 8311, 72, 2, 39, "Input",
  CellTags->"2"],
Cell[425873, 8315, 1768, 55, 159, "Output",
  CellTags->"2"],
Cell[427644, 8372, 523, 13, 74, "Text",
  CellTags->"2"],
Cell[428170, 8387, 196, 5, 48, "MathCaption",
  CellTags->"2"],
Cell[428369, 8394, 95, 2, 30, "Input",
  CellTags->"2"],
Cell[428467, 8398, 196, 4, 76, "Output",
  CellTags->"2"],
Cell[428666, 8404, 1046, 27, 139, "Text",
  CellTags->"2"],
Cell[429715, 8433, 142, 5, 31, "MathCaption",
  CellTags->"2"],
Cell[429860, 8440, 85, 2, 50, "Input",
  CellTags->"2"],
Cell[429948, 8444, 136, 4, 92, "MathCaption",
  CellTags->"2"],
Cell[430087, 8450, 79, 2, 50, "Input",
  CellTags->"2"],
Cell[430169, 8454, 84, 3, 78, "Output",
  CellTags->"2"],
Cell[430256, 8459, 435, 11, 176, "Text",
  CellTags->"2"],
Cell[430694, 8472, 120, 4, 31, "MathCaption",
  CellTags->"2"],
Cell[430817, 8478, 150, 11, 156, "Input",
  CellTags->"2"],
Cell[430970, 8491, 1007, 30, 29, "Output",
  CellTags->"2"],
Cell[431980, 8523, 74, 1, 31, "MathCaption",
  CellTags->"2"],
Cell[432057, 8526, 84, 2, 39, "Input",
  CellTags->"2"],
Cell[432144, 8530, 184, 4, 41, "Output",
  CellTags->"2"],
Cell[432331, 8536, 378, 15, 40, "MathCaption",
  CellTags->"2"],
Cell[432712, 8553, 80, 2, 39, "Input",
  CellTags->"2"],
Cell[432795, 8557, 92, 3, 26, "Output",
  CellTags->"2"],
Cell[432890, 8562, 68, 2, 39, "Input",
  CellTags->"2"],
Cell[432961, 8566, 81, 3, 26, "Output",
  CellTags->"2"],
Cell[433045, 8571, 167, 4, 55, "MathCaption",
  CellTags->"2"],
Cell[433215, 8577, 86, 2, 30, "Input",
  CellTags->"2"],
Cell[433304, 8581, 132, 3, 29, "Output",
  CellTags->"2"],
Cell[433439, 8586, 117, 4, 31, "MathCaption",
  CellTags->"2"],
Cell[433559, 8592, 96, 2, 30, "Input",
  CellTags->"2"],
Cell[433658, 8596, 130, 3, 29, "Output",
  CellTags->"2"],
Cell[433791, 8601, 777, 17, 112, "Text",
  CellTags->"2"],
Cell[434571, 8620, 134, 5, 29, "MathCaption",
  CellTags->"2"],
Cell[434708, 8627, 81, 2, 27, "Input",
  CellTags->"2"],
Cell[434792, 8631, 408, 13, 26, "Output",
  CellTags->"2"],
Cell[435203, 8646, 344, 9, 58, "MathCaption",
  CellTags->"2"],
Cell[435550, 8657, 96, 2, 27, "Input",
  CellTags->"2"],
Cell[435649, 8661, 191, 5, 70, "Output",
  CellTags->"2"],
Cell[435843, 8668, 391, 11, 48, "Text",
  CellTags->"2"],
Cell[436237, 8681, 505, 16, 74, "MathCaption",
  CellTags->"2"],
Cell[436745, 8699, 124, 5, 54, "Input",
  CellTags->"2"],
Cell[436872, 8706, 146, 4, 46, "Output",
  CellTags->"2"],
Cell[437021, 8712, 226, 7, 56, "MathCaption",
  CellTags->"2"],
Cell[437250, 8721, 173, 8, 114, "Input",
  CellTags->"2"],
Cell[437426, 8731, 16217, 522, 186, 5698, 386, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"2"],
Cell[453646, 9255, 692, 19, 91, "Text",
  CellTags->"2"],
Cell[454341, 9276, 147, 4, 54, "MathCaption",
  CellTags->"2"],
Cell[454491, 9282, 110, 2, 54, "Input",
  CellTags->"2"],
Cell[454604, 9286, 368, 10, 26, "Output",
  CellTags->"2"],
Cell[454975, 9298, 153, 5, 41, "MathCaption",
  CellTags->"2"],
Cell[455131, 9305, 62, 2, 39, "Input",
  CellTags->"2"],
Cell[455196, 9309, 1001, 24, 94, "Output",
  CellTags->"2"],
Cell[456200, 9335, 400, 12, 65, "MathCaption",
  CellTags->"2"],
Cell[456603, 9349, 110, 2, 54, "Input",
  CellTags->"2"],
Cell[456716, 9353, 1370, 31, 79, "Output",
  CellTags->"2"],
Cell[458089, 9386, 310, 8, 69, "MathCaption",
  CellTags->"2"],
Cell[458402, 9396, 152, 8, 99, "Input",
  CellTags->"2"],
Cell[458557, 9406, 804, 22, 56, "Output",
  CellTags->"2"],
Cell[459364, 9430, 655, 18, 84, "MathCaption",
  CellTags->"2"],
Cell[460022, 9450, 268, 12, 159, "Input",
  CellTags->"2"],
Cell[460293, 9464, 1530, 37, 86, "Output",
  CellTags->"2"],
Cell[461826, 9503, 327, 9, 70, "MathCaption",
  CellTags->"2"],
Cell[462156, 9514, 180, 8, 99, "Input",
  CellTags->"2"],
Cell[462339, 9524, 20778, 694, 186, 9641, 551, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"2"],
Cell[483120, 10220, 387, 9, 84, "MathCaption",
  CellTags->"2"],
Cell[483510, 10231, 179, 8, 99, "Input",
  CellTags->"2"],
Cell[483692, 10241, 27088, 881, 186, 11996, 689, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"2"],
Cell[510783, 11124, 85, 1, 40, "MathCaption",
  CellTags->"2"],
Cell[510871, 11127, 208, 9, 114, "Input",
  CellTags->"2"],
Cell[511082, 11138, 25589, 979, 186, 14010, 830, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"2"],
Cell[536674, 12119, 266, 6, 69, "MathCaption",
  CellTags->"2"],
Cell[536943, 12127, 76, 2, 39, "Input",
  CellTags->"2"],
Cell[537022, 12131, 25828, 899, 186, 12370, 727, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"2"],
Cell[562853, 13032, 729, 18, 90, "Text",
  CellTags->"2"],
Cell[563585, 13052, 116, 4, 40, "MathCaption",
  CellTags->"2"],
Cell[563704, 13058, 164, 8, 99, "Input",
  CellTags->"2"],
Cell[563871, 13068, 270, 8, 26, "Output",
  CellTags->"2"],
Cell[564144, 13078, 436, 11, 68, "MathCaption",
  CellTags->"2"],
Cell[564583, 13091, 227, 11, 144, "Input",
  CellTags->"2"],
Cell[564813, 13104, 875, 22, 56, "Output",
  CellTags->"2"],
Cell[565691, 13128, 391, 11, 54, "MathCaption",
  CellTags->"2"],
Cell[566085, 13141, 188, 8, 114, "Input",
  CellTags->"2"],
Cell[566276, 13151, 25455, 816, 186, 10757, 629, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"2"],
Cell[591734, 13969, 242, 5, 74, "Text",
  CellTags->"2"],
Cell[591979, 13976, 238, 7, 42, "MathCaption",
  CellTags->"2"],
Cell[592220, 13985, 195, 8, 114, "Input",
  CellTags->"2"],
Cell[592418, 13995, 33069, 1095, 186, 14438, 859, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"2"],
Cell[625490, 15092, 114, 4, 40, "MathCaption",
  CellTags->"2"],
Cell[625607, 15098, 225, 10, 129, "Input",
  CellTags->"2"],
Cell[625835, 15110, 28701, 940, 186, 12291, 731, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"2"],
Cell[654539, 16052, 358, 9, 74, "Text",
  CellTags->"2"],
Cell[654900, 16063, 92, 1, 40, "MathCaption",
  CellTags->"2"],
Cell[654995, 16066, 104, 2, 39, "Input",
  CellTags->"2"],
Cell[655102, 16070, 455, 13, 26, "Output",
  CellTags->"2"],
Cell[655560, 16085, 334, 11, 54, "MathCaption",
  CellTags->"2"],
Cell[655897, 16098, 91, 2, 39, "Input",
  CellTags->"2"],
Cell[655991, 16102, 246, 7, 26, "Output",
  CellTags->"2"],
Cell[656240, 16111, 122, 5, 41, "MathCaption",
  CellTags->"2"],
Cell[656365, 16118, 107, 2, 39, "Input",
  CellTags->"2"],
Cell[656475, 16122, 1419, 33, 56, "Output",
  CellTags->"2"],
Cell[657897, 16157, 162, 5, 41, "MathCaption",
  CellTags->"2"],
Cell[658062, 16164, 109, 2, 54, "Input",
  CellTags->"2"],
Cell[658174, 16168, 2691, 55, 122, "Output",
  CellTags->"2"],
Cell[660868, 16225, 56, 1, 40, "MathCaption",
  CellTags->"2"],
Cell[660927, 16228, 166, 8, 87, "Input",
  CellTags->"2"],
Cell[661096, 16238, 270, 8, 26, "Output",
  CellTags->"2"],
Cell[661369, 16248, 464, 12, 58, "MathCaption",
  CellTags->"2"],
Cell[661836, 16262, 343, 13, 177, "Input",
  CellTags->"2"],
Cell[662182, 16277, 30910, 1106, 186, 14620, 899, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"2"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

