(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    863402,      22161]*)
(*NotebookOutlinePosition[    885785,      22807]*)
(*  CellTagsIndexPosition[    885531,      22794]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["3. Description of Dynamic Systems", "Section",
  CellTags->"3.0"],

Cell[TextData[{
  StyleBox["Control System Professional", "TI"],
  " deals with state\[Hyphen]space and transfer function models of continuous\
\[Hyphen]time (analog) and discrete\[Hyphen]time (sampled) systems. The \
transfer function representations can be in rational polynomial or zero\
\[Hyphen]pole\[Hyphen]gain form. This chapter introduces the available data \
types and the means to convert between them. "
}], "Text",
  CellTags->"3.0"],

Cell["3.1 Transfer Function Representations", "Subsection",
  CellTags->"3.1"],

Cell[TextData[{
  "The basic form for representing transfer function matrices is the ",
  StyleBox["TransferFunction", "MR"],
  " data structure. ",
  StyleBox["TransferFunction", "MR"],
  " in many respects behaves like ",
  StyleBox["Function", "MR"],
  ", the built\[Hyphen]in ",
  StyleBox["Mathematica", "TI"],
  " pure\[Hyphen]function. Like ",
  StyleBox["Function", "MR"],
  ", ",
  StyleBox["TransferFunction", "MR"],
  " can have a formal parameter, \"variable\", and is capable of operating on \
any ",
  StyleBox["Mathematica", "TI"],
  " expression. Unlike ",
  StyleBox["Function", "MR"],
  ", ",
  StyleBox["TransferFunction", "MR"],
  " currently accepts at most one formal parameter and does not accept the \
list of attributes, but it does accept options. "
}], "Text",
  CellTags->"3.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["TransferFunction",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["m",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["transfer",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["function",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["as",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["rational",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["polynomial",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["matrix",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["m",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["formal",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["parameter",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["that",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["behaves",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["as",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["pure",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["function",
                SingleLetterItalics->False]}]},
          {
            RowBox[{
              StyleBox["TransferFunction",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["var",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["m",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["transfer",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["function",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["formal",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["parameter",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["var",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "DefinitionBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.39, 0.61}},
  CellTags->"3.1"],

Cell["Transfer function representation as a pure function. ", "Caption",
  CellTags->"3.1"],

Cell["Load the application. ", "MathCaption",
  CellTags->"3.1"],

Cell["<<ControlSystems`", "Input",
  CellLabel->"In[1]:=",
  CellTags->"3.1"],

Cell[TextData[{
  "This is the transfer function representation of a two\[Hyphen]input, one\
\[Hyphen]output system. The ",
  StyleBox["TransferFunction", "MR"],
  " object comprises a variable and a matrix in that variable. "
}], "MathCaption",
  CellTags->"3.1"],

Cell["TransferFunction[var, {{2/(1+var^2), var/(var-1)}}]", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[var, {{2\/\(1 + var\^2\), var\/\(\(-1\) + var\)}}]\)], 
  "Output",
  CellLabel->"Out[2]= ",
  CellTags->"3.1"],

Cell["\<\
Supplying the variable to this function leads to a matrix in that \
variable. \
\>", "MathCaption",
  CellTags->"3.1"],

Cell["%[s]", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \({{2\/\(1 + s\^2\), s\/\(\(-1\) + s\)}}\)], "Output",
  CellLabel->"Out[3]= ",
  CellTags->"3.1"],

Cell["\<\
If a particular numeric frequency is supplied, the value of the \
transfer matrix at this frequency is obtained. \
\>", "MathCaption",
  CellTags->"3.1"],

Cell["%%[I 10.]", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \({{\(-0.0202020202020202033`\), 
        \(\(0.99009900990099009`\)\(\[InvisibleSpace]\)\) - 
          0.099009900990099009`\ I}}\)], "Output",
  CellLabel->"Out[4]= ",
  CellTags->"3.1"],

Cell["\<\
We can name the internal variable whatever we please or drop it \
altogether and still have a mathematically identical object. \
\>", 
  "MathCaption",
  CellTags->"3.1"],

Cell["TransferFunction[{{1/#}}]", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[{{1\/#1}}]\)], "Output",
  CellLabel->"Out[5]= ",
  CellTags->"3.1"],

Cell[TextData[{
  "Without the formal parameter, ",
  StyleBox["TransferFunction", "MR"],
  " behaves as a pure function in ",
  StyleBox["#", "MR"],
  ". "
}], "MathCaption",
  CellTags->"3.1"],

Cell["%[s]", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \({{1\/s}}\)], "Output",
  CellLabel->"Out[6]= ",
  CellTags->"3.1"],

Cell[TextData[{
  StyleBox["TransferFunction", "MR"],
  " deals with multiple\[Hyphen]input, multiple\[Hyphen]output (MIMO) \
systems. Scalar, or single\[Hyphen]input, single\[Hyphen]output (SISO), \
transfer functions are \"upgraded\" to the matrix representation \
automatically.  "
}], "Text",
  CellTags->"3.1"],

Cell[TextData[{
  "A scalar transfer function is represented as a ",
  Cell[BoxData[
      \(TraditionalForm\`1\[Cross]1\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " transfer matrix. "
}], "MathCaption",
  CellTags->"3.1"],

Cell["TransferFunction[1/#]", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[{{1\/#1}}]\)], "Output",
  CellLabel->"Out[7]= ",
  CellTags->"3.1"],

Cell[TextData[{
  "It is often useful to factor the elements of a transfer matrix so that the \
zeros and poles of individual elements become apparent. The factored form can \
be obtained by using the function ",
  StyleBox["FactorRational", "MR"],
  ". The opposite function is ",
  StyleBox["ExpandRational", "MR"],
  ", which expands the individual numerators and denominators of transfer \
matrix elements. "
}], "Text",
  CellTags->"3.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["FactorRational",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["transferfunction",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"3.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["represent",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["transferfunction",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["object",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["in",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["factored",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["form",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"3.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ExpandRational",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["transferfunction",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"3.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["represent",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["transferfunction",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["object",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["in",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["expanded",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["form",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"3.1"],

Cell["Converting transfer function objects to standard forms. ", "Caption",
  CellTags->"3.1"],

Cell["This is some rational polynomial transfer function. ", "MathCaption",
  CellTags->"3.1"],

Cell["\<\
TransferFunction[s,
 {{2/(1+s^2), (6 - 5*s + s^2)/(s^4-1)}}]\
\>", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[s, 
      {{2\/\(1 + s\^2\), \(6 - 5\ s + s\^2\)\/\(\(-1\) + s\^4\)}}]\)], 
  "Output",
  CellLabel->"Out[8]= ",
  CellTags->"3.1"],

Cell["\<\
This factors the numerators and denominators of all elements. \
\>",
   "MathCaption",
  CellTags->"3.1"],

Cell["FactorRational[%]", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[s, 
      {{2\/\(\((\(-I\) + s)\)\ \((I + s)\)\), 
          \(\((\(-3\) + s)\)\ \((\(-2\) + s)\)\)\/\(\((\(-1\) + s)\)\ \((\(-I\
\) + s)\)\ \((I + s)\)\ \((1 + s)\)\)}}]\)], "Output",
  CellLabel->"Out[9]= ",
  CellTags->"3.1"],

Cell["\<\
This expands the numerators and denominators of the previous \
result. \
\>", "MathCaption",
  CellTags->"3.1"],

Cell["ExpandRational[%]", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[s, 
      {{2\/\(1 + s\^2\), \(6 - 5\ s + s\^2\)\/\(\(-1\) + s\^4\)}}]\)], 
  "Output",
  CellLabel->"Out[10]= ",
  CellTags->"3.1"],

Cell[TextData[{
  "Both ",
  StyleBox["FactorRational", "MR"],
  " and ",
  StyleBox["ExpandRational", "MR"],
  " can be viewed as means to transform arbitrary ",
  StyleBox["TransferFunction", "MR"],
  " objects into their standard forms, whereas ",
  StyleBox["TransferFunction", "MR"],
  " itself behaves merely as a wrapper with respect to polynomial \
expressions. "
}], "Text",
  CellTags->"3.1"],

Cell[TextData[{
  "By itself, ",
  StyleBox["TransferFunction", "MR"],
  " does not change polynomial expressions in a transfer function matrix. "
}], "MathCaption",
  CellTags->"3.1"],

Cell["TransferFunction[s, 1/s + 1/(s-1)]", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[s, {{1\/\(\(-1\) + s\) + 1\/s}}]\)], "Output",
  CellLabel->"Out[11]= ",
  CellTags->"3.1"],

Cell[TextData[{
  "However, ",
  StyleBox["ExpandRational", "MR"],
  " and ",
  StyleBox["FactorRational", "MR"],
  " do convert arbitrary rational polynomial matrices to the standard forms. \
"
}], "MathCaption",
  CellTags->"3.1"],

Cell["ExpandRational[%]", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[s, {{\(\(-1\) + 2\ s\)\/\(\(-s\) + s\^2\)}}]\)], 
  "Output",
  CellLabel->"Out[12]= ",
  CellTags->"3.1"],

Cell["FactorRational[%%]", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[s, 
      {{\(2\ \((\(-\(1\/2\)\) + s)\)\)\/\(\((\(-1\) + s)\)\ s\)}}]\)], 
  "Output",
  CellLabel->"Out[13]= ",
  CellTags->"3.1"],

Cell[TextData[{
  "The coefficients of the factored form of the individual transfer matrix \
elements (",
  StyleBox["i.e.", "TI"],
  ", zeros, poles, and gains) can be stored using the special data structure \
",
  StyleBox["ZeroPoleGain", "MR"],
  ". To allow complete restoration of the transfer function object from its \
zero\[Hyphen]pole\[Hyphen]gain equivalent, ",
  StyleBox["ZeroPoleGain", "MR"],
  " may optionally contain the variable used in the transfer function.    "
}], "Text",
  CellTags->"3.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ZeroPoleGain",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["zeros",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["poles",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["gains",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"3.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            
            StyleBox[
              \(a\ collection\ of\ matrices\ representing\ the\ zeros, \ 
              poles, \ and\ gains\ of\ the\ elements\ of\ a\ transfer\ matrix
                \),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"3.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ZeroPoleGain",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["var",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["zeros",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["poles",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["gains",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"3.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["use",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["variable",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["var",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["in",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["descendent",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["TransferFunction",
                "MR"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["objects",
                SingleLetterItalics->False]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"3.1"],

Cell[TextData[{
  StyleBox["ZeroPoleGain", "MR"],
  " data structure. "
}], "Caption",
  CellTags->"3.1"],

Cell[TextData[{
  "Structurally, both ",
  StyleBox["zeros", "TI"],
  " and ",
  StyleBox["poles", "TI"],
  " are matrices of vectors of the corresponding coefficients, whereas ",
  StyleBox["gains", "TI"],
  " is just a matrix of coefficients. All three of these matrices and the \
parent transfer matrix have the same dimensions down to the second level. "
}], "Text",
  CellTags->"3.1"],

Cell["Here is another transfer function. ", "MathCaption",
  CellTags->"3.1"],

Cell["tf = TransferFunction[s, {{2/(1+s^2), s/(s-1)}}]", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[s, {{2\/\(1 + s\^2\), s\/\(\(-1\) + s\)}}]\)], "Output",\

  CellLabel->"Out[14]= ",
  CellTags->"3.1"],

Cell["\<\
This picks up its zeros, poles, and gains. Notice that there are no \
finite zeros in the first element of the transfer matrix, so the \
corresponding list of zeros is empty. \
\>", "MathCaption",
  CellTags->"3.1"],

Cell["ZeroPoleGain[%]", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(ZeroPoleGain[s, {{{}, {0}}}, {{{\(-I\), I}, {1}}}, {{2, 1}}]\)], 
  "Output",
  CellLabel->"Out[15]= ",
  CellTags->"3.1"],

Cell[TextData[{
  "Applying ",
  StyleBox["TransferFunction", "MR"],
  " to the ",
  StyleBox["ZeroPoleGain", "MR"],
  " object brings out the transfer function in its factored form. "
}], "MathCaption",
  CellTags->"3.1"],

Cell["TransferFunction[%]", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[s, 
      {{2\/\(\((\(-I\) + s)\)\ \((I + s)\)\), s\/\(\(-1\) + s\)}}]\)], 
  "Output",
  CellLabel->"Out[16]= ",
  CellTags->"3.1"],

Cell["The same result can be arrived at directly. ", "MathCaption",
  CellTags->"3.1"],

Cell["FactorRational[tf]", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[s, 
      {{2\/\(\((\(-I\) + s)\)\ \((I + s)\)\), s\/\(\(-1\) + s\)}}]\)], 
  "Output",
  CellLabel->"Out[17]= ",
  CellTags->"3.1"],

Cell[TextData[{
  "Like ",
  StyleBox["TransferFunction", "MR"],
  " objects, ",
  StyleBox["ZeroPoleGain", "MR"],
  " objects need not have a named variable. If a ",
  StyleBox["ZeroPoleGain", "MR"],
  " object does not have one, neither will the descendent transfer function. \
"
}], "Text",
  CellTags->"3.1"],

Cell[TextData[{
  "This ",
  Cell[BoxData[
      \(TraditionalForm\`1\[Cross]1\)], "InlineFormula",
    CellTags->"S0.0.2"],
  " system does not have finite zeros, has a single pole at the origin, and \
has a\[NonBreakingSpace]unit gain. Therefore, it represents an ideal \
integrator. "
}], "MathCaption",
  CellTags->"3.1"],

Cell["ZeroPoleGain[{{{}}}, {{{0}}}, {{1}}]", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(ZeroPoleGain[{{{}}}, {{{0}}}, {{1}}]\)], "Output",
  CellLabel->"Out[18]= ",
  CellTags->"3.1"],

Cell[TextData[{
  "Here is its transfer function. As no variable was used in the parent ",
  StyleBox["ZeroPoleGain", "MR"],
  ", none appears here. "
}], "MathCaption",
  CellTags->"3.1"],

Cell["TransferFunction[%]", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[{{1\/#1}}]\)], "Output",
  CellLabel->"Out[19]= ",
  CellTags->"3.1"],

Cell[TextData[{
  "It is worth emphasizing that the variable in the ",
  StyleBox["TransferFunction", "MR"],
  " and ",
  StyleBox["ZeroPoleGain", "MR"],
  " objects is a ",
  StyleBox["formal", "TI"],
  " parameter and has nothing to do with distinguishing Laplace and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)], "InlineFormula",
    CellTags->"S0.0.2"],
  "\[Hyphen]transform domains (which is what the ",
  StyleBox["Sampled", "MR"],
  " option is for). The variable may simply be omitted or easily renamed if \
desired using the built\[Hyphen]in ",
  StyleBox["Mathematica", "TI"],
  " functions. Again, renaming does not change the domain of the object; to \
transform the system from one domain to another, use either ",
  StyleBox["ToDiscreteTime", "MR"],
  " or ",
  StyleBox["ToContinuousTime", "MR"],
  ", whichever is appropriate (see ",
  ButtonBox["Section 3.4",
    ButtonData:>{"Continuous-Time versus Discrete-Time Systems"},
    ButtonStyle->"AddOnsLink"],
  ")."
}], "Text",
  CellTags->"3.1"],

Cell[TextData[{
  "This is a transfer function in the variable ",
  StyleBox["var", "MR"],
  ". "
}], "MathCaption",
  CellTags->"3.1"],

Cell["TransferFunction[var, 1/(1+var^2)]", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[var, {{1\/\(1 + var\^2\)}}]\)], "Output",
  CellLabel->"Out[20]= ",
  CellTags->"3.1"],

Cell[TextData[{
  "This changes the variable to ",
  StyleBox["z", "MR"],
  ". No change of domain has occurred. "
}], "MathCaption",
  CellTags->"3.1"],

Cell["% /. var -> z", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"3.1"],

Cell[BoxData[
    \(TransferFunction[z, {{1\/\(1 + z\^2\)}}]\)], "Output",
  CellLabel->"Out[21]= ",
  CellTags->"3.1"],

Cell[TextData[{
  "Both ",
  StyleBox["TransferFunction", "MR"],
  " and ",
  StyleBox["ZeroPoleGain", "MR"],
  ", as well as the head ",
  StyleBox["StateSpace", "MR"],
  " described in the next section, work as \"active wrappers\". This means \
that, on the one hand, they keep system components together allowing the \
system as a whole to be conveniently passed from one function to another. \
They can also be used to convert between the data structures by applying one \
wrapper over another. \nFor conversion and most other purposes, the elements \
of the transfer matrix must be in rational polynomial form. However, \
nonlinear terms can be handled in some cases, notably in some frequency \
response functions (",
  ButtonBox["Chapter 5",
    ButtonData:>{"Nyquist Plot"},
    ButtonStyle->"AddOnsLink"],
  ") and system interconnection functions (",
  ButtonBox["Chapter 6",
    ButtonData:>{"Elementary Interconnections"},
    ButtonStyle->"AddOnsLink"],
  "). \nTwo additional utility functions, ",
  StyleBox["Zeros", "MR"],
  " and ",
  StyleBox["Poles", "MR"],
  " return zeros and poles of transfer functions for control objects. In the \
case of ",
  StyleBox["ZeroPoleGain", "MR"],
  " objects, these functions simply extract the relevant parts from the data \
structure. "
}], "Text",
  CellTags->"3.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["Zeros",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["gives",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["matrix",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["zeros",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["transfer",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["function",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["corresponding",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]},
          {
            RowBox[{
              StyleBox["Poles",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["gives",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["matrix",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["poles",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["transfer",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["function",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["corresponding",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "DefinitionBox",
  GeneratedCell->True,
  CellTags->"3.1"],

Cell["Computing zeros and poles separately. ", "Caption",
  CellTags->"3.1"],

Cell["3.2 State\[Hyphen]Space Representations", "Subsection",
  CellTags->"3.2"],

Cell["Continuous\[Hyphen]time state\[Hyphen]space systems (Figure\
\[NonBreakingSpace]3.1) ", "Text",
  CellTags->"3.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{
                OverscriptBox[
                  StyleBox["\<\"x\"\>",
                    "TB"], "."], \((t)\), "=", 
                StyleBox["\<\"A\"\>",
                  "TB"], 
                StyleBox["\<\"x\"\>",
                  "TB"], \((t)\), "+", 
                StyleBox["\<\"B\"\>",
                  "TB"], 
                StyleBox["\<\"u\"\>",
                  "TB"], \((t)\)}],
              "DisplayFormula"]},
          {
            StyleBox[
              RowBox[{
                StyleBox["\<\"y\"\>",
                  "TB"], \((t)\), "=", 
                StyleBox["\<\"C\"\>",
                  "TB"], 
                StyleBox["\<\"x\"\>",
                  "TB"], \((t)\), "+", 
                StyleBox["\<\"D\"\>",
                  "TB"], 
                StyleBox["\<\"u\"\>",
                  "TB"], \((t)\)}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right}], TraditionalForm]], "DisplayFormula",
  CellTags->"3.2"],

Cell["and discrete\[Hyphen]time state\[Hyphen]space systems (Figure\
\[NonBreakingSpace]3.2) ", "Text",
  CellTags->"3.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{
                StyleBox["\<\"x\"\>",
                  "TB"], \((k + 1)\), "=", 
                StyleBox["\<\"A\"\>",
                  "TB"], 
                StyleBox["\<\"x\"\>",
                  "TB"], \((k)\), "+", 
                StyleBox["\<\"B\"\>",
                  "TB"], 
                StyleBox["\<\"u\"\>",
                  "TB"], \((k)\)}],
              "DisplayFormula"]},
          {
            StyleBox[
              RowBox[{
                StyleBox["\<\"y\"\>",
                  "TB"], \((k)\), "=", 
                StyleBox["\<\"C\"\>",
                  "TB"], 
                StyleBox["\<\"x\"\>",
                  "TB"], \((k)\), "+", 
                StyleBox["\<\"D\"\>",
                  "TB"], 
                StyleBox["\<\"u\"\>",
                  "TB"], \((k)\)}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right}], TraditionalForm]], "DisplayFormula",
  CellTags->"3.2"],

Cell[TextData[{
  "are represented by the ",
  StyleBox["StateSpace", "MR"],
  " data structure; this guide refers to component matrices using the same \
symbols, ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  ", and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"D\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  ". Here ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " is the ",
  StyleBox["state", "TI"],
  " (or ",
  StyleBox["evolution", "TI"],
  ") matrix,  ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " is the ",
  StyleBox["input", "TI"],
  " (or ",
  StyleBox["control", "TI"],
  ") matrix,  ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " is the ",
  StyleBox["output", "TI"],
  " (or ",
  StyleBox["observation", "TI"],
  ") matrix, and  ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"D\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " is the ",
  StyleBox["feedthrough", "TI"],
  " (or the ",
  StyleBox["direct transmission", "TI"],
  ") matrix.  Keeping the same notation for continuous\[Hyphen] and discrete\
\[Hyphen]time systems is common in the literature and allows sharing many \
concepts and algorithms that are essentially identical. (It is also common to \
use ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"F\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"G\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"H\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  ", and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"J\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " instead of ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"C\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  ", and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"D\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " for continuous\[Hyphen]time systems and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " instead of ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"B\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " in the discrete\[Hyphen]time case.) \nTo distinguish between the two \
types of systems, the option ",
  StyleBox["Sampled", "MR"],
  " is introduced later in ",
  ButtonBox["Section 3.4",
    ButtonData:>{"Continuous-Time versus Discrete-Time Systems"},
    ButtonStyle->"AddOnsLink"],
  ". \n",
  Cell["", "Message",
    GeneratedCell->False,
    CellAutoOverwrite->False,
    CellTags->"S0.0.3"]
}], "Text",
  CellTags->"3.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["StateSpace",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["a",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["b",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox[\(state - space\ object\ comprising\ two\ matrices\),
                SingleLetterItalics->False], 
              StyleBox[",",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              RowBox[{
                StyleBox["a",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["and",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["b",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"]}]}]},
          {
            RowBox[{
              StyleBox["StateSpace",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["a",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["b",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["c",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              RowBox[{
                StyleBox["state",
                  SingleLetterItalics->False], 
                StyleBox["-",
                  SingleLetterItalics->False], 
                RowBox[{
                  StyleBox["space",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["object",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["comprising",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["matrices",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["a",
                    SingleLetterItalics->False,
                    FontSlant->"Italic"]}]}], 
              StyleBox[",",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["b",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[",",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              RowBox[{
                StyleBox["and",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["c",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"]}], 
              StyleBox[",",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              RowBox[{
                StyleBox["which",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["assumes",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["that",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["the",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["direct",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["transmission",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["term",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["matrix",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["d",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["is",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["zero",
                  SingleLetterItalics->False]}]}]},
          {
            RowBox[{
              StyleBox["StateSpace",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["a",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["b",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["c",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["d",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              RowBox[{
                StyleBox["state",
                  SingleLetterItalics->False], 
                StyleBox["-",
                  SingleLetterItalics->False], 
                RowBox[{
                  StyleBox["space",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["object",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["comprising",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["matrices",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox["a",
                    SingleLetterItalics->False,
                    FontSlant->"Italic"]}]}], 
              StyleBox[",",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["b",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[",",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["c",
                SingleLetterItalics->False,
                FontSlant->"Italic"], 
              StyleBox[",",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              RowBox[{
                StyleBox["and",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["d",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"]}]}]}
          }], NotebookDefault]], "DefinitionBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.33, 0.67}},
  CellTags->"3.2"],

Cell["State\[Hyphen]space data structure. ", "Caption",
  CellTags->"3.2"],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 47 4 361 122
%%HiResBoundingBox: 47 4 361 122
%%Creator: (Mathematica Macintosh 3.0)
%%Title: Clipboard
%%CreationDate: (Friday, January 31, 1997) (10:44:47 AM)
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 126 translate 1 -1 scale
gsave
47 122 translate
314 -118 scale
1 string
1247 469 1 [1247 0 0 469 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } image
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE0000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC0000000000000000000001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE0000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC0000000000000000000001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFBFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFD1FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFA0FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFE07407FFFFFFFE1FFFFFD001FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFBFE0FFFFFFFFE0FFFFE8003FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFF9FC0FFFFFFFFE1FFF400007FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFBFC1FFFFFFFFE0FF800000AAAAAAAAAAAA
AAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFDFC1FFFFFFFFE1D0000000000000000000
000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000
0000000000000000023FFFFFFFEA83FFFFFFFFE000000000800000000000
000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000
0000000000000000001FFFFFFFC503FFFFFFFFE140000000000000000000
000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000
0000000000000000023FFFFFFFEF83FFFFFFFFE0FE800000800000000000
000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000
0000000000000000001FFFFFFFE707FFFFFFFFE1FFF40000555555555555
555555555507FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000
0000000000000000023FFFFFFFF70FFFFFFFFFE0FFFFA0003FFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE05555555555555
5555555555555555541FFFFFFFF707FFFFFFFFE1FFFFFD001FFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFA0FFFFFFFFFE0FFFFFFFA0FFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFF81FFFFFFFFFE1FFFFFFFF41FFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFF83FFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFC1FFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFE3FFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFC3FFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFE7FFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFF7FFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC0000000000000000000001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE0000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC0000000000000000000001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE0000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FBFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FBFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCE077FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEE0E7FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE6047FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE20E7FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0007FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFC01FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFC03FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFC03FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFE03FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFC03FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFE03FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD5157FC07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000FFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF800003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFC0007FE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000000000
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFEA0AFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000000000
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF801FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000000000
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFF0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000000000
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC155555555
5555555555541FFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF8003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC155555555555555555554
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFF0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF8201FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFF0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFF8FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83E03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87F01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83F80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD017FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FFF007FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFD417FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0002FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000001FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFC00001FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFFE000000FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000001FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFFC0004001FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00BFFA03FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFF803FFA00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01DDDD007FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFF01DDDD807FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFE03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFE0BFFFFE03FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF0177777701FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFF0077777701FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFF80FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFA0FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFC05DDDDDDC07FFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFF05DDDDDDC07FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFFFE07FFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFF83FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFC17777777703FFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFC17777777701FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF83FFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF83FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFF05DDDDDDDDC1FFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FD7FFFFF00FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFF81DDDDDDDDC1FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFE0FFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83F83FFFFFC03FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFE077777777740FFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87F81FFFFFE01FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFF0777777777607FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFE0FFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FFCFFFFFF80FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFEBFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFF0FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFC0
017FFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFC1DDDDDDDDDD07FFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FFCFFFFFFC07FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFF001FFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFF0DDDDDDDDDD07FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFF8
383FFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF8FFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FFCFFFFFFE01FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFE3F9FFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFF87FFFFFFFFFFFFFFFFFFEFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFFFFFF17FFFFFFFFC3FFFFFFF0
7C1FFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFC1777777777707FFFFFF
FFFFFFFFFFF7FFFFFFFFF07FF87FFC7FFFFFF007FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFC07FFFFFFFFFFFFFFFF7FFFFFFFFFC1FFFFFFF07FC7FFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFC1777777777707FFFFFFFFFFFFFFFFFFF05
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFE2FFFFFFFFC3FFFFFFF8
7E1FFFFFFFFE3FFFFFFFFFFFFFFFFFBFFFFFFFFFC3FFFFFFFFFF87FFFFFF
FFFFFFFFFFFEBFFFFFFFF8FFF83FFEFFFFFFFE03FFFFFFFFFFFFFFFFFFFF
FFFFFFFFF003FFFFFFFFFFFFFFFFABFFFFFFFFC3FFFFFFF87FF7FFFFFFFE
1FFFFFFFFFFFFFFBFFFFFFFFFE3FFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE0
3FFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFFFF005FFFFFFC3FFFFFFF0
7C1FFFFFFFFC1FFFFFFFFFFFFFFFFFC1FFFFFFFFC1DDDDDDDDDD87FFFFFF
FFFFFFFFFFFF05FFFFFFF07FF87FFC7FFFFFFF01FFFFFFFFFFFFFFFFFFFF
FFFFFFFFC000FFFFFFFFFFFFFFFFF01FFFFFFFC1FFFFFFF07FFFFFFFFFFC
1FFFFFFFFFFFFFFC17FFFFFFFC1DDDDDDDDDDC3FFFFFFFFFFFFFFFFFFFF0
017FFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFFFFC00BFFFFFC3FFFFFFF8
7E0FFFFFFFFE3FFFFFFFFFFFFFFFFFF82FFFFFFFC3FFFFFFFFFF83FFFFFF
FFFFFFFFFFFFE02FFFFFF8FFF83FFEFFFFFFFF80FFFFFFFFFFFFFFFFFFFF
FFFFFFFFC000FFFFFFFFFFFFFFFFFC02FFFFFFC3FFFFFFE0FFFFFFFFFFFE
1FFFFFFFFFFFFFFF80FFFFFFFE3FFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFC
000FFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFE0001FFFFFFFFFFFFFFC00017FFFC3FFFFFFF0
7C1FFFFFFFFC1FFFFFFFFFFFFFFFFFFC005FFFFFC3777777777707FFFFFF
FFFFFFFFFFFFF0007FFFF07FF87FFC7FFFFFFFC01FFFFFFFFFFFFFFFFFFF
FFFFFFFFC0007FFFFFFFFFFFFFFFFE0007FFFFC1FFFFFFE0FFFFFFFFFFFC
1FFFFFFFFFFFFFFFC005FFFFFC1777777777743FFFFFFFFFFFFFFFFFFFFC
00005FFFFFFE
FFFFFFFFFFFFFFFFFFFFFFE0000FFFFFFFFFFFFFFE00002FFFC3FFFFFFF8
7E3FFFFFFFFE3FFFFFFFFFFFFFFFFFFE0003FFFF83FFFFFFFFFF83FFFFFF
FFFFFFFFFFFFF8000BFFF8FFF83FFE7FFFFFFFF80FFFFFFFFFFFFFFFFFFF
FFFFFFFF80003FFFFFFFFFFFFFFFFF0000BFFFC3FFFFFFE0FFFFFFFFFFFE
1FFFFFFFFFFFFFFFE0003FFFFE3FFFFFFFFFFC2AAAAAAAAAAAAAAAAAAAAA
000003FFFFFE
FFFF800000000000000000000000000000000000000000005FC3FFFFFFF0
783FFFFFFFFC1FFFFFFFFFFFFFFFFFFF000017FFC1DDDDDDDDDD83FFFFFF
FFFFFFFFFFFFFC00001FF07FF87FFC7FFFFFFFFC04000000000000000000
0000000000000000000000000000000000017FC1FFFFFFC0FFFFFFFFFFFC
1FFFFFFFFFFFFFFFF000017FFC1DDDDDDDDDDC0000000000000000000000
00000017FFFE
FFFF8000000000000000000000000000000000000000000003C3FFFFFFF8
28FFFFFFFFFE00000000000000000000000000FFC3FFFFFFFFFF82AAAAAA
AAAAAAAAAAAAA8000002F8FFF83FFE7FFFFFFFFE02000000000000000000
0000000000000000000000000000000000002FC3FFFFFFE0FFFFFFFFFFFE
1FFFFFFFFFFFFFFFF800000BFE3FFFFFFFFFFC0000000000000000000000
00000000BFFE
FFFF800000000000000000000000000000000000000000000003FFFFFFF0
41FFFFFFFFFC0000000000000000000000000005C3777777777700000000
00000000000000000000007FF87FFC7FFFFFFFFF00000000000000000000
0000000000000000000000000000000000000041FFFFFFC0FFFFFFFFFFFC
000000000000000000000000141777777777740000000000000000000000
000000017FFE
FFFF800000000000000000000000000000000000000000000BC3FFFFFFF8
78FFFFFFFFFE000000000000000000000000000003FFFFFFFFFF80000000
0000000000000000000000FFF83FFE7FFFFFFFFFE0000000000000000000
0000000000000000000000000000000000000083FFFFFFE0FFFFFFFFFFFE
000000000000000000000000023FFFFFFFFFF80000000000000000000000
000002BFFFFE
FFFF800000000000000000000000000000000000000000017FC3FFFFFFF0
7C3FFFFFFFFC0000000000000000000000000005C1DDDDDDDDDD80000000
00000000000000000000107FF87FFC7FFFFFFFFFC0000000000000000000
00000000000000000000000000000000000017C1FFFFFFF0FFF7FFFFFFFC
0000000000000000000000001C1DDDDDDDDDDC1555555555555555555554
000017FFFFFE
FFFFFFFFFFFFFFFFFFFFFFE0000FFFFFFFFFFFFFFE0000BFFFC3FFFFFFF8
7C3FFFFFFFFE00000000000000000000000000FFC3FFFFFFFFFF80000000
0000000000000000000BF8FFF83FFE7FFFFFFFFF802AAAAAAAAAAAAAAAAA
AAAAAAAA80002AAAAAAAAAAAAAAAAA800003FFC3FFFFFFE0FFEFFFFFFFFE
00000000000000000000000BFE1FFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFE
000BFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFE0000FFFFFFFFFFFFFFC0005FFFFC3FFFFFFF0
7C1FFFFFFFFC15555555555555555554000017FFC1777777777705555555
5555555555555000007FF07FF87FFC7FFFFFFFFF007FFFFFFFFFFFFFFFFF
FFFFFFFF80007FFFFFFFFFFFFFFFFF00005FFFC1FFFFFFF07FE7FFFFFFFC
00000000000000000000017FFE1777777777707FFFFFFFFFFFFFFFFFFFF0
007FFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFE0003FFFFFFFFFFFFFF802FFFFFFC3FFFFFFF8
783FFFFFFFFE3FFFFFFFFFFFFFFFFFFE000BFFFFE1FFFFFFFFFF0FFFFFFF
FFFFFFFFFFFFF8003FFFF8FFF83FFE7FFFFFFFFE03FFFFFFFFFFFFFFFFFF
FFFFFFFFC0007FFFFFFFFFFFFFFFFE002FFFFFC3FFFFFFF87FEFFFFFFFFE
1FFFFFFFFFFFFFFFE000BFFFFE0FFFFFFFFFF87FFFFFFFFFFFFFFFFFFFE0
3FFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFF0001FFFFFFFFFFFFFF05FFFFFFFC3FFFFFFF0
783FFFFFFFFC1FFFFFFFFFFFFFFFFFF8017FFFFFE1DDDDDDDDDD07FFFFFF
FFFFFFFFFFFFC005FFFFF07FF87FFE7FFFFFFFFC07FFFFFFFFFFFFFFFFFF
FFFFFFFFC0007FFFFFFFFFFFFFFFFC01FFFFFFC1FFFFFFFC7F87FFFFFFFC
1FFFFFFFFFFFFFFFC005FFFFFF0DDDDDDDDDD07FFFFFFFFFFFFFFFFFFF85
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFFFAFFFFFFFFFC3FFFFFFF8
38FFFFFFFFFE3FFFFFFFFFFFFFFFFFE0BFFFFFFFE0FFFFFFFFFE0FFFFFFF
FFFFFFFFFFFF82FFFFFFF8FFF83FFE7FFFFFFFF80FFFFFFFFFFFFFFFFFFF
FFFFFFFFE000FFFFFFFFFFFFFFFFE8FFFFFFFFC3FFFFFFFE3F8FFFFFFFFE
1FFFFFFFFFFFFFFF82FFFFFFFF0FFFFFFFFFF0FFFFFFFFFFFFFFFFFFFEFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFF7FFFFFFFFFC3FFFFFFC0
01FFFFFFFFFC1FFFFFFFFFFFFFFFFF45FFFFFFFFF077777777740FFFFFFF
FFFFFFFFFFFC5FFFFFFFF07FF87FFE7FFFFFFFC01FFFFFFFFFFFFFFFFFFF
FFFFFFFFF001FFFFFFFFFFFFFFFF57FFFFFFFFC1FFFFFFFF0077FFFFFFFC
1FFFFFFFFFFFFFFC5FFFFFFFFF0777777777607FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFE1FFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FFF3FFFFFFF80FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFEBFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFF01DDDDDDDDC1FFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FFF33FFFFFF01FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFF81DDDDDDDDC1FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF83FFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FFFA3FFFFFE03FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFF83FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFC17777777707FFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FFFC3FFFFF007FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFC07777777703FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFE0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFF03FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFE05DDDDDDC0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFF01DDDDDDC07FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFC7FFF83FFFFFF81FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF8FFF83FFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFE3FFF83FFFFFF80FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC7FFF0077777401FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF07FF87FFFFFFFFE01FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFC7FFFC077777701FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFC7FFFE03FFFFA07FFFFFFFF
FFFFFBFFFFFFFFFFFFFFF8FFF83FFFFFFFFA03FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFE3FFFE03FFFFE03FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC7FFFE015DDD00FFFFFFFFF
FFFFF7FF7FFFFFFFFFFFF07FF87FFFFFFFF01FFFFFFFFFFFFFFFF3FF9FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFC7FFFF005DDD007FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFC7FFFF803FF803FFFFFFFFF
FFFFEFFFBFFFFFFFFFFFF8FFF83FFFFFFFE03FFFFFFFFFFFFFFFEFFFDFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFE3FFFF802FE800FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFF7FFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFC0000007FFFFFFFFF
FFFFDFFFDFFFFFFFFFFFF07FF87FFFFFFF407FFFFFFFFFFFFFFFC7FFC7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFC7FFFFC0000007FFFFFFFFFFFFFFFF07FFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFEFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF0001FFFF000003FFFFFFFFFF
FFFFBFFFEFFFFFFFFFFFF8FFF83FFFFFFF00FFFFFFFFFFFFFFFFEFFFE7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFF8000FFFF800000FFFFFFFFFFFFFFFFF03FFFBFF
FFFFFFFFFFFE
FFFFFFFFFFFFFDFFF7FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF0001FFFFC00007FFFFFFFFFF
14071F1FE7FFFFFFFFFFF07FF87FFFFFFC01FFFFFFFFFFFF05079F9FF7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFF0001FFFFC00001FFFFFFFFFFFFFFFFF19FFF7FF
9FFFFFFFFFFE
FFFFFFFFFFFFFDFFFBFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF0001FFFFF8003FFFFFFFFFFF
9E0F3F2FE7FFFFFFFFFFF8FFF83FFFFFF80FFFFFFFFFFFFFEF0FBF8FF3FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFF8000FFFFFA003FFFFFFFFFFFFFFFFFFBBFFEFFF
DFFFFFFFFFFE
FFFFFFFFFFFFF1FFFDFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFD7FFFFFFFFFFFF
DE1F3F17F3FFFFFFFFFFF07FF87FFFFFF01FFFFFFFFFFFFFC7071F17F1FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFC7FFFFFFFD5FFFFFFFFFFFFFFFFFFFFDFFDFFF
C7FFFFFFFFFE
FFFFFFFFFBFFF3FFFEFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFF
EE3E3FBFF3FFFFFFFFFFF8FFF83FFFFFE03FFFFFFFFFFFFFF60F3F9BFBFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFE3FFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFBFBF
EFFFFFFFFFFE
FFFFFFFFF041F7E1FC7FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFF
F41E7F1FF1FFFFFFFFFFF07FF87FFFFF007FFFFFFFFFFFFFF41F1FDFF1FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFC7FFFFFFFF7FFFFFFFFFFFFFFFFFFFFCFF1F1F
F7FFFFFFFFFE
FFFFFFFFE0A1E7E6FEFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFF
F83E7F9FF3FFFFFFFFFFF8FFF83FFFFE03FFFFFFFFFFFFFFF83E3FCFF9FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFE3FFFFFFFE7FFFFFFFFFFFFFFFFFFFF8FFBFAF
F3FFFFFFFFFE
FFFFFFFFE1C1C7F77E7FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFF
F07C7F9FF1FFFFFFFFFFF07FF87FFFFC07FFFFFFFFFFFFFFF03F3FC7F1FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFC7FFFFFFFE7FFFC7FFFFFFFFFFFFFFF87F3F17
F3FFFFFFFFFE
FFFFFFFFE1E3EFF3FE3FFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFFFFFF
F0FE7F8FF3FFFFFFFFFFF8FFF83FFFF80FFFFFFFFFFFFFFFF87E3FEFF9FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFE3FFFFFFFE3FFFC7FFFFFFFFFFFFFFF87E3FBF
F3FFFFFFFFFE
FFFFFFFFE1C1C7F1FE7FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E07C7FCFF1FFFFFFFFFFF07FF87FFFC01FFFFFFFFFFFFFFFF07F3FC7F1FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFC7FFFFFFFFFFFFFFF07E7F9F
F1FFFFFFFFFE
FFFFFFFFE1E3CFFBFE3FFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E0FE7FCFF3FFFFFFFFFFF8FFF83FFFC07FFFFFFFFFFFFFFFE0BF3FEFF9FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFC7FFFFFFFFFFFFFFF0BE3F8F
FBFFFFFFFFFE
FFFFFFFFE1C1C7F1FE3FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C13E7FC7F3FFFFFFFFFFF07FF87FFF007FFFFFFFFFFFFFFFC1DF1FE7F1FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFC7FFFFFFFFFFFFFFE03E7FCF
F1FFFFFFFFFE
FFFFFFFFE1E3CFF9FE3FFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
83BE3FA3F3FFFFFFFFFFF8FFF83FFE03FFFFFFFFFFFFFFFFE3FF3FA2FBFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFC7FFFFFFFFFFFFFFE1BE3FCF
FBFFFFFFFFFE
FFFFFFFFE1C1C7F9FE3FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
03DF3FC5F7FFFFFFFFFFF07FF87FFC07FFFFFFFFFFFFFFFFC1C71FC1F1FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FF0001FFFFFFFFFFFFFC1DE7FC7
F1FFFFFFFFFE
FFFFFFFFE1E3EFF8FE3FFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
ABAFBFE7E7FFFFFFFFFFF8FFF83FF80FFFFFFFFFFFFFFFFFAAAFBFF3F3FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FF0001FFFFFFFFFFFFFE3DE3FEF
F3FFFFFFFFFE
FFFFFFFFE1C1C7FCFE7FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF1FF7E7FFFFFFFFFFF07FF87FC01FFFFFFFFFFFFFFFFFFFFFDFF1F7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FF0001FFFFFFFFFFFFFC1DE3FC7
F1FFFFFFFFFE
FFFFFFFFE1E3E7F03E7FFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFBFFBEFFFFFFFFFFFF8FFF83F80FFFFFFFFFFFFFFFFFFFFFFEFFFEFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFC7FFFFFFFFFFFFFF83EF3F80
F3FFFFFFFFFE
FFFFFFFFC1C1E7FC7C7FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFDFFFDFFFFFFFFFFFF07FF87F01FFFFFFFFFFFFFFFFFFFFFFC7FFCFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFC7FFFFFFFFFFFFFF01C71FC7
F7FFFFFFFFFE
FFFFFFFFFFFFE3FEFEFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFEFFFBFFFFFFFFFFFF8FFF83E03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFC7FFFFFFFFFFFFFFFFFFBFF3
E7FFFFFFFFFE
FFFFFFFFFFFFF3FF7DFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF7FF7FFFFFFFFFFFF07FF87007FFFFFFFFFFFFFFFFFFFFFFF1FF3FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFC7FFFFFFFFFFFFFFFFFF9FF3
E7FFFFFFFFFE
FFFFFFFFFFFFFBFFFBFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E3FFFBFFFFFFFFFFFFFFF8FFF8203FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFE
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFC7FFFFFFFFFFFFFFFFFFFFFB
EFFFFFFFFFFE
FFFFFFFFFFFFFDFFF3FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC155555555
5555555555541FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C1FFFFFFFFFFFFFFFFFFF07FF8007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC155555555555555555554
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFC7FFFFFFFFFFFFFFFFFFCFFF
DFFFFFFFFFFE
FFFFFFFFFFFFFEFFEFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E1FFFFFFFFFFFFFFFFFFF8FFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000000000
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFF
BFFFFFFFFFFE
FFFFFFFFFFFFFF7FC7FFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C1FFFFFFFFFFFFFFFFFFF0555001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000000000
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFF3FF
7FFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
EBFFFFFFFFFFFFFFFFFFF8000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000000000
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000000000
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF800003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC003FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC003FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC011FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8839FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9C11FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB83EFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9C1DFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB83EFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7C1EFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7C1F7FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFEAAAAAAAAAAAAAAAAAAAAABFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC0000000000000000000001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC0000000000000000000001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF82AAAAAAAAAAAAAAAAAAAA3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFEAAFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFC011FFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFF0F8FFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFF07C3FFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFF0FE3FFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFD7FFFFFFFFC3FFFFFFF07E1FFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF8BFFFFFFF83FFFFFFF0FE0FFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFC057FFFFFC3FFFFFFF07E07FFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF002FFFFF83FFFFFFF0FE0FFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF80005FFFC3FFFFFFF07F07FFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF82AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAA80000BFF83FFFFFFF0FE0FFFFFFFFE2AAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA83FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00000000000000017C3FFFFFFF07F07FFFFFFFC000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF800000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000283FFFFFFF0FE0FFFFFFFFE000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000003FFFFFFF07E0FFFFFFFFC000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF800000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000083FFFFFFF0FE0FFFFFFFFE000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00000000000000017C3FFFFFFF07C1FFFFFFFFC000000000000000000000
000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFE0000BFF83FFFFFFF0FE3FFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF80015FFFC3FFFFFFF0787FFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFF002FFFFF83FFFFFFE068FFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFC05FFFFFFC3FFFFFFC007FFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFAFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC0000000000000000000001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC0000000000000000000001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFD5555555555555555555555FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFE
pop
grestore
%%Trailer
%%EOF
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{314, 118},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004j0000MQ000`40O003h00Oogoo>goo003oOolk
Ool00?mooc]oo`00RWoo00=Nmb488@P0524800=_NgooOol0UWoo002:Ool00e:D:DYNm`0CG_L00`00
Kg]oo`2GOol008Yoo`03DY@aS7oo01=oo`03001_Ngoo09Moo`00RWoo00=BU36<Ool04goo00<006mk
Ool0Ugoo002:Ool00e:D<Haoo`0COol00`00Kg]oo`2GOol008Yoo`03DY@aS7oo01=oo`03001_Ngoo
09Moo`00RWoo00=BU36<Ool04goo00<006mkOol0Ugoo002:Ool00e:D<Haoo`0COol00`00Kg]oo`2G
Ool008Yoo`03DY@aS7oo01=oo`03001_Ngoo00Eoo`04MkeF]EkgMkf>Ool008Yoo`03DY@aS7oo00Eo
o`06Mke247Nm@Q08@WNm27oo00X006mkOom_Ne:D@Q0Q20Q2000YBQE_N`03JeYg_Goo07Qoo`00JWoo
00=BU2488@P07R4800<aS7ooOol01Goo00AJeUkg8@PicPUoo`04001242U:248500000a240000000D
00000b48Oomoo`1gOol006Yoo`03@Q08@S6<00daS003=JdaS36<00daS003:DXaS7oo00Ioo`04MkeF
]@00Kg/9Ool02`00Kg]oogooKg]F]CW>:DXHaQ24IcT056mk00<YBR48Ool0N7oo001ZOol00d8@48Ao
o`0MOol00e:D<Haoo`07Ool00cW><Haoo`09Ool00`00Kg]oo`06Ool00fmkG_Moo`0COol00bU:8@Qo
o`1hOol006Yoo`03@Q0@Q7oo01eoo`03DY@aS7oo00Moo`03IcUNmgoo00Uoo`03001_Ngoo01aoo`03
:DXQ27oo07Qoo`00JWoo00=24124Ool07Goo00=BU36<Ool04goo00<006mkOol077oo00<YBR48Ool0
N7oo001ZOol00d8@48Aoo`0MOol00e:D<Haoo`0COol00`00Kg]oo`0LOol00bU:8@Qoo`1hOol006Yo
o`03@Q08@Woo01eoo`03BU8YBWoo01=oo`03001g_Goo01aoo`03:DXQ27oo07Qoo`00JWoo00=24124
Ool07Goo00=BU36<Ool04goo00<006mkOol077oo00<YBR48Ool0N7oo001ZOol00d8@48Aoo`0MOol0
0e:D<Haoo`0COol00`00Kg]oo`0LOol00bU:8@Qoo`1hOol006Yoo`03@Q0@Q7oo01eoo`03DY@aS7oo
01=oo`03001_Ngoo01aoo`03:DXQ27oo07Qoo`00JWoo00=24124Ool07Goo00=BU36<Ool04goo00<0
06mkOol077oo00<YBR48Ool0N7oo001ZOol00d8@48Aoo`0MOol00e:D:DYNm`0CG_L00`00Kg]oo`0L
Ool00bU:8@Qoo`1hOol006Yoo`03@Q0@Q7oo01eoo`03G_LQ224801@Q2003Kg]oogoo01]oo`03:DXQ
27oo07Qoo`00JWoo00=24124Ool0DWoo00<YBR48Ool0N7oo001ZOol00d8@48Aoo`1BOol00bU:8@Qo
o`1hOol006Yoo`03@Q0@Q7oo059oo`03:DXQ27oo07Qoo`00JWoo00=24124Ool0DWoo00<YBR48Ool0
N7oo001ZOol00d8@48Aoo`1BOol00bU:8@Qoo`1hOol006Yoo`03@Q0@Q7oo059oo`03:DXQ27oo07Qo
o`00JWoo00=24124Ool0DWoo00<YBR48Ool0N7oo001ZOol00d8@48Aoo`1BOol00bU:8@Qoo`1hOol0
06Yoo`03@Q0@Q7oo059oo`03:DXQ27oo07Qoo`00JWoo00=24124Ool0DWoo00<YBR48Ool0N7oo001Z
Ool00d8@48Aoo`1BOol00bU:8@Qoo`1hOol006Yoo`03@Q0@Q7oo059oo`03:DXQ27oo07Qoo`00JWoo
00=24124Ool0DWoo00<YBR48Ool0N7oo001ZOol00d8@48Aoo`1BOol00bU:8@Qoo`1hOol006Yoo`03
@Q0@Q7oo059oo`03:DXQ27oo07Qoo`00JGoo00=_Nd8@48@0Dgoo00<YBR48Ool0N7oo001YOol01FLi
@Q0@Q7NmKg/0DGoo00<YBR48Ool0N7oo001YOol014YB:DX@Q2U:DWoo00<YBR48Ool0N7oo001YOol0
15Je000001S6DWoo00<YBR48Ool0N7oo001YOol016mk0000036<DWoo00<YBR48Ool0N7oo001UOol2
Mkd3Ool00`Q2001:DP1BOol00bU:8@Qoo`1hOol006Eoo`03G_MBU7oo009oo`03:DX005kg059oo`03
:DXQ27oo07Qoo`00<Woo00=g_EkgG_L055kg00=g_GooOol067oo00A242U:8@PicP9oo`03>Lh007Nm
025oo`03:DXQ2248008Q2003BU9oogoo02Uoo`03:DXQ27oo01YooaINm`03Kg]oogoo04Eoo`00<Woo
00=Nm`005:D04a2400<006mkOol06Goo00Ag_Dic@Q1_N`9oo`03E[D@Q7oo025oo`0848A>LekgG_LH
aP006<I_NbUoo`03:DXQ27oo01Yoo`03000@Q12400<@Q003248@Q12400`@Q003249247oo04Ioo`00
<Woo00=Nmb48Ool04goo00<@Q6mkOol06Woo00=_NekgOol00Woo00=W>BU:Ool08Goo00T@Q6mkOomo
ob48BU8icPQ2DY@0:7oo00<YBR48Ool06Woo00<006mkOol04Woo00<aS48@Ool0AWoo000bOol00ekg
8@Qoo`0COol00a24Kg]oo`0POol00d8@Oomoo`0POol02a24Kg]oogoo8@QBU7ooF]HHaRU:Mkd09Woo
00<YBR48Ool06Woo00<006mkOol04Woo00<aS48@Ool0AWoo000bOol00ekg8@Qoo`0COol00a24Kg]o
o`0MOol01gNmE[DaS1S6:DYBU6mk01moo`0648A_NgooOolQ25:D0Woo00Ag_CW>48ABU2Eoo`03:DXQ
27oo01Yoo`03001_Ngoo019oo`03<Ha247oo01]oo`06Kg]242U::DXicVLi9Goo000bOol00ekg8@Qo
o`0COol00a24Kg]oo`0LOol015Je48@HaS6<0SW>00<HaPQ2BU807Woo00H@Q6mkOomoob48DY@4Ool0
15[F249:DWNm8goo00<YBR48Ool06Woo00<006mkOol04Woo00<aS48@Ool06Woo00TaS0Q2:DXicT8@
:DX8@RU:Mkd08goo000bOol00ekg8@Qoo`0COol00a24Kg]oo`0KOol00eJe00124005Kg/00ekg248a
S00MOol01Q24Kg]oogoo8@QBU0Eoo`04MkdHaQS6IcTROol00bU:8@Qoo`0JOol00`00Kg]oo`0BOol0
0c6<@Q1oo`0IOol28@P00fLiKg]_N`02Kg/016Li8@PHaWNm8Woo000bOol00ekg8@Qoo`0COol00a24
Kg]oo`0JOol00gNm48A24007Kg/00ekg249Nm`0LOol01a24Kg]oogoo8@QBU7oo009g_@Aoo`04DY@0
048@MkdPOol00bU:8@Qoo`0JOol00`00Kg]oo`0BOol00c6<@Q1oo`0HOol00cW>8@Q_N`07Kg/00b48
<Haoo`0QOol0039oo`03G_LQ27oo00Ioo`=Nm`03Kg]oogoo00Moo`0348A_Ngoo01Yoo`03@Q0Q26mk
00Q_N`03>LhHaWoo01]oo`0948A_NgooOolQ25:DOomBU3W>00Eoo`04IcTQ20Q2IcTOOol00bU:8@Qo
o`0JOol00`00Kg]oo`06Ool017NmE[EF]Fmk27oo00<aS48@Ool067oo00<8@UkgKg/01fmk00=Nm`00
Kg/08Goo000GOol016mk:DXQ25kg3Goo00AW>DYBE[EW>@Ioo`03G_LQ27oo00Ioo`05DY@HaWNm249W
>@08Ool00a24Kg]oo`0@Ool00ekgKg]oo`07Ool00bU:@Q1_N`09Kg/00`Q2Oomoo`0@Ool00fmkE[E_
N`07Ool01Q24Kg]oogoo8@QBU09oo`03BU9_Ngoo00Eoo`03BU88@SW>01aoo`05Mke240Q248A_N`0?
Ool016mkG_MNmgNm1goo00<006mkOol01Goo00E_Na24Mkeooe:D00Qoo`03<Ha247oo00eoo`03G_MW
>Goo00Moo`03DY@Q26mk00U_N`038@QBU7oo019oo`05G_LaS4YBG_Mg_@09Ool001Moo`055:D00000
249g_@0=Ool01f]J000001BU:DYF]GNm009oo`03G_LQ27oo00Ioo`05E[DQ27oo5:ENm`08Ool00aBU
Mkeoo`0AOol01B485:DYBTYBMkd017oo00<DYEJeMkd02GNm00<006]JOol04Goo00Ig_@Q2248YBTYB
Mkd3Ool01QBUMkeoogoo8@Q:DP9oo`03E[E[FWoo00Ioo`04G_LDYB48MkdJOol01EJe000000008@P0
4Goo00DQ20008@Pe[Ekg00Aoo`03001g_Goo00Eoo`03@Q0Q27oo00Yoo`03=Je247oo00ioo`058@P8
@RU:AS5[FP04Ool00eJe=Jeg_@09Mkd2=Jd?JeX00g>LJeY[FP02JeX01eJe000000008@Pe[Ekg00Io
o`0017oo00<Q20000000:@0000@8@SW>AS4Q20Moo`04DY@HaT8@>Lh9Ool00a246<HQ200A8@P00aS6
0000000200001PQ2:DY245Je6<I>L`Y_N`03000YBS6<00HaS003:DXaS36<00TaS0036<H000000080
0005248YBT8@249_N`02Ool01R48DYAoogooDYANm`Qoo`03MkdYBQ2403H0000548@icU:D001_N`06
Ool00c6<8@Qoo`0:Ool00c6<8@Q2400>@Q000cW>0000000200001PQ26<HicTYB>LhaS0Y_N`03<H`0
000001T00004248@Q3W>IcT3Ool000Aoo`03IcUNmekg011Nm`<00003249>Lekg00aNm`0;BU8000Q2
6<HYBU:DG_Mg_GooG_LQ2007Ool01E:D8@Qg_@00Mkd027oo00<@Q36<<H`0336<00<YBS6<<H`00S6<
00/HaP000008@QS6:DY:DUkgMkdYBT8@00U_N`03IcT8@S6<00LaS003=JdaS36<00TaS00:24800000
48@Q23W>E[EW>A24Kg/2Ool01R48DYAoogooDYANm`Uoo`03<H`8@SW>01UBU005<H`00000000@Q00A
DY@02bU:000001S6:DXicUkgKg]oo`00Kg/01Woo00ENma24Oomooe[F00Qoo`03<H`@Q24800hQ200;
48@00000000HaRU:>LiF]FLiE[DHaP0:Kg/00b48BU9_N`0>Kg/00f]JKg]_N`02Kg/01cW>248Q236<
DYANmgNm00Ioo`005goo00ABU124248icPeoo`03Kg]NmfLi00Moo`03G_LQ27oo00Ioo`04BU8YBTic
BU89Ool00a24Kg]oo`0?Ool01GNmF]I245JeIcT01Woo00=BU1S6Kg/026mk00<icR48Ool04Goo00E_
NdYBBU9Nmfmk00Eoo`0648A_NgooOolQ25:D0Woo00=W>EJeOol01Woo00AW>BU:6<IW>AYoo`05MkdY
BPQ28@QBU00?Ool01GNmG_MBU5kgMkd01Woo00<006mkOol01Woo00ABU5JeG_M240Qoo`03<Ha247oo
00eoo`05IcU245:DG_Mg_@06Ool00`Q2G_M_N`07Kg/00ekg001_N`0COol2IcT<Ool001Qoo`03<H`Q
27oo01Moo`03G_LQ27oo01=oo`0348A_Ngoo01Yoo`03MkdHaSW>00M_N`03G_L@Q6Li01aoo`0648A_
NgooOolQ25:D0goo0U:D1Goo00=:DQ24>Lh0>goo00<006mkOol04Woo00<aS48@Ool067oo00=24124
Kg/01fmk00<HaSW>Ool08Goo000HOol00c6<8@Qoo`0GOol00ekg8@Qoo`0COol00a24Kg]oo`0GOol0
23W>OomoogooIcT@Q36<IcT4Kg/00dYB249:DP0=Ool00gNmOomoo`0=Ool01Q24Kg]oogoo8@QBU0Qo
o`04IcTQ20Q2IcTlOol00`00Kg]oo`0BOol00c6<@Q1oo`0DOol00ekgF]Ioo`02Ool00c6<6<INm`04
Kg/016Li6<HHaWNm8Woo000>Ool00gNmOomg_@07Ool00c6<8@Qoo`0GOol00ekg8@Qoo`0COol00a24
Kg]oo`0EOol01GNmG_LHaUkgKg/00Woo00A_Nb48248aS08icP0348@HaUkg00eoo`05IcUg_GooOomN
m`0<Ool01Q24Kg]oogoo8@QBU0Moo`03@Q00048@00moo`06MkeBU7ooOomNmf<H:Goo00<006mkOol0
4Woo00<aS48@Ool04goo00AW>CW>@Q1Nm`=oo`09>Lh8@QS6>LhaS248000icWNm00moo`03@Q1W>Goo
009oo`03Mkeoogoo00aoo`002Goo00Eg_GooOomoodYB00=oo`03G_Mg_Goo00Aoo`03<H`Q27oo01Mo
o`03G_LQ27oo01=oo`0348A_Ngoo01Eoo`05Kg]24124@Q1S6004Ool01FLi@Q0aS48@E[D02Woo00]g
_DYBBU8HaVmk>Liooc6<Mke_Ne:D00]oo`0648A_NgooOolQ25:D1Goo00Ag_AS66<IW>@aoo`0:G_M:
DQS6DYA247oo>LiW>GooBU8YOol00`00Kg]oo`0BOol00c6<@Q1oo`0COol014YB:DXYBTYB17oo00I_
Ne:D>LhYBU:DIcTAOol015kgHaQoogoo0Vmk00Ag_GooG_MW>@Yoo`0027oo00QW>A24@Q0YBUkgIcU_
Nd8@0WNm00=247ooOol00goo00<aS248Ool05goo00=Nmb48Ool04goo00<@Q6mkOol05goo00<Q27oo
Ool057oo00MW>@Q2DYAF]EkgOolaS002Ool00c6<Oomoo`09Ool01Q24Kg]oogoo8@QBU0Aoo`04DY@0
04YBMkd>Ool02CW>8@QoobU:OomW>EkgOolaS00YOol00`00Kg]oo`0BOol00c6<@Q1oo`0DOol2DY@7
Ool00fLiE[Eoo`02Ool00f<HKg]oo`0>Ool02BU:JeYoocW>Oom246mkOom:DP0:Ool000Qoo`08G_LQ
25:D<Ha246mkOolicP9oo`03:DYoogoo00=oo`03<H`Q27oo01Moo`03G_LQ27oo01=oo`0348A_Ngoo
02ioo`03:DXQ26<H009F]@05Oom246LiOolicP0;Ool01Q24Kg]oogoo8@QBU09oo`04MkdQ2124E[D?
Ool02WNm48AF]Goo>Lioofmk@Q1g_CW>:Goo00<006mkOol04Woo00<aS48@Ool07Goo00=F]CW>Ool0
0Woo00=245kgOol03Goo00Y_N`Q2BU9ooc6<OomBU6LiOom240Yoo`0027oo00]Nmb48DY@aS5:DIcUo
obU:Kg]ooc6<00Eoo`03<H`Q27oo01Moo`03G_LQ27oo01=oo`0348A_Ngoo02eoo`09MkeBU6]JIcUo
odYBOomW>EJe009W>@]oo`0;48A_NgooOolQ25:DOomJeQS6:DYg_@0@Ool01FmkDYAW>FLiF]H00WNm
00<icWooBU80:Goo00<006mkOol04Woo00<aS48@Ool07Goo00PicRU:Oomoob4848@HaSW>3Goo00Y2
436<G_Mg_C6<OomNmcW>MkdaS0Yoo`0027oo00]_NfLiKg]W>FmkDYAoofLiKg]NmfLi00Eoo`03<H`Q
27oo01Moo`03G_LQ27oo01=oo`0348A_Ngoo02ioo`04Kg]g_GooOol2Kg/2Ool00fLiOomoo`0:Ool0
2A24Kg]oogoo8@Q:DSW>48ABU00FOol01WNmE[EoogooIcUg_BUoo`03001_Ngoo019oo`03<Ha247oo
01eoo`03:DX8@Woo009oo`03@Q1Nmgoo00eoo`0:G_MW>GNmKg]BU7ooMke:DWooDY@:Ool000eoo`05
Kg]g_GooIcUNm`06Ool00c6<8@Qoo`0GOol00ekg000DY@0C48@00`00Kg]oo`0^Ool00cW>=Jeoo`0B
Ool02124BU9BU5:D48@001S6Mke6Ool00`0048@@Q00348@00`Q248@@Q00<48@00`Q2@Q1oo`0MOol0
0`Q2001g_@02Ool00fmkMkeoo`0AOol01GNmIcUoogooIcT02goo000HOol00c6<8@Qoo`0GOol00gNm
G_MNm`0DG_L00gNmOomoo`12Ool00bU:8@PQ20028@P00dYBOomoo`16OolFG_L00fmkOomoo`0KOol0
17Nm000005kg9Woo000HOol00c6<8@Qoo`3eOol015Je000004YB9Woo000HOol00c6<8@Qoo`3eOol0
14YB0000036<9Woo000HOol00c6<8@Qoo`3eOol0148@8@PaS3W>9Woo000HOol00c6<8@Qoo`3eOol0
15kg<H`aS6Li9Woo000HOol00c6<8@Qoo`3eOol01GNm<H`aS7ooMkd09Goo000HOol00c6<8@Qoo`3f
Ool2<H`WOol001Qoo`03<H`Q27oo0?Ioo`8aS2Moo`0067oo00<aS248Ool0mWoo0S6<9goo000HOol0
0c6<8@Qoo`3fOol2<H`WOol001Qoo`03<H`Q27oo0?Ioo`8aS2Moo`0067oo00<aS248Ool0mWoo0S6<
9goo000HOol00c6<8@Qoo`3fOol2<H`WOol001Qoo`03<H`Q27oo0?Ioo`8aS2Moo`0067oo00<aS248
Ool0mWoo0S6<9goo000HOol00c6<8@Qoo`3fOol2<H`WOol001Qoo`03<H`Q27oo0?Ioo`8aS2Moo`00
67oo00<aS248Ool0mWoo0S6<9goo000HOol00c6<8@Qoo`3fOol2<H`WOol001Qoo`03<H`Q27oo0?Io
o`8aS2Moo`0067oo00<aS248Ool0mWoo0S6<9goo000HOol00c6<8@Qoo`1_Ool00gNmKg]_N`0@Kg/0
17NmKg]_NfmkL7oo0S6<9goo000HOol00c6<8@Qoo`1_Ool00c6<248@Q00@48@011BU48@@Q124L7oo
0S6<9goo000HOol00c6<8@Qoo`1_Ool00c6<@Q1oo`0BOol00fmk48Aoo`1_Ool2<H`WOol001Qoo`03
<H`Q27oo06moo`03<Ha247oo019oo`03Kg/@Q7oo06moo`8aS2Moo`0067oo00<aS248Ool0Kgoo00<a
S48@Ool04Woo00=_Na24Ool0Kgoo0S6<9goo000HOol00c6<8@Qoo`1_Ool00c6<@Q1oo`0BOol00fmk
48Aoo`1_Ool2<H`WOol001Qoo`03:DXQ27oo06moo`03=Je247oo019oo`03JeX8@Woo06moo`03=JdY
BWoo02Ioo`0067oo00<aS248Ool0Kgoo00<aS48@Ool04Woo00=_Na24Ool0Kgoo0S6<9goo000HOol0
0c6<8@Qoo`1_Ool00c6<@Q1oo`0BOol00fmk48Aoo`1_Ool2<H`WOol001Qoo`03<H`Q27oo06moo`03
<Ha247oo00Eoo`05IcT@Q5:D@Q1_N`08Ool00fmk48Aoo`1_Ool2<H`WOol001Qoo`03<H`Q27oo06Eo
o`05MkeBU5JeKg]g_@05Ool00c6<@Q1oo`06Ool01@00Kg]NmaS6Mkd01goo00=_Na24Ool0Kgoo0S6<
9goo000HOol00c6<6<IBU00IDY@00dYBDYABU00PDY@00eJeDYABU00PDY@00dYBDYABU005DY@02Q24
0008@R48<HaF]FLiMkdaS48@1goo00D006mkKg/006mk00Moo`03Kg/@Q5:D01eBU003BU9BU5:D021B
U003E[EBU5:D021BU003BU9BU5:D00UBU0038@PaS7oo02Ioo`0067oo00<aS0000000K@0000@8@R48
8@Q240Moo`04001_NeJe2488Ool00fmk0000001`00000c6<Oomoo`0UOol0085oo`07Kg/Q2124:DY:
DU:DMkd00Woo00<aS48@Ool01Goo00EW>@00BU9246Li00Qoo`03Kg/@Q7oo09Qoo`00P7oo00=g_Fmk
Ool01goo00<aS48@Ool04Woo00=_Na24Ool0V7oo002:Ool00c6<@Q1oo`0BOol00fmk48Aoo`2HOol0
08Yoo`03<Ha247oo019oo`03Kg/@Q7oo09Qoo`00RWoo00<aS48@Ool04Woo00=_Na24Ool0V7oo002:
Ool00c6<@Q1oo`0BOol00fmk48Aoo`2HOol008Yoo`03<Ha247oo019oo`03Kg/@Q7oo09Qoo`00RWoo
00<aS48@Ool04Woo00=_Na24Ool0V7oo002:Ool00c6<@Q1oo`0BOol00fmk48Aoo`2HOol008Yoo`03
<H`@Q24801<Q200348Aoogoo09Moo`00RWoo00=Nme:DDY@045:D00A:DU:DDYAF]IUoo`00ogoo>goo
003oOolkOol00001\
\>"],
  CellTags->"3.2"],

Cell[TextData[{
  StyleBox["Figure 3.1.",
    FontWeight->"Bold"],
  " State\[Hyphen]space model of a continuous\[Hyphen]time system."
}], "Caption",
  CellTags->"3.2"],

Cell[TextData[{
  Cell["", "Message",
    GeneratedCell->False,
    CellAutoOverwrite->False,
    CellTags->"S0.0.3"],
  "   "
}], "Text",
  CellTags->"3.2"],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 47 4 370 123
%%HiResBoundingBox: 47 4 370 123
%%Creator: (Mathematica Macintosh 3.0)
%%Title: Clipboard
%%CreationDate: (Friday, January 31, 1997) (10:46:06 AM)
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 127 translate 1 -1 scale
gsave
47 123 translate
323 -119 scale
1 string
1283 473 1 [1283 0 0 473 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } image
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFAFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFF45FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFE80FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFC1F007FFFFFFFC3FFFFFC003FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFEFF83FFFFFFFFC3FFFFA000FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFF7F81FFFFFFFFC3FFD00000FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFF7F83FFFFFFFFC3FE800000AAAAA
AAAAAAAAAAAAAAAAAAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFF7F07FFFFFFFFC34000000100000
0000000000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000
00000000000000000000000083FFFFFFFAA07FFFFFFFFC20000000200000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000000000000000000007FFFFFFF9407FFFFFFFFC10000000100000
0000000000000000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000
00000000000000000000000083FFFFFFF9E0FFFFFFFFFC3FA00000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000000000000000000007FFFFFFFDC0FFFFFFFFFC3FFD0000055555
5555555555555555407FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00000000000000
00000000000000000000000083FFFFFFFEE1FFFFFFFFFC3FFFFA000FFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF05555555555555
55555555555555555555555587FFFFFFFCC1FFFFFFFFFC3FFFFFC003FFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFE83FFFFFFFFFC3FFFFFFE81FFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFF03FFFFFFFFFC3FFFFFFFF47FFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF03FFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFF07FFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF8FFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFF87FFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF8FFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFDFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF80000000000000000000003FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF07DFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FBFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCF077FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEE0F7FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7067FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE20E7FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1007FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFFC01FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFC03FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFC01FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFE03FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFC03FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFE03FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD5157FC07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC000000000000000000000000000001FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000FFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC000000000000000000000000000003FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFC0007FE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC000000000000000000000000000001FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000000
00000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFEA0AFFE07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC000000000000000000000000000003FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000000
00000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000000
00000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFF0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000000
00000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC155555555
5555555555541FFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFF07FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC15555555555555
55555541FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFF8FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFF0FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFF8FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF1FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD017FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFD417FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8002FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8002FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000001FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFF800001FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFE000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF40000001FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFC0004001FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFA01FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFF803FFA00FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC01DDDD007FFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFC01DDDD007FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFE03FFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFC0FFFFFE03FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF0177777701FFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFF0177777701FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFF80FFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFA0FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFC05DDDDDDC07FFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFE05DDDDDDC07FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFE07FFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFF03FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFC17777777703FFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFF1FFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFC17777777703FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF83FFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFF0FFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFF05DDDDDDDDC1FFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFF07FFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF01DDDDDDDDC1FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFE0FFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFBFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFE0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFF077777777740FFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFF1FFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF0777777777607FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFF0FFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFBFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFABFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFF0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFC0
017FFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFC1DDDDDDDDDD07FFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFD557FFC5F579F7FDFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF007FF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFE1DDDDDDDDDD07FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFF8
383FFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF8FFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFE0A0FF80F8F0A3FCFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFE3FBFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFF87FFFFFFFFFFFFFF
FFFFEFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFFFFFF57FFFFFFFFC3FFFFFFF0
7C1FFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFC1777777777707FFFFFF
FFFFFFFFFFDFFFFFFFFFC3FFFFF1F47F0471E1C7FCFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFF7FFFFFFFFFC3FFFFFFF07FC7F
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC1777777777707FFFFFFFFFFFFFF
FFFFF05FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFE2FFFFFFFFC3FFFFFFF8
7E1FFFFFFFFE3FFFFFFFFFFFFFFFFFBFFFFFFFFFC3FFFFFFFFFF87FFFFFF
FFFFFFFFFFFBFFFFFFFFC3FFFFF9FE3E3F79E3E7F8FFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFA03FFFFFFFFFFFFFFFFABFFFFFFFFC3FFFFFFF0FFEFF
FFFFFFE3FFFFFFFFFFFFFFBFFFFFFFFFE3FFFFFFFFFF83FFFFFFFFFFFFFF
FFFFFE0BFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFFFF005FFFFFFC3FFFFFFF0
7C1FFFFFFFFC1FFFFFFFFFFFFFFFFFC1FFFFFFFFC1DDDDDDDDDD87FFFFFF
FFFFFFFFFFFC17FFFFFFC3FFFFF1FF1C7FF1F3C7F07FFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFF05FFFFFFFC3FFFFFFF0FFFFF
FFFFFFC1FFFFFFFFFFFFFFC1FFFFFFFFC1DDDDDDDDDD83FFFFFFFFFFFFFF
FFFFFF0017FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFFFFC00BFFFFFC3FFFFFFF8
7E0FFFFFFFFE3FFFFFFFFFFFFFFFFFF82FFFFFFFC3FFFFFFFFFF83FFFFFF
FFFFFFFFFFFF80FFFFFFC3FFFFF9FF8E7FF9FBE7F3FFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFE000FFFFFFFFFFFFFFFFF802FFFFFFC3FFFFFFE0FFFFF
FFFFFFE3FFFFFFFFFFFFFFF82FFFFFFFC3FFFFFFFFFF83FFFFFFFFFFFFFF
FFFFFFC000FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFE0001FFFFFFFFFFFFFFC00017FFFC3FFFFFFF0
7C1FFFFFFFFC1FFFFFFFFFFFFFFFFFFC005FFFFFC3777777777707FFFFFF
FFFFFFFFFFFFC005FFFFC3FFFFF1FF847FF1F5C7F17FFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFC0007FFFFFFFFFFFFFFFFC0007FFFFC3FFFFFFC0FFFFF
FFFFFFC1FFFFFFFFFFFFFFFC005FFFFFC1777777777743FFFFFFFFFFFFFF
FFFFFFC00005FFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFE0000FFFFFFFFFFFFFFE00002FFFC3FFFFFFF8
7E3FFFFFFFFE3FFFFFFFFFFFFFFFFFFE0003FFFF83FFFFFFFFFF83FFFFFF
FFFFFFFFFFFFE0003FFFC3FFFFF9FF8EFFF9FEA7E3BFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFF80003FFFFFFFFFFFFFFFFF0000BFFFC3FFFFFFE0FFFFF
FFFFFFE3FFFFFFFFFFFFFFFE0003FFFFC3FFFFFFFFFF82AAAAAAAAAAAAAA
AAAAAAA000003FFFFFFFE0
FFFF800000000000000000000000000000000000000000005FC3FFFFFFF0
783FFFFFFFFC1FFFFFFFFFFFFFFFFFFF000017FFC1DDDDDDDDDDC3FFFFFF
FFFFFFFFFFFFE000017FC3FFFFF1FFC45571FFC7C7BFFFFFFC0000000000
0000000000000000000000000000000000000000001FFC3FFFFFFC1FFFFF
FFFFFFC1FFFFFFFFFFFFFFFF000017FFC1DDDDDDDDDDC000000000000000
000000000000017FFFFFE0
FFFF8000000000000000000000000000000000000000000003C3FFFFFFF8
28FFFFFFFFFE00000000000000000000000000FFC3FFFFFFFFFF82AAAAAA
AAAAAAAAAAAAA000000BC3FFFFF9FF8EA879FBE7CFBFFFFFFE0000000000
00000000000000000000000000000000000000000002FC3FFFFFFE0FFFFF
FFFFFFE3FFFFFFFFFFFFFFFF800000FFC3FFFFFFFFFFC000000000000000
000000000000000FFFFFE0
FFFF800000000000000000000000000000000000000000000003FFFFFFF0
41FFFFFFFFFC0000000000000000000000000005C3777777777700000000
0000000000000000000003FFFFF1FFC67C71F1C7C7DFFFFFFC0000000000
00000000000000000000000000000000000000000000043FFFFFFC1FFFFF
FFFFFFC0000000000000000000000005C177777777774000000000000000
0000000000000057FFFFE0
FFFF800000000000000000000000000000000000000000000BC3FFFFFFF8
78FFFFFFFFFE000000000000000000000000000003FFFFFFFFFF80000000
0000000000000000000003FFFFF9FF8F7CF9F3EF8FDFFFFFFE0000000000
00000000000000000000000000000000000000000000083FFFFFFE0FFFFF
FFFFFFE000000000000000000000000023FFFFFFFFFF8000000000000000
0000000000002BFFFFFFE0
FFFF800000000000000000000000000000000000000000017FC3FFFFFFF0
7C3FFFFFFFFC0000000000000000000000000001C1DDDDDDDDDD80000000
0000000000000000000143FFFFF1FF8791F1F9CF0FDFFFFFFC0000000000
000000000000000000000000000000000000000000017C3FFFFFFE0FFF7F
FFFFFFC0000000000000000000000001C1DDDDDDDDDD8155555555555555
5555554000017FFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFE0000FFFFFFFFFFFFFFE0000BFFFC3FFFFFFF8
7C3FFFFFFFFE00000000000000000000000000FFC3FFFFFFFFFF80000000
0000000000000000002FC3FFFFF9FF8FEBF9FEBFAFAFFFFFFE2AAAAAAAAA
AAAAAAAAAAAAAAA80002AAAAAAAAAAAAAAAAA80000BFFC3FFFFFFE0FFEFF
FFFFFFE00000000000000000000000FFE1FFFFFFFFFF83FFFFFFFFFFFFFF
FFFFFFC000BFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFE0000FFFFFFFFFFFFFFC0005FFFFC3FFFFFFF0
7C1FFFFFFFFC15555555555555555554000017FFC1777777777705555555
555555555555400005FFC3FFFFF1FF0FFFF1FFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFF00003FFFFFFFFFFFFFFFFF00005FFFC3FFFFFFF07FC7F
FFFFFFC00000000000000000000017FFC1777777777707FFFFFFFFFFFFFF
FFFFFF0007FFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFF0003FFFFFFFFFFFFFF802FFFFFFC3FFFFFFF8
783FFFFFFFFE3FFFFFFFFFFFFFFFFFFE000BFFFFE1FFFFFFFFFF0FFFFFFF
FFFFFFFFFFFFA002FFFFC3FFFFF9FF1FFFF9FFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFF80003FFFFFFFFFFFFFFFFE002FFFFFC3FFFFFFF8FFEFF
FFFFFFE3FFFFFFFFFFFFFFFE000BFFFFE0FFFFFFFFFF87FFFFFFFFFFFFFF
FFFFFE03FFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFF0001FFFFFFFFFFFFFF05FFFFFFFC3FFFFFFF0
783FFFFFFFFC1FFFFFFFFFFFFFFFFFF8017FFFFFE1DDDDDDDDDD07FFFFFF
FFFFFFFFFFFF001FFFFFC3FFFFF1FC1FFFF1FFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFC0007FFFFFFFFFFFFFFFF801FFFFFFC3FFFFFFFC7F87F
FFFFFFC1FFFFFFFFFFFFFFFC015FFFFFF0DDDDDDDDDD07FFFFFFFFFFFFFF
FFFFF05FFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFFFAFFFFFFFFFC3FFFFFFF8
38FFFFFFFFFE3FFFFFFFFFFFFFFFFFF82FFFFFFFE0FFFFFFFFFE0FFFFFFF
FFFFFFFFFFFE0BFFFFFFC3FFFFF9F8FFFFF9FFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFE000FFFFFFFFFFFFFFFFE0FFFFFFFFC3FFFFFFFE3E0FF
FFFFFFE3FFFFFFFFFFFFFFF82FFFFFFFE0FFFFFFFFFE0FFFFFFFFFFFFFFF
FFFFEFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFF7FFFFFFFFFC3FFFFFFC0
01FFFFFFFFFC1FFFFFFFFFFFFFFFFF45FFFFFFFFF077777777740FFFFFFF
FFFFFFFFFFF17FFFFFFFC3FFFFF041FFFFF1FFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFE001FFFFFFFFFFFFFFFF57FFFFFFFFC3FFFFFFFF0067F
FFFFFFC1FFFFFFFFFFFFFFC5FFFFFFFFF077777777760FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFE1FFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFEABFFFFFFBFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFE0FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFF01DDDDDDDDC1FFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFD17FFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF81DDDDDDDDC1FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF83FFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFF83FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFC17777777707FFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFC07777777703FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFE07FFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFE07FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFF05DDDDDDC0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFF05DDDDDDC07FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFC7FFF83FFFFFF81FFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFE7FFF83FFFFFF80FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC7FFF0077777701FFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFE7FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFC7FFF8077777701FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFC7FFFE03FFFFA03FFFFFFFF
FFFFFFFFFFFBFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFE7FFFE03FFFFA03FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC7FFFF015DDD00FFFFFFFFD
FFFFFFFFFFFDFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFF9FFFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFC7FFFF015DDD007FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFC7FFFF802FE803FFFFFFFFF
FFFFFFFFFFFEFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFBFFEFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFE7FFFF802FE801FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFF7FFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFC0000007FFFFFFFF3
FFFFFFFFFFFF7FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFF1
4073E7C7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFC7FFFFC0000007FFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF0001FFFF000002FFFFFFFFF3
FFFFFFFFFFFFBFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFB
E0F3E38BF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFF8001FFFF800000FFFFFFFFFFFFFFFFF8
3FFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFDFFFF3FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFF0001FFFFC00007FFFFC1C1F7
CFCFF9FFC17F1FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFD
C1E7F39DF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFF0001FFFFC00005FFFFFFFFFFFFFFFFF8
5FFF9FFFE7FFFFFFFFFFE0
FFFFFFFFFFFFFDFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF0001FFFFF8003FFFFFFBC1EF
EF8FF9FFF3FF9FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFE
C3E7F39FFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFF8001FFFFFA003FFFFFFFFFFFFFFFFFFC
EFFFBFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFF1FFFFCFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFD7FFFFFFF1C1C7
C717F9FFF1FF9FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
03C7F11FF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFC7FFFFFFFD5FFFFFFFFFFFFFFFFFFFF
E7FE7FFFF1FFFFFFFFFFE0
FFFFFFFFFBFFF3FFFFEFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFB83EF
E73FF9FFF3FF8FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
07E7FB3FF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7FEFFFBFBFFFFFFFFFFE0
FFFFFFFFF041F7C7C7E7FFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFD07CF
E73FF9FFF1FFCFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
07C7F93FF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFC7FFFFFFFF7FFFFFFFFFFFFFFFFFFFF
F7FCF9F1FDFFFFFFFFFFE0
FFFFFFFFE0A1E7E78BE3FFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFE0FCF
E27FF9FFF3FFCFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFE
0FE7F9BFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFE7FFFFFFFE7FFFFFFFFFFFFFFFFFFFF
E3FCF8E2FCFFFFFFFFFFE0
FFFFFFFFE1C1C7E71FF3FFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFE0FCF
F07F5157F1FFC7FFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFC
07C7FDDFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFC7FFFFFFFE7FFFC7FFFFFFFFFFFFFFF
C3F9FCE77C7FFFFFFFFFE0
FFFFFFFFE1E3EFE3BFF3FFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFC7FFFFFFFFFFFFFFFFE1F8F
F2FE0007F3FFCFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFE
37E7F8EFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFE7FFFFFFFE3FFFCFFFFFFFFFFFFFFFF
E3F9FCE7FEFFFFFFFFFFE0
FFFFFFFFE1C1C7F33FF1FFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FCF
F17D5157F1FFC7FFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFC
13E7FCF7F1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFC7FFFFFFFFFFFFFFF
C1F1FC47FC7FFFFFFFFFE0
FFFFFFFFE1E3CFF23FF3FFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF82FCF
FBBFF9FFF3FFCFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFF8
3BE7FEF3F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFCFFFFFFFFFFFFFFFF
81F9FECFFE7FFFFFFFFFE0
FFFFFFFFE1C1C7F07FF1FFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF067C7
F1CFF9FFF1FFCFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFF0
1077FC7FF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFC7FFFFFFFFFFFFFFF
05F1FC4FFC7FFFFFFFFFE0
FFFFFFFFE1E3CFFBFFF3FFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF073EF
F9E7F9FFF3FF8FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFF3FE7FF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFCFFFFFFFFFFFFFFFF
86F9FE6FFE7FFFFFFFFFE0
FFFFFFFFE1C1C7F99FF1FFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF071C7
F9D5F9FFF1FF9FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFF1FE7FE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FF0001FFFFFFFFFFFFFF
0671FF77FC7FFFFFFFFFE0
FFFFFFFFE1E3EFF9EFF3FFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAEBEF
FCFFF9FFF3FFBFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFF9FE7FEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FF0003FFFFFFFFFFFFFF
0EF9FF3BFEFFFFFFFFFFE0
FFFFFFFFE1C1C7FDE7F3FFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7
FCFFF9FFF1FF1FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFCFF3FDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FF0001FFFFFFFFFFFFFE
0F71FF3DFC7FFFFFFFFFE0
FFFFFFFFE1E3E7F8E3F3FFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3
FEFFFFFFF3FF3FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFEFF3FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFF87FFFFFFFFFFFFFFE
1F39FF3AFEFFFFFFFFFFE0
FFFFFFFFC1C1E7FCFFF7FFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9
FC7FFFFFF1FF7FFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFF7D1F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFC7FFFFFFFFFFFFFFC
051DFF1FFCFFFFFFFFFFE0
FFFFFFFFFFFFE3FEFFEFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD
FEFFFFFFE3FEFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFCFFFFFFFFFFFFFFFF
FFFCFFBFF9FFFFFFFFFFE0
FFFFFFFFFFFFF3FC7FC7FFFF03FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
7C7FFFFFF1FDFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFC7FFFFFFFFFFFFFFF
FFFC7F9FF9FFFFFFFFFFE0
FFFFFFFFFFFFFBFE7FEFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFF
FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFBFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFF
FFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFCFFFFFFFFFFFFFFFF
FFFE7F9FFBFFFFFFFFFFE0
FFFFFFFFFFFFFDFE7F9FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC155555555
5555555555541FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC15555555555555
55555541FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFC7FFFFFFFFFFFFFFF
FFFF3FDFF7FFFFFFFFFFE0
FFFFFFFFFFFFFEFE3FBFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000000
00000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFFFFFFFFFFFFFFFF
FFFFBFCFEFFFFFFFFFFFE0
FFFFFFFFFFFFFF7C3F7FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC155555555555555555555555555541FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000000
00000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFF
FFFFDF47DFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC000000000000000000000000000003FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000000
00000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFC000000000
0000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC000000000000000000000000000001FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000000
00000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC000000000000000000000000000003FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFC000000000000000000000000000001FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC003FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC003FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8003FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8001FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8839FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9811FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB839FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF381DFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFB83EFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF781EFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF781FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000007FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000007FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000007FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000007FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF05555555555555555555507FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFF0007FFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFE0E3FFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFC1F07FFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFE0F87FFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFC1FC3FFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFAFFFFFFFFF0FFFFFFFE0FC3FFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF05FFFFFFF07FFFFFFC1FC1FFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFA03FFFFFF0FFFFFFFE0FE1FFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC0017FFFF07FFFFFFC1FC1FFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF8000FFFF0FFFFFFFE0FE1FFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000000005FF07FFFFFFC1FC1FFFFFFFF000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF800000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00000000000000000000003F0FFFFFFFE0FE1FFFFFFFF800000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000003FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00000000000000000000000107FFFFFFC1FC1FFFFFFFF000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF800000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000FFFFFFFE0FC3FFFFFFFF800000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000003FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000
00000000000000000000000507FFFFFFC1FC3FFFFFFFF000000000000000
000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF800002FF0FFFFFFFE0F83FFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00001FFF07FFFFFFC1F07FFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE000BFFFF0FFFFFFFE0E0FFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC017FFFFF07FFFFFF0007FFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF83FFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFC5FFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0FFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000007FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000007FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000007FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000007FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE0
pop
grestore
%%Trailer
%%EOF
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{323, 119},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000530000Ma000`40O003h00OogooA7oo003oOom4
Ool00?moodAoo`00TGoo00<icR488@P04b4800<icWooOol0VGoo002AOol00b48>LiNm`0BG_L00dHa
8@Qoo`2JOol0095oo`038@QBU7oo019oo`03G_LQ27oo09Yoo`00TGoo00<Q25:DOol04Woo00=Nmb48
Ool0VWoo002AOol00b48DYAoo`0BOol00ekg8@Qoo`2JOol0095oo`038@QBU7oo019oo`03G_LQ27oo
09Yoo`00TGoo00<Q25:DOol04Woo00=Nmb48Ool0VWoo002AOol00b48DYAoo`0BOol00ekg8@Qoo`2J
Ool0095oo`038@QBU7oo019oo`03G_LQ27oo00Ioo`04IcUBU5JeMkf@Ool0095oo`038@QBU7oo00Eo
o`06IcUF]Goo6<HYBWNm1goo00QNmb48OomooekgBU8icQS60P0000=:DVmkKg/04Vmk00=[FVmkMkd0
Ngoo001ZOol00e[F8@PQ200T8@P00aS6DYAoo`06Ool014YBCW<006Li27oo00ANmaS6>LhHaPD00003
248@Q00001D00003<Haoogoo07Uoo`00JWoo00=BU0Q2<H`0436<00<e[C6<<H`04C6<00<HaU:DOol0
1Woo00=JeT8@8@P02Goo00]Nmb48OomoogNmIcUF]CW>8@P8@RU:01A_N`03MkdQ236<07]oo`00JWoo
00=BU124Ool097oo00<Q25:DOol01goo00<8@U[FOol027oo00=Nmb48Ool01goo0Vmk57oo0S6<Ngoo
001ZOol00e:D48Aoo`0TOol00b48DYAoo`07Ool00dYBMkeoo`08Ool00ekg8@Qoo`0MOol2<HakOol0
06Yoo`03DY@@Q7oo02Aoo`038@QBU7oo019oo`03G_LQ27oo01eoo`8aS7]oo`00JWoo00=BU124Ool0
97oo00<Q25:DOol04Woo00=Nmb48Ool07Goo0S6<Ngoo001ZOol00eJe249oo`0TOol00b48E[Eoo`0B
Ool00ekg8@Qoo`0MOol00cF]:DYoo`1jOol006Yoo`03DY@@Q7oo02Aoo`038@QBU7oo019oo`03G_LQ
27oo01eoo`8aS7]oo`00JWoo00=BU124Ool097oo00<Q25:DOol04Woo00=Nmb48Ool07Goo0S6<Ngoo
001ZOol00e:D48Aoo`0TOol00b48DYAoo`0BOol00ekg8@Qoo`0MOol2<HakOol006Yoo`03DY@@Q7oo
02Aoo`038@QBU7oo019oo`03G_LQ27oo01eoo`8aS7]oo`00JWoo00=BU124Ool097oo00<Q23W>G_L0
4Ukg00=6<B48Ool07Goo0S6<Ngoo001ZOol00e:D48Aoo`0TOol00cW>8@PQ200C8@P00cW>Oomoo`0L
Ool2<HakOol006Yoo`03DY@@Q7oo05Uoo`8aS7]oo`00JWoo00=BU124Ool0FGoo0S6<Ngoo001ZOol0
0e:D48Aoo`1IOol2<HakOol006Yoo`03DY@@Q7oo05Uoo`8aS7]oo`00JWoo00=BU124Ool0FGoo0S6<
Ngoo001ZOol00e:D48Aoo`1IOol2<HakOol006Yoo`03DY@@Q7oo05Uoo`8aS7]oo`00JWoo00=BU124
Ool0FGoo0S6<Ngoo001ZOol00e:D48Aoo`1IOol2<HakOol006Yoo`03DY@@Q7oo05Uoo`8aS7]oo`00
JWoo00=BU124Ool0FGoo0S6<Ngoo001ZOol00e:D48Aoo`1IOol2<HakOol006Yoo`03DY@@Q7oo05Uo
o`8aS7]oo`00JWoo00=BU124Ool0FGoo0S6<Ngoo001ZOol00e:D48Aoo`1IOol2<HakOol006Uoo`05
MkeBU124Oomg_@1HOol2<HakOol006Uoo`03IcUBU124009g_EQoo`8aS7]oo`00JGoo00ABU3W>48@i
cUUoo`8aS7]oo`00JGoo00AF]@00000HaUUoo`8aS7]oo`00JGoo00Ag_@00000YBUUoo`8aS7]oo`00
IGoo0WNm0goo00<8@P00BU80FGoo0S6<Ngoo001UOol00ekgDYAoo`02Ool00bU:001F]@1IOol2<Hak
Ool0039oo`03MkeNmekg01ANm`03Mkeoogoo01Qoo`04@Q0YBR48>Lh2Ool00cW>001g_@0POol00e:D
8@PQ200K8@P00bU:Oomoo`0HOol2<H`KOolFG_L00fmkOomoo`17Ool0039oo`04G_L001245:DB48@0
0`00Kg]oo`0IOol017NmCW=246mk0Woo00=F]@Q2Ool087oo00=2436<G_L06Ukg00=>La24Ool06Goo
0S6<6goo00<0012448@00a2400<8@Q2448@0312400<8@U:DOol0B7oo000bOol00ekg8@Qoo`0COol0
0a24Kg]oo`0JOol00fmkG_Moo`02Ool00fmk:DYoo`0POol2@Q0KOol00fmk48Aoo`0IOol2<H`KOol0
0`00Oomoo`0BOol00c6<DYAoo`18Ool0039oo`03G_LQ27oo01=oo`0348A_Ngoo021oo`03@Q1oogoo
01moo`9241]oo`03Kg/@Q7oo01Uoo`8aS1]oo`03001oogoo019oo`03<HaBU7oo04Qoo`00<Woo00=N
mb48Ool04goo00<@Q6mkOol07Goo00Mg_Ekg<H`Q22U:DYA_N`0NOol2@Q0KOol00fmk48Aoo`0IOol2
<H`KOol00`00Oomoo`0BOol00c6<DYAoo`0KOol01VLi@Q0YBRU:@Q1W>BMoo`00<Woo00=Nmb48Ool0
4goo00<@Q6mkOol077oo00AF]AS648@aS08icP036<H8@T8@01eoo`9241]oo`03Kg/@Q7oo01Uoo`8a
S1]oo`03001oogoo019oo`03<HaBU7oo01Uoo`0:Kg/aS0Q2:DXicT8@:DX002U:MkdUOol0039oo`03
G_LQ27oo01=oo`0348A_Ngoo01]oo`03E[D8@T8@00E_N`03G_L8@S6<01aoo`9241]oo`03Kg/@Q7oo
01Uoo`8aS1]oo`03001oogoo019oo`03<HaBU7oo01Qoo`03Mkd@Q2U:00E_N`04IcTQ21S6MkdTOol0
039oo`03G_LQ27oo01=oo`0348A_Ngoo01Yoo`03MkdHaT8@00M_N`03G_L8@Ukg01]oo`92419oo`03
8@QW>Goo00Ioo`03Kg/@Q7oo01Uoo`8aS1]oo`03001oogoo019oo`03<HaBU7oo01Qoo`03<H`Q26mk
00M_N`036<HicWoo02=oo`00<Woo00=Nmb48Ool01Woo0ekg00=_NgooOol01goo00<@Q6mkOol06Woo
00=:DQS6Kg/026mk00=241S6Ool06Woo0T8@17oo00Ag_FmkKg]g_@9oo`9_N`08Oom_NgNmKg]oogNm
OomBU0Moo`03Kg/@Q7oo01Uoo`8aS1]oo`03001oogoo00Ioo`03MkeBU5Je00Uoo`03<HaBU7oo01Mo
o`03Kg/@Q6Li00Q_N`03G_L006mk02=oo`005goo00A_NbU:8@QNm`eoo`04Kg]:DUJeIcT6Ool00ekg
8@Qoo`06Ool01E:D6<Ig_@Q2IcT027oo00<@Q6mkOol047oo00=NmfmkOol01goo00<YBT8@Kg/02Fmk
00<8@WooOol03goo00Ag_FLiIcUg_@Ioo`9240Aoo`0AMkdQ26mk@Q1BU6Li<Ha:DVmk:DY_NbU:BU9F
]GooBU9F]@06Ool00fmk48Aoo`0HOol015kg8@PHaWNm3goo00A_NekgIcUg_@Moo`03001oogoo00Eo
o`05IcTQ27NmOomF]@08Ool00c6<DYAoo`0=Ool00ekgKg]oo`07Ool00e:D8@Q_N`09Kg/00aS6DYAo
o`0BOol01Ekg<HaBU5kgMkd02goo0004Ool00fLiG_MNm`0@G_L01A24000000Q2E[D03Ekg00]>L`00
000@Q248@Q1F]FLiOomNmb4800Moo`05DY@Q27Nm48AW>@08Ool00a24Kg]oo`0AOol01S6<48@Q23W>
E[EW>@=oo`036<I>Lfmk00U_N`03249W>Goo015oo`08BU800248<HaBU6LiMkeoo`9240Eoo`0@<Hao
ogoo:DY245kgKg]g_C6<OomNmdYBG_Mg_C6<IcT6Ool00fmk48ANm`0GG_L01DYB000000006<H045kg
00QF]A24000HaRU:BU9NmgNm0Woo00<007ooOol01Goo00<aS2U:Ool02Woo00<aS5:DOol03Woo00La
S1248@PicUJeIcUg_@02Ool00d8@<Ha_N`09Kg/2:DXADY@015JeDYABU48@0`0000DHaRU:BU9NmgNm
00Ioo`0017oo00<Q20000000:P0000<Q248@8@P01goo00AF]ABU=Je:DPUoo`035:D0000001L00005
248YBTYB5:EF]@0:Mkd00`005:DDY@095:D00`aS5:DDY@065:D600000b485:E24005Ool043F]Oomo
obU:G_MF]CF]JeXe[Goo@Q1F]F]JAS5F]Ekg1Woo00=g_@000000=00000<Q248@00001goo00<e[BU:
Ool02Woo00<e[B48:DX03bU:1P0000@YBT8@=Jde[@Yg_@03:DX0000001T00004248DYCF]JeX5Ool0
00Aoo`03IcUNmekg011Nm`0524800000249>L`0=G_L02dYB0008@QS6:DYBU5kgMkeooekg8@P01goo
00EBU248Mkd007Nm00Qoo`0348@aS36<00haS004:DXaS36<6<H2000020Q26<HYBTYBG_M_NbU:@Q09
Kg/00fLi248aS00:<H`00cF]<H`aS005<H`02QS6000000Q28@PaS4YBIcTicT8@1Goo00XaS7ooOolH
aWNmIcUNmgoo<Haoo`9W>@05OomF]FmkKg]g_@05Ool00fmk48ABU00GDY@00b4800000002000ADY@0
2RU:000001S6:DY245kgKg]oo`001goo00EJeQS6Oomooe:D00Qoo`03<H`HaR4800hQ200;48@00000
248DYBU:>LiNmfLiDY@HaP0:Kg/00aS6BU9_N`0@Kg/02V]JKg]_Nc6<248Q236<DYANmgNm27oo000G
Ool015:D48@8@SW>3Goo00=_NekgIcT01goo00=Nmb48Ool01Woo00A:DRU:CW=:DPUoo`0348A_Ngoo
00moo`05MkeW>CW>DYAW>@06Ool00e:D6<I_N`08Kg/00cW>8@Qoo`0AOol015kg>LiF]FLi1Goo0T8@
17oo00Eg_BU:G_M246Li00Aoo`03>Lioogoo00]oo`03Kg/@Q7oo01Moo`05MkdDY@00001BU00?Ool0
1GNmDYABU5kgMkd01Woo00<007ooOol01Woo00ABU5JeDY@icPQoo`03<HaBU7oo00eoo`05IcU245:D
IcUg_@05Ool00gNm249Nm`08Kg/00eJe001g_@0COol00ekgIcUoo`0=Ool001Qoo`03<H`Q27oo01Mo
o`03G_LQ27oo01=oo`0348A_Ngoo01Yoo`03MkdHaSW>00M_N`03G_L8@VLi01]oo`9241]oo`03Kg/@
Q7oo01Uoo`03IcU_Ngoo01Yoo`03001oogoo019oo`03<HaBU7oo01Qoo`03>LhHaVmk00I_N`03IcTH
aT8@02Aoo`0067oo00<aS248Ool05goo00=Nmb48Ool04goo00<@Q6mkOol05goo00PicWooOomoofmk
48@aS6Li16mk00=F]@Q2@Q004goo00=g_GooOol01Woo0T8@6goo00=_Na24Ool037oo00E_NgooOomo
ofLi02Eoo`03001oogoo019oo`03<HaBU7oo01Aoo`03G_MW>Goo009oo`03:DXQ25kg00A_N`04G_LH
aQS6MkdTOol000ioo`03Mkeoogoo00Moo`03<H`Q27oo01Moo`03G_LQ27oo01=oo`0348A_Ngoo01Eo
o`05MkeNmaS6G_M_N`02Ool01WNm8@P8@RU:>LhaS08@Q003G_Moogoo00Eoo`03Kg]W>Goo00Yoo`9_
N`Moo`9241]oo`03Kg/@Q7oo00Moo`0;G_M_Nd8@IcU:DWooF]IW>EJeMke:DP0TOol00`00Oomoo`0B
Ool00c6<DYAoo`0COol016Li>Li6<FLi0goo00TicQ246<HicS6<8@P0048@Mkd03goo0U[F57oo0009
Ool01GNmOomoogooBU8017oo00=W>FmkOol00goo00<aS248Ool05goo00=Nmb48Ool04goo00<@Q6mk
Ool05Goo00E_Nd8@48A246<H00Aoo`05IcU2436<@Q1F]@05Ool02EkgDY@HaTYBDYAood8@Kg/icP02
Ool0248@Oomoofmk<Hag_Goo<H`7Ool2@Q0KOol00fmk48Aoo`07Ool02gNm>LhQ27Nm@Q1ood8@>Lig
_Goo>Lh097oo00<007ooOol04Woo00<aS5:DOol04goo00A:DRU:<HaBU0Aoo`06Kg]BU3W><HaBU6mk
4Goo00=JeUkgKg/00Woo00IBU7ooOomg_GooDY@;Ool000Qoo`06IcT@Q48@:DYNmfLi0UJe00@icV]J
OolicPAoo`03<H`Q27oo01Moo`03G_LQ27oo01=oo`0348A_Ngoo01Moo`038@Qoogoo00moo`0?@Q0Q
27oo>Liooe:D<Hag_FLiE[DYBU:DKg]ooc6<009oo`03@Q1g_Goo00Eoo`9241]oo`03Kg/@Q7oo00Mo
o`0;Mkd@Q5:DKg]247ooBU9F]GNmOolicP0TOol00`00Oomoo`0BOol00c6<DYAoo`0DOol00e:DG_Mo
o`06Ool00fLiE[Eoo`02Ool00f<HMkeoo`0>Ool02ekgBU9ood8@Kg]BU6Li<Ha_NfLiG_L02Woo0008
Ool02Ekg8@QBU36<@Q1_Ngoo<HaJeP02Ool00c6<Oomoo`02Ool00c6<8@Qoo`0GOol00ekg8@Qoo`0C
Ool00a24Kg]oo`0XOol046mk249:DWNm@Q1oofmk@Q1F]FmkMkdicVmkMkeooc6<0Woo00<icWNmOol0
1Goo0T8@6goo00=_Na24Ool01goo00]BU2U:DYA_NdYBOom_Ne:DIcUoocW>02Aoo`03001oogoo019o
o`03<HaBU7oo01eoo`03DYA247oo009oo`03@Q1_Ngoo00ioo`0;8@PaS7oo5:Eoofmk<HaF]GooKg]2
400:Ool000Qoo`0<G_LQ25:D<HaBU6LiOom245JeG_MoocW>17oo00<aS248Ool05goo00=Nmb48Ool0
4goo00<@Q6mkOol0:7oo00a_Ne:DKg]W>DYBMkeoodYBKg]g_GooDY@3Ool0136<Oomood8@1goo0T8@
6goo00=_Na24Ool02goo00MBU6mkOom247ooKg]W>@0TOol00`00Oomoo`0BOol00c6<DYAoo`0MOol0
23W><Haoogoo8@P8@QS6@Q0=Ool01Fmk249W>Ekg5:D00Woo00E:DUkgMke_Ne:D00Yoo`0027oo00a_
NfLiKg]W>FmkDYAooe:DKg]oogNmF]H4Ool00c6<8@Qoo`0GOol00ekg8@Qoo`0COol00a24Kg]oo`0]
Ool00dicOom:DP06Ool01GNm@Q1oofLiMkd01goo0T8@6goo00=_Na24Ool037oo0WNm00=W>GooMkd0
9Goo00<007ooOol04Woo00<aS5:DOol07Goo0QS60goo00=246mkOol03Goo00Q_NekgKg]W>EkgF]Io
od8@0Woo00=BU7NmOol02Goo000=Ool01VmkMkeNme[FOomNm`Eoo`03<H`Q27oo01Moo`04G_L00124
5:DB48@00`00Kg]oo`12Ool00d8@:DYBU00ADY@00dYBDYABU006DY@00dYB48Aoo`0fOol00`0048@@
Q00348@00`Q248@@Q00<48@00`Q2DYAoo`0MOol00`Q2001g_@02Ool00fmkMkeoo`0BOol01UkgOomN
mfLiMke_N`]oo`0067oo00<aS248Ool05goo00=g_EkgG_L055kg00=g_GooOol0@Goo00=BU2488@P0
6b4800<YBWooOol0=Goo5Ukg00=_NgooOol06goo00AW>@00001W>BQoo`0067oo00<aS248Ool0o7oo
00ABU000001BU2Qoo`0067oo00<aS248Ool0o7oo00@icP00000icRQoo`0067oo00<aS248Ool0o7oo
00@icQS6:DXaS2Qoo`0067oo00<aS248Ool0o7oo00AS6248<HaW>BQoo`0067oo00<aS248Ool0o7oo
00=g_B48<H`0:Goo000HOol00c6<8@Qoo`3mOol00b48<Haoo`0XOol001Qoo`03<H`Q27oo0?eoo`03
8@PaS7oo02Qoo`0067oo00<aS248Ool0oGoo00<Q236<Ool0:7oo000HOol00c6<8@Qoo`3mOol00b48
<Haoo`0XOol001Qoo`03<H`Q27oo0?eoo`038@PaS7oo02Qoo`0067oo00<aS248Ool0oGoo00<Q236<
Ool0:7oo000HOol00c6<8@Qoo`3mOol00b48<Haoo`0XOol001Qoo`03<H`Q27oo0?eoo`038@PaS7oo
02Qoo`0067oo00<aS248Ool0oGoo00<Q236<Ool0:7oo000HOol00c6<8@Qoo`3mOol00b48<Haoo`0X
Ool001Qoo`03<H`Q27oo0?eoo`038@PaS7oo02Qoo`0067oo00<aS248Ool0oGoo00<Q236<Ool0:7oo
000HOol00c6<8@Qoo`3mOol00b48<Haoo`0XOol001Qoo`03<H`Q27oo0?eoo`038@PaS7oo02Qoo`00
67oo00<aS248Ool0oGoo00<Q236<Ool0:7oo000HOol00c6<8@Qoo`3mOol00b48<Haoo`0XOol001Qo
o`03<H`Q27oo07IooaH00003@Q1oogoo06ioo`038@PaS7oo02Qoo`0067oo00<aS248Ool0MWoo00<0
06LiKg/03Fmk00=[FVmkKg/00Vmk00<aS48@Ool0Kgoo00<Q236<Ool0:7oo000HOol00c6<8@Qoo`1f
Ool00`00Kg]oo`0BOol00c6<@Q1oo`1_Ool00b48<Haoo`0XOol001Qoo`03<H`Q27oo07Ioo`03001_
Ngoo019oo`03<Ha247oo06moo`038@PaS7oo02Qoo`0067oo00<aS248Ool0MWoo00<006mkOol04Woo
00<aS48@Ool0Kgoo00<Q236<Ool0:7oo000HOol00c6<8@Qoo`1fOol00`00Kg]oo`0BOol00c6<@Q1o
o`1_Ool00b48<Haoo`0XOol001Qoo`03:DXQ27oo07Ioo`03001[FWoo019oo`03:DY247oo06moo`03
8@PYBWoo02Qoo`0067oo00<aS248Ool0MWoo00<006mkOol04Woo00<aS48@Ool0Kgoo00<Q236<Ool0
:7oo000HOol00c6<8@Qoo`1fOol00`00Kg]oo`05Ool01DYB:DYF]DYBMkd027oo00<aS48@Ool0Kgoo
00<Q236<Ool0:7oo000HOol00c6<8@Qoo`1/Ool00fmkG_M_N`07Ool00`00Kg]oo`05Ool01E:D48Ao
ocW>@Q0027oo00<aS48@Ool0Kgoo00<Q236<Ool0:7oo000HOol00c6<6<INm`1]G_L01d8@248@Q2U:
>LiNmfmk009oo`03001_Ngoo00Eoo`05DY@@Q7ooDY@Q2008Ool2<Ha`G_L00aS6<Haoo`0XOol001Qo
o`03<H`0000007@0000448@icP00Kg/6Ool01E:D48AoodYB<H`027oo00<aS0000000L00000<aS7oo
Ool09goo0028Ool01fLi2488@QS6>Li:DVLi009oo`03001_Ngoo00Eoo`05@Q08@UJe8@QW>@08Ool0
0c6<@Q1oo`2JOol008Moo`03Kg]F]Fmk00Moo`03001_Ngoo019oo`03<Ha247oo09Yoo`00TGoo00<0
06mkOol04Woo00<aS48@Ool0VWoo002AOol00`00Kg]oo`0BOol00c6<@Q1oo`2JOol0095oo`03001_
Ngoo019oo`03<Ha247oo09Yoo`00TGoo00<006mkOol04Woo00<aS48@Ool0VWoo002AOol00`00Kg]o
o`0BOol00c6<@Q1oo`2JOol0095oo`03001_Ngoo019oo`03<Ha247oo09Yoo`00TGoo00<006mkOol0
4Woo00<aS48@Ool0VWoo002AOol00`00>Li2400B@Q000aS6@Q1oo`2JOol0095ooaI24003HaQoogoo
09Uoo`00ogooA7oo003oOom4Ool00?moodAoo`00\
\>"],
  CellTags->"3.2"],

Cell[TextData[{
  StyleBox["Figure 3.2.",
    FontWeight->"Bold"],
  " ",
  "State\[Hyphen]space model of a discrete\[Hyphen]time system."
}], "Caption",
  CellTags->"3.2"],

Cell[TextData[{
  "The ",
  StyleBox["StateSpace", "MR"],
  " objects can contain as few as two matrices ",
  StyleBox["a", "TI"],
  " and ",
  StyleBox["b", "TI"],
  ", but for most functions, at least matrix ",
  StyleBox["c", "TI"],
  " and optionally ",
  StyleBox["d", "TI"],
  " are required too. If matrices ",
  StyleBox["c", "TI"],
  " and ",
  StyleBox["d", "TI"],
  " are absent, no assumptions are made about them; if only matrix ",
  StyleBox["d", "TI"],
  " is absent, it is routinely assumed to be a zero matrix. The truncated ",
  StyleBox["StateSpace[", "MR"],
  StyleBox["a", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["b", "TI"],
  StyleBox["]", "MR"],
  " representation is, of course, of limited value, but contains all the \
necessary information, for instance, for feedback regulator design. "
}], "Text",
  CellTags->"3.2"],

Cell["\<\
Here is a second\[Hyphen]order SISO system with no direct \
transition term. \
\>", "MathCaption",
  CellTags->"3.2"],

Cell["\<\
StateSpace[{{a1, a2}, {a3, a4}}, {{b1}, {b2}},
 {{c1, c2}}]\
\>", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"3.2"],

Cell[BoxData[
    \(StateSpace[{{a1, a2}, {a3, a4}}, {{b1}, {b2}}, {{c1, c2}}]\)], "Output",\

  CellLabel->"Out[22]= ",
  CellTags->"3.2"],

Cell["\<\
This is the same system with a zero direct transition term added. \
\
\>", "MathCaption",
  CellTags->"3.2"],

Cell["\<\
StateSpace[{{a1, a2}, {a3, a4}}, {{b1}, {b2}},
 {{c1, c2}}, {{0}}]\
\>", "Input",
  CellLabel->"In[23]:= ",
  CellTags->"3.2"],

Cell[BoxData[
    \(StateSpace[{{a1, a2}, {a3, a4}}, {{b1}, {b2}}, {{c1, c2}}, {{0}}]\)], 
  "Output",
  CellLabel->"Out[23]= ",
  CellTags->"3.2"],

Cell["\<\
The two systems yield the same transfer function and so correspond \
to the same physical system. \
\>", "MathCaption",
  CellTags->"3.2"],

Cell["SameQ @@ TransferFunction /@ {%, %%}", "Input",
  CellLabel->"In[24]:= ",
  CellTags->"3.2"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[24]= ",
  CellTags->"3.2"],

Cell[TextData[{
  "The state\[Hyphen]space representation can be obtained directly from the \
differential equations of the system (difference equations in the case of a \
discrete\[Hyphen]time system) or from the transfer matrix. In the latter \
case, the state\[Hyphen]space model is constructed in the ",
  StyleBox["controllable companion", "TI"],
  " form by inspection. The adopted definition of the controllable companion \
form is due to, for example, Gopal (1993). (In the literature, this form is \
sometimes referred to as the ",
  StyleBox["controllable canonical", "TI"],
  " form.) For the strictly proper transfer matrix "
}], "Text",
  CellTags->"3.2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["\<\"H\"\>",
          "TB"], \((s)\), "=", 
        FractionBox[
          RowBox[{
            SubscriptBox[
              StyleBox["\<\"c\"\>",
                "TB"], "1"], \(s\^\(n - 1\)\), "+", 
            SubscriptBox[
              StyleBox["\<\"c\"\>",
                "TB"], "2"], \(s\^\(n - 2\)\), "+", 
            \(\(\[CenterEllipsis]\)\(\ \)\), "+", 
            SubscriptBox[
              StyleBox["\<\"c\"\>",
                "TB"], "n"]}], 
          \(s\^n + \(a\_1\) s\^\(n - 1\) + \(\(\[CenterEllipsis]\)\(\ \)\) + 
            a\_n\)]}], TraditionalForm]], "DisplayFormula",
  CellTags->"3.2"],

Cell[TextData[{
  "of size ",
  Cell[BoxData[
      \(TraditionalForm\`q\[Cross]p\)], "InlineFormula",
    CellTags->"S0.0.3"],
  ", where ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\<\"c\"\>",
            "TB"], "i"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " are of that size as well, ",
  Cell[BoxData[
      \(TraditionalForm\`p\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`q\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " being the number of inputs and outputs, respectively, the controllable \
companion realization is assumed to be "
}], "Text",
  CellTags->"3.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              OverscriptBox[
                StyleBox["\<\"x\"\>",
                  "TB"], "."],
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
                RowBox[{"[", GridBox[{
                      {
                        StyleBox["\<\"0\"\>",
                          "TB"], 
                        StyleBox["\<\"I\"\>",
                          "TB"], 
                        StyleBox["\<\"0\"\>",
                          "TB"], 
                        StyleBox["\[CenterEllipsis]",
                          "DisplayFormula"], 
                        StyleBox["\<\"0\"\>",
                          "TB"]},
                      {
                        StyleBox["\<\"0\"\>",
                          "TB"], 
                        StyleBox["\<\"0\"\>",
                          "TB"], 
                        StyleBox["\<\"I\"\>",
                          "TB"], 
                        StyleBox["\[CenterEllipsis]",
                          "DisplayFormula"], 
                        StyleBox["\<\"0\"\>",
                          "TB"]},
                      {
                        StyleBox["\[VerticalEllipsis]",
                          "DisplayFormula"], 
                        StyleBox["\[VerticalEllipsis]",
                          "DisplayFormula"], 
                        StyleBox["\[VerticalEllipsis]",
                          "DisplayFormula"], 
                        StyleBox["\[Null]",
                          "DisplayFormula"], 
                        StyleBox["\[VerticalEllipsis]",
                          "DisplayFormula"]},
                      {
                        StyleBox["\<\"0\"\>",
                          "TB"], 
                        StyleBox["\<\"0\"\>",
                          "TB"], 
                        StyleBox["\<\"0\"\>",
                          "TB"], 
                        StyleBox["\[CenterEllipsis]",
                          "DisplayFormula"], 
                        StyleBox["\<\"I\"\>",
                          "TB"]},
                      {
                        StyleBox[
                          RowBox[{"-", \(a\_n\), 
                            StyleBox["\<\"I\"\>",
                              "TB"]}],
                          "DisplayFormula"], 
                        StyleBox[
                          RowBox[{"-", \(a\_\(n - 1\)\), 
                            StyleBox["\<\"I\"\>",
                              "TB"]}],
                          "DisplayFormula"], 
                        StyleBox[
                          RowBox[{"-", \(a\_\(n - 2\)\), 
                            StyleBox["\<\"I\"\>",
                              "TB"]}],
                          "DisplayFormula"], 
                        StyleBox["\[CenterEllipsis]",
                          "DisplayFormula"], 
                        StyleBox[
                          RowBox[{"-", \(a\_1\), 
                            StyleBox["\<\"I\"\>",
                              "TB"]}],
                          "DisplayFormula"]}
                      },
                    ColumnAlignments->{Center}], "]"}], 
                StyleBox["\<\"x\"\>",
                  "TB"], "+", 
                RowBox[{"[", GridBox[{
                      {
                        StyleBox["\<\"0\"\>",
                          "TB"]},
                      {
                        StyleBox["\<\"0\"\>",
                          "TB"]},
                      {
                        StyleBox["\[VerticalEllipsis]",
                          "DisplayFormula"]},
                      {
                        StyleBox["\<\"0\"\>",
                          "TB"]},
                      {
                        StyleBox["\<\"I\"\>",
                          "TB"]}
                      },
                    ColumnAlignments->{Center}], "]"}], 
                StyleBox["\<\"u\"\>",
                  "TB"]}],
              "DisplayFormula"]},
          {
            StyleBox["\<\"y\"\>",
              "TB"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
                RowBox[{"[", GridBox[{
                      {
                        StyleBox[
                          SubscriptBox[
                            StyleBox["\<\"c\"\>",
                              "TB"], "n"],
                          "DisplayFormula"], 
                        StyleBox[
                          SubscriptBox[
                            StyleBox["\<\"c\"\>",
                              "TB"], \(n - 1\)],
                          "DisplayFormula"], 
                        StyleBox[
                          SubscriptBox[
                            StyleBox["\<\"c\"\>",
                              "TB"], \(n - 2\)],
                          "DisplayFormula"], 
                        StyleBox["\[CenterEllipsis]",
                          "DisplayFormula"], 
                        StyleBox[
                          SubscriptBox[
                            StyleBox["\<\"c\"\>",
                              "TB"], "1"],
                          "DisplayFormula"]}
                      },
                    ColumnAlignments->{Center}], "]"}], 
                StyleBox["\<\"x\"\>",
                  "TB"], "+", 
                StyleBox["\<\"D\"\>",
                  "TB"], 
                StyleBox["\<\"u\"\>",
                  "TB"]}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->"3.2"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"0\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"I\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " are zero and identity matrices of size ",
  Cell[BoxData[
      \(TraditionalForm\`p\[Cross]p\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " and the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"D\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " is zero. The dimension of the system is ",
  Cell[BoxData[
      \(TraditionalForm\`n  p\)], "InlineFormula",
    CellTags->"S0.0.3"],
  ". If the transfer matrix ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"H\"\>",
            "TB"], \((s)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " is proper (but not strictly proper), the same representation of the \
strictly proper part of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"H\"\>",
            "TB"], \((s)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " holds while the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"D\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " can be found as "
}], "Text",
  CellTags->"3.2"],

Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["\<\"D\"\>",
          "TB"], "=", 
        StyleBox["\<\"H\"\>",
          "TB"], \((\[Infinity])\)}], TraditionalForm]], "DisplayFormula",
  CellTags->"3.2"],

Cell["\<\
Note that the controllable form may not be of minimal order and, as \
a rule, is ill\[Hyphen]conditioned. Chapter\[NonBreakingSpace]8 describes the \
methods to transform the model further. \
\>", "Text",
  CellTags->"3.2"],

Cell["Here is a transfer function. ", "MathCaption",
  CellTags->"3.2"],

Cell["tf = TransferFunction[s, {{1/(s-a), 1/(s-b)}}]", "Input",
  CellLabel->"In[25]:= ",
  CellTags->"3.2"],

Cell[BoxData[
    \(TransferFunction[s, {{1\/\(\(-a\) + s\), 1\/\(\(-b\) + s\)}}]\)], 
  "Output",
  CellLabel->"Out[25]= ",
  CellTags->"3.2"],

Cell["This produces the controllable companion realization. ", "MathCaption",
  CellTags->"3.2"],

Cell["StateSpace[%]", "Input",
  CellLabel->"In[26]:= ",
  CellTags->"3.2"],

Cell[BoxData[
    \(StateSpace[
      {{0, 0, 1, 0}, {0, 0, 0, 1}, {\(-a\)\ b, 0, a + b, 0}, 
        {0, \(-a\)\ b, 0, a + b}}, {{0, 0}, {0, 0}, {1, 0}, {0, 1}}, 
      {{\(-b\), \(-a\), 1, 1}}]\)], "Output",
  CellLabel->"Out[26]= ",
  CellTags->"3.2"],

Cell[TextData[{
  "The structure of the state\[Hyphen]space system is more transparent with \
the use of ",
  StyleBox["ReviewForm", "MR"],
  " (see the next section). Clearly, this is not the minimal\[Hyphen]order \
model. "
}], "MathCaption",
  CellTags->"3.2"],

Cell["ReviewForm[%]", "Input",
  CellLabel->"In[27]:= ",
  CellTags->"3.2"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "0", "1", "0"},
                  {"0", "0", "0", "1"},
                  {\(\(-a\)\ b\), "0", \(a + b\), "0"},
                  {"0", \(\(-a\)\ b\), "0", \(a + b\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "0"},
                  {"0", "0"},
                  {"1", "0"},
                  {"0", "1"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(-b\), \(-a\), "1", "1"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[27]//ReviewForm= ",
  CellTags->"3.2"],

Cell["\<\
This reduces the order of the system. To obtain a simpler result, \
we assert that none of the symbolic variables are complex. \
\>", 
  "MathCaption",
  CellTags->"3.2"],

Cell["\<\
MinimalRealization[%, ComplexVariables -> None]//
 Simplify //ReviewForm\
\>", "Input",
  CellLabel->"In[28]:= ",
  CellTags->"3.2"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"a", "0"},
                  {"0", "b"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(-\(\(\@\(1 + 1\/b\^2\)\ b\)\/\(1 + b\^2\)\)\), "0"},
                  {"0", \(-\(\(\@\(1 + 1\/a\^2\)\ a\)\/\(1 + a\^2\)\)\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  
                  {\(\(-\@\(1 + 1\/b\^2\)\)\ b\), 
                    \(\(-\@\(1 + 1\/a\^2\)\)\ a\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[28]//ReviewForm= ",
  CellTags->"3.2"],

Cell["\<\
It is easy to demonstrate that the preceding result corresponds to \
the initial system. \
\>", "MathCaption",
  CellTags->"3.2"],

Cell["TransferFunction[s, %]//Simplify", "Input",
  CellLabel->"In[29]:= ",
  CellTags->"3.2"],

Cell[BoxData[
    \(TransferFunction[s, {{1\/\(\(-a\) + s\), 1\/\(\(-b\) + s\)}}]\)], 
  "Output",
  CellLabel->"Out[29]= ",
  CellTags->"3.2"],

Cell[TextData[{
  "By itself, ",
  StyleBox["StateSpace", "MR"],
  " does not check the consistency of component matrices; however, \
consistency ",
  StyleBox["is", "TI"],
  " the prerequisite for many other functions to operate in a meaningful way. \
Consistency here means that matrix ",
  StyleBox["a", "TI"],
  " must be square, ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Cross]n\)], "InlineFormula",
    CellTags->"S0.0.3"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " is the number of states; matrix ",
  StyleBox["b", "TI"],
  " must be ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Cross]p\)], "InlineFormula",
    CellTags->"S0.0.3"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`p\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " is the number of inputs; matrix ",
  StyleBox["c", "TI"],
  " must be ",
  Cell[BoxData[
      \(TraditionalForm\`q\[Cross]n\)], "InlineFormula",
    CellTags->"S0.0.3"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`q\)], "InlineFormula",
    CellTags->"S0.0.3"],
  " is the number of outputs; and matrix ",
  StyleBox["d", "TI"],
  ", if used, must be ",
  Cell[BoxData[
      \(TraditionalForm\`q\[Cross]p\)], "InlineFormula",
    CellTags->"S0.0.3"],
  ". When entering state\[Hyphen]space objects manually, these requirements \
should be kept in mind. The function ",
  StyleBox["ConsistentQ", "MR"],
  " checks that they are satisfied. \nAs will be referenced later, ",
  StyleBox["StateSpace", "MR"],
  " as well as other control objects can accept options, which could, if so \
desired, come wrapped in lists. Therefore, caution should be exercised to not \
confuse an empty list of options with an empty matrix in control object's \
description. For this reason, parsing an empty list as a valid list of \
options is disallowed for all control objects. "
}], "Text",
  CellTags->"3.2"],

Cell["3.3 Reviewing Transfer Function and State\[Hyphen]Space Objects", 
  "Subsection",
  CellTags->"3.3"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ReviewForm",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox[\(review\ the\ contents\ of\ the\ state\),
                SingleLetterItalics->False], 
              StyleBox["-",
                SingleLetterItalics->False], 
              StyleBox[\(space\ or\ transfer\),
                SingleLetterItalics->False], 
              StyleBox["-",
                SingleLetterItalics->False], 
              RowBox[{
                StyleBox["function",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["representation",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["of",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["system",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["in",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["traditional",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["matrix",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["notation",
                  SingleLetterItalics->False]}]}]}
          }], NotebookDefault]], "DefinitionBox",
  GeneratedCell->True,
  CellTags->"3.3"],

Cell["Reviewing the matrix content of system data structures. ", "Caption",
  CellTags->"3.3"],

Cell["Here is a state\[Hyphen]space object. ", "MathCaption",
  CellTags->"3.3"],

Cell["\<\
StateSpace[{{a1, a2}, {a3, a4}},
 {{b1}, {b2}}, {{c1, c2}} ]\
\>", "Input",
  CellLabel->"In[30]:= ",
  CellTags->"3.3"],

Cell[BoxData[
    \(StateSpace[{{a1, a2}, {a3, a4}}, {{b1}, {b2}}, {{c1, c2}}]\)], "Output",\

  CellLabel->"Out[30]= ",
  CellTags->"3.3"],

Cell["This represents the component matrices as tables. ", "MathCaption",
  CellTags->"3.3"],

Cell["ReviewForm[%]", "Input",
  CellLabel->"In[31]:= ",
  CellTags->"3.3"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"a1", "a2"},
                  {"a3", "a4"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"b1"},
                  {"b2"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"c1", "c2"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[31]//ReviewForm= ",
  CellTags->"3.3"],

Cell[TextData[{
  StyleBox["ReviewForm", "MR"],
  " provides a convenient formatting of control objects, but does not change \
their internal representation. In this respect, it behave much like ",
  StyleBox["OutputForm", "MR"],
  " or ",
  StyleBox["MatrixForm", "MR"],
  " (and all other members of the ",
  StyleBox["$OutputForms", "MR"],
  " list.) "
}], "Text",
  CellTags->"3.3"],

Cell["\<\
Despite different formatting, the object is the same as before. \
\
\>", "MathCaption",
  CellTags->"3.3"],

Cell["%", "Input",
  CellLabel->"In[32]:= ",
  CellTags->"3.3"],

Cell[BoxData[
    \(StateSpace[{{a1, a2}, {a3, a4}}, {{b1}, {b2}}, {{c1, c2}}]\)], "Output",\

  CellLabel->"Out[32]= ",
  CellTags->"3.3"],

Cell["3.4 Continuous\[Hyphen]Time versus Discrete\[Hyphen]Time Systems", 
  "Subsection",
  CellTags->"3.4"],

Cell[TextData[{
  "The way to attribute the ",
  StyleBox["TransferFunction", "MR"],
  ", ",
  StyleBox["StateSpace", "MR"],
  ", and ",
  StyleBox["ZeroPoleGain", "MR"],
  " objects to the continuous\[Hyphen]time or discrete\[Hyphen]time domain is \
to set the option ",
  StyleBox["Sampled", "MR"],
  " to either ",
  StyleBox["False", "MR"],
  ", ",
  StyleBox["True", "MR"],
  ", or ",
  StyleBox["Period[", "MR"],
  StyleBox["value", "TI"],
  StyleBox["]", "MR"],
  ". Once set, the option remains a part of the data structure. This allows \
the same set of functions to operate on both types of systems implementing an \
object\[Hyphen]oriented paradigm, according to which the method \"knows\" how \
to deal with the object. \nAs with all other ",
  StyleBox["Mathematica", "TI"],
  " options, setting of the option ",
  StyleBox["Sampled", "MR"],
  " is not mandatory. If a function does not find the option in a particular \
control object, it relies on the global variable ",
  StyleBox["$Sampled", "MR"],
  " to make the decision when necessary.  The default value of ",
  StyleBox["$Sampled", "MR"],
  " is ",
  StyleBox["False", "MR"],
  ". Changing the global domain specification makes sense if you deal \
primarily with the discrete\[Hyphen]time systems or, even more restrictively, \
with systems sampled primarily at one rate. If this is the case, you may want \
to change the variable ",
  StyleBox["$Sampled", "MR"],
  " in your ",
  StyleBox["Mathematica", "TI"],
  " session and/or include the corresponding line in your ",
  StyleBox["init.m", "MR"],
  " file. It should be emphasized that relying on the global variable, \
although convenient, may cause confusion if you save the results of your ",
  StyleBox["Mathematica", "TI"],
  " session to a file and later read it in after changing that variable, or \
if you send your file to a colleague who prefers another global value. A \
useful precaution, therefore, is to save the value of ",
  StyleBox["$Sampled", "MR"],
  " together with your data or use the ",
  StyleBox["Sampled", "MR"],
  " option explicitly in all your data structures. "
}], "Text",
  CellTags->"3.4"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox[
                RowBox[{"Sampled", " ", 
                  StyleBox["->",
                    "MR"], " ", 
                  StyleBox["False",
                    "MR"]}],
                "TraditionalForm"],
              "TI"], 
            
            StyleBox[
              \(attributes\ the\ system\ to\ the\ continuous - 
                time\ domain\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox[
                RowBox[{"Sampled", " ", 
                  StyleBox["->",
                    "MR"], " ", 
                  StyleBox["True",
                    "MR"]}],
                "TraditionalForm"],
              "TI"], 
            
            StyleBox[
              \(attributes\ the\ system\ to\ the\ discreet - time\ domain\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox[
                RowBox[{"Sampled", " ", 
                  StyleBox["->",
                    "MR"], " ", 
                  RowBox[{"Period", 
                    StyleBox["[",
                      "MR"], "T", 
                    StyleBox["]",
                      "MR"]}]}],
                "TraditionalForm"],
              "TI"], 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[\(attributes\ the\ system\ to\ the\ continuous\),
                    SingleLetterItalics->False], 
                  StyleBox["-",
                    SingleLetterItalics->False], 
                  StyleBox[" ",
                    SingleLetterItalics->False], 
                  StyleBox[\(or\ discreet\),
                    SingleLetterItalics->False], 
                  StyleBox["-",
                    SingleLetterItalics->False], 
                  RowBox[{
                    StyleBox["time",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["domain",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["depending",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["on",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["the",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["value",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["of",
                      SingleLetterItalics->False], 
                    StyleBox[" ",
                      SingleLetterItalics->False], 
                    StyleBox["T",
                      SingleLetterItalics->False,
                      FontSlant->"Italic"]}]}], 
                StyleBox[";",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                
                StyleBox[
                  \(a\ zero\ value\ refers\ to\ the\ continuous - 
                    time\ domain\),
                  SingleLetterItalics->False]}], 
              StyleBox[",",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              
              StyleBox[
                \(and\ everything\ else\ refers\ to\ the\ discreet - 
                  time\ domain\),
                SingleLetterItalics->False]}]},
          {
            StyleBox[
              FormBox["$Sampled",
                "StandardForm"],
              "Text"], 
            RowBox[{
              StyleBox["global",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["variable",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["that",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["determines",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["domain",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["in",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["which",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["is",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["assumed",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["to",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["be",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["in",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["absence",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Sampled",
                "MR"], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["option",
                SingleLetterItalics->False]}]},
          {
            RowBox[{
              StyleBox["ContinuousTimeQ",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              RowBox[{
                StyleBox["test",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["if",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["system",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["is",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["in",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["the",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["continuous",
                  SingleLetterItalics->False]}], 
              StyleBox["-",
                SingleLetterItalics->False], 
              StyleBox[\(time\ domain\),
                SingleLetterItalics->False]}]},
          {
            RowBox[{
              StyleBox["DiscreteTimeQ",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              RowBox[{
                StyleBox["test",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["if",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["system",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["is",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["in",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["the",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["discrete",
                  SingleLetterItalics->False]}], 
              StyleBox["-",
                SingleLetterItalics->False], 
              StyleBox[\(time\ domain\),
                SingleLetterItalics->False]}]},
          {
            RowBox[{
              StyleBox["SamplingPeriod",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["sampling",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["period",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "DefinitionBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.35, 0.65},
  RowLines->{False, False, True, True, False}},
  CellTags->"3.4"],

Cell["\<\
Options, global variables, and test functions pertaining to domain \
specification. \
\>", "Caption",
  CellTags->"3.4"],

Cell[TextData[{
  "There is no domain\[Hyphen]specifying option in this ",
  StyleBox["StateSpace", "MR"],
  " object, so it is attributed to continuous\[Hyphen]time by default. "
}], "MathCaption",
  CellTags->"3.4"],

Cell["ContinuousTimeQ[StateSpace[a, b, c]]", "Input",
  CellLabel->"In[33]:= ",
  CellTags->"3.4"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[33]= ",
  CellTags->"3.4"],

Cell["\<\
Now the system is explicitly set to be in the discrete\[Hyphen]time \
domain. \
\>", "MathCaption",
  CellTags->"3.4"],

Cell["\<\
ContinuousTimeQ[
 StateSpace[a, b, c, Sampled -> True]
]\
\>", "Input",
  CellLabel->"In[34]:= ",
  CellTags->"3.4"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[34]= ",
  CellTags->"3.4"],

Cell[TextData[{
  "This is another way to attribute the system to the discrete\[Hyphen]time \
domain\[LongDash]by using ",
  StyleBox["Period[", "MR"],
  StyleBox["T", "TI"],
  StyleBox["]", "MR"],
  " with a nonzero value of ",
  StyleBox["T", "TI"],
  ". "
}], "MathCaption",
  CellTags->"3.4"],

Cell["\<\
ContinuousTimeQ[
 StateSpace[a, b, c, Sampled -> Period[T]]
]\
\>", "Input",
  CellLabel->"In[35]:= ",
  CellTags->"3.4"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[35]= ",
  CellTags->"3.4"],

Cell[TextData[{
  "This changes the default domain. From now on the system will be assumed to \
be discrete\[Hyphen]time if not specified otherwise with the ",
  StyleBox["Sampled", "MR"],
  " option (until ",
  StyleBox["$Sampled", "MR"],
  " is changed back). "
}], "MathCaption",
  CellTags->"3.4"],

Cell["$Sampled = Period[1]", "Input",
  CellLabel->"In[36]:= ",
  CellTags->"3.4"],

Cell[BoxData[
    \(Period[1]\)], "Output",
  CellLabel->"Out[36]= ",
  CellTags->"3.4"],

Cell["\<\
The same system as before is now considered to be in the discrete\
\[Hyphen]time domain. \
\>", "MathCaption",
  CellTags->"3.4"],

Cell["ContinuousTimeQ[StateSpace[a, b, c]]", "Input",
  CellLabel->"In[37]:= ",
  CellTags->"3.4"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[37]= ",
  CellTags->"3.4"],

Cell["This restores the default behavior. ", "MathCaption",
  CellTags->"3.4"],

Cell["$Sampled = False", "Input",
  CellLabel->"In[38]:= ",
  CellTags->"3.4"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[38]= ",
  CellTags->"3.4"],

Cell["3.5 Discrete\[Hyphen]Time Models of Continuous\[Hyphen]Time Systems", 
  "Subsection",
  CellTags->"3.5"],

Cell[TextData[{
  "If an analog system is to be analyzed in the discrete\[Hyphen]time domain, \
the problem arises of finding a discrete\[Hyphen]time representation of the \
system such that the output variables sampled at times ",
  Cell[BoxData[
      \(TraditionalForm\`t\_0, t\_1, \[Ellipsis], t\_k, \[Ellipsis]\)], 
    "InlineFormula",
    CellTags->"S0.0.6"],
  " suitably approximate the ones of the original system. A possible way to \
make such a conversion is to apply the function ",
  StyleBox["ToDiscreteTime", "MR"],
  " to a continuous\[Hyphen]time system. ",
  StyleBox["ToDiscreteTime", "MR"],
  " operates on all control objects. Note that the functions ",
  StyleBox["LaplaceTransform", "MR"],
  " and ",
  StyleBox["ZTransform", "MR"],
  " from the standard ",
  StyleBox["Mathematica", "TI"],
  " distribution can, in principle, perform similar task. However, the \
procedures in ",
  StyleBox["Control System Professional", "TI"],
  " use the state\[Hyphen]space approach and so the conversion is, as a rule, \
more efficient.    "
}], "Text",
  CellTags->"3.5"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ToDiscreteTime",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox[\(find\ the\ discreet\),
                SingleLetterItalics->False], 
              StyleBox["-",
                SingleLetterItalics->False], 
              StyleBox[\(time\ approximation\ of\ continous\),
                SingleLetterItalics->False], 
              StyleBox["-",
                SingleLetterItalics->False], 
              RowBox[{
                StyleBox["time",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["system",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["sampled",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["with",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["the",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["default",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["sampling",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["period",
                  SingleLetterItalics->False]}]}]}
          }], NotebookDefault]], "TopBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.34, 0.59}},
  CellTags->"3.5"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ToDiscreteTime",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["system",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox[
                  FormBox[
                    RowBox[{"Sampled", " ", 
                      StyleBox["->",
                        "MR"], " ", 
                      RowBox[{"Period", 
                        StyleBox["[",
                          "MR"], "t", 
                        StyleBox["]",
                          "MR"]}]}],
                    "TraditionalForm"],
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"3.5"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox[\(find\ the\ discrete\),
                SingleLetterItalics->False], 
              StyleBox["-",
                SingleLetterItalics->False], 
              StyleBox[\(time\ approximation\ of\ continuous\),
                SingleLetterItalics->False], 
              StyleBox["-",
                SingleLetterItalics->False], 
              RowBox[{
                StyleBox["time",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["system",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["sampled",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["with",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["period",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["T",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"]}]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  GridBoxOptions->{GridBaseline->Axis,
  ColumnWidths->{0.34, 0.59}},
  CellTags->"3.5"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              FormBox["$SamplingPeriod",
                "StandardForm"],
              "Text"], 
            StyleBox[\(default\ numeric\ value\ of\ sampling\ period\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.34, 0.59}},
  CellTags->"3.5"],

Cell["\<\
Finding discrete\[Hyphen]time equivalents of \
continuous\[Hyphen]time systems. \
\>", "Caption",
  CellTags->"3.5"],

Cell["Consider a simple continuous\[Hyphen]time system. ", "MathCaption",
  CellTags->"3.5"],

Cell["tf = TransferFunction[s, a/(s+a)]", "Input",
  CellLabel->"In[39]:= ",
  CellTags->"3.5"],

Cell[BoxData[
    \(TransferFunction[s, {{a\/\(a + s\)}}]\)], "Output",
  CellLabel->"Out[39]= ",
  CellTags->"3.5"],

Cell[TextData[{
  "This is a possible discrete\[Hyphen]time approximation. As noted \
previously, the formal internal variable (in this case ",
  StyleBox["s", "MR"],
  ") does not indicate the domain, but the ",
  StyleBox["Sampled", "MR"],
  " option does. "
}], "MathCaption",
  CellTags->"3.5"],

Cell["hz = ToDiscreteTime[%, Sampled->Period[T]]", "Input",
  CellLabel->"In[40]:= ",
  CellTags->"3.5"],

Cell[BoxData[
    \(TransferFunction[s, 
      {{\(\(-1\) + E\^\(a\ T\)\)\/\(\(-1\) + E\^\(a\ T\)\ s\)}}, 
      Sampled \[Rule] Period[T]]\)], "Output",
  CellLabel->"Out[40]= ",
  CellTags->"3.5"],

Cell["\<\
Should the need arise, it is easy to rename the formal variable. \
\
\>", "MathCaption",
  CellTags->"3.5"],

Cell["% /. s -> z", "Input",
  CellLabel->"In[41]:= ",
  CellTags->"3.5"],

Cell[BoxData[
    \(TransferFunction[z, 
      {{\(\(-1\) + E\^\(a\ T\)\)\/\(\(-1\) + E\^\(a\ T\)\ z\)}}, 
      Sampled \[Rule] Period[T]]\)], "Output",
  CellLabel->"Out[41]= ",
  CellTags->"3.5"],

Cell["Consider a state\[Hyphen]space continuous\[Hyphen]time system.  ", 
  "MathCaption",
  CellTags->"3.5"],

Cell["\<\
(cont =
 StateSpace[{{0, 1}, {0, -1}}, {{0}, {1}},
 {{1, 0}}]
)//ReviewForm\
\>", "Input",
  CellLabel->"In[42]:=",
  CellTags->"3.5"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "1"},
                  {"0", \(-1\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0"},
                  {"1"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"1", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[42]//ReviewForm=",
  CellTags->"3.5"],

Cell[TextData[{
  "This is its discrete\[Hyphen]time approximation. The result is still a ",
  StyleBox["StateSpace", "MR"],
  " object that is in the discrete\[Hyphen]time domain as indicated by its ",
  StyleBox["Sampled", "MR"],
  " option. "
}], "MathCaption",
  CellTags->"3.5"],

Cell["disc = ToDiscreteTime[%, Sampled->Period[tau]]", "Input",
  CellLabel->"In[43]:=",
  CellTags->"3.5"],

Cell[BoxData[
    \(StateSpace[{{1, E\^\(-tau\)\ \((\(-1\) + E\^tau)\)}, {0, E\^\(-tau\)}}, 
      {{E\^\(-tau\)\ \((1 - E\^tau + E\^tau\ tau)\)}, 
        {E\^\(-tau\)\ \((\(-1\) + E\^tau)\)}}, {{1, 0}}, 
      Sampled \[Rule] Period[tau]]\)], "Output",
  CellLabel->"Out[43]=",
  CellTags->"3.5"],

Cell[TextData[{
  "Here is same system in ",
  StyleBox["ReviewForm", "MR"],
  ". "
}], "MathCaption",
  CellTags->"3.5"],

Cell["ReviewForm[%]", "Input",
  CellLabel->"In[44]:=",
  CellTags->"3.5"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"1", \(E\^\(-tau\)\ \((\(-1\) + E\^tau)\)\)},
                  {"0", \(E\^\(-tau\)\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(E\^\(-tau\)\ \((1 - E\^tau + E\^tau\ tau)\)\)},
                  {\(E\^\(-tau\)\ \((\(-1\) + E\^tau)\)\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"1", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[44]//ReviewForm=",
  CellTags->"3.5"],

Cell[TextData[{
  "The default value for the option ",
  StyleBox["Sampled", "MR"],
  " in ",
  StyleBox["ToDiscreteTime", "MR"],
  " is the global variable ",
  StyleBox["$SamplingPeriod", "MR"],
  ". This variable also provides a fallback where some functions retreat in \
situations when the sampling period does not evaluate to a number, but the \
numeric value is needed to perform the task (for example, to simulate the \
transient behavior of a system). Thus, ",
  StyleBox["$SamplingPeriod", "MR"],
  " must never be set to anything that has no numeric value. If it is desired \
that ",
  StyleBox["ToDiscreteTime", "MR"],
  " use a symbolic sampling period ",
  StyleBox["T", "MR"],
  " by default, this can be easily achieved by using the standard ",
  StyleBox["Mathematica", "TI"],
  " mechanism, say with a command ",
  StyleBox["SetOptions[ToDiscreteTime,", "MR"],
  " ",
  StyleBox["Sampled", "MR"],
  " ",
  StyleBox["->", "MR"],
  " ",
  StyleBox["Period[T]]", "MR"],
  " \nIt is worth emphasizing that the \"conversion\" from an analog to a \
sampled system is merely an approximation, the quality of which depends on \
the method used and the sampling period. The time\[Hyphen]domain response \
functions described later in ",
  ButtonBox["Chapter 4",
    ButtonData:>{"Symbolic Solution for Time-Domain Response"},
    ButtonStyle->"AddOnsLink"],
  " can make the difference between the original and approximated system \
readily apparent. "
}], "Text",
  CellTags->"3.5"],

Cell["\<\
This is the analog output response of the original system to the \
sinusoidal input signal. \
\>", "MathCaption",
  CellTags->"3.5"],

Cell["OutputResponse[cont, Sin[t], t]", "Input",
  CellLabel->"In[45]:=",
  CellTags->"3.5"],

Cell[BoxData[
    \({1\/2\ \((2 - E\^\(-t\))\) + 1\/2\ \((\(-Cos[t]\) - Sin[t])\)}\)], 
  "Output",
  CellLabel->"Out[45]=",
  CellTags->"3.5"],

Cell["\<\
Here is a piece of that curve on the time interval from 0 to 10 \
seconds. \
\>", "MathCaption",
  CellTags->"3.5"],

Cell["Plot[%, {t, 0, 10}]", "Input",
  CellLabel->"In[46]:=",
  CellTags->"3.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.346785 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .10141 -24 -4.5 ]
[.01131 .10141 0 4.5 ]
[.01131 .18811 -18 -4.5 ]
[.01131 .18811 0 4.5 ]
[.01131 .2748 -24 -4.5 ]
[.01131 .2748 0 4.5 ]
[.01131 .3615 -6 -4.5 ]
[.01131 .3615 0 4.5 ]
[.01131 .4482 -24 -4.5 ]
[.01131 .4482 0 4.5 ]
[.01131 .53489 -18 -4.5 ]
[.01131 .53489 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10141 m
.03006 .10141 L
s
[(0.25)] .01131 .10141 1 0 Mshowa
.02381 .18811 m
.03006 .18811 L
s
[(0.5)] .01131 .18811 1 0 Mshowa
.02381 .2748 m
.03006 .2748 L
s
[(0.75)] .01131 .2748 1 0 Mshowa
.02381 .3615 m
.03006 .3615 L
s
[(1)] .01131 .3615 1 0 Mshowa
.02381 .4482 m
.03006 .4482 L
s
[(1.25)] .01131 .4482 1 0 Mshowa
.02381 .53489 m
.03006 .53489 L
s
[(1.5)] .01131 .53489 1 0 Mshowa
.125 Mabswid
.02381 .03205 m
.02756 .03205 L
s
.02381 .04939 m
.02756 .04939 L
s
.02381 .06673 m
.02756 .06673 L
s
.02381 .08407 m
.02756 .08407 L
s
.02381 .11875 m
.02756 .11875 L
s
.02381 .13609 m
.02756 .13609 L
s
.02381 .15343 m
.02756 .15343 L
s
.02381 .17077 m
.02756 .17077 L
s
.02381 .20545 m
.02756 .20545 L
s
.02381 .22279 m
.02756 .22279 L
s
.02381 .24013 m
.02756 .24013 L
s
.02381 .25746 m
.02756 .25746 L
s
.02381 .29214 m
.02756 .29214 L
s
.02381 .30948 m
.02756 .30948 L
s
.02381 .32682 m
.02756 .32682 L
s
.02381 .34416 m
.02756 .34416 L
s
.02381 .37884 m
.02756 .37884 L
s
.02381 .39618 m
.02756 .39618 L
s
.02381 .41352 m
.02756 .41352 L
s
.02381 .43086 m
.02756 .43086 L
s
.02381 .46553 m
.02756 .46553 L
s
.02381 .48287 m
.02756 .48287 L
s
.02381 .50021 m
.02756 .50021 L
s
.02381 .51755 m
.02756 .51755 L
s
.02381 .55223 m
.02756 .55223 L
s
.02381 .56957 m
.02756 .56957 L
s
.02381 .58691 m
.02756 .58691 L
s
.02381 .60425 m
.02756 .60425 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01473 L
.03053 .01474 L
.03163 .01475 L
.03279 .01476 L
.03395 .01478 L
.0352 .01481 L
.03746 .01488 L
.03884 .01493 L
.04016 .01499 L
.04262 .01514 L
.045 .01532 L
.04753 .01555 L
.0521 .01612 L
.05752 .01705 L
.06244 .01818 L
.06787 .01978 L
.07287 .0216 L
.08414 .02708 L
.09408 .03366 L
.10458 .04252 L
.12422 .06468 L
.14255 .09209 L
.18146 .17024 L
.22282 .27545 L
.26267 .38446 L
.301 .48112 L
.32038 .52234 L
.34178 .55933 L
.35152 .57277 L
.36203 .58464 L
.37195 .59325 L
.37671 .59646 L
.38104 .59885 L
.38578 .60089 L
.38839 .60174 L
.39085 .60238 L
.39195 .60262 L
.39312 .60283 L
.39414 .60298 L
.39522 .60311 L
.39639 .60322 L
.39748 .60328 L
.39878 .60332 L
.39997 .60331 L
.40125 .60326 L
Mistroke
.40196 .60321 L
.4026 .60315 L
.40386 .60301 L
.40505 .60284 L
.40771 .60231 L
.41059 .60152 L
.41584 .5995 L
.42067 .597 L
.43043 .59004 L
.43953 .58135 L
.46021 .55416 L
.4806 .51832 L
.49917 .47928 L
.53907 .38217 L
.57745 .28491 L
.59687 .23937 L
.61828 .19506 L
.63881 .16039 L
.6576 .13676 L
.66705 .12811 L
.67186 .12459 L
.67699 .1215 L
.68216 .11909 L
.68446 .11824 L
.68696 .11749 L
.68849 .1171 L
.6899 .11681 L
.69122 .11658 L
.69267 .11639 L
.69398 .11626 L
.69519 .11618 L
.69648 .11614 L
.6972 .11614 L
.69786 .11615 L
.69903 .1162 L
.70014 .11628 L
.70135 .1164 L
.70265 .11658 L
.70531 .11708 L
.70775 .11771 L
.71222 .11928 L
.71692 .12151 L
.72682 .1281 L
.73767 .1382 L
.75726 .16366 L
.7782 .20006 L
.81966 .29301 L
.85961 .39486 L
.89805 .48758 L
.91751 .52764 L
Mistroke
.93893 .56368 L
.94821 .57621 L
.95817 .58741 L
.96759 .59571 L
.97619 .60131 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[46]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00C7oo0`00<Goo0`00;Woo0P00<Woo00<007ooOol0:goo1@000Woo00<007ooOol0
0goo001<Ool00`00Oomoo`0bOol00`00Oomoo`0]Ool00`00Ool0000`Ool00`00Ool0000^Ool01`00
Oomoogoo001oo`0000Aoo`00CGoo00<007ooOol0;goo1000;Woo00<007oo0000<7oo00<007oo0000
;Woo00L007ooOomoo`00Ool00004Ool004eoo`03001oogoo02moo`03001oo`0002moo`80039oo`03
001oogoo02eoo`07001oogooOol007oo000017oo001<Ool00`00Ool0000aOol2000_Ool00`00Oomo
o`0`Ool00`00Ool0000^Ool01`00Oomoogoo001oo`0000Aoo`00CGoo00<007ooOol0<Goo00<007oo
Ool0;Woo0P00<Goo00<007ooOol0;7oo0P0017oo00<007ooOol00goo003oOolQOol001]oo`03001o
ogoo0?moo`=oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool001]oo`03001o
ogoo0?moo`=oo`0057ooo`003@00000KOol00`00Oomoo`05Ool5000<Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool001]oo`03001oogoo00Yoo`8002=oo`03001o
ogoo031oo`03001oogoo031oo`03001oogoo02moo`03001oogoo031oo`03001oogoo00Eoo`006goo
00<007ooOol037oo0P00m7oo000KOol00`00Oomoo`0>Ool2003bOol001]oo`80015oo`03001oogoo
0>moo`006goo00<007ooOol04Goo00<007ooOol0kWoo000KOol00`00Oomoo`0BOol00`00Oomoo`3]
Ool001]oo`03001oogoo01=oo`03001oogoo0>aoo`006goo0P005Goo00<007ooOol0jgoo000KOol0
0`00Oomoo`0EOol00`00Oomoo`3ZOol001]oo`03001oogoo01Ioo`03001oogoo0>Uoo`006goo00<0
07ooOol05goo00<007ooOol0j7oo000KOol00`00Oomoo`0HOol00`00Oomoo`3WOol001]oo`8001Yo
o`03001oogoo0>Ioo`006goo00<007ooOol06Goo00<007ooOol0iWoo000KOol00`00Oomoo`0JOol0
0`00Oomoo`3UOol001]oo`03001oogoo01Yoo`03001oogoo0>Eoo`006goo0P0077oo00<007ooOol0
i7oo000KOol00`00Oomoo`0KOol00`00Oomoo`3TOol001]oo`03001oogoo01aoo`03001oogoo0>=o
o`001Woo00<007ooOol00Woo00@007ooOomoo`<000=oo`03001oogoo00=oo`03001oogoo01aoo`03
001oogoo0>=oo`001Goo00<007oo00001goo00<007ooOol00Woo00<007oo000017oo00<007ooOol0
7Goo00<007ooOol0hWoo0005Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`02Ool2000N
Ool00`00Oomoo`3ROol000Eoo`03001oo`0000Qoo`04001oogooOol20005Ool00`00Oomoo`0NOol0
0`00Oomoo`3QOol000Eoo`03001oo`0000Moo`03001oo`00009oo`03001oogoo00Aoo`03001oogoo
01ioo`03001oogoo0>5oo`001Woo00<007ooOol01goo00@007ooOomoo`<000Aoo`03001oogoo01mo
o`03001oogoo0>1oo`006goo00<007ooOol07goo00<007ooOol0Rgoo1`00CWoo000KOol2000QOol0
0`00Oomoo`28Ool20007Ool2001<Ool001]oo`03001oogoo021oo`03001oogoo08Ioo`8000]oo`80
04Yoo`006goo00<007ooOol08Goo00<007ooOol0Q7oo00<007ooOol03Goo00<007ooOol0Agoo000K
Ool00`00Oomoo`0ROol00`00Oomoo`21Ool2000AOol00`00Oomoo`16Ool001]oo`8002=oo`03001o
ogoo081oo`03001oogoo019oo`03001oogoo04Eoo`006goo00<007ooOol08goo00<007ooOol0OWoo
00<007ooOol057oo00<007ooOol0A7oo000KOol00`00Oomoo`0SOol00`00Oomoo`1nOol00`00Oomo
o`0EOol00`00Oomoo`13Ool001]oo`03001oogoo02Aoo`03001oogoo07aoo`03001oogoo01Ioo`03
001oogoo04=oo`006goo00<007ooOol097oo00<007ooOol0Ngoo00<007ooOol067oo00<007ooOol0
@Woo000KOol2000VOol00`00Oomoo`1iOol00`00Oomoo`0JOol00`00Oomoo`11Ool001]oo`03001o
ogoo02Eoo`03001oogoo07Uoo`03001oogoo01]oo`03001oogoo041oo`006goo00<007ooOol09Woo
00<007ooOol0Mgoo00<007ooOol077oo00<007ooOol0@7oo000KOol00`00Oomoo`0VOol00`00Oomo
o`1fOol00`00Oomoo`0NOol00`00Oomoo`0oOol001]oo`8002Qoo`03001oogoo07Eoo`03001oogoo
01moo`03001oogoo03ioo`006goo00<007ooOol09goo00<007ooOol0M7oo00<007ooOol087oo00<0
07ooOol0?Woo000KOol00`00Oomoo`0XOol00`00Oomoo`1cOol00`00Oomoo`0QOol00`00Oomoo`0m
Ool000]oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo02Qoo`03001o
ogoo079oo`03001oogoo02=oo`03001oogoo03aoo`002Woo00<007oo00001goo00<007oo000017oo
00<007ooOol0:Goo00<007ooOol0LGoo00<007ooOol08goo00<007ooOol0?7oo000:Ool00`00Ool0
0009Ool00`00Oomoo`02Ool2000ZOol00`00Oomoo`1`Ool00`00Oomoo`0UOol00`00Oomoo`0kOol0
00Yoo`03001oo`0000Moo`8000Eoo`03001oogoo02Uoo`03001oogoo071oo`03001oogoo02Ioo`03
001oogoo03Yoo`002Woo00<007oo00001goo00<007ooOol017oo00<007ooOol0:Woo00<007ooOol0
KWoo00<007ooOol09goo00<007ooOol0>Woo000;Ool00`00Oomoo`06Ool30004Ool00`00Oomoo`0Z
Ool00`00Oomoo`1]Ool00`00Oomoo`0YOol00`00Oomoo`0iOol001]oo`03001oogoo02]oo`03001o
ogoo06aoo`03001oogoo02Uoo`03001oogoo03Uoo`006goo0P00;7oo00<007ooOol0Jgoo00<007oo
Ool0:goo00<007ooOol0>7oo000KOol00`00Oomoo`0[Ool00`00Oomoo`1[Ool00`00Oomoo`0[Ool0
0`00Oomoo`0hOol001]oo`03001oogoo02aoo`03001oogoo06Uoo`03001oogoo02eoo`03001oogoo
03Moo`006goo00<007ooOol0;7oo00<007ooOol0JGoo00<007ooOol0;Goo00<007ooOol0=goo000K
Ool2000^Ool00`00Oomoo`1WOol00`00Oomoo`0_Ool00`00Oomoo`0fOol001]oo`03001oogoo02eo
o`03001oogoo06Moo`03001oogoo02moo`03001oogoo03Ioo`006goo00<007ooOol0;Goo00<007oo
Ool0IWoo00<007ooOol0<Goo00<007ooOol0=Goo000KOol00`00Oomoo`0^Ool00`00Oomoo`1UOol0
0`00Oomoo`0aOol00`00Oomoo`0eOol001]oo`03001oogoo02ioo`03001oogoo06Aoo`03001oogoo
039oo`03001oogoo03Eoo`006goo0P00;goo00<007ooOol0I7oo00<007ooOol0<goo00<007ooOol0
=7oo000KOol00`00Oomoo`0_Ool00`00Oomoo`1SOol00`00Oomoo`0cOol00`00Oomoo`0dOol001]o
o`03001oogoo02moo`03001oogoo069oo`03001oogoo03Eoo`03001oogoo03=oo`006goo00<007oo
Ool0<7oo00<007ooOol0HGoo00<007ooOol0=Goo00<007ooOol0<goo000KOol00`00Oomoo`0`Ool0
0`00Oomoo`1POol00`00Oomoo`0gOol00`00Oomoo`0bOol001]oo`80035oo`03001oogoo061oo`03
001oogoo03Moo`03001oogoo039oo`006goo00<007ooOol0<Goo00<007ooOol0GWoo00<007ooOol0
>7oo00<007ooOol0<Woo0006Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`03Ool00`00Oomoo`0aOol00`00Oomoo`1NOol00`00Oomoo`0iOol00`00Oomoo`0aOol000Eo
o`03001oo`0000Qoo`07001oogooOol007oo000017oo00<007ooOol0<Woo00<007ooOol0GGoo00<0
07ooOol0>Goo00<007ooOol0<Goo0005Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool2000cOol00`00Oomoo`1LOol00`00Oomoo`0kOol00`00Oomoo`0`Ool000Eoo`03001oo`0000Uo
o`03001oogoo008000Eoo`03001oogoo039oo`03001oogoo05aoo`03001oogoo03]oo`03001oogoo
031oo`001Goo00<007oo00001goo00<007oo00000Woo00<007ooOol017oo00<007ooOol0<goo00<0
07ooOol0FWoo00<007ooOol0?Goo00<007ooOol0;goo0006Ool00`00Oomoo`06Ool30002Ool30004
Ool00`00Oomoo`0cOol00`00Oomoo`1JOol00`00Oomoo`0mOol00`00Oomoo`0_Ool001]oo`03001o
ogoo03=oo`03001oogoo05Yoo`03001oogoo03ioo`03001oogoo02ioo`006goo0P00=Goo00<007oo
Ool0F7oo00<007ooOol0?goo00<007ooOol0;Woo000KOol00`00Oomoo`0dOol00`00Oomoo`1HOol0
0`00Oomoo`0oOol00`00Oomoo`0^Ool001]oo`03001oogoo03Aoo`03001oogoo05Moo`03001oogoo
045oo`03001oogoo02eoo`006goo00<007ooOol0=Goo00<007ooOol0EWoo00<007ooOol0@Goo00<0
07ooOol0;Goo000KOol2000fOol00`00Oomoo`1FOol00`00Oomoo`11Ool00`00Oomoo`0]Ool001]o
o`03001oogoo03Eoo`03001oogoo05Eoo`03001oogoo04=oo`03001oogoo02aoo`006goo00<007oo
Ool0=Woo00<007ooOol0E7oo00<007ooOol0@goo00<007ooOol0;7oo000KOol00`00Oomoo`0fOol0
0`00Oomoo`1DOol00`00Oomoo`14Ool00`00Oomoo`0[Ool001]oo`03001oogoo03Ioo`03001oogoo
05=oo`03001oogoo04Eoo`03001oogoo02]oo`006goo0P00>7oo00<007ooOol0DWoo00<007ooOol0
AGoo00<007ooOol0:goo000KOol00`00Oomoo`0gOol00`00Oomoo`1AOol00`00Oomoo`17Ool00`00
Oomoo`0ZOol001]oo`03001oogoo03Qoo`03001oogoo051oo`03001oogoo04Moo`03001oogoo02Yo
o`006goo00<007ooOol0>7oo00<007ooOol0D7oo00<007ooOol0Agoo00<007ooOol0:Woo000KOol0
0`00Oomoo`0hOol00`00Oomoo`1?Ool00`00Oomoo`19Ool00`00Oomoo`0YOol001]oo`8003Yoo`03
001oogoo04ioo`03001oogoo04Uoo`03001oogoo02Uoo`006goo00<007ooOol0>Goo00<007ooOol0
CGoo00<007ooOol0Bgoo00<007ooOol0:7oo000COol50003Ool00`00Oomoo`0iOol00`00Oomoo`1=
Ool00`00Oomoo`1;Ool00`00Oomoo`0XOol001Eoo`03001oogoo00=oo`03001oogoo03Yoo`03001o
ogoo04aoo`03001oogoo04]oo`03001oogoo02Qoo`005Goo00<007ooOol00goo0P00>goo00<007oo
Ool0Bgoo00<007ooOol0CGoo00<007ooOol09goo000EOol00`00Oomoo`03Ool00`00Oomoo`0jOol0
0`00Oomoo`1;Ool00`00Oomoo`1=Ool00`00Oomoo`0WOol001Eoo`03001oogoo00=oo`03001oogoo
03]oo`03001oogoo04Yoo`03001oogoo04eoo`03001oogoo02Moo`0057oo0P001Goo00<007ooOol0
>goo00<007ooOol0BGoo00<007ooOol0Cgoo00<007ooOol09Woo000KOol00`00Oomoo`0kOol00`00
Oomoo`19Ool00`00Oomoo`1?Ool00`00Oomoo`0VOol001]oo`8003eoo`03001oogoo04Moo`03001o
ogoo055oo`03001oogoo02Eoo`006goo00<007ooOol0?7oo00<007ooOol0Agoo00<007ooOol0DGoo
00<007ooOol09Goo000KOol00`00Oomoo`0lOol00`00Oomoo`17Ool00`00Oomoo`1AOol00`00Oomo
o`0UOol001]oo`03001oogoo03eoo`03001oogoo04Eoo`03001oogoo05=oo`03001oogoo02Aoo`00
6goo0P00?Woo00<007ooOol0AGoo00<007ooOol0Dgoo00<007ooOol097oo000KOol00`00Oomoo`0n
Ool00`00Oomoo`13Ool00`00Oomoo`1DOol00`00Oomoo`0TOol001]oo`03001oogoo03ioo`03001o
ogoo04=oo`03001oogoo05Eoo`03001oogoo02=oo`006goo00<007ooOol0?goo00<007ooOol0@Goo
00<007ooOol0EWoo00<007ooOol08goo000KOol00`00Oomoo`0oOol00`00Oomoo`11Ool00`00Oomo
o`1GOol00`00Oomoo`0ROol001]oo`80041oo`03001oogoo045oo`03001oogoo05Moo`03001oogoo
029oo`006goo00<007ooOol0@7oo00<007ooOol0?goo00<007ooOol0F7oo00<007ooOol08Woo000K
Ool00`00Oomoo`10Ool00`00Oomoo`0oOol00`00Oomoo`1IOol00`00Oomoo`0QOol001]oo`03001o
ogoo045oo`03001oogoo03eoo`03001oogoo05Yoo`03001oogoo025oo`006goo00<007ooOol0@Goo
00<007ooOol0?Goo00<007ooOol0Fgoo00<007ooOol087oo000KOol20013Ool00`00Oomoo`0kOol0
0`00Oomoo`1LOol00`00Oomoo`0POol001]oo`03001oogoo049oo`03001oogoo03]oo`03001oogoo
05aoo`03001oogoo021oo`0017oo1@000Woo00@007ooOomoo`<000=oo`03001oogoo00=oo`03001o
ogoo049oo`03001oogoo03]oo`03001oogoo05eoo`03001oogoo01moo`001Woo00<007ooOol01Woo
00<007ooOol00Woo00<007oo000017oo00<007ooOol0@goo00<007ooOol0>Goo00<007ooOol0GWoo
00<007ooOol07goo0006Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`02Ool20014Ool0
0`00Oomoo`0iOol00`00Oomoo`1OOol00`00Oomoo`0NOol000Ioo`03001oogoo00Moo`04001oogoo
Ool20005Ool00`00Oomoo`14Ool00`00Oomoo`0gOol00`00Oomoo`1POol00`00Oomoo`0NOol000Io
o`03001oogoo00Ioo`03001oo`00009oo`03001oogoo00Aoo`03001oogoo04Aoo`03001oogoo03Mo
o`03001oogoo061oo`03001oogoo01ioo`001Goo0P002Goo00@007ooOomoo`<000Aoo`03001oogoo
04Aoo`03001oogoo03Moo`03001oogoo065oo`03001oogoo01eoo`006goo00<007ooOol0AGoo00<0
07ooOol0=Goo00<007ooOol0HWoo00<007ooOol07Goo000KOol20016Ool00`00Oomoo`0eOol00`00
Oomoo`1SOol00`00Oomoo`0LOol001]oo`03001oogoo04Ioo`03001oogoo03=oo`03001oogoo06Ao
o`03001oogoo01aoo`006goo00<007ooOol0AWoo00<007ooOol0<goo00<007ooOol0I7oo00<007oo
Ool077oo000KOol00`00Oomoo`17Ool00`00Oomoo`0aOol00`00Oomoo`1VOol00`00Oomoo`0KOol0
01]oo`8004Qoo`03001oogoo035oo`03001oogoo06Ioo`03001oogoo01]oo`006goo00<007ooOol0
Agoo00<007ooOol0<7oo00<007ooOol0J7oo00<007ooOol06Woo000KOol00`00Oomoo`18Ool00`00
Oomoo`0_Ool00`00Oomoo`1XOol00`00Oomoo`0JOol001]oo`03001oogoo04Qoo`03001oogoo02io
o`03001oogoo06Yoo`03001oogoo01Uoo`006goo00<007ooOol0BGoo00<007ooOol0;Goo00<007oo
Ool0JWoo00<007ooOol06Goo000KOol2001:Ool00`00Oomoo`0/Ool00`00Oomoo`1/Ool00`00Oomo
o`0HOol001]oo`03001oogoo04Yoo`03001oogoo02]oo`03001oogoo06aoo`03001oogoo01Qoo`00
6goo00<007ooOol0BWoo00<007ooOol0:Woo00<007ooOol0KWoo00<007ooOol05goo000KOol00`00
Oomoo`1;Ool00`00Oomoo`0YOol00`00Oomoo`1_Ool00`00Oomoo`0FOol001]oo`03001oogoo04]o
o`03001oogoo02Qoo`03001oogoo071oo`03001oogoo01Ioo`006goo0P00CGoo00<007ooOol09goo
00<007ooOol0LGoo00<007ooOol05Goo000KOol00`00Oomoo`1<Ool00`00Oomoo`0VOol00`00Oomo
o`1bOol00`00Oomoo`0EOol000Uoo`D0009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
04eoo`03001oogoo02Eoo`03001oogoo07=oo`03001oogoo01Aoo`002goo00<007ooOol01Woo00<0
07oo000017oo00<007ooOol0CGoo00<007ooOol097oo00<007ooOol0MGoo00<007ooOol04goo000;
Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2001?Ool00`00Oomoo`0SOol00`00Oomoo`1eOol00`00
Oomoo`0COol000]oo`03001oogoo00Ioo`8000Eoo`03001oogoo04ioo`03001oogoo029oo`03001o
ogoo07Moo`03001oogoo019oo`002goo00<007ooOol01Woo00<007ooOol017oo00<007ooOol0Cgoo
00<007ooOol08Goo00<007ooOol0Mgoo00<007ooOol04Woo000:Ool20008Ool30004Ool00`00Oomo
o`1?Ool00`00Oomoo`0POol00`00Oomoo`1iOol00`00Oomoo`0AOol001]oo`03001oogoo051oo`03
001oogoo01moo`03001oogoo07Uoo`03001oogoo015oo`006goo0P00DGoo00<007ooOol07Woo00<0
07ooOol0Ngoo00<007ooOol047oo000KOol00`00Oomoo`1AOol00`00Oomoo`0LOol00`00Oomoo`1l
Ool00`00Oomoo`0@Ool001]oo`03001oogoo055oo`03001oogoo01]oo`03001oogoo07ioo`03001o
ogoo00moo`006goo00<007ooOol0DWoo00<007ooOol06Woo00<007ooOol0OWoo00<007ooOol03goo
000KOol00`00Oomoo`1COol00`00Oomoo`0HOol00`00Oomoo`20Ool00`00Oomoo`0>Ool001]oo`80
05Eoo`03001oogoo01Ioo`03001oogoo089oo`03001oogoo00eoo`006goo00<007ooOol0EGoo00<0
07ooOol057oo00<007ooOol0Q7oo00<007ooOol037oo000KOol00`00Oomoo`1FOol00`00Oomoo`0C
Ool00`00Oomoo`25Ool00`00Oomoo`0;Ool001]oo`03001oogoo05Ioo`03001oogoo019oo`03001o
ogoo08Ioo`03001oogoo00]oo`006goo0P00F7oo00<007ooOol047oo00<007ooOol0R7oo00<007oo
Ool02Woo000KOol00`00Oomoo`1HOol00`00Oomoo`0>Ool00`00Oomoo`2:Ool2000:Ool001]oo`03
001oogoo05Uoo`03001oogoo00]oo`8008moo`03001oogoo00Moo`006goo00<007ooOol0FWoo0`00
2Goo00<007ooOol0T7oo00<007ooOol01Woo000KOol00`00Oomoo`1MOol9002DOol00`00Oomoo`05
Ool001]oo`80065oo`800:1oo`006goo00<007ooOol0ogoo0goo000KOol00`00Oomoo`3oOol3Ool0
01]oo`03001oogoo0?moo`=oo`00ogoo8Goo003oOolQOol00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.07864, -0.155973, 
  0.0394728, 0.0108405}},
  CellTags->"3.5"],

Cell[TextData[{
  "This plots the simulated response of the discrete\[Hyphen]time system for \
the sampling period ",
  StyleBox["tau", "MR"],
  " of 0.5 seconds over the same time interval. For reference, we include the \
analog response from the previous plot (structurally, the line is the first \
element of the ",
  StyleBox["Graphics", "MR"],
  " object returned by the previous command and is extracted with ",
  StyleBox["First", "MR"],
  "). \nWe can see that the sampled values systematically lag behind \
corresponding points on the analog curve, which is typical for the default ",
  StyleBox["ZeroOrderHold", "MR"],
  " method. Choosing smaller values of ",
  StyleBox["tau", "MR"],
  " can make the lag less noticeable. "
}], "MathCaption",
  CellTags->"3.5"],

Cell["\<\
SimulationPlot[disc/.tau->.5, Sin[t], {t, 0, 10},
 PlotJoined -> False,
 PlotStyle -> PointSize[.015],
 PlotLabel -> \"Output Response\",
 Epilog -> First[%]
]\
\>", "Input",
  CellLabel->"In[47]:=",
  CellTags->"3.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0952381 0.0147151 0.355341 [
[.21429 .00222 -3 -9 ]
[.21429 .00222 3 0 ]
[.40476 .00222 -3 -9 ]
[.40476 .00222 3 0 ]
[.59524 .00222 -3 -9 ]
[.59524 .00222 3 0 ]
[.78571 .00222 -3 -9 ]
[.78571 .00222 3 0 ]
[.97619 .00222 -6 -9 ]
[.97619 .00222 6 0 ]
[.01131 .10355 -24 -4.5 ]
[.01131 .10355 0 4.5 ]
[.01131 .19239 -18 -4.5 ]
[.01131 .19239 0 4.5 ]
[.01131 .28122 -24 -4.5 ]
[.01131 .28122 0 4.5 ]
[.01131 .37006 -6 -4.5 ]
[.01131 .37006 0 4.5 ]
[.01131 .45889 -24 -4.5 ]
[.01131 .45889 0 4.5 ]
[.01131 .54773 -18 -4.5 ]
[.01131 .54773 0 4.5 ]
[.5 .63053 -47 0 ]
[.5 .63053 47 12.5625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
.21429 .01472 m
.21429 .02097 L
s
[(2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(10)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10355 m
.03006 .10355 L
s
[(0.25)] .01131 .10355 1 0 Mshowa
.02381 .19239 m
.03006 .19239 L
s
[(0.5)] .01131 .19239 1 0 Mshowa
.02381 .28122 m
.03006 .28122 L
s
[(0.75)] .01131 .28122 1 0 Mshowa
.02381 .37006 m
.03006 .37006 L
s
[(1)] .01131 .37006 1 0 Mshowa
.02381 .45889 m
.03006 .45889 L
s
[(1.25)] .01131 .45889 1 0 Mshowa
.02381 .54773 m
.03006 .54773 L
s
[(1.5)] .01131 .54773 1 0 Mshowa
.125 Mabswid
.02381 .03248 m
.02756 .03248 L
s
.02381 .05025 m
.02756 .05025 L
s
.02381 .06802 m
.02756 .06802 L
s
.02381 .08578 m
.02756 .08578 L
s
.02381 .12132 m
.02756 .12132 L
s
.02381 .13908 m
.02756 .13908 L
s
.02381 .15685 m
.02756 .15685 L
s
.02381 .17462 m
.02756 .17462 L
s
.02381 .21015 m
.02756 .21015 L
s
.02381 .22792 m
.02756 .22792 L
s
.02381 .24569 m
.02756 .24569 L
s
.02381 .26345 m
.02756 .26345 L
s
.02381 .29899 m
.02756 .29899 L
s
.02381 .31676 m
.02756 .31676 L
s
.02381 .33452 m
.02756 .33452 L
s
.02381 .35229 m
.02756 .35229 L
s
.02381 .38782 m
.02756 .38782 L
s
.02381 .40559 m
.02756 .40559 L
s
.02381 .42336 m
.02756 .42336 L
s
.02381 .44112 m
.02756 .44112 L
s
.02381 .47666 m
.02756 .47666 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .51219 m
.02756 .51219 L
s
.02381 .52996 m
.02756 .52996 L
s
.02381 .56549 m
.02756 .56549 L
s
.02381 .58326 m
.02756 .58326 L
s
.02381 .60103 m
.02756 .60103 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Output) show
105.000000 12.812500 moveto
(Response) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.015 w
.02381 .01472 Mdot
.07143 .01472 Mdot
.11905 .03286 Mdot
.16667 .09109 Mdot
.21429 .19114 Mdot
.2619 .31822 Mdot
.30952 .4471 Mdot
.35714 .54979 Mdot
.40476 .60332 Mdot
.45238 .59589 Mdot
.5 .53013 Mdot
.54762 .42261 Mdot
.59524 .29995 Mdot
.64286 .19236 Mdot
.69048 .12629 Mdot
.7381 .11798 Mdot
.78571 .16951 Mdot
.83333 .26828 Mdot
.88095 .39013 Mdot
.92857 .50523 Mdot
.97619 .5854 Mdot
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01473 L
.03053 .01474 L
.03163 .01475 L
.03279 .01476 L
.03395 .01478 L
.0352 .01481 L
.03746 .01488 L
.03884 .01494 L
.04016 .015 L
.04262 .01515 L
.045 .01533 L
.04753 .01557 L
.0521 .01615 L
.05752 .01711 L
.06244 .01827 L
.06787 .0199 L
.07287 .02177 L
.08414 .02739 L
.09408 .03412 L
.10458 .0432 L
.12422 .06591 L
.14255 .094 L
.18146 .17408 L
.22282 .28188 L
.26267 .39358 L
.301 .49263 L
.32038 .53486 L
.34178 .57277 L
.35152 .58654 L
.36203 .5987 L
.37195 .60752 L
.37671 .61081 L
.38104 .61326 L
.38578 .61535 L
.38839 .61623 L
.39085 .61688 L
.39195 .61712 L
.39312 .61734 L
.39414 .6175 L
.39522 .61763 L
.39639 .61774 L
.39748 .61781 L
.39878 .61784 L
.39997 .61783 L
.40125 .61778 L
Mistroke
.40196 .61773 L
.4026 .61767 L
.40386 .61753 L
.40505 .61735 L
.40771 .61681 L
.41059 .616 L
.41584 .61393 L
.42067 .61136 L
.43043 .60424 L
.43953 .59533 L
.46021 .56747 L
.4806 .53074 L
.49917 .49074 L
.53907 .39124 L
.57745 .29158 L
.59687 .24491 L
.61828 .19951 L
.63881 .16399 L
.6576 .13977 L
.66705 .13091 L
.67186 .12731 L
.67699 .12414 L
.68216 .12166 L
.68446 .1208 L
.68696 .12002 L
.68849 .11963 L
.6899 .11933 L
.69122 .11909 L
.69267 .11889 L
.69398 .11876 L
.69519 .11868 L
.69648 .11864 L
.6972 .11864 L
.69786 .11865 L
.69903 .1187 L
.70014 .11878 L
.70135 .11891 L
.70265 .11909 L
.70531 .11961 L
.70775 .12025 L
.71222 .12186 L
.71692 .12414 L
.72682 .1309 L
.73767 .14125 L
.75726 .16733 L
.7782 .20463 L
.81966 .29987 L
.85961 .40424 L
.89805 .49925 L
.91751 .54029 L
Mistroke
.93893 .57723 L
.94821 .59007 L
.95817 .60154 L
.96758 .61005 L
.97619 .61578 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[47]:=",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo001AOol3
000]Ool3000/Ool2000^Ool00`00Oomoo`0WOol50002Ool00`00Oomoo`0<Ool0055oo`03001oogoo
02ioo`03001oogoo02]oo`03001oo`0002aoo`03001oo`0002Yoo`07001oogooOol007oo00003Goo
001BOol00`00Oomoo`0[Ool4000/Ool00`00Ool0000/Ool00`00Ool0000ZOol01`00Oomoogoo001o
o`0000eoo`00DWoo00<007ooOol0:goo00<007oo0000;Goo0P00;Woo00<007ooOol0:Goo00L007oo
Oomoo`00Ool0000=Ool0055oo`03001oo`0002eoo`8002eoo`03001oogoo02aoo`03001oo`0002Yo
o`07001oogooOol007oo00003Goo001BOol00`00Oomoo`0]Ool00`00Oomoo`0/Ool2000]Ool00`00
Oomoo`0XOol20004Ool00`00Oomoo`0<Ool00?moob5oo`0097oo00<007ooOol0nGoo000TOol00`00
Oomoo`3iOol002Aoo`03001oogoo0?Uoo`008goo0P002Woo00<007ooOol0kWoo000NOooh000:Ool0
02=oo`8000Qoo`@000Yoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo
00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo
00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo
00ioo`0097oo00<007ooOol02Woo0P00kGoo000TOol00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00
Oomoo`3ROol002Aoo`8000ioo`8000Aoo`<00>=oo`0097oo00<007ooOol03goo00<007ooOol00Woo
00<007ooOol0hWoo000TOol00`00Oomoo`0@Ool00`00Oomoo`3VOol002Aoo`03001oogoo015oo`03
001oogoo0>Eoo`0097oo0P004goo00<007ooOol0i7oo000TOol00`00Oomoo`0COol00`00Oomoo`3S
Ool002Aoo`03001oogoo01Aoo`03001oogoo0>9oo`0097oo00<007ooOol05Goo00<007ooOol0hGoo
000TOol00`00Oomoo`0FOol00`00Oomoo`3POol002Aoo`8001Qoo`03001oogoo0=moo`0097oo00<0
07ooOol05goo00<007ooOol0ggoo000TOol00`00Oomoo`0HOol00`00Oomoo`3NOol002Aoo`03001o
ogoo01Qoo`03001oogoo0=ioo`0097oo0P006Woo00<007ooOol0gGoo000TOol00`00Oomoo`0IOol0
0`00Oomoo`04Ool00`00Oomoo`3FOol002Aoo`03001oogoo01Yoo`03001oogoo009oo`<00=Moo`00
3goo00<007ooOol00Woo00@007ooOomoo`<000=oo`03001oogoo00=oo`03001oogoo01]oo`03001o
ogoo009oo`03001oogoo0=Ioo`003Woo00<007oo00001goo00<007ooOol00Woo00<007oo000017oo
00<007ooOol06goo00<007ooOol0fgoo000>Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool2000MOol00`00Oomoo`3JOol000ioo`03001oo`0000Qoo`04001oogooOol20005Ool00`00
Oomoo`0LOol00`00Oomoo`3JOol000ioo`03001oo`0000Moo`03001oo`00009oo`03001oogoo00Ao
o`03001oogoo01eoo`03001oogoo08eoo`03001oogoo04Uoo`003goo00<007ooOol01goo00@007oo
Oomoo`<000Aoo`03001oogoo01eoo`03001oogoo089oo`@000Ioo`<004Yoo`0097oo0P007goo00<0
07ooOol0Ogoo0`000Woo0`001Goo00<007ooOol0BGoo000TOol00`00Oomoo`0NOol00`00Oomoo`1l
Ool300000goo001oo`05Ool2001?Ool002Aoo`03001oogoo01moo`03001oogoo07Yoo`04001oogoo
Ool30007Ool2001=Ool002Aoo`03001oogoo01moo`03001oogoo07Uoo`03001oogoo00=oo`03001o
ogoo00Qoo`03001oogoo04Yoo`0097oo0P008Goo00<007ooOol0N7oo00<007ooOol03Woo00<007oo
Ool0BWoo000TOol00`00Oomoo`0POol00`00Oomoo`1gOol00`00Oomoo`0@Ool00`00Oomoo`19Ool0
02Aoo`03001oogoo025oo`03001oogoo07Eoo`03001oogoo019oo`03001oogoo04Qoo`0097oo00<0
07ooOol08Goo00<007ooOol0M7oo00<007ooOol057oo00<007ooOol0Agoo000TOol00`00Oomoo`0R
Ool00`00Oomoo`1bOol00`00Oomoo`0FOol00`00Oomoo`16Ool002Aoo`8002=oo`03001oogoo079o
o`03001oogoo01Ioo`03001oogoo04Ioo`0097oo00<007ooOol08goo00<007ooOol0L7oo00<007oo
Ool067oo00<007ooOol0AGoo000TOol00`00Oomoo`0SOol00`00Oomoo`1_Ool00`00Oomoo`0JOol0
0`00Oomoo`04Ool00`00Oomoo`0mOol002Aoo`03001oogoo02Aoo`03001oogoo06eoo`03001oogoo
01aoo`03001oogoo009oo`<003ioo`0097oo0P009Goo00<007ooOol0KGoo00<007ooOol077oo00<0
07ooOol00goo00<007ooOol0?Goo000TOol00`00Oomoo`0TOol00`00Oomoo`1/Ool00`00Oomoo`0N
Ool00`00Oomoo`12Ool002Aoo`03001oogoo02Eoo`03001oogoo06Yoo`03001oogoo01moo`03001o
ogoo049oo`0057oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol09Goo
00<007ooOol0JWoo00<007ooOol087oo00<007ooOol0@Goo000COol00`00Ool00007Ool00`00Ool0
0004Ool00`00Oomoo`0UOol00`00Oomoo`04Ool00`00Oomoo`1ROol00`00Oomoo`02Ool00`00Oomo
o`0LOol00`00Oomoo`11Ool001=oo`03001oo`0000Uoo`03001oogoo009oo`8002Moo`03001oogoo
009oo`<006=oo`04001oogooOol3000NOol00`00Oomoo`10Ool001=oo`03001oo`0000Moo`8000Eo
o`03001oogoo02Ioo`03001oogoo00=oo`03001oogoo065oo`03001oogoo00=oo`03001oogoo01eo
o`03001oogoo041oo`004goo00<007oo00001goo00<007ooOol017oo00<007ooOol09goo00<007oo
Ool0IWoo00<007ooOol097oo00<007ooOol0?goo000DOol00`00Oomoo`06Ool30004Ool00`00Oomo
o`0WOol00`00Oomoo`1UOol00`00Oomoo`0UOol00`00Oomoo`0oOol002Aoo`8002Qoo`03001oogoo
06Eoo`03001oogoo02Eoo`03001oogoo03moo`0097oo00<007ooOol0:7oo00<007ooOol0Hgoo00<0
07ooOol09goo00<007ooOol0?Woo000TOol00`00Oomoo`0XOol00`00Oomoo`1SOol00`00Oomoo`0W
Ool00`00Oomoo`0nOol002Aoo`03001oogoo02Qoo`03001oogoo069oo`03001oogoo02Uoo`03001o
ogoo03eoo`0097oo0P00:Woo00<007ooOol0HGoo00<007ooOol0:Goo00<007ooOol0?Goo000TOol0
0`00Oomoo`0YOol00`00Oomoo`1QOol00`00Oomoo`0ZOol00`00Oomoo`0lOol002Aoo`03001oogoo
02Yoo`03001oogoo05moo`03001oogoo02]oo`03001oogoo03aoo`0097oo00<007ooOol0:Woo00<0
07ooOol0Ggoo00<007ooOol0;7oo00<007ooOol0>goo000TOol00`00Oomoo`0ZOol00`00Oomoo`1N
Ool00`00Oomoo`0]Ool00`00Oomoo`0kOol002Aoo`8002aoo`03001oogoo05eoo`03001oogoo02io
o`03001oogoo03Yoo`0097oo00<007ooOol0:goo00<007ooOol0GGoo00<007ooOol0;Woo00<007oo
Ool0>Woo000TOol00`00Oomoo`0[Ool00`00Oomoo`1LOol00`00Oomoo`0`Ool00`00Oomoo`0iOol0
02Aoo`03001oogoo02aoo`03001oogoo05]oo`03001oogoo031oo`03001oogoo03Uoo`0097oo0P00
;Goo00<007ooOol0FWoo00<007ooOol0<Woo00<007ooOol0>7oo000TOol00`00Oomoo`0]Ool00`00
Oomoo`1IOol00`00Oomoo`0bOol00`00Oomoo`04Ool00`00Oomoo`0aOol002Aoo`03001oogoo02eo
o`03001oogoo05Qoo`03001oogoo03Aoo`03001oogoo009oo`<0039oo`003goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0;Goo00<007ooOol0F7oo
00<007ooOol0=7oo00<007ooOol00goo00<007ooOol0<Goo000>Ool00`00Ool00008Ool01`00Oomo
ogoo001oo`0000Aoo`03001oogoo02ioo`03001oogoo05Ioo`03001oogoo03Ioo`03001oogoo03Io
o`003Woo00<007oo000027oo00<007ooOol00goo00<007ooOol00Woo0P00;goo00<007ooOol0EWoo
00<007ooOol0=Woo00<007ooOol0=Woo000>Ool00`00Ool00009Ool00`00Oomoo`020005Ool00`00
Oomoo`0^Ool00`00Oomoo`1EOol00`00Oomoo`0hOol00`00Oomoo`0eOol000ioo`03001oo`0000Mo
o`03001oo`00009oo`03001oogoo00Aoo`03001oogoo02moo`03001oogoo05Aoo`03001oogoo03Qo
o`03001oogoo03Eoo`003goo00<007ooOol01Woo0`000Woo0`0017oo00<007ooOol0;goo00<007oo
Ool0E7oo00D007ooOomoo`0003Moo`03001oogoo03Aoo`0097oo0P00<7oo00<007ooOol0Dgoo00@0
07ooOomoo`<003Ioo`03001oogoo03Aoo`0097oo00<007ooOol0<7oo00<007ooOol0DWoo00<007oo
Ool00Woo00<007ooOol0=Goo00<007ooOol0=7oo000TOol00`00Oomoo`0`Ool00`00Oomoo`1AOol0
0`00Oomoo`0lOol00`00Oomoo`0cOol002Aoo`03001oogoo035oo`03001oogoo051oo`03001oogoo
03aoo`03001oogoo03=oo`0097oo0P00<Woo00<007ooOol00goo00<007ooOol0BWoo00<007ooOol0
?7oo00<007ooOol0<goo000TOol00`00Oomoo`0aOol00`00Oomoo`02Ool3001:Ool00`00Oomoo`0n
Ool00`00Oomoo`0bOol002Aoo`03001oogoo039oo`03001oogoo009oo`03001oogoo04Uoo`03001o
ogoo03ioo`03001oogoo039oo`0097oo00<007ooOol0<Woo00<007ooOol0CGoo00<007ooOol0?goo
00<007ooOol0<Woo000TOol00`00Oomoo`0bOol00`00Oomoo`1=Ool00`00Oomoo`10Ool00`00Oomo
o`0aOol002Aoo`8003Aoo`03001oogoo04aoo`03001oogoo041oo`03001oogoo035oo`0097oo00<0
07ooOol0<goo00<007ooOol0Bgoo00<007ooOol0@Goo00<007ooOol0<Goo000TOol00`00Oomoo`0d
Ool00`00Oomoo`1:Ool00`00Oomoo`12Ool00`00Oomoo`0`Ool002Aoo`03001oogoo03Aoo`03001o
ogoo04Uoo`03001oogoo04=oo`03001oogoo031oo`0097oo0P00=Goo00<007ooOol0BGoo00<007oo
Ool0A7oo00<007ooOol0;goo000TOol00`00Oomoo`0eOol00`00Oomoo`18Ool00`00Oomoo`14Ool0
0`00Oomoo`0_Ool002Aoo`03001oogoo03Eoo`03001oogoo04Moo`03001oogoo04Eoo`03001oogoo
02moo`0077oo1@000goo00<007ooOol0=Goo00<007ooOol0Agoo00<007ooOol0AWoo00<007ooOol0
;Woo000NOol00`00Oomoo`03Ool00`00Oomoo`0fOol00`00Oomoo`15Ool00`00Oomoo`17Ool00`00
Oomoo`0^Ool001ioo`03001oogoo00=oo`8003Moo`03001oogoo04Eoo`03001oogoo04Moo`03001o
ogoo02ioo`007Woo00<007ooOol00goo00<007ooOol0=goo00<007ooOol0A7oo00<007ooOol0B7oo
00<007ooOol0;Goo000NOol00`00Oomoo`03Ool00`00Oomoo`0gOol00`00Oomoo`13Ool00`00Oomo
o`19Ool00`00Oomoo`0]Ool001eoo`8000Eoo`03001oogoo03Moo`03001oogoo04=oo`03001oogoo
04Uoo`03001oogoo02eoo`0097oo0P00>Goo00<007ooOol0@Goo00<007ooOol0Bgoo00<007ooOol0
0goo00<007ooOol09Woo000TOol00`00Oomoo`0hOol00`00Oomoo`11Ool00`00Oomoo`1;Ool00`00
Oomoo`02Ool3000WOol002Aoo`03001oogoo03Qoo`03001oogoo045oo`03001oogoo04]oo`03001o
ogoo00=oo`03001oogoo02Ioo`0097oo00<007ooOol0>Goo00<007ooOol0?goo00<007ooOol0CGoo
00<007ooOol0:goo000TOol2000jOol00`00Oomoo`0oOol00`00Oomoo`1=Ool00`00Oomoo`0[Ool0
02Aoo`03001oogoo03Uoo`03001oogoo03ioo`03001oogoo04ioo`03001oogoo02]oo`0097oo00<0
07ooOol0>Woo00<007ooOol0?Goo00<007ooOol0Cgoo00<007ooOol0:Woo000TOol00`00Oomoo`0j
Ool00`00Oomoo`0lOol00`00Oomoo`1@Ool00`00Oomoo`0ZOol002Aoo`03001oogoo03]oo`03001o
ogoo03]oo`03001oogoo009oo`03001oogoo04aoo`03001oogoo02Uoo`0097oo0P00?7oo00<007oo
Ool0>goo00@007ooOomoo`<004eoo`03001oogoo02Uoo`0097oo00<007ooOol0>goo00<007ooOol0
>Woo00<007ooOol00goo00<007ooOol0CGoo00<007ooOol0:7oo000TOol00`00Oomoo`0lOol00`00
Oomoo`0iOol00`00Oomoo`1COol00`00Oomoo`0XOol002Aoo`03001oogoo03aoo`03001oogoo03Qo
o`03001oogoo05Aoo`03001oogoo02Qoo`0097oo0P00?Goo00<007ooOol0>7oo00<007ooOol0EGoo
00<007ooOol09goo000TOol00`00Oomoo`0mOol00`00Oomoo`03Ool00`00Oomoo`0aOol00`00Oomo
o`1EOol00`00Oomoo`0WOol000eoo`D0009oo`04001oogooOol30003Ool00`00Oomoo`03Ool00`00
Oomoo`0mOol00`00Oomoo`02Ool3000aOol00`00Oomoo`1GOol00`00Oomoo`0VOol000moo`03001o
ogoo00Ioo`03001oogoo009oo`03001oo`0000Aoo`03001oogoo03eoo`03001oogoo00=oo`03001o
ogoo031oo`03001oogoo05Moo`03001oogoo02Ioo`003goo00<007ooOol01goo00<007ooOol00goo
00<007ooOol00Woo0P00?goo00<007ooOol0=7oo00<007ooOol0FGoo00<007ooOol09Goo000?Ool0
0`00Oomoo`07Ool01000Oomoogoo0P001Goo00<007ooOol0?Woo00<007ooOol0=7oo00<007ooOol0
FGoo00<007ooOol09Goo000?Ool00`00Oomoo`06Ool00`00Ool00002Ool00`00Oomoo`04Ool00`00
Oomoo`0nOol00`00Oomoo`0cOol00`00Oomoo`1KOol00`00Oomoo`0TOol000ioo`8000Uoo`04001o
ogooOol30004Ool00`00Oomoo`0oOol00`00Oomoo`0bOol00`00Oomoo`1KOol00`00Oomoo`0TOol0
02Aoo`03001oogoo03moo`03001oogoo039oo`03001oogoo05]oo`03001oogoo02Aoo`0097oo0P00
@Goo00<007ooOol0<7oo00<007ooOol0GGoo00<007ooOol08goo000TOol00`00Oomoo`10Ool00`00
Oomoo`0`Ool00`00Oomoo`1MOol00`00Oomoo`0SOol002Aoo`03001oogoo041oo`03001oogoo02mo
o`03001oogoo05moo`03001oogoo029oo`0097oo00<007ooOol0@Goo00<007ooOol0;Woo00<007oo
Ool0Ggoo00<007ooOol08Woo000TOol20012Ool00`00Oomoo`0^Ool00`00Oomoo`1POol00`00Oomo
o`0QOol002Aoo`03001oogoo049oo`03001oogoo02aoo`03001oogoo065oo`03001oogoo025oo`00
97oo00<007ooOol0@Woo00<007ooOol0;7oo00<007ooOol0HGoo00<007ooOol017oo00<007ooOol0
6Woo000TOol00`00Oomoo`13Ool00`00Oomoo`0ZOol00`00Oomoo`1SOol00`00Oomoo`02Ool3000K
Ool002Aoo`03001oogoo04=oo`03001oogoo02Yoo`03001oogoo06=oo`03001oogoo00=oo`03001o
ogoo01Yoo`0097oo0P00AGoo00<007ooOol0:Goo00<007ooOol0I7oo00<007ooOol07goo000TOol0
0`00Oomoo`14Ool00`00Oomoo`0XOol00`00Oomoo`1UOol00`00Oomoo`0OOol002Aoo`03001oogoo
04Eoo`03001oogoo02Moo`03001oogoo06Ioo`03001oogoo01ioo`0097oo00<007ooOol0AGoo00<0
07ooOol09Woo00D007ooOomoo`0006Eoo`03001oogoo01ioo`0097oo0P00Agoo00<007ooOol09Goo
00<007ooOol00`00IGoo00<007ooOol07Goo000TOol00`00Oomoo`16Ool00`00Oomoo`0TOol00`00
Oomoo`02Ool00`00Oomoo`1TOol00`00Oomoo`0MOol0019oo`D0009oo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo04Moo`03001oogoo02=oo`03001oogoo06Yoo`03001oogoo01aoo`0057oo
00<007ooOol01Woo00<007oo000017oo00<007ooOol0Agoo00<007ooOol08Woo00<007ooOol0Jgoo
00<007ooOol077oo000DOol00`00Oomoo`08Ool00`00Oomoo`02Ool20019Ool00`00Oomoo`04Ool0
0`00Oomoo`0JOol00`00Oomoo`1/Ool00`00Oomoo`0KOol001Aoo`03001oogoo00Ioo`8000Eoo`03
001oogoo04Qoo`03001oogoo00=oo`<001Yoo`03001oogoo06eoo`03001oogoo01]oo`0057oo00<0
07ooOol01Woo00<007ooOol017oo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol06Goo00<0
07ooOol0KWoo00<007ooOol06Woo000COol20008Ool30004Ool00`00Oomoo`19Ool00`00Oomoo`0N
Ool00`00Oomoo`1_Ool00`00Oomoo`0JOol002Aoo`03001oogoo04Yoo`03001oogoo01eoo`03001o
ogoo071oo`03001oogoo01Uoo`0097oo0P00Bgoo00<007ooOol077oo00<007ooOol0LGoo00<007oo
Ool06Goo000TOol00`00Oomoo`1;Ool00`00Oomoo`0JOol00`00Oomoo`1cOol00`00Oomoo`0HOol0
02Aoo`03001oogoo04]oo`03001oogoo01Yoo`03001oogoo07=oo`03001oogoo01Qoo`0097oo00<0
07ooOol0C7oo00<007ooOol067oo00<007ooOol0MGoo00<007ooOol05goo000TOol2001>Ool00`00
Oomoo`0FOol00`00Oomoo`1gOol00`00Oomoo`05Ool00`00Oomoo`0>Ool002Aoo`03001oogoo04io
o`03001oogoo01Aoo`03001oogoo07Qoo`03001oogoo00Aoo`<000moo`0097oo00<007ooOol0Cgoo
00<007ooOol04goo00<007ooOol0NGoo00<007ooOol017oo00<007ooOol03Woo000TOol00`00Oomo
o`1?Ool00`00Oomoo`0BOol00`00Ool0001kOol00`00Oomoo`0DOol002Aoo`03001oogoo051oo`03
001oogoo00moo`800004Ool00000001kOol00`00Oomoo`0COol002Aoo`80059oo`8000Qoo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo07]oo`03001oogoo019oo`0097oo00<007ooOol0Dgoo
00<007ooOol017oo0`000goo00<007ooOol0PWoo00<007ooOol04Goo000TOol00`00Oomoo`1DOol0
0`00Oomoo`04Ool01@00Oomoogoo0000QWoo00<007ooOol047oo000TOol00`00Oomoo`1EOol30004
Ool30028Ool2000@Ool002Aoo`03001oogoo05Qoo`D009aoo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol007aoo`<002Moo`<007Moo`00OGoo00<007ooOol09goo00<007ooOol0
MWoo001_Ool20003Ool30002Ool20002Ool30003Ool30002Ool2000=Ool3000017oo001oogoo0P00
0Woo0P000goo0`000goo0P0000=oo`0000000Woo00@007oo000000Aoo`80069oo`00KWoo00H007oo
Ool007oo0002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool0
0`00Oomoo`0;Ool01P00Oomoo`00Ool000Ioo`04001oogoo0002Ool00`00Ool00002Ool00`00Ool0
0002Ool01@00Oomoogoo00000Woo00<007ooOol0HWoo001^Ool01P00Oomoo`00Ool0009oo`03001o
o`0000Aoo`06001oogoo001oo`000Woo00<007oo000047oo0`000Woo0`000goo00D007ooOomoo`00
009oo`03001oo`00009oo`03001oo`00009oo`04001oogoo0003Ool3001ROol006ioo`03001oogoo
00<00003Ool0000000@00003Ool0000000800004Ool00000Ool6000>Ool01@00Oomoo`00Ool00`00
0goo0P0000=oo`0000000P000goo0P0000=oo`0000000P000goo0P000Woo0`00HWoo001^Ool01000
Oomoo`001Woo00<007ooOol037oo00<007ooOol03Woo00@007ooOol008Aoo`00Kgoo0P009Woo1000
QGoo003oOolQOol00?moob5oo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-1.54087, -0.137595, 
  0.0424606, 0.0113803}},
  CellTags->"3.5"],

Cell["The Conversion Methods", "Subsubsection",
  CellTags->"3.5"],

Cell[TextData[{
  "The conversion from the continuous\[Hyphen]time domain to the discrete\
\[Hyphen]time domain can currently be performed using the following methods, \
described in Franklin ",
  StyleBox["et al.", "TI"],
  " (1990), Section\[NonBreakingSpace]4. The method can be selected with the \
",
  StyleBox["Method", "MR"],
  " option. \n\[FilledSmallSquare] ",
  StyleBox["Hold equivalence", "TI"],
  " methods\[LongDash]zero\[Hyphen] and first\[Hyphen]order (triangle) hold, \
implemented with ",
  StyleBox["ZeroOrderHold", "MR"],
  " and ",
  StyleBox["FirstOrderHold", "MR"],
  ", respectively    \n\[FilledSmallSquare] ",
  StyleBox["Numerical integration", "TI"],
  " methods\[LongDash]forward and backward rectangular rules, implemented \
with ",
  StyleBox["ForwardRectangularRule\[NonBreakingSpace]", "MR"],
  "and ",
  StyleBox["BackwardRectangularRule", "MR"],
  ", respectively, and bilinear (Tustin) transform with and without \
prewarping, implemented with ",
  StyleBox["BilinearTransform", "MR"],
  "      \n\[FilledSmallSquare] ",
  StyleBox["Zero\[Hyphen]pole mapping", "TI"],
  ", implemented with ",
  StyleBox["ZeroPoleMapping", "MR"],
  "  "
}], "Text",
  CellTags->"3.5"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], " "},
          {
            StyleBox[
              FormBox["Method",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["ZeroOrderHold",
                "StandardForm"],
              "Text"], 
            StyleBox[\(method\ to\ use\ for\ transformation\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["CriticalFrequency",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            
            StyleBox[\(critical\ frequency, \ if\ any, \ 
              at\ which\ to\ make\ comparisons\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.29, 0.3, 0.41},
  RowLines->{True, False}},
  CellTags->"3.5"],

Cell["Options related to continuous\[Hyphen] to discrete\[Hyphen]time \
conversion. ", "Caption",
  CellTags->"3.5"],

Cell[TextData[{
  "This is the result of conversion with the forward rule of the transfer \
function system ",
  StyleBox["tf", "MR"],
  " defined earlier in this chapter. "
}], "MathCaption",
  CellTags->"3.5"],

Cell["\<\
ToDiscreteTime[tf, Sampled->Period[T],
 Method->ForwardRectangularRule]\
\>", "Input",
  CellLabel->"In[48]:=",
  CellTags->"3.5"],

Cell[BoxData[
    \(TransferFunction[s, {{\(a\ T\)\/\(\(-1\) + s + a\ T\)}}, 
      Sampled \[Rule] Period[T]]\)], "Output",
  CellLabel->"Out[48]=",
  CellTags->"3.5"],

Cell["\<\
This is the conversion of the same transfer function using the \
backward rule. \
\>", "MathCaption",
  CellTags->"3.5"],

Cell["\<\
ToDiscreteTime[tf, Sampled->Period[T],
 Method->BackwardRectangularRule]\
\>", "Input",
  CellLabel->"In[49]:=",
  CellTags->"3.5"],

Cell[BoxData[
    \(TransferFunction[s, {{\(a\ s\ T\)\/\(\(-1\) + s + a\ s\ T\)}}, 
      Sampled \[Rule] Period[T]]\)], "Output",
  CellLabel->"Out[49]=",
  CellTags->"3.5"],

Cell["\<\
This conversion uses the bilinear transform and simplifies the \
result. \
\>", "MathCaption",
  CellTags->"3.5"],

Cell["\<\
ToDiscreteTime[tf, Sampled->Period[T],
 Method->BilinearTransform
] //Simplify\
\>", "Input",
  CellLabel->"In[50]:=",
  CellTags->"3.5"],

Cell[BoxData[
    \(TransferFunction[s, 
      {{\(a\ \((1 + s)\)\ T\)\/\(\(-2\) + 2\ s + a\ T + a\ s\ T\)}}, 
      Sampled \[Rule] Period[T]]\)], "Output",
  CellLabel->"Out[50]=",
  CellTags->"3.5"],

Cell["\<\
Here is how we find the discrete\[Hyphen]time approximation using \
zero\[Hyphen]pole mapping. \
\>", "MathCaption",
  CellTags->"3.5"],

Cell["\<\
ToDiscreteTime[tf, Sampled->Period[T],
 Method->ZeroPoleMapping]\
\>", "Input",
  CellLabel->"In[51]:=",
  CellTags->"3.5"],

Cell[BoxData[
    \(TransferFunction[s, 
      {{\(1 - E\^\(\(-a\)\ T\)\)\/\(\(-E\^\(\(-a\)\ T\)\) + s\)}}, 
      Sampled \[Rule] Period[T]]\)], "Output",
  CellLabel->"Out[51]=",
  CellTags->"3.5"],

Cell[TextData[{
  "This is the first\[Hyphen]order\[Hyphen]hold equivalent of the transfer \
function ",
  Cell[BoxData[
      \(TraditionalForm\`H(s) = 1/s\^2\)], "InlineFormula",
    CellTags->"S0.0.6"],
  ". "
}], "MathCaption",
  CellTags->"3.5"],

Cell["\<\
ToDiscreteTime[
 TransferFunction[s, 1/s^2],
 Sampled->Period[T],
 Method->FirstOrderHold
]//Simplify\
\>", "Input",
  CellLabel->"In[52]:=",
  CellTags->"3.5"],

Cell[BoxData[
    \(TransferFunction[s, 
      {{\(\((1 + 4\ s + s\^2)\)\ T\^2\)\/\(6\ \((\(-1\) + s)\)\^2\)}}, 
      Sampled \[Rule] Period[T]]\)], "Output",
  CellLabel->"Out[52]=",
  CellTags->"3.5"],

Cell[TextData[{
  "Yet another example, a lag network, illustrates the effect of the option ",
  
  StyleBox["CriticalFrequency", "MR"],
  " on accuracy of the conversion.  "
}], "MathCaption",
  CellTags->"3.5"],

Cell["lag = TransferFunction[s, (a s + 1)/(b s + 1)]", "Input",
  CellLabel->"In[53]:=",
  CellTags->"3.5"],

Cell[BoxData[
    \(TransferFunction[s, {{\(1 + a\ s\)\/\(1 + b\ s\)}}]\)], "Output",
  CellLabel->"Out[53]=",
  CellTags->"3.5"],

Cell["\<\
Here is the Bode plot for the network for some set of parameters. \
\
\>", "MathCaption",
  CellTags->"3.5"],

Cell["lagplot = BodePlot[lag/.{a->1, b->5}];", "Input",
  CellLabel->"In[54]:=",
  CellTags->"3.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.29787 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0309017 0.952381 [
[ 0 0 0 0 ]
[ 1 1.29787 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.29787 L
0 1.29787 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0309017 0.97619 0.619505 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.637418 0.0148941 [
[.02381 -0.0125 -14 -12.5625 ]
[.02381 -0.0125 14 0 ]
[.2457 -0.0125 -14 -12.5625 ]
[.2457 -0.0125 14 0 ]
[.34127 -0.0125 -11 -12.5625 ]
[.34127 -0.0125 11 0 ]
[.56317 -0.0125 -11 -12.5625 ]
[.56317 -0.0125 11 0 ]
[.65873 -0.0125 -5 -12.5625 ]
[.65873 -0.0125 5 0 ]
[.88063 -0.0125 -5 -12.5625 ]
[.88063 -0.0125 5 0 ]
[.97619 -0.0125 -8 -12.5625 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .04165 -18 -4.5 ]
[-0.0125 .04165 0 4.5 ]
[-0.0125 .19059 -18 -4.5 ]
[-0.0125 .19059 0 4.5 ]
[-0.0125 .33954 -18 -4.5 ]
[-0.0125 .33954 0 4.5 ]
[-0.0125 .48848 -18 -4.5 ]
[-0.0125 .48848 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -35 ]
[-0.01875 .30902 -18 35 ]
[.02381 .63053 -14 0 ]
[.02381 .63053 14 12.5625 ]
[.2457 .63053 -14 0 ]
[.2457 .63053 14 12.5625 ]
[.34127 .63053 -11 0 ]
[.34127 .63053 11 12.5625 ]
[.56317 .63053 -11 0 ]
[.56317 .63053 11 12.5625 ]
[.65873 .63053 -5 0 ]
[.65873 .63053 5 12.5625 ]
[.88063 .63053 -5 0 ]
[.88063 .63053 5 12.5625 ]
[.97619 .63053 -8 0 ]
[.97619 .63053 8 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2457 0 m
.2457 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.56317 0 m
.56317 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.88063 0 m
.88063 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.11937 0 m
.11937 .61803 L
s
.17528 0 m
.17528 .61803 L
s
.21494 0 m
.21494 .61803 L
s
.27084 0 m
.27084 .61803 L
s
.29209 0 m
.29209 .61803 L
s
.3105 0 m
.3105 .61803 L
s
.32674 0 m
.32674 .61803 L
s
.43683 0 m
.43683 .61803 L
s
.49274 0 m
.49274 .61803 L
s
.5324 0 m
.5324 .61803 L
s
.5883 0 m
.5883 .61803 L
s
.60955 0 m
.60955 .61803 L
s
.62797 0 m
.62797 .61803 L
s
.6442 0 m
.6442 .61803 L
s
.7543 0 m
.7543 .61803 L
s
.8102 0 m
.8102 .61803 L
s
.84986 0 m
.84986 .61803 L
s
.90576 0 m
.90576 .61803 L
s
.92702 0 m
.92702 .61803 L
s
.94543 0 m
.94543 .61803 L
s
.96166 0 m
.96166 .61803 L
s
0 .04165 m
1 .04165 L
s
0 .19059 m
1 .19059 L
s
0 .33954 m
1 .33954 L
s
0 .48848 m
1 .48848 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 0 m
.2457 .00625 L
s
gsave
.2457 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 0 m
.56317 .00625 L
s
gsave
.56317 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 0 m
.88063 .00625 L
s
gsave
.88063 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 0 m
.11937 .00375 L
s
.17528 0 m
.17528 .00375 L
s
.21494 0 m
.21494 .00375 L
s
.27084 0 m
.27084 .00375 L
s
.29209 0 m
.29209 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.32674 0 m
.32674 .00375 L
s
.43683 0 m
.43683 .00375 L
s
.49274 0 m
.49274 .00375 L
s
.5324 0 m
.5324 .00375 L
s
.5883 0 m
.5883 .00375 L
s
.60955 0 m
.60955 .00375 L
s
.62797 0 m
.62797 .00375 L
s
.6442 0 m
.6442 .00375 L
s
.7543 0 m
.7543 .00375 L
s
.8102 0 m
.8102 .00375 L
s
.84986 0 m
.84986 .00375 L
s
.90576 0 m
.90576 .00375 L
s
.92702 0 m
.92702 .00375 L
s
.94543 0 m
.94543 .00375 L
s
.96166 0 m
.96166 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .04165 m
.00625 .04165 L
s
[(-40)] -0.0125 .04165 1 0 Mshowa
0 .19059 m
.00625 .19059 L
s
[(-30)] -0.0125 .19059 1 0 Mshowa
0 .33954 m
.00625 .33954 L
s
[(-20)] -0.0125 .33954 1 0 Mshowa
0 .48848 m
.00625 .48848 L
s
[(-10)] -0.0125 .48848 1 0 Mshowa
.125 Mabswid
0 .07144 m
.00375 .07144 L
s
0 .10123 m
.00375 .10123 L
s
0 .13102 m
.00375 .13102 L
s
0 .16081 m
.00375 .16081 L
s
0 .22038 m
.00375 .22038 L
s
0 .25017 m
.00375 .25017 L
s
0 .27996 m
.00375 .27996 L
s
0 .30975 m
.00375 .30975 L
s
0 .36932 m
.00375 .36932 L
s
0 .39911 m
.00375 .39911 L
s
0 .4289 m
.00375 .4289 L
s
0 .45869 m
.00375 .45869 L
s
0 .01187 m
.00375 .01187 L
s
0 .51827 m
.00375 .51827 L
s
0 .54805 m
.00375 .54805 L
s
0 .57784 m
.00375 .57784 L
s
0 .60763 m
.00375 .60763 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -120.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
96 10.2813 translate
90 rotate
-96 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(deg) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(L) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 .61178 m
.2457 .61803 L
s
gsave
.2457 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 .61178 m
.34127 .61803 L
s
gsave
.34127 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 .61178 m
.56317 .61803 L
s
gsave
.56317 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 .61178 m
.65873 .61803 L
s
gsave
.65873 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 .61178 m
.88063 .61803 L
s
gsave
.88063 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 .61428 m
.11937 .61803 L
s
.17528 .61428 m
.17528 .61803 L
s
.21494 .61428 m
.21494 .61803 L
s
.27084 .61428 m
.27084 .61803 L
s
.29209 .61428 m
.29209 .61803 L
s
.3105 .61428 m
.3105 .61803 L
s
.32674 .61428 m
.32674 .61803 L
s
.43683 .61428 m
.43683 .61803 L
s
.49274 .61428 m
.49274 .61803 L
s
.5324 .61428 m
.5324 .61803 L
s
.5883 .61428 m
.5883 .61803 L
s
.60955 .61428 m
.60955 .61803 L
s
.62797 .61428 m
.62797 .61803 L
s
.6442 .61428 m
.6442 .61803 L
s
.7543 .61428 m
.7543 .61803 L
s
.8102 .61428 m
.8102 .61803 L
s
.84986 .61428 m
.84986 .61803 L
s
.90576 .61428 m
.90576 .61803 L
s
.92702 .61428 m
.92702 .61803 L
s
.94543 .61428 m
.94543 .61803 L
s
.96166 .61428 m
.96166 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04165 m
1 .04165 L
s
.99375 .19059 m
1 .19059 L
s
.99375 .33954 m
1 .33954 L
s
.99375 .48848 m
1 .48848 L
s
.125 Mabswid
.99625 .07144 m
1 .07144 L
s
.99625 .10123 m
1 .10123 L
s
.99625 .13102 m
1 .13102 L
s
.99625 .16081 m
1 .16081 L
s
.99625 .22038 m
1 .22038 L
s
.99625 .25017 m
1 .25017 L
s
.99625 .27996 m
1 .27996 L
s
.99625 .30975 m
1 .30975 L
s
.99625 .36932 m
1 .36932 L
s
.99625 .39911 m
1 .39911 L
s
.99625 .4289 m
1 .4289 L
s
.99625 .45869 m
1 .45869 L
s
.99625 .01187 m
1 .01187 L
s
.99625 .51827 m
1 .51827 L
s
.99625 .54805 m
1 .54805 L
s
.99625 .57784 m
1 .57784 L
s
.99625 .60763 m
1 .60763 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.05665 .59417 L
.08949 .5826 L
.12233 .56797 L
.15517 .54952 L
.18801 .52634 L
.22085 .4974 L
.25369 .4616 L
.28654 .41796 L
.31938 .36596 L
.35222 .30605 L
.38506 .24029 L
.4179 .1729 L
.45074 .11002 L
.48358 .05876 L
.51642 .02555 L
.54926 .01472 L
.5821 .02767 L
.61494 .06272 L
.64778 .11531 L
.68062 .17888 L
.71346 .24636 L
.74631 .31173 L
.77915 .37098 L
.81199 .42223 L
.84483 .46513 L
.87767 .50027 L
.91051 .52865 L
.94335 .55136 L
.97619 .56943 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.678366 0.97619 1.26697 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.603319 0.0422304 [
[.02381 -0.0125 -14 -12.5625 ]
[.02381 -0.0125 14 0 ]
[.2457 -0.0125 -14 -12.5625 ]
[.2457 -0.0125 14 0 ]
[.34127 -0.0125 -11 -12.5625 ]
[.34127 -0.0125 11 0 ]
[.56317 -0.0125 -11 -12.5625 ]
[.56317 -0.0125 11 0 ]
[.65873 -0.0125 -5 -12.5625 ]
[.65873 -0.0125 5 0 ]
[.88063 -0.0125 -5 -12.5625 ]
[.88063 -0.0125 5 0 ]
[.97619 -0.0125 -8 -12.5625 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .01209 -18 -4.5 ]
[-0.0125 .01209 0 4.5 ]
[-0.0125 .09655 -18 -4.5 ]
[-0.0125 .09655 0 4.5 ]
[-0.0125 .18102 -18 -4.5 ]
[-0.0125 .18102 0 4.5 ]
[-0.0125 .26548 -12 -4.5 ]
[-0.0125 .26548 0 4.5 ]
[-0.0125 .34994 -12 -4.5 ]
[-0.0125 .34994 0 4.5 ]
[-0.0125 .4344 -12 -4.5 ]
[-0.0125 .4344 0 4.5 ]
[-0.0125 .51886 -12 -4.5 ]
[-0.0125 .51886 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -44 ]
[-0.01875 .30902 -18 44 ]
[.02381 .63053 -14 0 ]
[.02381 .63053 14 12.5625 ]
[.2457 .63053 -14 0 ]
[.2457 .63053 14 12.5625 ]
[.34127 .63053 -11 0 ]
[.34127 .63053 11 12.5625 ]
[.56317 .63053 -11 0 ]
[.56317 .63053 11 12.5625 ]
[.65873 .63053 -5 0 ]
[.65873 .63053 5 12.5625 ]
[.88063 .63053 -5 0 ]
[.88063 .63053 5 12.5625 ]
[.97619 .63053 -8 0 ]
[.97619 .63053 8 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2457 0 m
.2457 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.56317 0 m
.56317 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.88063 0 m
.88063 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.11937 0 m
.11937 .61803 L
s
.17528 0 m
.17528 .61803 L
s
.21494 0 m
.21494 .61803 L
s
.27084 0 m
.27084 .61803 L
s
.29209 0 m
.29209 .61803 L
s
.3105 0 m
.3105 .61803 L
s
.32674 0 m
.32674 .61803 L
s
.43683 0 m
.43683 .61803 L
s
.49274 0 m
.49274 .61803 L
s
.5324 0 m
.5324 .61803 L
s
.5883 0 m
.5883 .61803 L
s
.60955 0 m
.60955 .61803 L
s
.62797 0 m
.62797 .61803 L
s
.6442 0 m
.6442 .61803 L
s
.7543 0 m
.7543 .61803 L
s
.8102 0 m
.8102 .61803 L
s
.84986 0 m
.84986 .61803 L
s
.90576 0 m
.90576 .61803 L
s
.92702 0 m
.92702 .61803 L
s
.94543 0 m
.94543 .61803 L
s
.96166 0 m
.96166 .61803 L
s
0 .09655 m
1 .09655 L
s
0 .18102 m
1 .18102 L
s
0 .26548 m
1 .26548 L
s
0 .34994 m
1 .34994 L
s
0 .4344 m
1 .4344 L
s
0 .51886 m
1 .51886 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 0 m
.2457 .00625 L
s
gsave
.2457 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 0 m
.56317 .00625 L
s
gsave
.56317 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 0 m
.88063 .00625 L
s
gsave
.88063 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 0 m
.11937 .00375 L
s
.17528 0 m
.17528 .00375 L
s
.21494 0 m
.21494 .00375 L
s
.27084 0 m
.27084 .00375 L
s
.29209 0 m
.29209 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.32674 0 m
.32674 .00375 L
s
.43683 0 m
.43683 .00375 L
s
.49274 0 m
.49274 .00375 L
s
.5324 0 m
.5324 .00375 L
s
.5883 0 m
.5883 .00375 L
s
.60955 0 m
.60955 .00375 L
s
.62797 0 m
.62797 .00375 L
s
.6442 0 m
.6442 .00375 L
s
.7543 0 m
.7543 .00375 L
s
.8102 0 m
.8102 .00375 L
s
.84986 0 m
.84986 .00375 L
s
.90576 0 m
.90576 .00375 L
s
.92702 0 m
.92702 .00375 L
s
.94543 0 m
.94543 .00375 L
s
.96166 0 m
.96166 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .01209 m
.00625 .01209 L
s
[(-14)] -0.0125 .01209 1 0 Mshowa
0 .09655 m
.00625 .09655 L
s
[(-12)] -0.0125 .09655 1 0 Mshowa
0 .18102 m
.00625 .18102 L
s
[(-10)] -0.0125 .18102 1 0 Mshowa
0 .26548 m
.00625 .26548 L
s
[(-8)] -0.0125 .26548 1 0 Mshowa
0 .34994 m
.00625 .34994 L
s
[(-6)] -0.0125 .34994 1 0 Mshowa
0 .4344 m
.00625 .4344 L
s
[(-4)] -0.0125 .4344 1 0 Mshowa
0 .51886 m
.00625 .51886 L
s
[(-2)] -0.0125 .51886 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03321 m
.00375 .03321 L
s
0 .05432 m
.00375 .05432 L
s
0 .07544 m
.00375 .07544 L
s
0 .11767 m
.00375 .11767 L
s
0 .13878 m
.00375 .13878 L
s
0 .1599 m
.00375 .1599 L
s
0 .20213 m
.00375 .20213 L
s
0 .22325 m
.00375 .22325 L
s
0 .24436 m
.00375 .24436 L
s
0 .28659 m
.00375 .28659 L
s
0 .30771 m
.00375 .30771 L
s
0 .32882 m
.00375 .32882 L
s
0 .37105 m
.00375 .37105 L
s
0 .39217 m
.00375 .39217 L
s
0 .41328 m
.00375 .41328 L
s
0 .45551 m
.00375 .45551 L
s
0 .47663 m
.00375 .47663 L
s
0 .49774 m
.00375 .49774 L
s
0 .53997 m
.00375 .53997 L
s
0 .56109 m
.00375 .56109 L
s
0 .5822 m
.00375 .5822 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -129.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 10.2813 translate
90 rotate
-105 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnitude) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 .61178 m
.2457 .61803 L
s
gsave
.2457 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 .61178 m
.34127 .61803 L
s
gsave
.34127 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 .61178 m
.56317 .61803 L
s
gsave
.56317 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 .61178 m
.65873 .61803 L
s
gsave
.65873 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 .61178 m
.88063 .61803 L
s
gsave
.88063 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 .61428 m
.11937 .61803 L
s
.17528 .61428 m
.17528 .61803 L
s
.21494 .61428 m
.21494 .61803 L
s
.27084 .61428 m
.27084 .61803 L
s
.29209 .61428 m
.29209 .61803 L
s
.3105 .61428 m
.3105 .61803 L
s
.32674 .61428 m
.32674 .61803 L
s
.43683 .61428 m
.43683 .61803 L
s
.49274 .61428 m
.49274 .61803 L
s
.5324 .61428 m
.5324 .61803 L
s
.5883 .61428 m
.5883 .61803 L
s
.60955 .61428 m
.60955 .61803 L
s
.62797 .61428 m
.62797 .61803 L
s
.6442 .61428 m
.6442 .61803 L
s
.7543 .61428 m
.7543 .61803 L
s
.8102 .61428 m
.8102 .61803 L
s
.84986 .61428 m
.84986 .61803 L
s
.90576 .61428 m
.90576 .61803 L
s
.92702 .61428 m
.92702 .61803 L
s
.94543 .61428 m
.94543 .61803 L
s
.96166 .61428 m
.96166 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01209 m
1 .01209 L
s
.99375 .09655 m
1 .09655 L
s
.99375 .18102 m
1 .18102 L
s
.99375 .26548 m
1 .26548 L
s
.99375 .34994 m
1 .34994 L
s
.99375 .4344 m
1 .4344 L
s
.99375 .51886 m
1 .51886 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03321 m
1 .03321 L
s
.99625 .05432 m
1 .05432 L
s
.99625 .07544 m
1 .07544 L
s
.99625 .11767 m
1 .11767 L
s
.99625 .13878 m
1 .13878 L
s
.99625 .1599 m
1 .1599 L
s
.99625 .20213 m
1 .20213 L
s
.99625 .22325 m
1 .22325 L
s
.99625 .24436 m
1 .24436 L
s
.99625 .28659 m
1 .28659 L
s
.99625 .30771 m
1 .30771 L
s
.99625 .32882 m
1 .32882 L
s
.99625 .37105 m
1 .37105 L
s
.99625 .39217 m
1 .39217 L
s
.99625 .41328 m
1 .41328 L
s
.99625 .45551 m
1 .45551 L
s
.99625 .47663 m
1 .47663 L
s
.99625 .49774 m
1 .49774 L
s
.99625 .53997 m
1 .53997 L
s
.99625 .56109 m
1 .56109 L
s
.99625 .5822 m
1 .5822 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60288 m
.05665 .60261 L
.08949 .60218 L
.12233 .60149 L
.15517 .60039 L
.18801 .59862 L
.22085 .59581 L
.25369 .59139 L
.28654 .58451 L
.31938 .57399 L
.35222 .55832 L
.38506 .53586 L
.4179 .50515 L
.45074 .46553 L
.48358 .41758 L
.51642 .36324 L
.54926 .30552 L
.5821 .24796 L
.61494 .19409 L
.64778 .14683 L
.68062 .108 L
.71346 .07808 L
.74631 .05629 L
.77915 .04116 L
.81199 .03102 L
.84483 .02441 L
.87767 .02016 L
.91051 .01747 L
.94335 .01578 L
.97619 .01472 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[54]:=",
  ImageSize->{221.875, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M000181000`40O003h00OgGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo001<Ool2000EOol2000EOol00`00Oomo
o`0lOol00`00Oomoo`0QOol004eoo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo01=oo`03
001oogoo02Qoo`03001oogoo021oo`00>Woo0`000goo0`000goo0P000goo0`000Woo0`000Woo0P00
00=oo`0000000Woo00<007oo00000P000goo00<007ooOol04Goo00@007ooOomoo`<00003Ool007oo
00@0009oo`<000Eoo`03001oogoo009oo`<000=oo`80009oo`<000=oo`800003Ool00000009oo`03
001oogoo00<000Uoo`03001oogoo01moo`00>goo00<007ooOol00goo00D007ooOomoo`0000Aoo`06
001oogoo001oo`000Woo00<007oo000017oo00H007ooOol007oo0004Ool00`00Ool0000BOol00`00
Oomoo`02Ool01@00Oomoo`00Ool00`000Woo00@007ooOol000Eoo`03001oogoo009oo`03001oo`00
009oo`03001oogoo009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<0
07ooOol01goo00<007ooOol07goo000kOol00`00Oomoo`03Ool01000Oomoogoo0`000Woo00H007oo
Ool007oo0002Ool00`00Ool000020002Ool01P00Oomoo`00Ool000Aoo`03001oo`00019oo`03001o
ogoo009oo`<000Aoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03
0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo00Moo`03
001oogoo01moo`00>goo0P000goo100000Aoo`00000000=oo`D00004Ool00000Ool300000goo0000
00020002Ool3000017oo000007oo0P004Goo00<007ooOol00Woo00@007ooOol0009oo`8000=oo`<0
00Ioo`03001oogoo009oo`04001oogooOol30002Ool30003Ool200000goo000000020003Ool30009
Ool00`00Oomoo`0OOol003]oo`04001oogoo000jOol01@00Oomoogoo00000Woo00<007ooOol01goo
00<007ooOol017oo00L007ooOomoo`00Ool0000IOol00`00Oomoo`06Ool00`00Oomoo`0POol003Yo
o`D003]oo`03001oo`0000<000Uoo`8000Moo`03001oogoo00<001Qoo`8000Moo`03001oogoo025o
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo000^Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`05000>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20004
Ool00`00Oomoo`05000COol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool5000MOol0
0`00Oomoo`06Ool50002Ool00`00Oomoo`0HOol002eoo`03001oo`0000Moo`03001oo`0000=oo`03
001oogoo00eoo`03001oo`0000Moo`03001oo`00009oo`@000Qoo`03001oogoo019oo`03001oo`00
00Moo`03001oo`0000Qoo`03001oogoo01aoo`03001oo`0000Uoo`07001oogooOol007oo00006Goo
000]Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Ool00007Ool00`00Ool0
0003Ool30008Ool00`00Oomoo`0BOol00`00Ool00009Ool00`00Oomoo`06Ool00`00Oomoo`0NOol0
0`00Oomoo`07Ool01`00Oomoogoo001oo`0001Uoo`00;Goo00<007oo00001goo00<007oo00000goo
00<007ooOol03Goo00<007oo00001goo00<007oo00000Woo0P0000=oo`00Ool01goo00<007ooOol0
4Woo00<007oo00001goo0P002Goo00<007ooOol077oo0P002Woo00L007ooOomoo`00Ool0000IOol0
02eoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo00eoo`03001oo`0000Moo`03001oo`00
009oo`800003Ool007oo00Moo`03001oogoo019oo`03001oo`0000Moo`03001oogoo00Qoo`03001o
ogoo01aoo`03001oogoo00Uoo`07001oogooOol007oo00006Goo000^Ool00`00Oomoo`07Ool01000
Oomoogoo0P0047oo00<007ooOol01goo00@007ooOomoo`<000Qoo`8001Eoo`03001oogoo00Ioo`<0
00Moo`8001ioo`<000Qoo`8000Aoo`03001oogoo01Qoo`00gGoo003MOol00=eoo`00=7ooT@0067oo
000dOol01@00Oomoogoo00003Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo00@0
07ooOol0009oo`08001oogoo001oo`00Ool000eoo`03001oogoo00Eoo`03001oogoo00=oo`05001o
ogooOol00003Ool01000Oomoo`000Woo00D007oo001oo`0000eoo`03001oogoo00Eoo`03001oogoo
009oo`03001oogoo009oo`04001oogoo0003Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomo
o`0FOol003Aoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00@03goo00moo`80
01Qoo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?000000020003Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00
Oomoo`0FOol002]oo`<0009oo`05001oogooOol00003Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<0
3gooOol01Goo00@03gooOomoo`<000=oo`0500l0000000003`02Ool0200?Oomoo`0?Ool03goo00l=
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l0
0Woo00<03goo00l00Woo00<007ooOol05Woo000/Ool01P00Oomoo`00Ool0009oo`05001oogooOol0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03goo
Ool03goo00moo`0?3Goo00<03gooOol01Goo00@03gooOol0009oo`0500moogooOol03`03Ool01000
Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol002Eoo`<0009o
o`@00004Ool007oo0002Ool2001700l00`0000l03`0:00l00`0000l03`0f00l2000HOol002Yoo`03
001oo`00009oo`03001oo`00009oo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo
00<03`00Ool00goo00D03gooOomoo`0?00=oo`0400moo`0000l2Ool01@0?Ool03goo00l03Goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`03
00moo`0?009oo`03001oogoo01Ioo`00:goo0P000Woo00<007oo00000Woo00D007ooOomoo`0?00eo
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?
Ool03goo00l=Ool00`0?Oomoo`05Ool00`00Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol0
009oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000/Ool01@00Oomoogoo
00000goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`04Ool00`0000moo`04Ool01@0?
Oomoogoo00l00goo00/03gooOol03`00Ool03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomo
o`0FOol003Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol00goo00<007oo00l01Goo
00D03gooOomoo`0?00=oo`0;00moogoo00moo`0000moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<0
07ooOol05Woo000dOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol00goo00<007oo
00l01Goo00D03gooOomoo`0?00=oo`0;00moogoo00moo`0000moo`0?Ool03`0=Ool00`0?Oomoo`05
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00@03goo00mo
o`8001Qoo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`02Ool01000Oomoo`0?
1Goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@00Ool03goo00l03Goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009o
o`03001oogoo01Ioo`005Woo00<007ooOol00Woo00<007ooOol05Woo00D007ooOomoo`0?00eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool0
3goo00l=Ool01@0?Oomoogoo00000goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo
00l2Ool01@00Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo1P0067oo00D0
07ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2
Ool0200?Oomoo`0?Ool03goo00l=Ool0100?Oomoo`0017oo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool01@0?00003goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`00
5Woo00H007ooOol007oo000HOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00@03gooOol000Ao
o`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03`0000moo`0?00eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool0
100?Ool03goo0P0067oo000FOol01000Oomoo`006Woo00D007ooOomoo`0?00eoo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool0
0`0?Ool00005Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`00
Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<0
3goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000GOol2000KOol01@00Oomoogoo00l03Goo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00mo
o`0?Ool03`eoo`0300l007oo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?
0Woo00D03goo001oo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`05001oogooOol0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03goo
Ool03goo00moo`0?3Goo00<03`00Ool01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03`0000l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo00<007oo
Ool00Woo00<007ooOol05Woo0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`03001oogoo00Eoo`03
00moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00l0000?00eoo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool0100?
Ool03goo0P0067oo000FOol6000HOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`03001oogoo00Eo
o`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0000eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool0
0`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`04001oogoo000HOol01@00Oomoogoo00l03Goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?
Ool03`aoo`0300003goo00Ioo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0000eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`03001oogoo01Uoo`05
001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00P03gooOol03goo00moo`0?37oo00<0000?Ool01Woo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool01P0?Ool03goo00l000aoo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol0
01Uoo`<001Qoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?2goo00<007oo00l01goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01P0?Ool03goo00l000aoo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool0
0`00Oomoo`0FOol001]oo`03001oogoo01Ioo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l;Ool00`00
Ool03`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0700moo`0?Ool0
3goo00002goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`03
00moo`0?009oo`0400moo`0?Ool2000HOol003Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?2Woo00@0
07ooOol03`Moo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00L03goo00mo
o`0?Ool0000;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo
00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000JOol2000>Ool20004Ool01@00Oomo
ogoo00000goo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`9oo`0800moogoo00moo`0?Ool03`Yoo`04001oogoo00l7Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`02Ool00`00Oomoo`08Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo
00l00Woo00<007ooOol05Woo000HOol01000Ool0000047oo00H007ooOol007oo0002Ool01@00Oomo
ogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`08
00moogoo00moo`0?Ool03`Uoo`05001oogooOol03`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`07Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<0
07ooOol05Woo000HOol01000Ool000002Goo0`000goo00L007ooOomoo`00Ool00002Ool2000i00l0
0`0000l03`0U00l00`0000l03`0Y00l2000HOol001Qoo`@0011oo`06001oogoo001oo`000Woo00D0
07ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2
Ool0200?Oomoo`0?Ool03goo00l8Ool00`00Oomoo`02Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`04Ool00`00Oomoo`06Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<0
3goo00l00Woo00<007ooOol05Woo000KOol00`00Oomoo`0<Ool00`00Ool00002Ool00`00Ool00002
Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`9oo`0800moogoo00moo`0?Ool03`Qoo`03001oogoo009oo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00Aoo`03001oogoo00Io
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02
Ool00`0?Ool03`02Ool00`00Oomoo`0FOol002]oo`03001oogoo009oo`05001oogooOol00003Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00P03gooOol03goo00moo`0?27oo00<007ooOol00Woo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l01Goo00<007ooOol01Goo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300mo
o`0?009oo`03001oogoo01Ioo`0067oo0P0000=oo`00Ool05goo0P000Woo00<03gooOol02goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?
Ool03`Moo`03001oogoo00=oo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00D03goo00moo`0?00Eoo`03001oogoo00Eoo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool0100?Ool03goo0P0067oo000H
Ool200000goo001oo`0GOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`Moo`03001oogoo00=oo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?
00Ioo`03001oogoo00Aoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`800003Ool007oo01Mo
o`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0Woo00P03gooOol03goo00moo`0?1Woo00<007ooOol017oo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l01Woo00<007ooOol017oo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009o
o`0300moo`0?009oo`03001oogoo01Ioo`0067oo00<007oo00006Goo00D007ooOomoo`0?00eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool0
3goo00l6Ool00`00Oomoo`04Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00@03gooOol03`9oo`0500moo`0?Ool03`07Ool00`00Oomoo`03Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007oo
Ool05Woo000dOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?1Goo00<007ooOol01Goo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l01goo
00<007ooOol00goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=o
o`0300moo`0?009oo`0400moo`0?Ool2000HOol003Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?1Goo
00<007ooOol01Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo
00l2Ool01@0?Ool03goo00l027oo00<007ooOol00Woo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`00
6Goo0P006Goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l4Ool00`00Oomoo`06Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`08Ool00`00
Oomoo`02Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<0
3goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000HOol200000goo001oo`0GOol01@00Oomo
ogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`08
00moogoo00moo`0?Ool03`Aoo`03001oogoo00Ioo`0300moogoo00Eoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00Uoo`05001oogooOol03`07Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<0
07ooOol05Woo000HOol200000goo001oo`0GOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`=oo`03001o
ogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00Uoo`05001oogooOol03`07Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000IOol00`00Ool0000H
Ool20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00P03gooOol03goo00moo`0?0goo00<007ooOol01goo00<03gooOol01Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l02Woo00@007ooOol0
3`Moo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool0100?Ool0
3goo0P0067oo000dOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`9oo`03001oogoo00Qoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00Yo
o`04001oogoo00l7Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l0
0Woo00<03goo00l00Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l03Goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`9oo`03
001oogoo00Qoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?
0Woo00D03goo00moo`0?00]oo`03001oo`0?00Moo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`05001oogooOol0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00X03goo
Ool03goo00moo`0?Ool000]oo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00D03goo00moo`0?00]oo`03001oo`0?00Moo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`80
009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l2Ool02@0?Oomoo`0?Ool03goo00l0000<Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0<Ool00`0000moo`06Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00@03goo00moo`8001Qoo`00=7oo
00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l2Ool02@0?Oomoo`0?Ool03goo00l0000<Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0<Ool00`0000moo`06Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol0
5Woo000ZOol30003Ool01@00Oomoogoo00000goo00<03gooOol02goo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool000eoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eo
o`03001oogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02
Ool00`0?Ool03`02Ool00`00Oomoo`0FOol002Yoo`03001oogoo009oo`03001oo`00009oo`05001o
ogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00P03gooOol03goo00moo`003Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<007ooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`009Goo
0`000goo00L007ooOomoo`00Ool00002Ool2000^00l00`0000l03`0k00l00`0000l03`0N00l2000H
Ool002]oo`07001oogooOol007oo00000Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03`0000l=Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=
Ool00`0?001oo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l0
0Woo00<03goo00l00Woo00<007ooOol05Woo000HOol4000>Ool00`00Ool00002Ool00`00Ool00002
Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`9oo`0800moogoo00moo`00Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moo`0000Eoo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0F
Ool001Moo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`05001oogooOol00003Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00P03gooOol03goo001oo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03goo00001Goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo
00<007ooOol017oo00<007ooOol057oo0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00l0000?Ool03`eoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eo
o`0400moogoo0004Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l0
0Woo00@03goo00moo`8001Qoo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`00Ool03goo00l=Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool0
100?Oomoo`0017oo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009o
o`0300moo`0?009oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`00Ool03goo00l=Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`0=Ool01@0?Oomoogoo00000goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`03
00moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`006Goo0P006Goo00D007ooOomoo`0?00eo
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Ool0000?
Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol0
3`9oo`0500moo`0?Ool03`0=Ool01@0?Oomoogoo00000goo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo00@007oo
Ool001Qoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00P03goo00003goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol00Woo00@007oo
Ool03`Aoo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00
Oomoo`0FOol001Ioo`03001oo`00009oo`03001oogoo01Ioo`80009oo`0300moogoo00]oo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?001oo`0?Ool03goo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`0=Ool00`0?Oomoo`03Ool00`00Ool03`04Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03goo00l00Woo00@03goo00moo`8001Qoo`005Woo1P0067oo00D007ooOomoo`0?00eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?001oo`0?Ool0
3goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`0500moo`0?Ool03`0=Ool00`0?Oomoo`04Ool00`0000moo`03Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000KOol00`00Oomoo`0FOol0
1@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol0
3`9oo`08001oogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol0
3`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Aoo`0300003goo00=oo`03
00moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol0
03Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01`0?
Oomoo`0?Ool0000?009oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`00Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007oo
Ool05Woo000IOol2000IOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool01`0?Oomoo`0?Ool0000?009oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?
Oomoo`05Ool00`0?001oo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00@0
3goo00moo`8001Qoo`0067oo0P0000=oo`00Ool05goo00D007ooOomoo`0?00eoo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0700moogoo00l007oo00l00Woo00D03goo00moo`0?00eo
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo
00moo`0?00eoo`0300moogoo00Eoo`0300moo`00009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`800003Ool007oo01Moo`05001o
ogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`000Woo
00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00H03gooOol007oo00l4Ool0
100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000IOol00`00Ool0
000HOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@0
3goo00003`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0600moogoo
001oo`0?17oo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`00
=7oo0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@0
3goo00003`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0600moogoo
Ool0000?17oo00@03gooOol03`=oo`0300moo`0?009oo`0400moo`0?Ool2000HOol003Aoo`05001o
ogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?001oo`0?0Woo
00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<007oo
Ool00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`006Goo
0P000Woo00<007ooOol057oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`04001oogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?001oo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo
00l00Woo00<007ooOol05Woo000HOol01P00Oomoo`00Ool000]oo`D0009oo`05001oogooOol00003
Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool01P0?Oomoogoo00003`9oo`0400mo
ogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3goo00000Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`00
67oo00H007ooOol007oo000=Ool01`00Oomoogoo001oo`00009oo`05001oogooOol03`0=Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool01P0?Oomoo`00Ool03`9oo`0400moogoo00l2Ool01@0?Ool03goo
00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool0
1@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03goo00000Woo00@03gooOol0
3`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo1@0027oo0`000goo00L0
07ooOomoo`00Ool00002Ool2000O00l00`0000l03`1I00l00`0000l03`0?00l2000HOol001Qoo`03
001oogoo011oo`07001oogooOol007oo00000Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`03
00moogoo009oo`0300l007oo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool01P0?Oomoogoo00003`9oo`0700moogooOol03goo
00l00Woo00<03goo00l00Woo00<007ooOol05Woo000[Ool01`00Oomoogoo001oo`00009oo`05001o
ogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`00Oomoo`02Ool0100?Oomoo`0?0Woo
00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@007ooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo
00<007ooOol017oo00<007ooOol02Woo0P0017oo00D007ooOomoo`0000=oo`0300moogoo00]oo`03
00moogoo00Eoo`0300moogoo0080000300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool0
3goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?0000
000?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000GOol00`00Oomoo`02Ool0
0`00Oomoo`0EOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Ool00002Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol000=oo`0300moo`0?009oo`0400moo`0?Ool2
000HOol001Qoo`@001Qoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?001oo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol0
1Goo00<03gooOol00Woo00<03gooOol00Woo00D03gooOol03`00009oo`0300moo`0?009oo`0300mo
o`0?009oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`03001oogoo
009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool02P0?Oomoo`0?Ool007oo00moo`0?0Woo
00<03goo00l00Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l03Goo00<03gooOol00goo0P00
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`03
00moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00mo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool20000
1goo00moogoo00moo`0?009oo`03001oogoo01Ioo`00=7oo0P000Woo00<03gooOol02goo00<03goo
Ool00Woo00@007ooOol03`Aoo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03`0000l00Woo00@03goo00moo`8001Qoo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo
008000=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00P03goo000007oo00moo`0?0Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l03Goo00<0
3`0000001Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?
Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool0100?Ool03goo0P0000Eoo`0?Oomoo`0001Qoo`00=7oo00D007ooOomoo`0?00aoo`8000Mo
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?
Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<0
3goo00l00Woo00<03`0000000Woo00<007ooOol05Woo000dOol20002Ool00`0?Oomoo`08Ool20000
0goo00moo`06Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo
00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2
Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moo`0?009oo`0400moo`0?Ool2000HOol003Aoo`05001oogooOol03`08Ool20003
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol0
3goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo
00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`00=7oo00D007ooOomo
o`0?00Ioo`8000Eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2
Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000d
Ool01@00Oomoogoo00l00Woo10001goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`05
00moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00
Oomoo`0FOol003Aoo`04001oogooOol3000;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009o
o`03001oogoo01Ioo`00=7oo0P000Woo00<007ooOol02goo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00@007ooOol03`9oo`0800moogoo00moo`0?Ool000eoo`0300moogoo00Eoo`03
00moogoo00=oo`0500moogooOol00003Ool0100?Oomoo`0?0Woo00D03goo00moo`0000eoo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`04001oogoo00l3Ool00`0?Ool03`02Ool0100?
Ool007oo0P0067oo000dOonA000HOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol002ioo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00D000ioo`03001oogoo009oo`03001oogoo009o
o`03001oogoo009oo`8000Aoo`03001oogoo00D001=oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo00Eoo`D001eoo`03001oogoo00Ioo`D0009oo`03001oogoo01Qoo`00;Goo00<007oo0000
1goo00<007oo00000goo00<007ooOol03Goo00<007oo00001goo00<007oo00000Woo100027oo00<0
07ooOol04Woo00<007oo00001goo00<007oo000027oo00<007ooOol077oo00<007oo00002Goo00L0
07ooOomoo`00Ool0000IOol002eoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo00eoo`03
001oo`0000Moo`03001oo`0000=oo`<000Qoo`03001oogoo019oo`03001oo`0000Uoo`03001oogoo
00Ioo`03001oogoo01ioo`03001oogoo00Moo`07001oogooOol007oo00006Goo000]Ool00`00Ool0
0007Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Ool00007Ool00`00Ool00002Ool200000goo
001oo`07Ool00`00Oomoo`0BOol00`00Ool00007Ool20009Ool00`00Oomoo`0LOol2000:Ool01`00
Oomoogoo001oo`0001Uoo`00;Goo00<007oo00001goo00<007oo00000goo00<007ooOol03Goo00<0
07oo00001goo00<007oo00000Woo0P0000=oo`00Ool01goo00<007ooOol04Woo00<007oo00001goo
00<007ooOol027oo00<007ooOol077oo00<007ooOol02Goo00L007ooOomoo`00Ool0000IOol002io
o`03001oogoo00Moo`04001oogooOol2000@Ool00`00Oomoo`07Ool01000Oomoogoo0`0027oo0P00
5Goo00<007ooOol01Woo0`001goo0P007Woo0`0027oo0P0017oo00<007ooOol067oo003MOol00=eo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00C7oo0P005Goo0P005Goo00<007ooOol0?7oo00<007ooOol08Goo001=
Ool00`00Oomoo`0DOol00`00Oomoo`0BOol00`00Oomoo`0COol00`00Oomoo`0XOol00`00Oomoo`0P
Ool003Yoo`<000=oo`<000=oo`8000=oo`<0009oo`<0009oo`800003Ool00000009oo`03001oo`00
008000=oo`03001oogoo015oo`04001oogooOol300000goo001oo`040002Ool30005Ool00`00Oomo
o`02Ool30003Ool20002Ool30003Ool200000goo00000002Ool00`00Oomoo`030009Ool00`00Oomo
o`0OOol003]oo`03001oogoo00=oo`05001oogooOol00004Ool01P00Oomoo`00Ool0009oo`03001o
o`0000Aoo`06001oogoo001oo`0017oo00<007oo00004Woo00<007ooOol00Woo00D007ooOol007oo
00<0009oo`04001oogoo0005Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo00Moo`03001oogoo01mo
o`00>goo00<007ooOol00goo00@007ooOomoo`<0009oo`06001oogoo001oo`000Woo00<007oo0000
0P000Woo00H007ooOol007oo0004Ool00`00Ool0000BOol00`00Oomoo`02Ool30004Ool01000Oomo
o`000Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol00`000Woo00<007ooOol00Woo00H0
07ooOol007oo0002Ool00`00Ool00002Ool00`00Oomoo`07Ool00`00Oomoo`0OOol003]oo`8000=o
o`@00004Ool000000003Ool5000017oo000007oo0`0000=oo`0000000P000Woo0`0000Aoo`00001o
o`80015oo`03001oogoo009oo`04001oogoo0002Ool20003Ool30006Ool00`00Oomoo`02Ool01000
Oomoogoo0`000Woo0`000goo0P0000=oo`0000000P000goo0`002Goo00<007ooOol07goo000kOol0
1000Oomoo`00>Woo00D007ooOomoo`00009oo`03001oogoo00Moo`03001oogoo00Aoo`07001oogoo
Ool007oo00006Goo00<007ooOol01Woo00<007ooOol087oo000jOol5000kOol00`00Ool000030009
Ool20007Ool00`00Oomoo`03000HOol20007Ool00`00Oomoo`0QOol00=eoo`00gGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00;Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01@003Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo0P0017oo00<007ooOol01@004goo00<0
07ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo1@007Goo00<007ooOol01Woo1@000Woo00<0
07ooOol067oo000]Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Ool00007
Ool00`00Ool00002Ool40008Ool00`00Oomoo`0BOol00`00Ool00007Ool00`00Ool00008Ool00`00
Oomoo`0LOol00`00Ool00009Ool01`00Oomoogoo001oo`0001Uoo`00;Goo00<007oo00001goo00<0
07oo00000goo00<007ooOol03Goo00<007oo00001goo00<007oo00000goo0`0027oo00<007ooOol0
4Woo00<007oo00002Goo00<007ooOol01Woo00<007ooOol07Woo00<007ooOol01goo00L007ooOomo
o`00Ool0000IOol002eoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo00eoo`03001oo`00
00Moo`03001oo`00009oo`800003Ool007oo00Moo`03001oogoo019oo`03001oo`0000Moo`8000Uo
o`03001oogoo01aoo`8000Yoo`07001oogooOol007oo00006Goo000]Ool00`00Ool00007Ool00`00
Ool00003Ool00`00Oomoo`0=Ool00`00Ool00007Ool00`00Ool00002Ool200000goo001oo`07Ool0
0`00Oomoo`0BOol00`00Ool00007Ool00`00Oomoo`08Ool00`00Oomoo`0LOol00`00Oomoo`09Ool0
1`00Oomoogoo001oo`0001Uoo`00;Woo00<007ooOol01goo00@007ooOomoo`80011oo`03001oogoo
00Moo`04001oogooOol30008Ool2000EOol00`00Oomoo`06Ool30007Ool2000NOol30008Ool20004
Ool00`00Oomoo`0HOol00=eoo`00gGoo003MOol002Uoo`D0009oo`<00003Ool0000008l001Qoo`00
:goo00<007ooOol00goo00@007ooOol000=oo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo
009oo`03001oogoo009oo`04001oogoo0002Ool02000Oomoo`00Ool007oo000=Ool00`00Oomoo`05
Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001oo`00Ool0000=Ool0
0`00Oomoo`05Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00H007ooOol007oo0002Ool00`00
Ool00002Ool00`00Oomoo`0FOol002Eoo`<000=oo`04001oogooOol400000goo00000002Ool00`0?
Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P0
3gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`04
00moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0600moogoo00moo`0?0Woo00@03goo00moo`8001Qoo`00:goo00L007ooOomoo`00Ool0
0002Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo
00=oo`0300moo`000100009oo`03001oogoo01Ioo`005Woo1P003goo00<007ooOol00Woo0P000Woo
00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`050002
Ool01@0?Oomoogoo00l00Woo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000FOol3
0002Ool00`00Oomoo`0<Ool20005Ool00`00Oomoo`020002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo
00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool0
3goo00l03Goo00<03gooOol00goo1@000goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo
00<03goo00l00Woo00<007ooOol05Woo000IOol00`00Oomoo`0HOol01@00Oomoogoo00l03Goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?
Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00eoo`0300moogoo00<0009oo`0300moogoo00=oo`0500moogooOol03`03Ool0
1P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo0`000Woo00<007ooOol0
5Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Ool00005Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol0
01Ioo`H001Qoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool20006Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0F
Ool001Ioo`03001oogoo009oo`03001oogoo01Ioo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<0
3gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo
00l037oo00<0000?Ool01Woo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?
0Woo00<03goo00l00Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l03Goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`03
00moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00mo
o`0?00Yoo`800003Ool03goo00Ioo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?
Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`006Woo0P0067oo0P000Woo00<03gooOol02goo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00mo
o`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?
0Woo00D03goo00moo`0?00Qoo`8000=oo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol0
3`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo00@007oo0000
00eoo`D00004Ool000000002Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`03
00moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00Moo`03001o
ogoo00=oo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool0
3`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo00@007oo000000moo`05001oogooOol00004
Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00Ioo`03001oogoo00Aoo`0300moogoo00Eo
o`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03
001oogoo01Ioo`0067oo10002Goo0`000goo00<007ooOol00Woo00@007ooOomoo`8006803`8002T0
3`8001Qoo`006goo00<007ooOol03Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`0300moogoo
00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomo
o`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol002]o
o`07001oogooOol007oo00000Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`02Ool00`00
Oomoo`08Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Uoo`80009oo`03001oogoo00Yoo`8000Aoo`04
001oogooOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01`0?Ool03goo00moo`0000]oo`0300moogoo00Eo
o`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03
001oogoo01Ioo`0067oo00H007ooOol007oo000FOol01@00Oomoogoo00l03Goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`03
00moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00H03goo00mo
o`0?000<Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`06001oogoo001oo`005Woo00D007ooOomo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?
Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@0
3gooOol03`9oo`0500moo`0?Ool0000=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`D001Moo`80
009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`0500moo`0?Ool0000=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qo
o`03001oogoo01Uoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03`0000l03Goo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<0
07ooOol05Woo000HOol01000Oomoo`0067oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`00Ool03`0=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool0
0`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`@001Qoo`80009oo`0300moogoo00]oo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500l0
000?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`03001oogoo00ioo`D0009oo`05001o
ogooOol00003Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?00003goo00l03Goo00<03gooOol01Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol0
5Woo000HOol00`00Oomoo`0@Ool01`00Oomoogoo001oo`00009oo`05001oogooOol03`0=Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00mo
o`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool0
1@00Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600mo
ogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000IOol30009Ool30003Ool01`00Oomo
ogoo001oo`00009oo`8005P03`0300003`0?03803`8001Qoo`006goo00<007ooOol03Goo00L007oo
Oomoo`00Ool00002Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool02`0?Oomoo`0?Ool0000?Ool03goo00l03Goo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<0
07ooOol05Woo000[Ool01`00Oomoogoo001oo`00009oo`05001oogooOol03`0=Ool00`0?Oomoo`05
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo
00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0;00moogoo00l007oo00moo`0?
Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol002Yoo`8000Aoo`04001oogooOol20002Ool00`0?
Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P0
3gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`04
00moogoo0002Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000HOol01000Oomo
o`0067oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00@03gooOol0009oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0F
Ool001Ioo`03001oo`0000<001Qoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moo`0000l2Ool01@0?Ool03goo00l03Goo00<0
3gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo
00l00Woo00<007ooOol05Woo000KOol00`00Oomoo`0FOol20002Ool00`0?Oomoo`0;Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?
3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400l007oo00l2Ool01@0?
Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo
00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l03Goo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool0
3`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?001oo`0?0Woo00D0
3goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomo
o`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo00<007ooOol06Goo00D007ooOomo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?
Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@0
07ooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Moo`@001Uoo`05
001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`04001oogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000HOol0
1000Oomoo`0067oo0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`02Ool01@0000moogoo00l00Woo00D03goo00moo`0?00eoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009o
o`03001oogoo01Ioo`0067oo00@007ooOol001Aoo`05001oogooOol00003Ool00`0?Oomoo`0;Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo
00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00T03gooOomoo`0?Ool007oo00l00Woo00P0
3gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`06
00moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000HOol00`00Ool0000DOol00`00
Ool00002Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`09
00moogooOol03goo001oo`0?009oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo
01Ioo`00:Woo0`000Woo00<007oo00000Woo0P00D00?00<0000?00l0>P0?0P0067oo000HOol00`00
Oomoo`0EOol01@00Oomoogoo00000goo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`03
00moogoo00=oo`0500moogooOol00003Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?
009oo`03001oogoo01Ioo`0067oo0`0057oo00<007oo00000Woo00D007ooOomoo`0?00eoo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00000goo00@03gooOol03`9oo`05
00moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001]oo`03001oogoo019oo`04001oogoo
Ool20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03goo
Ool0000?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo
000HOol00`00Ool0000IOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300mo
ogoo00=oo`0500moogoo00003`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009o
o`03001oogoo01Ioo`0067oo100067oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool01@0?Ool007oo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?
Ool03`02Ool00`00Oomoo`0FOol001]oo`03001oogoo01Ioo`80009oo`0300moogoo00]oo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Ool007oo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`0=Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00mo
o`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03`00Oomoo`0?00=oo`0400moogoo00l2Ool0
1@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600mo
ogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000IOol2000IOol01@00Oomoogoo00l0
3Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo
00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500l007ooOol03`03Ool0100?Oomo
o`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo00@007ooOol001Qo
o`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@00Oomo
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol0
01Ioo`03001oo`00009oo`03001oogoo015oo`8000=oo`05001oogooOol03`0=Ool00`0?Oomoo`05
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo
00<03gooOol01Goo00<03gooOol00goo00D007ooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool0
3goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00mo
o`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000FOol6000COol00`00Ool00002Ool01@00Oomo
ogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`08
00moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo009oo`0300003goo009oo`0500mo
ogooOol03`02Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001]oo`03
001oogoo00aoo`<0009oo`03001oo`00009oo`8004X03`0300003`0?04003`8001Qoo`00;goo0P00
0goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool01`0?Oomoogoo001oo`0?00=o
o`0500moogooOol03`02Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol0
01Uoo`8001Aoo`03001oogoo009oo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo
00L03gooOomoo`00Ool03`03Ool01@0?Oomoogoo00l00Woo00P03gooOol03goo00moo`0?3Goo00<0
3gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo
00l00Woo00<007ooOol05Woo000HOol200000goo001oo`0COol20002Ool20002Ool00`0?Oomoo`0;
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol0
3goo00moo`0?3Goo00<03gooOol01Goo00@03gooOol0009oo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo0P0000=oo`00Ool0
5goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool0100?Oomoo`000Woo00D03goo
Oomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo
000IOol00`00Ool0000HOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300mo
o`0000=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009o
o`03001oogoo01Ioo`00=7oo0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`03
00l007oo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?
009oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool0
0`00Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool0
3`02Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo
00<007ooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<0
3gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo
00l00Woo00<007ooOol05Woo000dOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol0
17oo00<0000?Ool017oo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo
00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<0
3goo00l00Woo00<007ooOol05Woo000`Ool300000goo001oo`02Ool00`0?Oomoo`0;Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?
3Goo00<03gooOol00goo00<007oo00l01Goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?
Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo
00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000aOol01000Oomoo`000goo00<03gooOol0
2goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo
00moo`0?Ool03`eoo`0300moogoo00=oo`03001oo`0?00Eoo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`00:Woo0`000Woo100000=o
o`000000@P0?00<0000?00l0B00?0P0067oo000_Ool00`00Ool00002Ool01@00Oomoogoo00l03Goo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00mo
o`0?Ool03`eoo`0500moogooOol00003Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol0031oo`80009oo`05001o
ogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00P03gooOol03goo00moo`0?3Goo00@03gooOol000Aoo`0300moogoo00=oo`0500moogooOol03`03
Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo1000
5Goo00<007ooOol00P000Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0400moogoo0004Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool0
0`00Oomoo`0FOol001Moo`03001oogoo009oo`03001oogoo01Eoo`05001oogooOol03`0=Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00mo
o`0?3Goo00<03goo00001Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool0
1@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600mo
ogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000FOol00`00Oomoo`04Ool00`00Oomo
o`0DOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300l007oo00Eoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Io
o`00=7oo0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`03001oogoo00Eoo`0300moogoo00=oo`05
00moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300mo
ogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo
01Ioo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l<Ool00`0000moo`06Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomo
o`0FOol001Uoo`8001Uoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?37oo00<0000?Ool01Woo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo
00<007ooOol05Woo000HOol01000Oomoo`0067oo0P000Woo00<03gooOol02goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`]oo`03
001oo`0?00Moo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00mo
o`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool0
3`9oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo00<007oo00000Woo00<007ooOol04Goo0`00
0Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l2Ool0200?Oomoo`0?Ool03goo00l:Ool01000Oomoo`0?1goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo
000FOol6000COol00`00Oomoo`02Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`Uoo`05001oogooOol0
3`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool0
0`0?Ool03`02Ool00`00Oomoo`0FOol001]oo`03001oogoo00aoo`<000=oo`04001oogooOol2000h
00l00`0000l03`1B00l2000HOol001Ioo`03001oogoo009oo`03001oogoo019oo`05001oogooOol0
0003Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0Woo00P03gooOol03goo00moo`0?1goo00<007ooOol00goo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<0
07ooOol05Woo000FOol6000COol00`00Ool00002Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`Ioo`03
001oogoo00Aoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?
0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0
1P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo00<007oo00000Woo00<0
07ooOol04Woo00@007ooOomoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l5Ool00`00Oomoo`05Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?
Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Ioo`03001oo`00009oo`03001oogoo01Ioo`05
001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00P03gooOol03goo00moo`0?0goo0P0027oo00<03gooOol01Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo
000GOol01000Ool000006Goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l2Ool00`00Oomoo`08Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2
Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`80009oo`0300moogoo00]oo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l2000;
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`0=Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo00l2000=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Ioo`03001oogoo00Aoo`03001oogoo01Ao
o`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0Woo00<03gooOol00`0000=oo`0?Ool037oo00<03gooOol01Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo
000GOol00`00Oomoo`02Ool00`00Oomoo`0EOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?1@0000D03goo00moo`0?00eoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eo
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`03
00moo`0?009oo`03001oogoo01Ioo`0067oo100057oo00D007ooOomoo`0000=oo`0300moogoo00]o
o`0300moogoo00Eoo`0300moogoo009oo`0400moogooOol50002Ool0200?Oomoo`0?Ool03goo00l=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol002moo`03001oo`00009oo`05001oogooOol0
3`0=Ool00`0?Oomoo`05Ool900001Goo00moogoo00l00Woo00P03gooOol03goo00moo`0?3Goo00<0
3gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo
00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?
0Woo00<03goo00l00Woo00<007ooOol05Woo000_Ool00`00Ool00002Ool20002OolF00000`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo
00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00@0
3goo00moo`8001Qoo`00;goo00<007oo00000Woo00D007ooOomoo`0000eoo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`04001oogoo00l2Ool0200?Oomoo`0?Ool03goo000=Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00000goo00@03gooOol03`9oo`0500moo`0?Ool0
000=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00000goo00H03gooOol03goo00l2
Ool00`0?Ool00002Ool00`00Oomoo`0FOol002moo`03001oo`00009ooi4001Qoo`00<7oo00<007oo
Ool0ZWoo003MOol00=eoo`00gGoo003MOol00=eoo`00;Woo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol01@003Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo0P0017oo00<0
07ooOol01@004goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo1@007Goo00<007oo
Ool01Woo1@000Woo00<007ooOol067oo000]Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomo
o`0=Ool00`00Ool00007Ool00`00Ool00002Ool40008Ool00`00Oomoo`0BOol00`00Ool00007Ool0
0`00Ool00008Ool00`00Oomoo`0LOol00`00Ool00009Ool01`00Oomoogoo001oo`0001Uoo`00;Goo
00<007oo00001goo00<007oo00000goo00<007ooOol03Goo00<007oo00001goo00<007oo00000goo
0`0027oo00<007ooOol04Woo00<007oo00002Goo00<007ooOol01Woo00<007ooOol07Woo00<007oo
Ool01goo00L007ooOomoo`00Ool0000IOol002eoo`03001oo`0000Moo`03001oo`0000=oo`03001o
ogoo00eoo`03001oo`0000Moo`03001oo`00009oo`800003Ool007oo00Moo`03001oogoo019oo`03
001oo`0000Moo`8000Uoo`03001oogoo01aoo`8000Yoo`07001oogooOol007oo00006Goo000]Ool0
0`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Ool00007Ool00`00Ool00002Ool2
00000goo001oo`07Ool00`00Oomoo`0BOol00`00Ool00007Ool00`00Oomoo`08Ool00`00Oomoo`0L
Ool00`00Oomoo`09Ool01`00Oomoogoo001oo`0001Uoo`00;Woo00<007ooOol01goo00@007ooOomo
o`80011oo`03001oogoo00Moo`04001oogooOol30008Ool2000EOol00`00Oomoo`06Ool30007Ool2
000NOol30008Ool20004Ool00`00Oomoo`0HOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol0
0=eoo`00gGoo003MOol00001\
\>"],
  ImageRangeCache->{{{0, 220.875}, {287, 0}} -> {-0.0250052, -0.033245, 
  0.00475387, 0.00475387}, {{5.25, 215.562}, {280, 150}} -> {-3.23716, 
  -58.6608, 0.0219425, 0.467693}, {{5.25, 215.562}, {137, 6.9375}} -> {
  -3.23535, -43.4496, 0.0219277, 0.164837}},
  CellTags->"3.5"],

Cell["This is the network after the bilinear transform. ", "MathCaption",
  CellTags->"3.5"],

Cell["\<\
dlag = ToDiscreteTime[lag, Sampled->Period[T],
 Method->BilinearTransform
] //Simplify\
\>", "Input",
  CellLabel->"In[55]:=",
  CellTags->"3.5"],

Cell[BoxData[
    \(TransferFunction[s, 
      {{\(2\ a\ \((\(-1\) + s)\) + \((1 + s)\)\ T\)\/\(\(-2\)\ b + 2\ b\ s + \
T + s\ T\)}}, Sampled \[Rule] Period[T]]\)], "Output",
  CellLabel->"Out[55]=",
  CellTags->"3.5"],

Cell[TextData[{
  "This computes the Bode plots for continuous and sampled lag networks\
\[LongDash]and displays them together using a utility function ",
  StyleBox["DisplayTogetherGraphicsArray", "MR"],
  ". \nAs we can see, the responses coincide for the low frequencies but \
differ somewhat near the Nyquist frequency. "
}], "MathCaption",
  CellTags->"3.5"],

Cell["\<\
DisplayTogetherGraphicsArray[
 lagplot,
 BodePlot[dlag /. {a->1, b->5, T->1},
 PlotStyle -> {
 RGBColor[1, 0, 0],
 Dashing[{.02}]
 }
 ]
]\
\>", "Input",
  CellLabel->"In[56]:=",
  CellTags->"3.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.29787 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0309017 0.952381 [
[ 0 0 0 0 ]
[ 1 1.29787 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.29787 L
0 1.29787 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0309017 0.97619 0.619505 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.637418 0.0148941 [
[.02381 -0.0125 -14 -12.5625 ]
[.02381 -0.0125 14 0 ]
[.2457 -0.0125 -14 -12.5625 ]
[.2457 -0.0125 14 0 ]
[.34127 -0.0125 -11 -12.5625 ]
[.34127 -0.0125 11 0 ]
[.56317 -0.0125 -11 -12.5625 ]
[.56317 -0.0125 11 0 ]
[.65873 -0.0125 -5 -12.5625 ]
[.65873 -0.0125 5 0 ]
[.88063 -0.0125 -5 -12.5625 ]
[.88063 -0.0125 5 0 ]
[.97619 -0.0125 -8 -12.5625 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .04165 -18 -4.5 ]
[-0.0125 .04165 0 4.5 ]
[-0.0125 .19059 -18 -4.5 ]
[-0.0125 .19059 0 4.5 ]
[-0.0125 .33954 -18 -4.5 ]
[-0.0125 .33954 0 4.5 ]
[-0.0125 .48848 -18 -4.5 ]
[-0.0125 .48848 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -35 ]
[-0.01875 .30902 -18 35 ]
[.02381 .63053 -14 0 ]
[.02381 .63053 14 12.5625 ]
[.2457 .63053 -14 0 ]
[.2457 .63053 14 12.5625 ]
[.34127 .63053 -11 0 ]
[.34127 .63053 11 12.5625 ]
[.56317 .63053 -11 0 ]
[.56317 .63053 11 12.5625 ]
[.65873 .63053 -5 0 ]
[.65873 .63053 5 12.5625 ]
[.88063 .63053 -5 0 ]
[.88063 .63053 5 12.5625 ]
[.97619 .63053 -8 0 ]
[.97619 .63053 8 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2457 0 m
.2457 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.56317 0 m
.56317 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.88063 0 m
.88063 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.11937 0 m
.11937 .61803 L
s
.17528 0 m
.17528 .61803 L
s
.21494 0 m
.21494 .61803 L
s
.27084 0 m
.27084 .61803 L
s
.29209 0 m
.29209 .61803 L
s
.3105 0 m
.3105 .61803 L
s
.32674 0 m
.32674 .61803 L
s
.43683 0 m
.43683 .61803 L
s
.49274 0 m
.49274 .61803 L
s
.5324 0 m
.5324 .61803 L
s
.5883 0 m
.5883 .61803 L
s
.60955 0 m
.60955 .61803 L
s
.62797 0 m
.62797 .61803 L
s
.6442 0 m
.6442 .61803 L
s
.7543 0 m
.7543 .61803 L
s
.8102 0 m
.8102 .61803 L
s
.84986 0 m
.84986 .61803 L
s
.90576 0 m
.90576 .61803 L
s
.92702 0 m
.92702 .61803 L
s
.94543 0 m
.94543 .61803 L
s
.96166 0 m
.96166 .61803 L
s
0 .04165 m
1 .04165 L
s
0 .19059 m
1 .19059 L
s
0 .33954 m
1 .33954 L
s
0 .48848 m
1 .48848 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 0 m
.2457 .00625 L
s
gsave
.2457 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 0 m
.56317 .00625 L
s
gsave
.56317 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 0 m
.88063 .00625 L
s
gsave
.88063 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 0 m
.11937 .00375 L
s
.17528 0 m
.17528 .00375 L
s
.21494 0 m
.21494 .00375 L
s
.27084 0 m
.27084 .00375 L
s
.29209 0 m
.29209 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.32674 0 m
.32674 .00375 L
s
.43683 0 m
.43683 .00375 L
s
.49274 0 m
.49274 .00375 L
s
.5324 0 m
.5324 .00375 L
s
.5883 0 m
.5883 .00375 L
s
.60955 0 m
.60955 .00375 L
s
.62797 0 m
.62797 .00375 L
s
.6442 0 m
.6442 .00375 L
s
.7543 0 m
.7543 .00375 L
s
.8102 0 m
.8102 .00375 L
s
.84986 0 m
.84986 .00375 L
s
.90576 0 m
.90576 .00375 L
s
.92702 0 m
.92702 .00375 L
s
.94543 0 m
.94543 .00375 L
s
.96166 0 m
.96166 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .04165 m
.00625 .04165 L
s
[(-40)] -0.0125 .04165 1 0 Mshowa
0 .19059 m
.00625 .19059 L
s
[(-30)] -0.0125 .19059 1 0 Mshowa
0 .33954 m
.00625 .33954 L
s
[(-20)] -0.0125 .33954 1 0 Mshowa
0 .48848 m
.00625 .48848 L
s
[(-10)] -0.0125 .48848 1 0 Mshowa
.125 Mabswid
0 .07144 m
.00375 .07144 L
s
0 .10123 m
.00375 .10123 L
s
0 .13102 m
.00375 .13102 L
s
0 .16081 m
.00375 .16081 L
s
0 .22038 m
.00375 .22038 L
s
0 .25017 m
.00375 .25017 L
s
0 .27996 m
.00375 .27996 L
s
0 .30975 m
.00375 .30975 L
s
0 .36932 m
.00375 .36932 L
s
0 .39911 m
.00375 .39911 L
s
0 .4289 m
.00375 .4289 L
s
0 .45869 m
.00375 .45869 L
s
0 .01187 m
.00375 .01187 L
s
0 .51827 m
.00375 .51827 L
s
0 .54805 m
.00375 .54805 L
s
0 .57784 m
.00375 .57784 L
s
0 .60763 m
.00375 .60763 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -120.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
96 10.2813 translate
90 rotate
-96 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(deg) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(L) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 .61178 m
.2457 .61803 L
s
gsave
.2457 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 .61178 m
.34127 .61803 L
s
gsave
.34127 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 .61178 m
.56317 .61803 L
s
gsave
.56317 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 .61178 m
.65873 .61803 L
s
gsave
.65873 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 .61178 m
.88063 .61803 L
s
gsave
.88063 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 .61428 m
.11937 .61803 L
s
.17528 .61428 m
.17528 .61803 L
s
.21494 .61428 m
.21494 .61803 L
s
.27084 .61428 m
.27084 .61803 L
s
.29209 .61428 m
.29209 .61803 L
s
.3105 .61428 m
.3105 .61803 L
s
.32674 .61428 m
.32674 .61803 L
s
.43683 .61428 m
.43683 .61803 L
s
.49274 .61428 m
.49274 .61803 L
s
.5324 .61428 m
.5324 .61803 L
s
.5883 .61428 m
.5883 .61803 L
s
.60955 .61428 m
.60955 .61803 L
s
.62797 .61428 m
.62797 .61803 L
s
.6442 .61428 m
.6442 .61803 L
s
.7543 .61428 m
.7543 .61803 L
s
.8102 .61428 m
.8102 .61803 L
s
.84986 .61428 m
.84986 .61803 L
s
.90576 .61428 m
.90576 .61803 L
s
.92702 .61428 m
.92702 .61803 L
s
.94543 .61428 m
.94543 .61803 L
s
.96166 .61428 m
.96166 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04165 m
1 .04165 L
s
.99375 .19059 m
1 .19059 L
s
.99375 .33954 m
1 .33954 L
s
.99375 .48848 m
1 .48848 L
s
.125 Mabswid
.99625 .07144 m
1 .07144 L
s
.99625 .10123 m
1 .10123 L
s
.99625 .13102 m
1 .13102 L
s
.99625 .16081 m
1 .16081 L
s
.99625 .22038 m
1 .22038 L
s
.99625 .25017 m
1 .25017 L
s
.99625 .27996 m
1 .27996 L
s
.99625 .30975 m
1 .30975 L
s
.99625 .36932 m
1 .36932 L
s
.99625 .39911 m
1 .39911 L
s
.99625 .4289 m
1 .4289 L
s
.99625 .45869 m
1 .45869 L
s
.99625 .01187 m
1 .01187 L
s
.99625 .51827 m
1 .51827 L
s
.99625 .54805 m
1 .54805 L
s
.99625 .57784 m
1 .57784 L
s
.99625 .60763 m
1 .60763 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.05665 .59417 L
.08949 .5826 L
.12233 .56797 L
.15517 .54952 L
.18801 .52634 L
.22085 .4974 L
.25369 .4616 L
.28654 .41796 L
.31938 .36596 L
.35222 .30605 L
.38506 .24029 L
.4179 .1729 L
.45074 .11002 L
.48358 .05876 L
.51642 .02555 L
.54926 .01472 L
.5821 .02767 L
.61494 .06272 L
.64778 .11531 L
.68062 .17888 L
.71346 .24636 L
.74631 .31173 L
.77915 .37098 L
.81199 .42223 L
.84483 .46513 L
.87767 .50027 L
.91051 .52865 L
.94335 .55136 L
.97619 .56943 L
s
1 0 0 r
[ .02 ] 0 setdash
.02381 .60332 m
.05115 .59586 L
.07848 .58679 L
.10582 .57575 L
.13315 .56235 L
.16049 .54611 L
.18783 .52648 L
.21516 .50286 L
.2425 .47461 L
.26983 .44112 L
.29717 .40195 L
.32451 .35693 L
.35184 .30651 L
.37918 .25193 L
.40651 .19548 L
.43385 .1405 L
.46119 .09103 L
.48852 .05128 L
.51586 .02495 L
.54319 .01476 L
.57053 .02218 L
.59787 .04735 L
.6252 .08909 L
.65254 .14508 L
.67988 .21217 L
.70721 .28703 L
.73455 .36696 L
.76188 .45066 L
.78922 .53918 L
s
.78922 .53918 m
.81116 .61803 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.678366 0.97619 1.26697 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.603319 0.0422304 [
[.02381 -0.0125 -14 -12.5625 ]
[.02381 -0.0125 14 0 ]
[.2457 -0.0125 -14 -12.5625 ]
[.2457 -0.0125 14 0 ]
[.34127 -0.0125 -11 -12.5625 ]
[.34127 -0.0125 11 0 ]
[.56317 -0.0125 -11 -12.5625 ]
[.56317 -0.0125 11 0 ]
[.65873 -0.0125 -5 -12.5625 ]
[.65873 -0.0125 5 0 ]
[.88063 -0.0125 -5 -12.5625 ]
[.88063 -0.0125 5 0 ]
[.97619 -0.0125 -8 -12.5625 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .01209 -18 -4.5 ]
[-0.0125 .01209 0 4.5 ]
[-0.0125 .09655 -18 -4.5 ]
[-0.0125 .09655 0 4.5 ]
[-0.0125 .18102 -18 -4.5 ]
[-0.0125 .18102 0 4.5 ]
[-0.0125 .26548 -12 -4.5 ]
[-0.0125 .26548 0 4.5 ]
[-0.0125 .34994 -12 -4.5 ]
[-0.0125 .34994 0 4.5 ]
[-0.0125 .4344 -12 -4.5 ]
[-0.0125 .4344 0 4.5 ]
[-0.0125 .51886 -12 -4.5 ]
[-0.0125 .51886 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -44 ]
[-0.01875 .30902 -18 44 ]
[.02381 .63053 -14 0 ]
[.02381 .63053 14 12.5625 ]
[.2457 .63053 -14 0 ]
[.2457 .63053 14 12.5625 ]
[.34127 .63053 -11 0 ]
[.34127 .63053 11 12.5625 ]
[.56317 .63053 -11 0 ]
[.56317 .63053 11 12.5625 ]
[.65873 .63053 -5 0 ]
[.65873 .63053 5 12.5625 ]
[.88063 .63053 -5 0 ]
[.88063 .63053 5 12.5625 ]
[.97619 .63053 -8 0 ]
[.97619 .63053 8 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2457 0 m
.2457 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.56317 0 m
.56317 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.88063 0 m
.88063 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.11937 0 m
.11937 .61803 L
s
.17528 0 m
.17528 .61803 L
s
.21494 0 m
.21494 .61803 L
s
.27084 0 m
.27084 .61803 L
s
.29209 0 m
.29209 .61803 L
s
.3105 0 m
.3105 .61803 L
s
.32674 0 m
.32674 .61803 L
s
.43683 0 m
.43683 .61803 L
s
.49274 0 m
.49274 .61803 L
s
.5324 0 m
.5324 .61803 L
s
.5883 0 m
.5883 .61803 L
s
.60955 0 m
.60955 .61803 L
s
.62797 0 m
.62797 .61803 L
s
.6442 0 m
.6442 .61803 L
s
.7543 0 m
.7543 .61803 L
s
.8102 0 m
.8102 .61803 L
s
.84986 0 m
.84986 .61803 L
s
.90576 0 m
.90576 .61803 L
s
.92702 0 m
.92702 .61803 L
s
.94543 0 m
.94543 .61803 L
s
.96166 0 m
.96166 .61803 L
s
0 .09655 m
1 .09655 L
s
0 .18102 m
1 .18102 L
s
0 .26548 m
1 .26548 L
s
0 .34994 m
1 .34994 L
s
0 .4344 m
1 .4344 L
s
0 .51886 m
1 .51886 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 0 m
.2457 .00625 L
s
gsave
.2457 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 0 m
.56317 .00625 L
s
gsave
.56317 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 0 m
.88063 .00625 L
s
gsave
.88063 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 0 m
.11937 .00375 L
s
.17528 0 m
.17528 .00375 L
s
.21494 0 m
.21494 .00375 L
s
.27084 0 m
.27084 .00375 L
s
.29209 0 m
.29209 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.32674 0 m
.32674 .00375 L
s
.43683 0 m
.43683 .00375 L
s
.49274 0 m
.49274 .00375 L
s
.5324 0 m
.5324 .00375 L
s
.5883 0 m
.5883 .00375 L
s
.60955 0 m
.60955 .00375 L
s
.62797 0 m
.62797 .00375 L
s
.6442 0 m
.6442 .00375 L
s
.7543 0 m
.7543 .00375 L
s
.8102 0 m
.8102 .00375 L
s
.84986 0 m
.84986 .00375 L
s
.90576 0 m
.90576 .00375 L
s
.92702 0 m
.92702 .00375 L
s
.94543 0 m
.94543 .00375 L
s
.96166 0 m
.96166 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .01209 m
.00625 .01209 L
s
[(-14)] -0.0125 .01209 1 0 Mshowa
0 .09655 m
.00625 .09655 L
s
[(-12)] -0.0125 .09655 1 0 Mshowa
0 .18102 m
.00625 .18102 L
s
[(-10)] -0.0125 .18102 1 0 Mshowa
0 .26548 m
.00625 .26548 L
s
[(-8)] -0.0125 .26548 1 0 Mshowa
0 .34994 m
.00625 .34994 L
s
[(-6)] -0.0125 .34994 1 0 Mshowa
0 .4344 m
.00625 .4344 L
s
[(-4)] -0.0125 .4344 1 0 Mshowa
0 .51886 m
.00625 .51886 L
s
[(-2)] -0.0125 .51886 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03321 m
.00375 .03321 L
s
0 .05432 m
.00375 .05432 L
s
0 .07544 m
.00375 .07544 L
s
0 .11767 m
.00375 .11767 L
s
0 .13878 m
.00375 .13878 L
s
0 .1599 m
.00375 .1599 L
s
0 .20213 m
.00375 .20213 L
s
0 .22325 m
.00375 .22325 L
s
0 .24436 m
.00375 .24436 L
s
0 .28659 m
.00375 .28659 L
s
0 .30771 m
.00375 .30771 L
s
0 .32882 m
.00375 .32882 L
s
0 .37105 m
.00375 .37105 L
s
0 .39217 m
.00375 .39217 L
s
0 .41328 m
.00375 .41328 L
s
0 .45551 m
.00375 .45551 L
s
0 .47663 m
.00375 .47663 L
s
0 .49774 m
.00375 .49774 L
s
0 .53997 m
.00375 .53997 L
s
0 .56109 m
.00375 .56109 L
s
0 .5822 m
.00375 .5822 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -129.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 10.2813 translate
90 rotate
-105 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnitude) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 .61178 m
.2457 .61803 L
s
gsave
.2457 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 .61178 m
.34127 .61803 L
s
gsave
.34127 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 .61178 m
.56317 .61803 L
s
gsave
.56317 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 .61178 m
.65873 .61803 L
s
gsave
.65873 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 .61178 m
.88063 .61803 L
s
gsave
.88063 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 .61428 m
.11937 .61803 L
s
.17528 .61428 m
.17528 .61803 L
s
.21494 .61428 m
.21494 .61803 L
s
.27084 .61428 m
.27084 .61803 L
s
.29209 .61428 m
.29209 .61803 L
s
.3105 .61428 m
.3105 .61803 L
s
.32674 .61428 m
.32674 .61803 L
s
.43683 .61428 m
.43683 .61803 L
s
.49274 .61428 m
.49274 .61803 L
s
.5324 .61428 m
.5324 .61803 L
s
.5883 .61428 m
.5883 .61803 L
s
.60955 .61428 m
.60955 .61803 L
s
.62797 .61428 m
.62797 .61803 L
s
.6442 .61428 m
.6442 .61803 L
s
.7543 .61428 m
.7543 .61803 L
s
.8102 .61428 m
.8102 .61803 L
s
.84986 .61428 m
.84986 .61803 L
s
.90576 .61428 m
.90576 .61803 L
s
.92702 .61428 m
.92702 .61803 L
s
.94543 .61428 m
.94543 .61803 L
s
.96166 .61428 m
.96166 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01209 m
1 .01209 L
s
.99375 .09655 m
1 .09655 L
s
.99375 .18102 m
1 .18102 L
s
.99375 .26548 m
1 .26548 L
s
.99375 .34994 m
1 .34994 L
s
.99375 .4344 m
1 .4344 L
s
.99375 .51886 m
1 .51886 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03321 m
1 .03321 L
s
.99625 .05432 m
1 .05432 L
s
.99625 .07544 m
1 .07544 L
s
.99625 .11767 m
1 .11767 L
s
.99625 .13878 m
1 .13878 L
s
.99625 .1599 m
1 .1599 L
s
.99625 .20213 m
1 .20213 L
s
.99625 .22325 m
1 .22325 L
s
.99625 .24436 m
1 .24436 L
s
.99625 .28659 m
1 .28659 L
s
.99625 .30771 m
1 .30771 L
s
.99625 .32882 m
1 .32882 L
s
.99625 .37105 m
1 .37105 L
s
.99625 .39217 m
1 .39217 L
s
.99625 .41328 m
1 .41328 L
s
.99625 .45551 m
1 .45551 L
s
.99625 .47663 m
1 .47663 L
s
.99625 .49774 m
1 .49774 L
s
.99625 .53997 m
1 .53997 L
s
.99625 .56109 m
1 .56109 L
s
.99625 .5822 m
1 .5822 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60288 m
.05665 .60261 L
.08949 .60218 L
.12233 .60149 L
.15517 .60039 L
.18801 .59862 L
.22085 .59581 L
.25369 .59139 L
.28654 .58451 L
.31938 .57399 L
.35222 .55832 L
.38506 .53586 L
.4179 .50515 L
.45074 .46553 L
.48358 .41758 L
.51642 .36324 L
.54926 .30552 L
.5821 .24796 L
.61494 .19409 L
.64778 .14683 L
.68062 .108 L
.71346 .07808 L
.74631 .05629 L
.77915 .04116 L
.81199 .03102 L
.84483 .02441 L
.87767 .02016 L
.91051 .01747 L
.94335 .01578 L
.97619 .01472 L
s
1 0 0 r
[ .02 ] 0 setdash
.02381 .60288 m
.05115 .60267 L
.07848 .60235 L
.10582 .60188 L
.13315 .60118 L
.16049 .60015 L
.18783 .59863 L
.21516 .5964 L
.2425 .59312 L
.26983 .58837 L
.29717 .58155 L
.32451 .57188 L
.35184 .55846 L
.37918 .5403 L
.40651 .5165 L
.43385 .48648 L
.46119 .45018 L
.48852 .40818 L
.51586 .36169 L
.54319 .31242 L
.57053 .26233 L
.59787 .21348 L
.6252 .1678 L
.65254 .12697 L
.67988 .09212 L
.70721 .06383 L
.73455 .04207 L
.76188 .02646 L
.78922 .01663 L
.81656 .01296 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[56]:=",
  ImageSize->{221.875, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M000181000`40O003h00OgGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo001<Ool2000EOol2000EOol00`00Oomo
o`0lOol00`00Oomoo`0QOol004eoo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo01=oo`03
001oogoo02Qoo`03001oogoo021oo`00>Woo0`000goo0`000goo0P000goo0`000Woo0`000Woo0P00
00=oo`0000000Woo00<007oo00000P000goo00<007ooOol04Goo00@007ooOomoo`<00003Ool007oo
00@0009oo`<000Eoo`03001oogoo009oo`<000=oo`80009oo`<000=oo`800003Ool00000009oo`03
001oogoo00<000Uoo`03001oogoo01moo`00>goo00<007ooOol00goo00D007ooOomoo`0000Aoo`06
001oogoo001oo`000Woo00<007oo000017oo00H007ooOol007oo0004Ool00`00Ool0000BOol00`00
Oomoo`02Ool01@00Oomoo`00Ool00`000Woo00@007ooOol000Eoo`03001oogoo009oo`03001oo`00
009oo`03001oogoo009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<0
07ooOol01goo00<007ooOol07goo000kOol00`00Oomoo`03Ool01000Oomoogoo0`000Woo00H007oo
Ool007oo0002Ool00`00Ool000020002Ool01P00Oomoo`00Ool000Aoo`03001oo`00019oo`03001o
ogoo009oo`<000Aoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03
0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo00Moo`03
001oogoo01moo`00>goo0P000goo100000Aoo`00000000=oo`D00004Ool00000Ool300000goo0000
00020002Ool3000017oo000007oo0P004Goo00<007ooOol00Woo00@007ooOol0009oo`8000=oo`<0
00Ioo`03001oogoo009oo`04001oogooOol30002Ool30003Ool200000goo000000020003Ool30009
Ool00`00Oomoo`0OOol003]oo`04001oogoo000jOol01@00Oomoogoo00000Woo00<007ooOol01goo
00<007ooOol017oo00L007ooOomoo`00Ool0000IOol00`00Oomoo`06Ool00`00Oomoo`0POol003Yo
o`D003]oo`03001oo`0000<000Uoo`8000Moo`03001oogoo00<001Qoo`8000Moo`03001oogoo025o
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo000^Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`05000>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20004
Ool00`00Oomoo`05000COol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool5000MOol0
0`00Oomoo`06Ool50002Ool00`00Oomoo`0HOol002eoo`03001oo`0000Moo`03001oo`0000=oo`03
001oogoo00eoo`03001oo`0000Moo`03001oo`00009oo`@000Qoo`03001oogoo019oo`03001oo`00
00Moo`03001oo`0000Qoo`03001oogoo01aoo`03001oo`0000Uoo`07001oogooOol007oo00006Goo
000]Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Ool00007Ool00`00Ool0
0003Ool30008Ool00`00Oomoo`0BOol00`00Ool00009Ool00`00Oomoo`06Ool00`00Oomoo`0NOol0
0`00Oomoo`07Ool01`00Oomoogoo001oo`0001Uoo`00;Goo00<007oo00001goo00<007oo00000goo
00<007ooOol03Goo00<007oo00001goo00<007oo00000Woo0P0000=oo`00Ool01goo00<007ooOol0
4Woo00<007oo00001goo0P002Goo00<007ooOol077oo0P002Woo00L007ooOomoo`00Ool0000IOol0
02eoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo00eoo`03001oo`0000Moo`03001oo`00
009oo`800003Ool007oo00Moo`03001oogoo019oo`03001oo`0000Moo`03001oogoo00Qoo`03001o
ogoo01aoo`03001oogoo00Uoo`07001oogooOol007oo00006Goo000^Ool00`00Oomoo`07Ool01000
Oomoogoo0P0047oo00<007ooOol01goo00@007ooOomoo`<000Qoo`8001Eoo`03001oogoo00Ioo`<0
00Moo`8001ioo`<000Qoo`8000Aoo`03001oogoo01Qoo`00gGoo003MOol00=eoo`00=7ooT@0067oo
000dOol01@00Oomoogoo00003Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo00@0
07ooOol0009oo`08001oogoo001oo`00Ool000eoo`03001oogoo00Eoo`03001oogoo00=oo`05001o
ogooOol00003Ool01000Oomoo`000Woo00D007oo001oo`0000eoo`03001oogoo00Eoo`03001oogoo
009oo`03001oogoo009oo`04001oogoo0003Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomo
o`0FOol003Aoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00@03goo00moo`80
01Qoo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool4
O002000017`0Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo
01Ioo`00:goo0`000Woo00D007ooOomoo`0000=oo`0300moogoo00]oo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomo
o`05Ool0100?Oomoogoo0`000goo00D03g`00000000?009oo`0800moogoo00moo`0?Ool03`eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool0
0`0?Ool03`02Ool00`00Oomoo`0FOol002aoo`06001oogoo001oo`000Woo00D007ooOomoo`0?00eo
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?
Ool03goo00l=Ool00`0?Oomoo`05Ool0100?Oomoog`00Woo00H03gooOomoo`0?Ool2O0001000Oomo
o`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol002Eoo`<0009oo`@0
0004Ool007oo0002Ool2001700l00g`000l03`0:00l00`0000l03`0f00l2000HOol002Yoo`03001o
o`00009oo`03001oo`00009oo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<0
3g`0Ool00goo00D03gooOomoo`0?00=oo`0400ml000000l2Ool01@0?Ool03goo00l03Goo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300mo
o`0?009oo`03001oogoo01Ioo`00:goo0P000Woo00<007oo00000Woo00D007ooOomoo`0?00eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool0
3goo00l=Ool00`0?Oomoo`05Ool00`00Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooO000009o
o`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000/Ool01@00Oomoogoo0000
0goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`04Ool00g`000moo`04Ool01@0?Oomo
ogoo00l00goo00/03gooOoml0000Ool03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0F
Ool003Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol00goo00=l07oo00l01Goo00D0
3gooOomoo`0?00=oo`0;00moogoo00moo`0000moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007oo
Ool05Woo000dOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol00Woo00Al0000Ool0
3`Eoo`0500moogooOol03`03Ool02`0?Oomoo`0?Ool0000?Ool03goo00l03Goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0400moo`0?Ool2
000HOol003Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol00Woo00@007ooOol03`Eo
o`0500moogooOol03`03Ool02`0?Oomoo`0?O01oo`00Ool03goo00l03Goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03
001oogoo01Ioo`005Woo00<007ooOol00Woo00<007ooOol05Woo00D007ooOomoo`0?00eoo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo
00l=Ool01@0?Oomoogoo00000goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0;00moogoo00mo
og`0001oo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000FOol6000HOol01@00Oomo
ogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`08
00moogoo00moo`0?Ool03`eoo`0500moogoo001l0003Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00@03gooOol03`9oo`05O000000?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000F
Ool01P00Oomoo`00Ool001Qoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool0100?Oomoog`017oo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?00003goo00l03Goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`04
00moo`0?Ool2000HOol001Ioo`04001oogoo000JOol01@00Oomoogoo00l03Goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`03
00moog`000Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo001o
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?
Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Moo`8001]oo`05001oogooOol03`0=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo
00moo`0?3Goo00<03`00Ool01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2
Ool01@0?O00007oo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?
00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomo
o`0?Ool03goo00l=Ool00`0?001oo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500ml000?00003`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000FOol00`00Oomo
o`02Ool00`00Oomoo`0FOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<007`0Ool01Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ooml000000l03Goo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0400mo
o`0?Ool2000HOol001Ioo`H001Qoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00=l07ooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ooml07oo00003Goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`03
00moo`0?009oo`03001oogoo01Ioo`0067oo00@007ooOol001Qoo`05001oogooOol03`0=Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00mo
o`0?37oo0W`01goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool0
3goo00003Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`03
00moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo00<007ooOol06Goo00D007ooOomo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?
Oomoo`0?Ool03goo00l<Ool00`0000moo`06Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@0
3gooOol03`9oo`0600moo`0?O0003`0037oo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`006Goo0`00
67oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l2Ool0200?Oomoo`0?Ool03goo00l;Ool00`00Ool03`07Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`0600moo`0?Ooml000037oo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo
01Ioo`006goo00<007ooOol05Woo0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`]oo`03O01oo`0?00Mo
o`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00L03goo00moog`0Ool0000;
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l0
0Woo00@03goo00moo`8001Qoo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l:Ool017`0Oomoo`0?
1goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01`0?Ool03goo00ml0000
00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0
3`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Yoo`8000ioo`8000Aoo`05001oogooOol00003
Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00P03gooOol03goo00moo`0?2Woo00Al07ooOol03`Moo`0300moogoo00=oo`0500moogooOol0
3`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?009oo`03001oogoo00Qoo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool0
0`00Oomoo`0FOol001Qoo`04001oo`00000@Ool01P00Oomoo`00Ool0009oo`05001oogooOol03`0=
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol0
3goo00moo`0?2Goo00D007ooOomoo`0?00Moo`0300moogoo00=oo`0500moogooOol03`03Ool0100?
Oomoo`0?0Woo00T03goo00moo`0?Ooml07oo00002Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`00
67oo00@007oo000000Uoo`<000=oo`07001oogooOol007oo00000Woo0P00>@0?00<0000?00l08`0?
00=l000?0000:`0?0P0067oo000HOol4000@Ool01P00Oomoo`00Ool0009oo`05001oogooOol03`0=
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol0
3goo00moo`0?27oo00<007`0Ool00Woo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00Woo00=l07oo000027oo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03
001oogoo01Ioo`006goo00<007ooOol037oo00<007oo00000Woo00<007oo00000Woo00D007ooOomo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?
Oomoo`0?Ool03goo00l8Ool00g`0Oomoo`02Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`02Ool00g`0Ool00008Ool00`0?Oomoo`05
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l0
0Woo00<007ooOol05Woo000[Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<03gooOol02goo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00mo
o`0?Ool03`Moo`03O00007oo00=oo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00Eoo`03001oogoo00Eoo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00
Oomoo`0FOol001Qoo`800003Ool007oo01Moo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l7Ool00`00
Oomoo`03Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`0500moo`0?Ool03`05Ool00`00Oomoo`05Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00@03goo00moo`8001Qoo`0067oo0P0000=oo`00
Ool05goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l2Ool0200?Oomoo`0?Ool03goo00l7Ool00`00Oomoo`03Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool017`0Oomo
o`001Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300mo
o`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo0P0000=oo`00Ool05goo00D007ooOomo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?
Oomoo`0?Ool03goo00l6Ool00g`0Oomoo`04Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`04Ool00g`0Ool00006Ool00`0?Oomoo`05
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l0
0Woo00<007ooOol05Woo000HOol00`00Ool0000IOol01@00Oomoogoo00l03Goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`Ioo`03
O01oogoo00Aoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?
0Woo00D03goo00moo`0?00Aoo`04O01oogoo0005Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000d
Ool20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00P03gooOol03goo00moo`0?1Goo00=l07ooOol01Goo00<03gooOol01Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l01goo00<007ooOol0
0goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?
009oo`0400moo`0?Ool2000HOol003Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?1Goo00=l07ooOol0
1Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?
Ool03goo00l027oo00<007ooOol00Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`006Goo0P006Goo
00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l2Ool0200?Oomoo`0?Ool03goo00l4Ool00`00Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`05Ool017`0Oomoo`0017oo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009o
o`0300moo`0?009oo`03001oogoo01Ioo`0067oo0P0000=oo`00Ool05goo00D007ooOomoo`0?00eo
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?
Ool03goo00l4Ool00g`0Oomoo`06Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00@03gooOol03`9oo`0500moo`0?Ool03`05Ool01G`0Oomoogoo00000goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009o
o`03001oogoo01Ioo`0067oo0P0000=oo`00Ool05goo00D007ooOomoo`0?00eoo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l3Ool0
0g`0Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol0
3`9oo`0500moo`0?Ool03`06Ool017`0Oomoo`000goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`00
6Goo00<007oo000067oo0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`=oo`03O01oogoo00Moo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?
00Ioo`05O01oogooOol00002Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03goo00l00Woo00@03goo00moo`8001Qoo`00=7oo00D007ooOomoo`0?00eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool0
3goo00l2Ool00g`0Oomoo`08Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00@03gooOol03`9oo`0500moo`0?Ool03`0:Ool01000Oomoo`0?1goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`00=7oo
00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l2Ool0200?Oomoo`0?Ool03goo00l2Ool00`00Oomoo`08Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0;Ool00`00Ool03`07Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo
00<007ooOol05Woo000dOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`9oo`0:00moogoo00moo`0?Ool03gooO00;Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`07Ool01g`0
Oomoogoo001oo`0?00Moo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0
3`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`80009oo`0300moogoo00]oo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool02P0?Oomoo`0?Ool03goo00l0
07`02goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool0
1@0?Ool03goo00l027oo00Il07ooOomoo`0000l7Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03goo00l00Woo00@03goo00moo`8001Qoo`00=7oo00D007ooOomoo`0?00eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool02@0?Oomoo`0?Ool0
3goo00ml000<Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol0
3`9oo`0500moo`0?Ool03`08Ool01W`0Oomoogoo00003`Moo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol002Yoo`<000=o
o`05001oogooOol00003Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00T03gooOol03goo00moo`00O00037oo00<03gooOol01Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<007ooOol0
1Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?
009oo`03001oogoo01Ioo`00:Woo00<007ooOol00Woo00<007oo00000Woo00D007ooOomoo`0?00eo
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?
Ool03goo000=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol0
3`9oo`0500moo`0?Ool03`0=Ool00`00Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000UOol30003Ool01`00
Oomoogoo001oo`00009oo`8002h03`03O0003`0?03D03`03O0003`0?00<03`0300003`0?01h03`80
01Qoo`00:goo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?O0003`eoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?
00Qoo`03O01oogoo009oo`0300l007oo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`@000ioo`03001oo`00
009oo`03001oo`00009oo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03gooO01oo`0?3Goo00<03gooOol01Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l02Goo00Ml07ooOomo
o`0?Ool00005Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo
00<03goo00l00Woo00<007ooOol05Woo000GOol00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomo
o`02Ool01@00Oomoogoo00000goo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`9oo`0800moogoo00moog`0Ool03`eoo`0300moogoo00Eoo`0300mo
ogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00Uoo`07O01oogoo
Ool03goo00001Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009o
o`0300moo`0?009oo`03001oogoo01Ioo`005Woo00<007ooOol017oo00<007ooOol057oo0P000Woo
00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9o
o`0800moogoo00l0000?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0400moogoo0004Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00@03goo00moo`8001Qoo`00=7oo00D007oo
Oomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0
200?Oomoog`0Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00@03gooOol03`9oo`0500moo`0?Ool03`0:Ool017`0Oomoo`0?0Woo00<007ooOol00Woo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001o
ogoo01Ioo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoog`0Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0:Ool017`0Oomoo`0?0goo
00D007ooOomoo`0?00Aoo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool0
3`02Ool00`00Oomoo`0FOol001Uoo`8001Uoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooO0003goo00moo`0?3Goo00<03goo
Ool01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l0
2goo00=l07oo00l00goo00D007ooOomoo`0?00Aoo`0300moogoo009oo`0400moogoo00l3Ool00`0?
Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`04001oogoo000HOol01@00Oomoogoo
00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800mo
og`000moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?
Oomoo`0?0Woo00D03goo00moo`0?00]oo`03O01oo`0?00Aoo`04001oogoo00l4Ool00`0?Oomoo`02
Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000FOol00`00
Ool00002Ool00`00Oomoo`0FOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03`00Ool03goo00moo`0?3Goo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<0
3gooOol00goo00<007oo00l017oo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`04
00moo`0?Ool2000HOol001Ioo`H001Qoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00Ql0000Ool03goo00moo`0?3Goo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo
00<03gooOol017oo00<0000?Ool00goo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009o
o`0300moo`0?009oo`03001oogoo01Ioo`006goo00<007ooOol05Woo00D007ooOomoo`0?00eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool027`0Oomoo`0?Ool0
3goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`0500moo`0?Ool03`0<Ool00g`000moo`05Ool00`0000moo`03Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l0
3Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00L03gooOol03gooO0003`02Ool0
1@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03goo00l037oo00=l000?Ool01Woo00<007ooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`006Goo0P006Goo
0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00L03goo
Ool03gooO0003`02Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00=l07ooOol01Goo00<03`00Ool0
0Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0400moo`0?Ool2000HOol001Qo
o`800003Ool007oo01Moo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool01`0?Oomoo`0?001oo`0?009oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00g`0Oomo
o`05Ool00`0?Ool00002Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo
00l00Woo00<007ooOol05Woo000HOol200000goo001oo`0GOol01@00Oomoogoo00l03Goo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOoml009oo`0800moogoo00moo`0?Ool0
3`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D0
3goo00moo`0?00eoo`0300moogoo00Eoo`0600moogoo001oo`0?17oo00@03gooOol03`=oo`0300mo
o`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`006Goo00<007oo000067oo00D007ooOomoo`0?
00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moog`000l2Ool0200?Oomo
o`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`0=Ool00`0?O01oo`05Ool01P0?Oomoo`00Ool03`Aoo`0400moogoo
00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`80009oo`0300moogoo
00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400ml000000l2Ool0200?Oomo
o`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`0=Ool00`0?O01oo`05Ool01P0?Oomoogoo00003`Aoo`0400moogoo
00l3Ool00`0?Ool03`02Ool0100?Ool03goo0P0067oo000dOol01@00Oomoogoo00l03Goo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00@03`00Ool03`9oo`0800moogoo00moo`0?Ool0
3`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D0
3goo00moo`0?00eoo`0300moog`000Eoo`0300moogoo009oo`03001oogoo009oo`0400moogoo00l3
Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Uoo`80009oo`03001oogoo01Ao
o`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool01P0?OomoogooO000009oo`04
00moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooO0001Goo00<03gooOol00Woo
00<03`00Ool00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Io
o`0067oo00H007ooOol007oo000;Ool50002Ool01@00Oomoogoo00000goo00<03gooOol02goo00<0
3gooOol01Goo00<03gooOol00Woo00H03gooOomoog`000l2Ool0100?Oomoo`0?0Woo00D03goo00mo
o`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moo`00009oo`0400moogoo
00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`06001oogoo001oo`00
3Goo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol0
0Woo00H03gooO01l07oo00l2Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eo
o`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moo`00009oo`0400moogoo00l3Ool00`0?Ool03`02Ool0
0`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`D000Qoo`<000=oo`07001oogooOol007oo00000Woo
0P007`0?00<0000?00l0C00?00=l000?00l02P0?00<0000?00l03`0?0P0067oo000HOol00`00Oomo
o`0@Ool01`00Oomoogoo001oo`00009oo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00g`0001oo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo
00@03gooOoml00Aoo`0300moogoo009oo`0600moogooOol0000?0Woo00L03gooOomoo`0?Ool03`02
Ool00`0?Ool03`02Ool00`00Oomoo`0FOol002]oo`07001oogooOol007oo00000Woo00D007ooOomo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`03O01oogoo009oo`0400moogoo00l2Ool0200?
Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@0
3gooOol03`9oo`0500moo`0?Ool03`0=Ool0100?Oomoog`017oo00<03gooOol00Woo00<03gooOol0
0Woo00@007ooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo00<0
07ooOol017oo00<007ooOol02Woo0P0017oo00D007ooOomoo`0000=oo`0300moogoo00]oo`0300mo
ogoo00Eoo`0300moogoo009l000300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`0=Ool0100?Oomoog`017oo00<03gooOol00Woo00<03gooOol00Woo00@03`000000
3`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`005goo00<007ooOol00Woo00<0
07ooOol05Goo0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03goo00000Woo00<03gooOol0
0Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=o
o`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0400moogoo0003Ool00`0?Ool03`02Ool0100?Ool03goo0P00
67oo000HOol4000HOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03g`0Ool00Woo00<03goo
Ool00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0500moogooOoml
0003Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01@0?Oomoo`0?00000Woo00<03goo00l00Woo00<0
3goo00l00Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00=l07oo
Ool00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eo
o`0300moogoo009oo`04O01oogoo00l4Ool00`0?Oomoo`02Ool02P0?Oomoo`0?Ool007oo00moo`0?
0Woo00<03goo00l00Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l03Goo00<03gooOol00goo
00<007`000l017oo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`03
00moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00mo
o`0?00eoo`0300moogoo009oo`04O01oogoo00l4Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo0P00
00Moo`0?Oomoo`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`80009oo`0300moogoo00]oo`0300mo
ogoo009oo`04001oogoo00l4Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00mo
o`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool0
1@0?Ool03goo00l03Goo00<03gooOol00Woo00Al07ooOol03`Aoo`0300moogoo009oo`0400moogoo
00l3Ool00`0?00003`02Ool0100?Ool03goo0P0067oo000dOol01@00Oomoogoo00l03Goo00D03goo
Ool007`000=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool0
3goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`0500moo`0?Ool03`0=Ool00`0?Oomoo`03Ool00g`0Ool03`04Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00P03goo000007oo00moo`0?0Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l03Goo
00@03`00O01l00Aoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?
Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol0
3`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`03Ool00g`0Ool03`04Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00@03goo00moo`800005Ool03gooOol0000HOol003Aoo`05001oogooOol03`0<Ool0
0g`0001oo`06Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo
00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2
Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moo`0?009oo`0300l00000009oo`03001oogoo01Ioo`00=7oo0P000Woo00<03goo
Ool027oo0W`000=oo`0?Ool01Woo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`08
00moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00=oo`03O01oo`0?00Aoo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Ool03`02Ool0100?Ool03goo0P0067oo000dOol01@00Oomoogoo
00l027oo0P000goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9o
o`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00=oo`03O01oo`0?00Aoo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Ao
o`05001oogooOol03`04Ool4O005Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol017oo00=l000?
Ool00goo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001o
ogoo01Ioo`00=7oo00H007ooOomoo`0?Ool2O0030007Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03goo
Ool017oo00=l000?Ool00goo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300mo
o`0?009oo`03001oogoo01Ioo`00=7oo00@007ooOomoo`9l0003001oogoo00Uoo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?
Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<0
3goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000dOol20002Ool00`00Oomoo`0;Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01000Oomoo`0?0Woo00P03gooOol03goo00mo
o`003Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0000=oo`0400moogoo00l2Ool0
1@0?Ool03goo00003Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@007ooOol0
3`=oo`0300moo`0?009oo`0400moo`00Ool2000HOol003AoogD00003O000000001T001Qoo`00gGoo
003MOol00=eoo`00gGoo003MOol00=eoo`00;Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool01@003Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo0P0017oo00<007ooOol0
1@004goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo1@007Goo00<007ooOol01Woo
1@000Woo00<007ooOol067oo000]Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0=Ool0
0`00Ool00007Ool00`00Ool00002Ool40008Ool00`00Oomoo`0BOol00`00Ool00007Ool00`00Ool0
0008Ool00`00Oomoo`0LOol00`00Ool00009Ool01`00Oomoogoo001oo`0001Uoo`00;Goo00<007oo
00001goo00<007oo00000goo00<007ooOol03Goo00<007oo00001goo00<007oo00000goo0`0027oo
00<007ooOol04Woo00<007oo00002Goo00<007ooOol01Woo00<007ooOol07Woo00<007ooOol01goo
00L007ooOomoo`00Ool0000IOol002eoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo00eo
o`03001oo`0000Moo`03001oo`00009oo`800003Ool007oo00Moo`03001oogoo019oo`03001oo`00
00Moo`8000Uoo`03001oogoo01aoo`8000Yoo`07001oogooOol007oo00006Goo000]Ool00`00Ool0
0007Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Ool00007Ool00`00Ool00002Ool200000goo
001oo`07Ool00`00Oomoo`0BOol00`00Ool00007Ool00`00Oomoo`08Ool00`00Oomoo`0LOol00`00
Oomoo`09Ool01`00Oomoogoo001oo`0001Uoo`00;Woo00<007ooOol01goo00@007ooOomoo`80011o
o`03001oogoo00Moo`04001oogooOol30008Ool2000EOol00`00Oomoo`06Ool30007Ool2000NOol3
0008Ool20004Ool00`00Oomoo`0HOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00
gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo001<Ool2000EOol2
000EOol00`00Oomoo`0lOol00`00Oomoo`0QOol004eoo`03001oogoo01Aoo`03001oogoo019oo`03
001oogoo01=oo`03001oogoo02Qoo`03001oogoo021oo`00>Woo0`000goo0`000goo0P000goo0`00
0Woo0`000Woo0P0000=oo`0000000Woo00<007oo00000P000goo00<007ooOol04Goo00@007ooOomo
o`<00003Ool007oo00@0009oo`<000Eoo`03001oogoo009oo`<000=oo`80009oo`<000=oo`800003
Ool00000009oo`03001oogoo00<000Uoo`03001oogoo01moo`00>goo00<007ooOol00goo00D007oo
Oomoo`0000Aoo`06001oogoo001oo`000Woo00<007oo000017oo00H007ooOol007oo0004Ool00`00
Ool0000BOol00`00Oomoo`02Ool01@00Oomoo`00Ool00`000Woo00@007ooOol000Eoo`03001oogoo
009oo`03001oo`00009oo`03001oogoo009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<0
07oo00000Woo00<007ooOol01goo00<007ooOol07goo000kOol00`00Oomoo`03Ool01000Oomoogoo
0`000Woo00H007ooOol007oo0002Ool00`00Ool000020002Ool01P00Oomoo`00Ool000Aoo`03001o
o`00019oo`03001oogoo009oo`<000Aoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool00`00Oomoo`030002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03
001oogoo00Moo`03001oogoo01moo`00>goo0P000goo100000Aoo`00000000=oo`D00004Ool00000
Ool300000goo000000020002Ool3000017oo000007oo0P004Goo00<007ooOol00Woo00@007ooOol0
009oo`8000=oo`<000Ioo`03001oogoo009oo`04001oogooOol30002Ool30003Ool200000goo0000
00020003Ool30009Ool00`00Oomoo`0OOol003]oo`04001oogoo000jOol01@00Oomoogoo00000Woo
00<007ooOol01goo00<007ooOol017oo00L007ooOomoo`00Ool0000IOol00`00Oomoo`06Ool00`00
Oomoo`0POol003Yoo`D003]oo`03001oo`0000<000Uoo`8000Moo`03001oogoo00<001Qoo`8000Mo
o`03001oogoo025oo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo000^Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`05000>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool20004Ool00`00Oomoo`05000COol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool5000MOol00`00Oomoo`06Ool50002Ool00`00Oomoo`0HOol002eoo`03001oo`0000Moo`03
001oo`0000=oo`03001oogoo00eoo`03001oo`0000Moo`03001oo`00009oo`@000Qoo`03001oogoo
019oo`03001oo`0000Moo`03001oo`0000Qoo`03001oogoo01aoo`03001oo`0000Uoo`07001oogoo
Ool007oo00006Goo000]Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Ool0
0007Ool00`00Ool00003Ool30008Ool00`00Oomoo`0BOol00`00Ool00009Ool00`00Oomoo`06Ool0
0`00Oomoo`0NOol00`00Oomoo`07Ool01`00Oomoogoo001oo`0001Uoo`00;Goo00<007oo00001goo
00<007oo00000goo00<007ooOol03Goo00<007oo00001goo00<007oo00000Woo0P0000=oo`00Ool0
1goo00<007ooOol04Woo00<007oo00001goo0P002Goo00<007ooOol077oo0P002Woo00L007ooOomo
o`00Ool0000IOol002eoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo00eoo`03001oo`00
00Moo`03001oo`00009oo`800003Ool007oo00Moo`03001oogoo019oo`03001oo`0000Moo`03001o
ogoo00Qoo`03001oogoo01aoo`03001oogoo00Uoo`07001oogooOol007oo00006Goo000^Ool00`00
Oomoo`07Ool01000Oomoogoo0P0047oo00<007ooOol01goo00@007ooOomoo`<000Qoo`8001Eoo`03
001oogoo00Ioo`<000Moo`8001ioo`<000Qoo`8000Aoo`03001oogoo01Qoo`00gGoo003MOol00=eo
o`00:Goo1@000Woo0`0000=oo`000000S`0067oo000[Ool00`00Oomoo`03Ool01000Oomoo`000goo
00<007ooOol02goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009o
o`08001oogoo001oo`00Ool000eoo`03001oogoo00Eoo`03001oogoo00=oo`05001oogooOol00003
Ool01000Oomoo`000Woo00D007oo001oo`0000eoo`03001oogoo00Eoo`03001oogoo00=oo`05001o
ogooOol00003Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo01Ioo`009Goo0`00
0goo00@007ooOomoo`@00003Ool00000009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool0100?
Ool03goo0P0067oo000[Ool01`00Oomoogoo001oo`00009oo`05001oogooOol03`0=Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?
3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?
Ool03goo00l03Goo00@03gooOomoo`Al000300moogoo00=oo`0300moo`000100009oo`03001oogoo
01Ioo`005Woo1P003goo00<007ooOol00Woo0P000Woo00D007ooOomoo`0?00eoo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?
Ool03`0=Ool00`0?O01oo`05Ool00`0?Oomoo`050002Ool01@0?Oomoogoo00l00Woo00<03goo00l0
0Woo00<03goo00l00Woo00<007ooOol05Woo000FOol30002Ool00`00Oomoo`0<Ool20005Ool00`00
Oomoo`020002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l037oo0W`01Goo1@000goo00D03goo
Oomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000IOol00`00
Oomoo`0HOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`05
00moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00<0009oo`03
00moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001o
ogoo01Ioo`005Woo0`000Woo00<007ooOol05Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`09Ool01g`0Oomoogoo00moo`0000Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomo
o`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo1P0067oo0P000Woo00<03gooOol0
2goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo
00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00D03goo00moo`0?00Qoo`03O01oogoo009oo`8000Ioo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo00<007oo
Ool00Woo00<007ooOol05Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`07Ool00g`0Oomo
o`02Ool00`0000moo`06Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2
Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<0
3gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo
00l02Woo0P0000=oo`0?Ool01Woo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00mo
o`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000JOol2000HOol20002Ool00`0?Oomoo`0;Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo
00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2
Ool01@0?Ool03goo00l01Goo00=l07ooOol00P000goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000HOol0
1000Ool000003Goo1@0000Aoo`000000009oo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03goo
Ool01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l0
17oo00Al07ooOol000Eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo00@007oo000000moo`05001o
ogooOol00004Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=o
o`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`04O01oogoo0006Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?
Ool03`02Ool00`00Oomoo`0FOol001Qoo`@000Uoo`<000=oo`03001oogoo009oo`04001oogooOol2
001R00l2000Y00l2000HOol001]oo`03001oogoo00eoo`03001oogoo009oo`05001oogooOol00003
Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool02@0?Ool03goo00moog`0Ool00009Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0F
Ool002]oo`07001oogooOol007oo00000Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0800moo`0?Ool03g`0
Ool000Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool0
3`9oo`0300moo`0?009oo`03001oogoo01Ioo`006Goo0P000Woo00<007ooOol02Woo0P0017oo00@0
07ooOomoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00@03gooOol03`9oo`0700moo`0?Ooml07oo00002goo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<0
07ooOol05Woo000HOol01P00Oomoo`00Ool001Ioo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<0
3gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01P0?Ool03goo
00l000aoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool0
3`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo00H007ooOol007oo000FOol01@00Oomoogoo
00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800mo
ogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?
Oomoo`0?0Woo00D03goo00ml000000eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol0
3`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo1@005goo0P00
0Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol0
3`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol0
3`03Ool0100?Oomoo`0?0Woo00D03gooO01oo`0000eoo`0300moogoo00Eoo`0300moogoo00=oo`05
00moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo
00<007ooOol06Goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moog`000003`0=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00
Oomoo`0FOol001Qoo`04001oogoo000HOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03g`0001oo`0?00eo
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`03
00moo`0?009oo`03001oogoo01Ioo`0067oo100067oo0P000Woo00<03gooOol02goo00<03gooOol0
1Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eo
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03`00
00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?
Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo00<007ooOol03Woo1@000Woo00D007oo
Oomoo`0000=oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00@03gooOol03`9oo`05O000000?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0F
Ool001Qoo`03001oogoo011oo`07001oogooOol007oo00000Woo00D007ooOomoo`0?00eoo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00/03gooOol03gooO000
07oo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomo
o`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`006Goo0`002Goo0`000goo00L007ooOomo
o`00Ool00002Ool2001G00l00g`000003`0c00l2000HOol001]oo`03001oogoo00eoo`07001oogoo
Ool007oo00000Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00/03gooOol03g`000003goo00moo`0?00eoo`0300moogoo00Eoo`03
00moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001o
ogoo01Ioo`00:goo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`03
00moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool02`0?Oomoo`0?001oo`0?Ool03goo
00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?
0Woo00<03goo00l00Woo00<007ooOol05Woo000ZOol20004Ool01000Oomoogoo0P000Woo00<03goo
Ool02goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800mo
ogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?
Oomoog`00Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol0
3`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo00@007ooOol0
01Qoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0400moog`00002Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo
000FOol00`00Ool00003000HOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`03
00moogoo00=oo`0500moogooOol03`03Ool0100?O000000?0Woo00D03goo00moo`0?00eoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?
009oo`03001oogoo01Ioo`006goo00<007ooOol05Woo0P000Woo00<03gooOol02goo00<03gooOol0
1Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eo
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?001oo`0?0Woo00D03goo
00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?
Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03`00Ool03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`03001oogoo01Uoo`05001oogooOol0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03goo
Ool03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`04O01o
ogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000GOol4000IOol01@00
Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9o
o`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`02
Ool01G`0001oogoo00l00Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`05
00moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo
00@007ooOol001Qoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00Woo00El000?Oomoo`0?009oo`0500moo`0?Ool03`0=Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02
Ool00`00Oomoo`0FOol001Qoo`04001oogoo000DOol01@00Oomoogoo00000goo00<03gooOol02goo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00mo
o`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0900moogooOol03gooO01oo`0?009oo`08
00moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0
1P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo00<007oo000057oo00<0
07oo00000Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
2@0?Oomoogoo00moo`00Ool03`02Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomo
o`0FOol002Yoo`<0009oo`03001oo`00009oo`8005003`03O0003`0?03X03`8001Qoo`0067oo00<0
07ooOol05Goo00D007ooOomoo`0000=oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01P0?Oomoogoo001l009oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<0
3gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo
00l00Woo00<007ooOol05Woo000HOol3000DOol00`00Ool00002Ool01@00Oomoogoo00l03Goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?
Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOoml0003Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`006goo00<007ooOol04Woo00@007oo
Oomoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?
Oomoo`00O0000goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0F
Ool001Qoo`03001oo`0001Uoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<0
3gooOol00goo00D03gooOol0000?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03goo
Ool01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l0
0Woo00<007ooOol05Woo000HOol4000HOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moog`0Ool03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eo
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`03
00moo`0?009oo`03001oogoo01Ioo`006goo00<007ooOol05Woo0P000Woo00<03gooOol02goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?
Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500ml0000Ool03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?00eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool0
3goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?O01oogoo00l00goo00@03gooOol03`9o
o`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H0
3gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Uoo`8001Uoo`05001oogooOol0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03goo
Ool03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03g`0Oomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000HOol01000Oomoo`00
67oo0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`05001o
ogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Io
o`005Woo00<007oo00000Woo00<007ooOol04Goo0P000goo00D007ooOomoo`0?00eoo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00g`0001oo`02Ool01@0?Oomoogoo00l00Woo00P03goo
Ool03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600mo
ogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000FOol6000COol00`00Ool00002Ool0
1@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol0
3`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo009oo`03O0003goo009o
o`0500moogooOol03`02Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol0
01]oo`03001oogoo00aoo`<0009oo`03001oo`00009oo`8004T03`03O000000?04403`8001Qoo`00
;goo0P000goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool01`0?OomoogooO01o
o`0?00=oo`0500moogooOol03`02Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomo
o`0FOol001Uoo`8001Aoo`03001oogoo009oo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03goo
Ool01Goo00L03gooOomoo`00Ool03`03Ool01@0?Oomoogoo00l00Woo00P03gooOol03goo00moo`0?
3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo
00<03goo00l00Woo00<007ooOol05Woo000HOol200000goo001oo`0COol20002Ool20002Ool00`0?
Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P0
3gooOol03goo00moo`0?3Goo00<03gooOol01Goo00@03gooOoml009oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo0P0000=o
o`00Ool05goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool0100?Ooml00000Woo
00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007oo
Ool05Woo000IOol00`00Ool0000HOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eo
o`0300moog`000=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`03
00moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300mo
o`0?009oo`03001oogoo01Ioo`00=7oo0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo
00Eoo`0300ml07oo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eo
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`03
00moo`0?009oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomo
o`05Ool00`00Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool0
0`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03goo
Ool01Goo00=l07ooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l0
3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo
00<03goo00l00Woo00<007ooOol05Woo000dOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<0
3gooOol017oo00=l000?Ool017oo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo
00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?
0Woo00<03goo00l00Woo00<007ooOol05Woo000`Ool300000goo001oo`02Ool00`0?Oomoo`0;Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo
00moo`0?3Goo00<03gooOol00goo00=l07oo00l01Goo00D03gooOomoo`0?00=oo`0400moogoo00l2
Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`06
00moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000aOol01000Oomoo`000goo00<0
3gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`08
00moogoo00moo`0?Ool03`eoo`0300moogoo00=oo`03001oo`0?00Eoo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`00:Woo0`000Woo
100000=oo`000000@P0?00<0000?00l0B00?0P0067oo000_Ool00`00Ool00002Ool01@00Oomoogoo
00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800mo
ogoo00moo`0?Ool03`eoo`0500moogooOoml0003Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol0031oo`80009o
o`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0Woo00P03gooOol03goo00moo`0?3Goo00D03gooOol007`000=oo`0300moogoo00=oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Io
o`0067oo10005Goo00<007ooOol00P000Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0400moogooO004
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?
Ool03`02Ool00`00Oomoo`0FOol001Moo`03001oogoo009oo`03001oogoo01Eoo`05001oogooOol0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03goo
Ool03goo00moo`0?3Goo00<03goo00001Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000FOol00`00Oomoo`04
Ool00`00Oomoo`0DOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300ml07oo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eo
o`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03
001oogoo01Ioo`00=7oo0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`03O01oogoo00Eoo`0300mo
ogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009o
o`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l<Ool00`00O01oo`06Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02
Ool00`00Oomoo`0FOol001Uoo`8001Uoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?37oo00=l000?Ool0
1Woo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo
00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<0
3goo00l00Woo00<007ooOol05Woo000HOol01000Oomoo`0067oo0P000Woo00<03gooOol02goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?
Ool03`]oo`03001oo`0?00Moo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo00<007oo00000Woo00<007oo
Ool04Goo0`000Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l:Ool017`0Oomoo`0?1goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<0
07ooOol05Woo000FOol6000COol00`00Oomoo`02Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`Uoo`05
O01oogooOol03`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001]oo`03001oogoo00aoo`<000=oo`04001o
ogooOol2000h00l2O01C00l2000HOol001Ioo`03001oogoo009oo`03001oogoo019oo`05001oogoo
Ool00003Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00P03gooOol03goo00moo`0?1goo00<007ooOol00goo00<03gooOol01Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo
00<007ooOol05Woo000FOol6000COol00`00Ool00002Ool01@00Oomoogoo00l03Goo00<03gooOol0
1Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`Io
o`03O01oogoo00Aoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo00<007oo00000Woo
00<007ooOol04Woo00@007ooOomoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l5Ool00g`0Oomoo`05
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Ioo`03001oo`00009oo`03001oogoo01Io
o`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0Woo00P03gooOol03goo00moo`0?0goo00<007`0Ool01goo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<0
07ooOol05Woo000GOol01000Ool000006Goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l2Ool00g`0Oomo
o`08Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03goo
Ool03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`80009oo`0300moogoo00]oo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool02P0?Oomoo`0?Ool0
3goo00l007`02goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo
00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l0
3Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0700moogoo
00moo`0?00000W`037oo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000FOol00`00Oomoo`04
Ool00`00Oomoo`0DOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`9oo`0800moogoo001l0000Ool03`eoo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eo
o`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03
001oogoo01Ioo`005goo00<007ooOol00Woo00<007ooOol05Goo0P000Woo00<03gooOol02goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`@0009l0004Ool03goo00l=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`@001Aoo`05001oogooOol00003Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0100?Oomoogoo0`0017`000P03gooOol0
3goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo
00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000_Ool00`00Ool00002Ool0
1@00Oomoogoo00l03Goo00<03gooOol01Goo00<007`0O0000W`00P000g`000@03gooOol03`9oo`08
00moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`00;goo00<007oo
00000Woo0P000Woo17`00P000g`00P0017`00P0017`000<0000?Ool00goo00<03gooOol00Woo00@0
3gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0400moo`0?Ool2000HOol002moo`03
001oo`00009oo`05001oogooOol0000=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01000Oomoo`0?0Woo00P03gooOol03goo00moo`003Goo00<03gooOol01Goo00<03gooOol00goo
00D03gooOomoo`0000=oo`0400moogoo00l2Ool01@0?Ool03goo00003Goo00<03gooOol01Goo00<0
3gooOol00goo00D03gooOomoo`0000=oo`0600moogoo00moo`0?0Woo00<03goo00000Woo00<007oo
Ool05Woo000_Ool00`00Ool00002OonA000HOol0031oo`03001oogoo0:Yoo`00gGoo003MOol00=eo
o`00gGoo003MOol002ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo00D000ioo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo009oo`8000Aoo`03001oogoo00D001=oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo00Eoo`D001eoo`03001oogoo00Ioo`D0009oo`03001oogoo
01Qoo`00;Goo00<007oo00001goo00<007oo00000goo00<007ooOol03Goo00<007oo00001goo00<0
07oo00000Woo100027oo00<007ooOol04Woo00<007oo00001goo00<007oo000027oo00<007ooOol0
77oo00<007oo00002Goo00L007ooOomoo`00Ool0000IOol002eoo`03001oo`0000Moo`03001oo`00
00=oo`03001oogoo00eoo`03001oo`0000Moo`03001oo`0000=oo`<000Qoo`03001oogoo019oo`03
001oo`0000Uoo`03001oogoo00Ioo`03001oogoo01ioo`03001oogoo00Moo`07001oogooOol007oo
00006Goo000]Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Ool00007Ool0
0`00Ool00002Ool200000goo001oo`07Ool00`00Oomoo`0BOol00`00Ool00007Ool20009Ool00`00
Oomoo`0LOol2000:Ool01`00Oomoogoo001oo`0001Uoo`00;Goo00<007oo00001goo00<007oo0000
0goo00<007ooOol03Goo00<007oo00001goo00<007oo00000Woo0P0000=oo`00Ool01goo00<007oo
Ool04Woo00<007oo00001goo00<007ooOol027oo00<007ooOol077oo00<007ooOol02Goo00L007oo
Oomoo`00Ool0000IOol002ioo`03001oogoo00Moo`04001oogooOol2000@Ool00`00Oomoo`07Ool0
1000Oomoogoo0`0027oo0P005Goo00<007ooOol01Woo0`001goo0P007Woo0`0027oo0P0017oo00<0
07ooOol067oo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo0000\
\>"],
  ImageRangeCache->{{{0, 220.875}, {287, 0}} -> {-0.0250052, -0.033245, 
  0.00475387, 0.00475387}, {{5.25, 215.562}, {280, 150}} -> {-3.23716, 
  -58.6608, 0.0219425, 0.467693}, {{5.25, 215.562}, {137, 6.9375}} -> {
  -3.23535, -43.4496, 0.0219277, 0.164837}},
  CellTags->"3.5"],

Cell[TextData[{
  "We again use ",
  StyleBox["BilinearTransform", "MR"],
  ", this time with frequency prewarping at some critical frequency ",
  StyleBox["wc", "MR"],
  ". "
}], "MathCaption",
  CellTags->"3.5"],

Cell["\<\
ToDiscreteTime[lag,
 Sampled -> Period[T],
 Method -> BilinearTransform,
 CriticalFrequency -> wc
] //Simplify\
\>", "Input",
  CellLabel->"In[57]:=",
  CellTags->"3.5"],

Cell[BoxData[
    \(TransferFunction[s, 
      {{\(a\ \((\(-1\) + s)\)\ wc + \((1 + s)\)\ Tan[\(T\ wc\)\/2]\)\/\(b\ \
\((\(-1\) + s)\)\ wc + \((1 + s)\)\ Tan[\(T\ wc\)\/2]\)}}, 
      Sampled \[Rule] Period[T]]\)], "Output",
  CellLabel->"Out[57]=",
  CellTags->"3.5"],

Cell["\<\
We have achieved a perfect match at that frequency at the expense \
of less accurate behavior at other frequencies. \
\>", "MathCaption",
  CellTags->"3.5"],

Cell["\<\
DisplayTogetherGraphicsArray[
 lagplot,
 BodePlot[%/.{a->1, b->5, T->1, wc->2},
 PlotStyle -> {
 RGBColor[1, 0, 0],
 Dashing[{.02}]
 }
 ]
]\
\>", "Input",
  CellLabel->"In[58]:=",
  CellTags->"3.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.29787 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0309017 0.952381 [
[ 0 0 0 0 ]
[ 1 1.29787 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.29787 L
0 1.29787 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0309017 0.97619 0.619505 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.637418 0.0148941 [
[.02381 -0.0125 -14 -12.5625 ]
[.02381 -0.0125 14 0 ]
[.2457 -0.0125 -14 -12.5625 ]
[.2457 -0.0125 14 0 ]
[.34127 -0.0125 -11 -12.5625 ]
[.34127 -0.0125 11 0 ]
[.56317 -0.0125 -11 -12.5625 ]
[.56317 -0.0125 11 0 ]
[.65873 -0.0125 -5 -12.5625 ]
[.65873 -0.0125 5 0 ]
[.88063 -0.0125 -5 -12.5625 ]
[.88063 -0.0125 5 0 ]
[.97619 -0.0125 -8 -12.5625 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .04165 -18 -4.5 ]
[-0.0125 .04165 0 4.5 ]
[-0.0125 .19059 -18 -4.5 ]
[-0.0125 .19059 0 4.5 ]
[-0.0125 .33954 -18 -4.5 ]
[-0.0125 .33954 0 4.5 ]
[-0.0125 .48848 -18 -4.5 ]
[-0.0125 .48848 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -35 ]
[-0.01875 .30902 -18 35 ]
[.02381 .63053 -14 0 ]
[.02381 .63053 14 12.5625 ]
[.2457 .63053 -14 0 ]
[.2457 .63053 14 12.5625 ]
[.34127 .63053 -11 0 ]
[.34127 .63053 11 12.5625 ]
[.56317 .63053 -11 0 ]
[.56317 .63053 11 12.5625 ]
[.65873 .63053 -5 0 ]
[.65873 .63053 5 12.5625 ]
[.88063 .63053 -5 0 ]
[.88063 .63053 5 12.5625 ]
[.97619 .63053 -8 0 ]
[.97619 .63053 8 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2457 0 m
.2457 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.56317 0 m
.56317 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.88063 0 m
.88063 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.11937 0 m
.11937 .61803 L
s
.17528 0 m
.17528 .61803 L
s
.21494 0 m
.21494 .61803 L
s
.27084 0 m
.27084 .61803 L
s
.29209 0 m
.29209 .61803 L
s
.3105 0 m
.3105 .61803 L
s
.32674 0 m
.32674 .61803 L
s
.43683 0 m
.43683 .61803 L
s
.49274 0 m
.49274 .61803 L
s
.5324 0 m
.5324 .61803 L
s
.5883 0 m
.5883 .61803 L
s
.60955 0 m
.60955 .61803 L
s
.62797 0 m
.62797 .61803 L
s
.6442 0 m
.6442 .61803 L
s
.7543 0 m
.7543 .61803 L
s
.8102 0 m
.8102 .61803 L
s
.84986 0 m
.84986 .61803 L
s
.90576 0 m
.90576 .61803 L
s
.92702 0 m
.92702 .61803 L
s
.94543 0 m
.94543 .61803 L
s
.96166 0 m
.96166 .61803 L
s
0 .04165 m
1 .04165 L
s
0 .19059 m
1 .19059 L
s
0 .33954 m
1 .33954 L
s
0 .48848 m
1 .48848 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 0 m
.2457 .00625 L
s
gsave
.2457 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 0 m
.56317 .00625 L
s
gsave
.56317 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 0 m
.88063 .00625 L
s
gsave
.88063 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 0 m
.11937 .00375 L
s
.17528 0 m
.17528 .00375 L
s
.21494 0 m
.21494 .00375 L
s
.27084 0 m
.27084 .00375 L
s
.29209 0 m
.29209 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.32674 0 m
.32674 .00375 L
s
.43683 0 m
.43683 .00375 L
s
.49274 0 m
.49274 .00375 L
s
.5324 0 m
.5324 .00375 L
s
.5883 0 m
.5883 .00375 L
s
.60955 0 m
.60955 .00375 L
s
.62797 0 m
.62797 .00375 L
s
.6442 0 m
.6442 .00375 L
s
.7543 0 m
.7543 .00375 L
s
.8102 0 m
.8102 .00375 L
s
.84986 0 m
.84986 .00375 L
s
.90576 0 m
.90576 .00375 L
s
.92702 0 m
.92702 .00375 L
s
.94543 0 m
.94543 .00375 L
s
.96166 0 m
.96166 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .04165 m
.00625 .04165 L
s
[(-40)] -0.0125 .04165 1 0 Mshowa
0 .19059 m
.00625 .19059 L
s
[(-30)] -0.0125 .19059 1 0 Mshowa
0 .33954 m
.00625 .33954 L
s
[(-20)] -0.0125 .33954 1 0 Mshowa
0 .48848 m
.00625 .48848 L
s
[(-10)] -0.0125 .48848 1 0 Mshowa
.125 Mabswid
0 .07144 m
.00375 .07144 L
s
0 .10123 m
.00375 .10123 L
s
0 .13102 m
.00375 .13102 L
s
0 .16081 m
.00375 .16081 L
s
0 .22038 m
.00375 .22038 L
s
0 .25017 m
.00375 .25017 L
s
0 .27996 m
.00375 .27996 L
s
0 .30975 m
.00375 .30975 L
s
0 .36932 m
.00375 .36932 L
s
0 .39911 m
.00375 .39911 L
s
0 .4289 m
.00375 .4289 L
s
0 .45869 m
.00375 .45869 L
s
0 .01187 m
.00375 .01187 L
s
0 .51827 m
.00375 .51827 L
s
0 .54805 m
.00375 .54805 L
s
0 .57784 m
.00375 .57784 L
s
0 .60763 m
.00375 .60763 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -120.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
96 10.2813 translate
90 rotate
-96 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(deg) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(L) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 .61178 m
.2457 .61803 L
s
gsave
.2457 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 .61178 m
.34127 .61803 L
s
gsave
.34127 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 .61178 m
.56317 .61803 L
s
gsave
.56317 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 .61178 m
.65873 .61803 L
s
gsave
.65873 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 .61178 m
.88063 .61803 L
s
gsave
.88063 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 .61428 m
.11937 .61803 L
s
.17528 .61428 m
.17528 .61803 L
s
.21494 .61428 m
.21494 .61803 L
s
.27084 .61428 m
.27084 .61803 L
s
.29209 .61428 m
.29209 .61803 L
s
.3105 .61428 m
.3105 .61803 L
s
.32674 .61428 m
.32674 .61803 L
s
.43683 .61428 m
.43683 .61803 L
s
.49274 .61428 m
.49274 .61803 L
s
.5324 .61428 m
.5324 .61803 L
s
.5883 .61428 m
.5883 .61803 L
s
.60955 .61428 m
.60955 .61803 L
s
.62797 .61428 m
.62797 .61803 L
s
.6442 .61428 m
.6442 .61803 L
s
.7543 .61428 m
.7543 .61803 L
s
.8102 .61428 m
.8102 .61803 L
s
.84986 .61428 m
.84986 .61803 L
s
.90576 .61428 m
.90576 .61803 L
s
.92702 .61428 m
.92702 .61803 L
s
.94543 .61428 m
.94543 .61803 L
s
.96166 .61428 m
.96166 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04165 m
1 .04165 L
s
.99375 .19059 m
1 .19059 L
s
.99375 .33954 m
1 .33954 L
s
.99375 .48848 m
1 .48848 L
s
.125 Mabswid
.99625 .07144 m
1 .07144 L
s
.99625 .10123 m
1 .10123 L
s
.99625 .13102 m
1 .13102 L
s
.99625 .16081 m
1 .16081 L
s
.99625 .22038 m
1 .22038 L
s
.99625 .25017 m
1 .25017 L
s
.99625 .27996 m
1 .27996 L
s
.99625 .30975 m
1 .30975 L
s
.99625 .36932 m
1 .36932 L
s
.99625 .39911 m
1 .39911 L
s
.99625 .4289 m
1 .4289 L
s
.99625 .45869 m
1 .45869 L
s
.99625 .01187 m
1 .01187 L
s
.99625 .51827 m
1 .51827 L
s
.99625 .54805 m
1 .54805 L
s
.99625 .57784 m
1 .57784 L
s
.99625 .60763 m
1 .60763 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.05665 .59417 L
.08949 .5826 L
.12233 .56797 L
.15517 .54952 L
.18801 .52634 L
.22085 .4974 L
.25369 .4616 L
.28654 .41796 L
.31938 .36596 L
.35222 .30605 L
.38506 .24029 L
.4179 .1729 L
.45074 .11002 L
.48358 .05876 L
.51642 .02555 L
.54926 .01472 L
.5821 .02767 L
.61494 .06272 L
.64778 .11531 L
.68062 .17888 L
.71346 .24636 L
.74631 .31173 L
.77915 .37098 L
.81199 .42223 L
.84483 .46513 L
.87767 .50027 L
.91051 .52865 L
.94335 .55136 L
.97619 .56943 L
s
1 0 0 r
[ .02 ] 0 setdash
.02381 .61551 m
.05115 .61071 L
.07848 .60486 L
.10582 .59774 L
.13315 .58907 L
.16049 .57853 L
.18783 .56572 L
.21516 .55019 L
.2425 .5314 L
.26983 .50876 L
.29717 .48164 L
.32451 .4494 L
.35184 .41154 L
.37918 .3678 L
.40651 .31844 L
.43385 .26447 L
.46119 .20793 L
.48852 .15192 L
.51586 .10044 L
.54319 .05783 L
.57053 .02825 L
.59787 .01511 L
.6252 .0209 L
.65254 .04714 L
.67988 .09444 L
.70721 .16261 L
.73455 .25092 L
.76188 .35865 L
.78922 .48626 L
s
.78922 .48626 m
.81305 .61803 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.678366 0.97619 1.26697 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.65873 0.31746 0.603319 0.0422304 [
[.02381 -0.0125 -14 -12.5625 ]
[.02381 -0.0125 14 0 ]
[.2457 -0.0125 -14 -12.5625 ]
[.2457 -0.0125 14 0 ]
[.34127 -0.0125 -11 -12.5625 ]
[.34127 -0.0125 11 0 ]
[.56317 -0.0125 -11 -12.5625 ]
[.56317 -0.0125 11 0 ]
[.65873 -0.0125 -5 -12.5625 ]
[.65873 -0.0125 5 0 ]
[.88063 -0.0125 -5 -12.5625 ]
[.88063 -0.0125 5 0 ]
[.97619 -0.0125 -8 -12.5625 ]
[.97619 -0.0125 8 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .01209 -18 -4.5 ]
[-0.0125 .01209 0 4.5 ]
[-0.0125 .09655 -18 -4.5 ]
[-0.0125 .09655 0 4.5 ]
[-0.0125 .18102 -18 -4.5 ]
[-0.0125 .18102 0 4.5 ]
[-0.0125 .26548 -12 -4.5 ]
[-0.0125 .26548 0 4.5 ]
[-0.0125 .34994 -12 -4.5 ]
[-0.0125 .34994 0 4.5 ]
[-0.0125 .4344 -12 -4.5 ]
[-0.0125 .4344 0 4.5 ]
[-0.0125 .51886 -12 -4.5 ]
[-0.0125 .51886 0 4.5 ]
[-0.0125 .60332 -6 -4.5 ]
[-0.0125 .60332 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -44 ]
[-0.01875 .30902 -18 44 ]
[.02381 .63053 -14 0 ]
[.02381 .63053 14 12.5625 ]
[.2457 .63053 -14 0 ]
[.2457 .63053 14 12.5625 ]
[.34127 .63053 -11 0 ]
[.34127 .63053 11 12.5625 ]
[.56317 .63053 -11 0 ]
[.56317 .63053 11 12.5625 ]
[.65873 .63053 -5 0 ]
[.65873 .63053 5 12.5625 ]
[.88063 .63053 -5 0 ]
[.88063 .63053 5 12.5625 ]
[.97619 .63053 -8 0 ]
[.97619 .63053 8 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2457 0 m
.2457 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.56317 0 m
.56317 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.88063 0 m
.88063 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.11937 0 m
.11937 .61803 L
s
.17528 0 m
.17528 .61803 L
s
.21494 0 m
.21494 .61803 L
s
.27084 0 m
.27084 .61803 L
s
.29209 0 m
.29209 .61803 L
s
.3105 0 m
.3105 .61803 L
s
.32674 0 m
.32674 .61803 L
s
.43683 0 m
.43683 .61803 L
s
.49274 0 m
.49274 .61803 L
s
.5324 0 m
.5324 .61803 L
s
.5883 0 m
.5883 .61803 L
s
.60955 0 m
.60955 .61803 L
s
.62797 0 m
.62797 .61803 L
s
.6442 0 m
.6442 .61803 L
s
.7543 0 m
.7543 .61803 L
s
.8102 0 m
.8102 .61803 L
s
.84986 0 m
.84986 .61803 L
s
.90576 0 m
.90576 .61803 L
s
.92702 0 m
.92702 .61803 L
s
.94543 0 m
.94543 .61803 L
s
.96166 0 m
.96166 .61803 L
s
0 .09655 m
1 .09655 L
s
0 .18102 m
1 .18102 L
s
0 .26548 m
1 .26548 L
s
0 .34994 m
1 .34994 L
s
0 .4344 m
1 .4344 L
s
0 .51886 m
1 .51886 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 0 m
.2457 .00625 L
s
gsave
.2457 -0.0125 -75 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 0 m
.56317 .00625 L
s
gsave
.56317 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 0 m
.88063 .00625 L
s
gsave
.88063 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 0 m
.11937 .00375 L
s
.17528 0 m
.17528 .00375 L
s
.21494 0 m
.21494 .00375 L
s
.27084 0 m
.27084 .00375 L
s
.29209 0 m
.29209 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.32674 0 m
.32674 .00375 L
s
.43683 0 m
.43683 .00375 L
s
.49274 0 m
.49274 .00375 L
s
.5324 0 m
.5324 .00375 L
s
.5883 0 m
.5883 .00375 L
s
.60955 0 m
.60955 .00375 L
s
.62797 0 m
.62797 .00375 L
s
.6442 0 m
.6442 .00375 L
s
.7543 0 m
.7543 .00375 L
s
.8102 0 m
.8102 .00375 L
s
.84986 0 m
.84986 .00375 L
s
.90576 0 m
.90576 .00375 L
s
.92702 0 m
.92702 .00375 L
s
.94543 0 m
.94543 .00375 L
s
.96166 0 m
.96166 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .01209 m
.00625 .01209 L
s
[(-14)] -0.0125 .01209 1 0 Mshowa
0 .09655 m
.00625 .09655 L
s
[(-12)] -0.0125 .09655 1 0 Mshowa
0 .18102 m
.00625 .18102 L
s
[(-10)] -0.0125 .18102 1 0 Mshowa
0 .26548 m
.00625 .26548 L
s
[(-8)] -0.0125 .26548 1 0 Mshowa
0 .34994 m
.00625 .34994 L
s
[(-6)] -0.0125 .34994 1 0 Mshowa
0 .4344 m
.00625 .4344 L
s
[(-4)] -0.0125 .4344 1 0 Mshowa
0 .51886 m
.00625 .51886 L
s
[(-2)] -0.0125 .51886 1 0 Mshowa
0 .60332 m
.00625 .60332 L
s
[(0)] -0.0125 .60332 1 0 Mshowa
.125 Mabswid
0 .03321 m
.00375 .03321 L
s
0 .05432 m
.00375 .05432 L
s
0 .07544 m
.00375 .07544 L
s
0 .11767 m
.00375 .11767 L
s
0 .13878 m
.00375 .13878 L
s
0 .1599 m
.00375 .1599 L
s
0 .20213 m
.00375 .20213 L
s
0 .22325 m
.00375 .22325 L
s
0 .24436 m
.00375 .24436 L
s
0 .28659 m
.00375 .28659 L
s
0 .30771 m
.00375 .30771 L
s
0 .32882 m
.00375 .32882 L
s
0 .37105 m
.00375 .37105 L
s
0 .39217 m
.00375 .39217 L
s
0 .41328 m
.00375 .41328 L
s
0 .45551 m
.00375 .45551 L
s
0 .47663 m
.00375 .47663 L
s
0 .49774 m
.00375 .49774 L
s
0 .53997 m
.00375 .53997 L
s
0 .56109 m
.00375 .56109 L
s
0 .5822 m
.00375 .5822 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -129.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 10.2813 translate
90 rotate
-105 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnitude) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.01) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 .61178 m
.2457 .61803 L
s
gsave
.2457 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.05) show
87.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 .61178 m
.34127 .61803 L
s
gsave
.34127 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 .61178 m
.56317 .61803 L
s
gsave
.56317 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 .61178 m
.65873 .61803 L
s
gsave
.65873 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 .61178 m
.88063 .61803 L
s
gsave
.88063 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 .61428 m
.11937 .61803 L
s
.17528 .61428 m
.17528 .61803 L
s
.21494 .61428 m
.21494 .61803 L
s
.27084 .61428 m
.27084 .61803 L
s
.29209 .61428 m
.29209 .61803 L
s
.3105 .61428 m
.3105 .61803 L
s
.32674 .61428 m
.32674 .61803 L
s
.43683 .61428 m
.43683 .61803 L
s
.49274 .61428 m
.49274 .61803 L
s
.5324 .61428 m
.5324 .61803 L
s
.5883 .61428 m
.5883 .61803 L
s
.60955 .61428 m
.60955 .61803 L
s
.62797 .61428 m
.62797 .61803 L
s
.6442 .61428 m
.6442 .61803 L
s
.7543 .61428 m
.7543 .61803 L
s
.8102 .61428 m
.8102 .61803 L
s
.84986 .61428 m
.84986 .61803 L
s
.90576 .61428 m
.90576 .61803 L
s
.92702 .61428 m
.92702 .61803 L
s
.94543 .61428 m
.94543 .61803 L
s
.96166 .61428 m
.96166 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01209 m
1 .01209 L
s
.99375 .09655 m
1 .09655 L
s
.99375 .18102 m
1 .18102 L
s
.99375 .26548 m
1 .26548 L
s
.99375 .34994 m
1 .34994 L
s
.99375 .4344 m
1 .4344 L
s
.99375 .51886 m
1 .51886 L
s
.99375 .60332 m
1 .60332 L
s
.125 Mabswid
.99625 .03321 m
1 .03321 L
s
.99625 .05432 m
1 .05432 L
s
.99625 .07544 m
1 .07544 L
s
.99625 .11767 m
1 .11767 L
s
.99625 .13878 m
1 .13878 L
s
.99625 .1599 m
1 .1599 L
s
.99625 .20213 m
1 .20213 L
s
.99625 .22325 m
1 .22325 L
s
.99625 .24436 m
1 .24436 L
s
.99625 .28659 m
1 .28659 L
s
.99625 .30771 m
1 .30771 L
s
.99625 .32882 m
1 .32882 L
s
.99625 .37105 m
1 .37105 L
s
.99625 .39217 m
1 .39217 L
s
.99625 .41328 m
1 .41328 L
s
.99625 .45551 m
1 .45551 L
s
.99625 .47663 m
1 .47663 L
s
.99625 .49774 m
1 .49774 L
s
.99625 .53997 m
1 .53997 L
s
.99625 .56109 m
1 .56109 L
s
.99625 .5822 m
1 .5822 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60288 m
.05665 .60261 L
.08949 .60218 L
.12233 .60149 L
.15517 .60039 L
.18801 .59862 L
.22085 .59581 L
.25369 .59139 L
.28654 .58451 L
.31938 .57399 L
.35222 .55832 L
.38506 .53586 L
.4179 .50515 L
.45074 .46553 L
.48358 .41758 L
.51642 .36324 L
.54926 .30552 L
.5821 .24796 L
.61494 .19409 L
.64778 .14683 L
.68062 .108 L
.71346 .07808 L
.74631 .05629 L
.77915 .04116 L
.81199 .03102 L
.84483 .02441 L
.87767 .02016 L
.91051 .01747 L
.94335 .01578 L
.97619 .01472 L
s
1 0 0 r
[ .02 ] 0 setdash
.02381 .60314 m
.05115 .60305 L
.07848 .60292 L
.10582 .60272 L
.13315 .60243 L
.16049 .60201 L
.18783 .60137 L
.21516 .60043 L
.2425 .59904 L
.26983 .597 L
.29717 .594 L
.32451 .58964 L
.35184 .58335 L
.37918 .5744 L
.40651 .5619 L
.43385 .54485 L
.46119 .52227 L
.48852 .49343 L
.51586 .45805 L
.54319 .41646 L
.57053 .36963 L
.59787 .319 L
.6252 .26639 L
.65254 .21376 L
.67988 .16319 L
.70721 .11673 L
.73455 .07636 L
.76188 .04399 L
.78922 .02173 L
.81656 .01296 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[58]:=",
  ImageSize->{221.875, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M000181000`40O003h00OgGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo001<Ool2000EOol2000EOol00`00Oomo
o`0lOol00`00Oomoo`0QOol004eoo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo01=oo`03
001oogoo02Qoo`03001oogoo021oo`00>Woo0`000goo0`000goo0P000goo0`000Woo0`000Woo0P00
00=oo`0000000Woo00<007oo00000P000goo00<007ooOol04Goo00@007ooOomoo`<00003Ool007oo
00@0009oo`<000Eoo`03001oogoo009oo`<000=oo`80009oo`<000=oo`800003Ool00000009oo`03
001oogoo00<000Uoo`03001oogoo01moo`00>goo00<007ooOol00goo00D007ooOomoo`0000Aoo`06
001oogoo001oo`000Woo00<007oo000017oo00H007ooOol007oo0004Ool00`00Ool0000BOol00`00
Oomoo`02Ool01@00Oomoo`00Ool00`000Woo00@007ooOol000Eoo`03001oogoo009oo`03001oo`00
009oo`03001oogoo009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<0
07ooOol01goo00<007ooOol07goo000kOol00`00Oomoo`03Ool01000Oomoogoo0`000Woo00H007oo
Ool007oo0002Ool00`00Ool000020002Ool01P00Oomoo`00Ool000Aoo`03001oo`00019oo`03001o
ogoo009oo`<000Aoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03
0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo00Moo`03
001oogoo01moo`00>goo0P000goo100000Aoo`00000000=oo`D00004Ool00000Ool300000goo0000
00020002Ool3000017oo000007oo0P004Goo00<007ooOol00Woo00@007ooOol0009oo`8000=oo`<0
00Ioo`03001oogoo009oo`04001oogooOol30002Ool30003Ool200000goo000000020003Ool30009
Ool00`00Oomoo`0OOol003]oo`04001oogoo000jOol01@00Oomoogoo00000Woo00<007ooOol01goo
00<007ooOol017oo00L007ooOomoo`00Ool0000IOol00`00Oomoo`06Ool00`00Oomoo`0POol003Yo
o`D003]oo`03001oo`0000<000Uoo`8000Moo`03001oogoo00<001Qoo`8000Moo`03001oogoo025o
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo000^Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`05000>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20004
Ool00`00Oomoo`05000COol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool5000MOol0
0`00Oomoo`06Ool50002Ool00`00Oomoo`0HOol002eoo`03001oo`0000Moo`03001oo`0000=oo`03
001oogoo00eoo`03001oo`0000Moo`03001oo`00009oo`@000Qoo`03001oogoo019oo`03001oo`00
00Moo`03001oo`0000Qoo`03001oogoo01aoo`03001oo`0000Uoo`07001oogooOol007oo00006Goo
000]Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Ool00007Ool00`00Ool0
0003Ool30008Ool00`00Oomoo`0BOol00`00Ool00009Ool00`00Oomoo`06Ool00`00Oomoo`0NOol0
0`00Oomoo`07Ool01`00Oomoogoo001oo`0001Uoo`00;Goo00<007oo00001goo00<007oo00000goo
00<007ooOol03Goo00<007oo00001goo00<007oo00000Woo0P0000=oo`00Ool01goo00<007ooOol0
4Woo00<007oo00001goo0P002Goo00<007ooOol077oo0P002Woo00L007ooOomoo`00Ool0000IOol0
02eoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo00eoo`03001oo`0000Moo`03001oo`00
009oo`800003Ool007oo00Moo`03001oogoo019oo`03001oo`0000Moo`03001oogoo00Qoo`03001o
ogoo01aoo`03001oogoo00Uoo`07001oogooOol007oo00006Goo000^Ool00`00Oomoo`07Ool01000
Oomoogoo0P0047oo00<007ooOol01goo00@007ooOomoo`<000Qoo`8001Eoo`03001oogoo00Ioo`<0
00Moo`8001ioo`<000Qoo`8000Aoo`03001oogoo01Qoo`00gGoo003MOol00=eoo`00=7ooT@0067oo
000dOol01@00Oomoogoo00003Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00Woo00@0
07ooOol0009oo`08001oogoo001oo`00Ool000eoo`03001oogoo00Eoo`03001oogoo00=oo`05001o
ogooOol00003Ool01000Oomoo`000Woo00D007oo001oo`0000eoo`03001oogoo00Eoo`03001oogoo
009oo`03001oogoo009oo`04001oogoo0003Ool00`00Ool00002Ool00`00Ool00002Ool00`00Oomo
o`0FOol003Aoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00@03goo00moo`80
01Qoo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
0`0?000000020002Ool2O0000gooO01l0002O0001@0?Ool03goo00l03Goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03
001oogoo01Ioo`00:goo0`000Woo00D007ooOomoo`0000=oo`0300moogoo00]oo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool0
0`0?Oomoo`05Ool0100?Oomoogoo0`000goo00D03g`0O000000?009oo`0800moogoo00moo`0?Ool0
3`eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0
3`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol002aoo`06001oogoo001oo`000Woo00D007ooOomo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?
Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool0100?Oomoo`000Woo00H03gooOomoo`0?O002Ool0
1000Oomoo`0?0Woo00D03g`000moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol002Eoo`<0
009oo`@00004Ool007oo0002Ool2001700l00`0000l03`0:00l00`0000l03`0400l00g`000l03`0_
00l2000HOol002Yoo`03001oo`00009oo`03001oo`00009oo`05001oogooOol03`0=Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?
3Goo00<03gooOol01Goo00<03`00Ool00goo00D03gooOoml000?00=oo`0400moo`0000l2Ool01@0?
Ool03g`000l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=o
o`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`00:goo0P000Woo00<007oo00000Woo
00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`00Oomoo`03Ool01@0?Ooml07oo
00l00goo00@03gooOol0009oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo
000/Ool01@00Oomoogoo00000goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`04Ool0
0`0000moo`04Ool01@0?O01oogoo00l00goo00/03gooOol03`00Ool03goo00moo`0?00eoo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?
Ool03`02Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol0
0goo00<007oo00l01Goo00D03gooOomoo`0?00=oo`0<00moogoo00moo`0000moo`0?Ool03g`037oo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009o
o`0300moo`0?009oo`03001oogoo01Ioo`00=7oo0P000Woo00<03gooOol02goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`03
00moogoo00=oo`03001oo`0?00Eoo`05O01oogooOol03`03Ool03@0?Oomoo`0?Ool0000?Ool03goo
00moog`000]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Ool03`02Ool0100?Ool03goo0P0067oo000dOol01@00Oomoogoo00l03Goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`03
00moogoo009oo`04001oogoo00l4Ool00g`000moo`02Ool01@0?Oomoogoo00l00Woo00X03gooOol0
07oo00moo`0?Ooml00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Ioo`03001oogoo009oo`03
001oogoo01Ioo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00D03gooOomoo`0000=oo`0300moogoo
009oo`03O0003goo009oo`0500moogooOol03`02Ool0200?Oomoo`00Ool03goo00l=Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo
00l00Woo00<007ooOol05Woo000FOol6000HOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0400mo
ogoo0004Ool01`0?OomoogooO01oo`0?00=oo`0500moogooOol03`02Ool0200?Oomoo`0?00003goo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo
00l00Woo00<03goo00l00Woo00<007ooOol05Woo000FOol01P00Oomoo`00Ool001Qoo`80009oo`03
00moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0
200?Oomoo`0?Ool03goo00l=Ool0100?Oomoo`0017oo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool01@0?00003goo00l00Woo00=l07ooOol027oo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0400moo`0?Ool2000HOol0
01Ioo`04001oogoo000JOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moo`0000Eoo`0400mo
ogooO002Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`00Ool03`02Ool00g`0Oomo
o`08Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo
00l00Woo00<03goo00l00Woo00<007ooOol05Woo000GOol2000KOol01@00Oomoogoo00l03Goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?
Ool03`eoo`0300l007oo00Eoo`0300moog`000=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo001oo`0?00=oo`03O01oogoo00Moo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`05
001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00P03gooOol03goo00moo`0?3Goo00<03`00Ool01Goo00<03gooO0000goo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool01@0?Ool03`0000l00goo00=l07ooOol01goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03
001oogoo01Ioo`005Woo00<007ooOol00Woo00<007ooOol05Woo0P000Woo00<03gooOol02goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?
Ool03`eoo`03001oogoo00Eoo`0300ml07oo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00l0000?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Ool03`02Ool0100?Ool03goo0P0067oo000FOol6000HOol01@00Oomoogoo00l03Goo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00mo
o`0?Ool03`eoo`03001oogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?
0Woo00D03goo00moo`0000Eoo`03O01oogoo00Eoo`0300moogoo00Eoo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qo
o`04001oogoo000HOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`aoo`0300003goo00Ioo`03O01oogoo
00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0000Eoo`03O01oogoo00Eo
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02
Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`03001oogoo01Uoo`05001oogooOol03`0=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo
00moo`0?37oo00<0000?Ool01Woo00=l07ooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2
Ool01P0?Ool03goo00l000Eoo`03O01oogoo00Aoo`0300moogoo00Eoo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Uo
o`<001Qoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?2goo00<007oo00l01Woo00=l000?Ool017oo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01P0?Ool03goo00l000Eoo`03O01oogoo00Aoo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?
Ool03`02Ool00`00Oomoo`0FOol001]oo`03001oogoo01Ioo`80009oo`0300moogoo00]oo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo
00l;Ool00`00Ool03`06Ool00g`000moo`04Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`07
00moo`0?Ool03goo00002goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03goo
Ool03`=oo`0300moo`0?009oo`0400moo`0?Ool2000HOol003Aoo`05001oogooOol03`0=Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00mo
o`0?2Woo00@007ooOol03`Moo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00L03goo00moo`0?Ool0000;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000JOol2000>Ool20004
Ool01@00Oomoogoo00000goo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`Yoo`04001oogoo00l7Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`02Ool00`00Oomoo`02
Ool00g`0Oomoo`03Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000HOol01000Ool0000047oo00H0
07ooOol007oo0002Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`Uoo`05001oogooOol03`04Ool017`0
Oomoo`0?1Goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo00D007oo
Oomoog`000Eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`04001oo`000009Ool30003Ool0
1`00Oomoogoo001oo`00009oo`8003T03`0300003`0?00D03`03O0003`0?01d03`0500003`0?00ml
000W00l2000HOol001Qoo`@0011oo`06001oogoo001oo`000Woo00D007ooOomoo`0?00eoo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo
00l8Ool00`00Oomoo`02Ool01@0?OomoogooO0000goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool01@0?Ool03goo00l017oo00<007ooOol01Woo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001o
ogoo01Ioo`006goo00<007ooOol037oo00<007oo00000Woo00<007oo00000Woo00D007ooOomoo`0?
00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomo
o`0?Ool03goo00l8Ool00`00Oomoo`02Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`04Ool00`00Oomoo`06Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo
00<007ooOol05Woo000[Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<03gooOol02goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?
Ool03`Qoo`03001oogoo009oo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00D03goo00moo`0?00Eoo`04001oogooO004Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007oo
Ool05Woo000HOol200000goo001oo`0GOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?1goo00<007oo
Ool00goo00@03gooOoml00Aoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00Eoo`04001oogooO004Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00@03goo00moo`8001Qoo`0067oo0P0000=oo`00
Ool05goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l2Ool0200?Oomoo`0?Ool03goo00l7Ool00`00Oomoo`03Ool00`0?Ooml0005Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`06Ool01000Oomo
og`00goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300mo
o`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo0P0000=oo`00Ool05goo00D007ooOomo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?
Oomoo`0?Ool03goo00l6Ool00`00Oomoo`04Ool00`0?Ooml0005Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`06Ool01000Oomoog`00goo00<03gooOol0
1Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?
009oo`03001oogoo01Ioo`0067oo00<007oo00006Goo00D007ooOomoo`0?00eoo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l6Ool0
0`00Oomoo`04Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol0
3`9oo`0500moo`0?Ool03`07Ool00`00Oomoo`03Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000d
Ool20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00P03gooOol03goo00moo`0?1Goo00<007ooOol01Goo00<03gooOol01Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l01goo00<007ooOol0
0goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?
009oo`0400moo`0?Ool2000HOol003Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?1Goo00<007ooOol0
1Goo00=l07ooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?
Ool03goo00l027oo00<007ooO0000Woo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`006Goo0P006Goo
00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l2Ool0200?Oomoo`0?Ool03goo00l4Ool00`00Oomoo`06Ool00g`0Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`08Ool01P00Oomoog`0Ool0
3`Moo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool0
3`02Ool00`00Oomoo`0FOol001Qoo`800003Ool007oo01Moo`05001oogooOol03`0=Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?
17oo00<007ooOol01Goo00=l000?Ool01Woo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03goo00l02Goo00D007ooO01oo`0?00Moo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`80
0003Ool007oo01Moo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?0goo00<007ooOol01goo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l02Goo
00D007ooOomoo`0?00Moo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool0
3`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Uoo`03001oo`0001Qoo`80009oo`0300moogoo
00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomo
o`0?Ool03goo00l3Ool00`00Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0:Ool01000Oomoo`0?1goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0400moo`0?Ool2000HOol003Aoo`05
001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00P03gooOol03goo00moo`0?0Woo00<007ooOol01Woo00=l07oo00l01goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l02Woo00@007`0Ool03`Moo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool0
0`00Oomoo`0FOol003Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?0Woo00<007ooOol01Woo00=l07oo
00l01goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l0
2goo00=l07oo00l01goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?
009oo`0300moo`0?009oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?00eoo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool02P0?Oomoo`0?Ool03goo00moo`00
27oo00Al07ooOol03`Moo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D0
3goo00moo`0?00]oo`03001l000?00Moo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`80009oo`0300moogoo00]o
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool02@0?Oomoo`0?
Ool03goo00l00009Ool017`0Oomoo`0?1goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03goo00l037oo00=l000?Ool01Woo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moo`0?009oo`0400moo`0?Ool2000HOol003Aoo`05001oogooOol03`0=
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00T03gooOol0
3goo00moo`0?000037oo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03goo00l037oo00<0000?Ool01Woo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`00:Woo0`000goo
00D007ooOomoo`0000=oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo0008Ool00g`0Oomoo`02Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool0
0`00Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo
00<03goo00l00Woo00<007ooOol05Woo000ZOol00`00Oomoo`02Ool00`00Ool00002Ool01@00Oomo
ogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`08
00moogoo00moo`0?Ool000Qoo`03O01oogoo009oo`0300moogoo00Eoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`03O01oogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomo
o`0FOol002Eoo`<000=oo`07001oogooOol007oo00000Woo0P00;P0?00<0000?00l01P0?00=l000?
00l0<@0?00=l000000l07`0?0P0067oo000[Ool01`00Oomoogoo001oo`00009oo`05001oogooOol0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03goo
Ool03goo00l0000?1goo00=l07ooOol00goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00=l0000Ool01Goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Io
o`0067oo10003Woo00<007oo00000Woo00<007oo00000Woo00D007ooOomoo`0?00eoo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool007oo00l=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Ool00005Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo
00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000GOol00`00Oomoo`02Ool00`00Oomo
o`0<Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<03gooOol02goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`00Ool03`Eoo`03O01o
ogoo00Eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00eoo`0300moo`0000Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Ioo`03001oogoo00Aoo`03
001oogoo01Aoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?00003goo00l5Ool00g`0Oomoo`05Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool0
100?O01oo`0017oo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009o
o`0400moo`0?Ool2000HOol003Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol007oo00moo`0?17oo00=l07ooOol01Woo
00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool0
3goo00l03Goo00@03g`0Ool000Aoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool0
0`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`0=Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol007oo00mo
o`0?17oo00=l07ooOol01Woo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`04
00moogoo00l2Ool01@0?Ool03goo00l03Goo00D03gooO01oo`0000=oo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Uo
o`8001Uoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00P03goo00003goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00D03gooO01oo`0000=oo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool0
0`00Oomoo`0FOol001Qoo`04001oogoo000HOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moo`0000moo`0?Ool03`9oo`03O01o
ogoo00Qoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00eoo`0300moogoo009oo`04001oogoo00l4Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000FOol00`00Ool00002Ool0
0`00Oomoo`0FOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00X03`00Ool03goo00moo`0?Ooml00]oo`0300moogoo00Eoo`0300mo
ogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo
00=oo`03001oo`0?00Aoo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool0100?Ool0
3goo0P0067oo000FOol6000HOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`9oo`0:00l007oo00moo`0?Ool03gooO00;Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool0
0`0?Ooml0004Ool00`0000moo`03Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo
00<03goo00l00Woo00<007ooOol05Woo000KOol00`00Oomoo`0FOol01@00Oomoogoo00l03Goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`08001oogoo00moo`0?
Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00eoo`0300moog`000Aoo`0300003goo00=oo`0300moogoo009oo`0400moogoo
00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`0=
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01`0?Oomoo`0?Ool0000?009oo`05
00moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`0=Ool0100?Oomoog`017oo00<007ooOol00Woo00<03gooOol00Woo
00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`006Goo0P006Goo
0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00L03goo
Ool03goo00003`02Ool01@0?Ool03gooO0003Goo00<03gooOol01Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00@03gooOoml00Aoo`0300l007oo
009oo`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool0100?Ool03goo0P0067oo000H
Ool200000goo001oo`0GOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00L03gooOol03`00Ool03`02Ool01@0?Ool03g`000l03Goo00<03gooOol01Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03goo
Ool01Goo00<03goo00000Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300mo
o`0?009oo`03001oogoo01Ioo`0067oo0P0000=oo`00Ool05goo00D007ooOomoo`0?00eoo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo0002Ool0200?Oomoo`0?Ool03g`0
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`0=Ool00`0?Oomoo`05Ool01P0?Oomoo`00Ool03`Aoo`0400moogoo00l3Ool00`0?
Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Uoo`03001oo`0001Qoo`05001oogooOol0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Ool0000?0Woo00P03goo
Ool03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03goo00l03Goo00D03gooOomoog`000=oo`0600moogoo001oo`0?17oo00@0
3gooOol03`=oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`00=7oo0P000Woo00<0
3gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03goo00003`9oo`08
00moogoo00ml000?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0500moogooOoml0003Ool01P0?Oomoogoo00003`Ao
o`0400moogoo00l3Ool00`0?Ool03`02Ool0100?Ool03goo0P0067oo000dOol01@00Oomoogoo00l0
3Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03`00Ool03`9oo`0800moogoo
O01oo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00D03goo00moo`0?00eoo`0500moogooOoml0003Ool00`0?Oomoo`02Ool00`00Oomoo`02
Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000IOol20002
Ool00`00Oomoo`0DOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@007ooOol03`9oo`0800moogooO01oo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eo
o`0300moogoo009oo`0300l007oo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02
Ool00`00Oomoo`0FOol001Qoo`06001oogoo001oo`002goo1@000Woo00D007ooOomoo`0000=oo`03
00moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0600moogooOol0000?0Woo00/03gooOol0
3gooO0003goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moo`00
009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`06
001oogoo001oo`003Goo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo00l03Goo00<03gooOol0
1Goo00<03gooOol00Woo00H03gooOol007oo00l2Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eo
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo
00moo`0?00eoo`0300moogoo009oo`04O01oogoo00l4Ool00`0?Ool00002Ool0100?Oomoo`0?0goo
00<03goo00l00Woo00<03goo00l00Woo00<007ooOol05Woo000HOol50008Ool30003Ool01`00Oomo
ogoo001oo`00009oo`8001l03`0300003`0?00H03`03O0003`0?04D03`03O0003`0?00P03`030000
3`0?00l03`8001Qoo`0067oo00<007ooOol047oo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo
00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03`00Ool00Woo00L03gooOol03gooO0003`02
Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`04
00moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol00Woo00Al07ooOol03`Aoo`0600moogoo
Ool0000?0Woo00L03gooOomoo`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol002]oo`07
001oogooOol007oo00000Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`03
001oogoo009oo`0700moogoo00ml07oo00l00Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`03
00moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300mo
ogoo009oo`04O01oogoo00l4Ool00`0?Oomoo`02Ool01000Oomoo`0?0goo00<03goo00l00Woo00<0
3goo00l00Woo00<007ooOol05Woo000FOol00`00Oomoo`04Ool00`00Oomoo`0:Ool20004Ool01@00
Oomoogoo00000goo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00P0000<03gooOol00Woo
00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`05
00moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0400l0000000l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00
Oomoo`0FOol001Moo`03001oogoo009oo`03001oogoo01Eoo`80009oo`0300moogoo00]oo`0300mo
ogoo00Eoo`0300moo`00009oo`0300moogoo009oo`0400moog`000l2Ool0200?Oomoo`0?Ool03goo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`00
0goo00<03goo00l00Woo00@03goo00moo`8001Qoo`0067oo100067oo00D007ooOomoo`0?00eoo`03
00moogoo00Eoo`0300l007oo009oo`0300moogoo009oo`9l0005Ool03gooOol03`02Ool01@0?Ool0
3goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2
Ool01@0?Ool03goo00l03Goo00<03gooOol00goo00=l07oo00l017oo00<03gooOol00Woo00D03goo
Ool03`00009oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`00=7oo00D007ooOomo
o`0?00eoo`0300moogoo00Eoo`03001oogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?
Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@0
3gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`03Ool00g`0Ool03`04Ool00`0?Oomoo`02
Ool02P0?Oomoo`0?Ool007oo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000dOol01@00
Oomoogoo00l03Goo00<03gooOol00goo0P0000<03gooOol00Woo00<03gooO0000Woo00@03gooOol0
3`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol0
3`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00=oo`03O01oo`0?00Aoo`03
00moogoo009oo`0400moogoo00l2Ool200001goo00moogoo00moo`0?009oo`03001oogoo01Ioo`00
=7oo0P000Woo00<03gooOol02goo00<03gooOol00Woo00@007ooOol03`Aoo`9l00=oo`0400moogoo
00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`03Ool00g`0Ool03`04Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03`0000l00Woo00@03goo00moo`8001Qoo`00=7oo00D0
07ooOomoo`0?00eoo`0300moogoo008000=oo`0300moogoo009oo`03O01oogoo009oo`0400moogoo
00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0goo00P03goo000007oo00moo`0?0Woo00<007ooOol05Woo000d
Ool01@00Oomoogoo00l03Goo00<03`0000001Goo00<03gooO0000Woo00<03gooOol00Woo00@03goo
Ool03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l3Ool0100?Ool03goo0P0000Eoo`0?Oomoo`0001Qoo`00=7oo
00D007ooOomoo`0?00aoo`8000Moo`9l00=oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomo
o`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`04Ool00g`000moo`03Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0goo00<03goo00l00Woo00<03`0000000Woo00<007ooOol05Woo000dOol20002Ool0
0`0?Oomoo`08Ool200000goo00moo`06Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol017oo00=l000?Ool00goo00<0
3gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0400moo`0?Ool2000HOol003Aoo`05001o
ogooOol03`08Ool20003Ool00`0?Oomoo`02Ool017`0Oomoo`0?17oo00<03gooOol00Woo00@03goo
Ool03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Aoo`03O0003goo00=o
o`0300moogoo009oo`0400moogoo00l3Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0F
Ool003Aoo`05001oogooOol03`06Ool20005Ool00`0?Oomoo`02O003Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol0
1Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`=oo`0300moo`0?009oo`0300moo`0?
009oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?009oo`@000Aoo`Al00Moo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0goo00<03goo00l00Woo00<0
3goo00l00Woo00<007ooOol05Woo000dOol01000Oomoogoo0`001Goo00=l07ooOol00goo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool0
3`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D0
3goo00moo`0?00eoo`0300moogoo00Eoo`03O01oogoo009oo`0300moogoo009oo`0400moogoo00l3
Ool00`0?Ool03`02Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`80009oo`04001oog`0O002
Ool2O006Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01000Oomoo`0?0Woo00P0
3gooOol03goo00moo`003Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0000=oo`04
00moogoo00l2Ool01@0?Ool03goo00003Goo00<03gooOol01Goo00=l07ooOol00Woo00<03gooOol0
0Woo00@007ooOol03`=oo`0300moo`0?009oo`0400moo`00Ool2000HOol003Aoo`@0009l06l00003
O000000001T001Qoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00;Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol01@003Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo0P0017oo00<007ooOol01@004goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01Goo
1@007Goo00<007ooOol01Woo1@000Woo00<007ooOol067oo000]Ool00`00Ool00007Ool00`00Ool0
0003Ool00`00Oomoo`0=Ool00`00Ool00007Ool00`00Ool00002Ool40008Ool00`00Oomoo`0BOol0
0`00Ool00007Ool00`00Ool00008Ool00`00Oomoo`0LOol00`00Ool00009Ool01`00Oomoogoo001o
o`0001Uoo`00;Goo00<007oo00001goo00<007oo00000goo00<007ooOol03Goo00<007oo00001goo
00<007oo00000goo0`0027oo00<007ooOol04Woo00<007oo00002Goo00<007ooOol01Woo00<007oo
Ool07Woo00<007ooOol01goo00L007ooOomoo`00Ool0000IOol002eoo`03001oo`0000Moo`03001o
o`0000=oo`03001oogoo00eoo`03001oo`0000Moo`03001oo`00009oo`800003Ool007oo00Moo`03
001oogoo019oo`03001oo`0000Moo`8000Uoo`03001oogoo01aoo`8000Yoo`07001oogooOol007oo
00006Goo000]Ool00`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Ool00007Ool0
0`00Ool00002Ool200000goo001oo`07Ool00`00Oomoo`0BOol00`00Ool00007Ool00`00Oomoo`08
Ool00`00Oomoo`0LOol00`00Oomoo`09Ool01`00Oomoogoo001oo`0001Uoo`00;Woo00<007ooOol0
1goo00@007ooOomoo`80011oo`03001oogoo00Moo`04001oogooOol30008Ool2000EOol00`00Oomo
o`06Ool30007Ool2000NOol30008Ool20004Ool00`00Oomoo`0HOol00=eoo`00gGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eo
o`00gGoo001<Ool2000EOol2000EOol00`00Oomoo`0lOol00`00Oomoo`0QOol004eoo`03001oogoo
01Aoo`03001oogoo019oo`03001oogoo01=oo`03001oogoo02Qoo`03001oogoo021oo`00>Woo0`00
0goo0`000goo0P000goo0`000Woo0`000Woo0P0000=oo`0000000Woo00<007oo00000P000goo00<0
07ooOol04Goo00@007ooOomoo`<00003Ool007oo00@0009oo`<000Eoo`03001oogoo009oo`<000=o
o`80009oo`<000=oo`800003Ool00000009oo`03001oogoo00<000Uoo`03001oogoo01moo`00>goo
00<007ooOol00goo00D007ooOomoo`0000Aoo`06001oogoo001oo`000Woo00<007oo000017oo00H0
07ooOol007oo0004Ool00`00Ool0000BOol00`00Oomoo`02Ool01@00Oomoo`00Ool00`000Woo00@0
07ooOol000Eoo`03001oogoo009oo`03001oo`00009oo`03001oogoo009oo`03001oogoo009oo`06
001oogoo001oo`000Woo00<007oo00000Woo00<007ooOol01goo00<007ooOol07goo000kOol00`00
Oomoo`03Ool01000Oomoogoo0`000Woo00H007ooOol007oo0002Ool00`00Ool000020002Ool01P00
Oomoo`00Ool000Aoo`03001oo`00019oo`03001oogoo009oo`<000Aoo`04001oogoo0002Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`030002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0
009oo`03001oo`00009oo`03001oogoo00Moo`03001oogoo01moo`00>goo0P000goo100000Aoo`00
000000=oo`D00004Ool00000Ool300000goo000000020002Ool3000017oo000007oo0P004Goo00<0
07ooOol00Woo00@007ooOol0009oo`8000=oo`<000Ioo`03001oogoo009oo`04001oogooOol30002
Ool30003Ool200000goo000000020003Ool30009Ool00`00Oomoo`0OOol003]oo`04001oogoo000j
Ool01@00Oomoogoo00000Woo00<007ooOol01goo00<007ooOol017oo00L007ooOomoo`00Ool0000I
Ool00`00Oomoo`06Ool00`00Oomoo`0POol003Yoo`D003]oo`03001oo`0000<000Uoo`8000Moo`03
001oogoo00<001Qoo`8000Moo`03001oogoo025oo`00gGoo003MOol00=eoo`00gGoo003MOol00=eo
o`00gGoo000^Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05000>Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`05000COol00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool5000MOol00`00Oomoo`06Ool50002Ool00`00Oomoo`0HOol0
02eoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo00eoo`03001oo`0000Moo`03001oo`00
009oo`@000Qoo`03001oogoo019oo`03001oo`0000Moo`03001oo`0000Qoo`03001oogoo01aoo`03
001oo`0000Uoo`07001oogooOol007oo00006Goo000]Ool00`00Ool00007Ool00`00Ool00003Ool0
0`00Oomoo`0=Ool00`00Ool00007Ool00`00Ool00003Ool30008Ool00`00Oomoo`0BOol00`00Ool0
0009Ool00`00Oomoo`06Ool00`00Oomoo`0NOol00`00Oomoo`07Ool01`00Oomoogoo001oo`0001Uo
o`00;Goo00<007oo00001goo00<007oo00000goo00<007ooOol03Goo00<007oo00001goo00<007oo
00000Woo0P0000=oo`00Ool01goo00<007ooOol04Woo00<007oo00001goo0P002Goo00<007ooOol0
77oo0P002Woo00L007ooOomoo`00Ool0000IOol002eoo`03001oo`0000Moo`03001oo`0000=oo`03
001oogoo00eoo`03001oo`0000Moo`03001oo`00009oo`800003Ool007oo00Moo`03001oogoo019o
o`03001oo`0000Moo`03001oogoo00Qoo`03001oogoo01aoo`03001oogoo00Uoo`07001oogooOol0
07oo00006Goo000^Ool00`00Oomoo`07Ool01000Oomoogoo0P0047oo00<007ooOol01goo00@007oo
Oomoo`<000Qoo`8001Eoo`03001oogoo00Ioo`<000Moo`8001ioo`<000Qoo`8000Aoo`03001oogoo
01Qoo`00gGoo003MOol00=eoo`00:Goo1@000Woo0`0000=oo`000000S`0067oo000[Ool00`00Oomo
o`03Ool01000Oomoo`000goo00<007ooOol02goo00<007ooOol01Goo00<007ooOol00Woo00<007oo
Ool00Woo00@007ooOol0009oo`08001oogoo001oo`00Ool000eoo`03001oogoo00Eoo`03001oogoo
00=oo`05001oogooOol00003Ool01000Oomoo`000Woo00D007oo001oo`0000eoo`03001oogoo00Eo
o`03001oogoo00=oo`05001oogooOol00003Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03
001oogoo01Ioo`009Goo0`000goo00@007ooOomoo`@00003Ool00000009oo`0300moogoo00]oo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool0
3goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?O01oo`03Ool01@0?Oomoogoo00l00goo00H0
3gooOol03goo00l2Ool0100?Ool03goo0P0067oo000[Ool01`00Oomoogoo001oo`00009oo`05001o
ogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol00Woo00Al07ooOoml00Eoo`0300mo
o`000100009oo`03001oogoo01Ioo`005Woo1P003goo00<007ooOol00Woo0P000Woo00D007ooOomo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?
Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@0
3gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`02Ool017`0Oomoo`0?0Woo1@000Woo00D0
3gooOomoo`0?009oo`0300moo`0?009oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo0`000Woo
00<007ooOol037oo0P001Goo00<007ooOol00P000Woo00<03gooOol02goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?
00eoo`0300moogoo009l0003Ool0000000<000=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool0
3`9oo`0300moo`0?009oo`03001oogoo01Ioo`006Goo00<007ooOol067oo00D007ooOomoo`0?00eo
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?
Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol0
3`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`030002Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Ioo`<0009oo`03001o
ogoo01Ioo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03g`000001Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol0
5Woo000FOol6000HOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00=l0000Ool0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo
00<007ooOol05Woo000FOol00`00Oomoo`02Ool00`00Oomoo`0FOol01@00Oomoogoo00l03Goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?
Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00aoo`03O0003goo00Ioo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?00eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool0
3goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`0500moo`0?Ool03`0:Ool200000goo00moo`06Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Yoo`8001Qoo`80009oo`03
00moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0
200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00@03gooOol03`9oo`0500moo`0?Ool03`08Ool20003Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qo
o`04001oo`00000=Ool5000017oo000000000Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`07Ool01000Oomoog`00Woo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`06
00moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000HOol01000Ool000003goo00D0
07ooOomoo`0000Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l01Woo00@007ooOoml00=o
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`03
00moo`0?009oo`03001oogoo01Ioo`0067oo10002Goo0`000goo00<007ooOol00Woo00@007ooOomo
o`8006803`8000803`03O0003`0?02@03`8001Qoo`006goo00<007ooOol03Goo00<007ooOol00Woo
00D007ooOomoo`0000=oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?
Ool03`02Ool00`00Oomoo`0FOol002]oo`07001oogooOol007oo00000Woo00D007ooOomoo`0?00eo
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?
Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol0
3`9oo`0500moo`0?Ool03`02Ool00`00Oomoo`02Ool00g`0Oomoo`03Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomo
o`0FOol001Uoo`80009oo`03001oogoo00Yoo`8000Aoo`04001oogooOol20002Ool00`0?Oomoo`0;
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol0
3goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo
00l2Ool01`0?Ool03goo00moo`0000Aoo`03O01oogoo00Aoo`0300moogoo00Eoo`0300moogoo00=o
o`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`00
67oo00H007ooOol007oo000FOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`03
00moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00H03goo00moo`0?0004Ool00g`0
Oomoo`05Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo
00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`06001oogoo001oo`005Woo00D007ooOomo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?
Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@0
3gooOol03`9oo`0500moo`0?Ool00005Ool00g`0Oomoo`05Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol0
01Qoo`D001Moo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0000=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00
Oomoo`0FOol001Qoo`03001oogoo01Uoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03`0000l017oo
00=l07ooOol01Woo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo
00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000HOol01000Oomoo`0067oo00D007ooOomo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?
Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@0
3gooOol03`9oo`0500moo`00Ool03`03Ool00g`0Oomoo`07Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol0
01Qoo`@001Qoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500l0000?Ool03`03Ool00g`0Oomoo`07Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?
Ool03`02Ool00`00Oomoo`0FOol001Qoo`03001oogoo00ioo`D0009oo`05001oogooOol00003Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool01@0?00003goo00l00Woo00=l07ooOol027oo00<03gooOol01Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol0
5Woo000HOol00`00Oomoo`0@Ool01`00Oomoogoo001oo`00009oo`05001oogooOol03`0=Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00mo
o`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool0
1@00Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600mo
ogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000IOol30009Ool30003Ool01`00Oomo
ogoo001oo`00009oo`8005P03`0300003`0?00@03`03O0003`0?02/03`8001Qoo`006goo00<007oo
Ool03Goo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0300?Oomoo`0?Ool0000?Ool03goo00ml00ao
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`03
00moo`0?009oo`03001oogoo01Ioo`00:goo00L007ooOomoo`00Ool00002Ool01@00Oomoogoo00l0
3Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo
00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0300?Oomo
o`0?001oo`0?Ool03goo00ml00aoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`00:Woo0P0017oo00@007oo
Oomoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00@03gooOol0009oo`0500moo`0?Ooml000=Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0F
Ool001Qoo`04001oogoo000HOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`03
00moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`000Woo00D03goo00moo`0?00eoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?
009oo`03001oogoo01Ioo`005Woo00<007oo00000`0067oo00D007ooOomoo`0?00eoo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo00003`9oo`0500mo
o`0?O0003`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001]oo`03001oogoo01Ioo`80009oo`0300mo
ogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?
Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@0
3`00Ool03`9oo`0500moo`0?O0003`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`05001oogoo
Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P0
3gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`04
00l007oo00l2Ool01@0?Ooml07oo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000HOol00`00Oomo
o`0IOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool01000Oomoo`0?0Woo00D03gooO01oo`0?00eoo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Io
o`005goo10006Goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@007ooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00
Oomoo`0FOol001Qoo`04001oogoo000HOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03goo
Ool01Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0500003gooOol03`02Ool01G`0Ool03goo
00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?
0Woo00<03goo00l00Woo00<007ooOol05Woo000HOol01000Oomoo`0057oo00D007ooOomoo`0000=o
o`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2
Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool02@0?Oomoogoo00mo
o`00Ool03`02Ool0200?Oomoog`0Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`03
001oo`0001Aoo`03001oo`00009oo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo
00<03gooOol00goo00T03gooOomoo`0?Ool007oo00l00Woo00P03gooO0003goo00moo`0?3Goo00<0
3gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo
00l00Woo00<007ooOol05Woo000ZOol30002Ool00`00Ool00002Ool2001@00l00`0000l03`0500l0
0g`000l03`0b00l2000HOol001Qoo`03001oogoo01Eoo`05001oogooOol00003Ool00`0?Oomoo`0;
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol0
3goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0000=oo`0400moogoo
00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000HOol3000DOol00`00Ool0
0002Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500mo
ogooOol00003Ool02`0?Oomoo`0?O01oo`0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo
000KOol00`00Oomoo`0BOol01000Oomoogoo0P000Woo00<03gooOol02goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogoo00003`03Ool0100?Oomoog`00Woo00D03goo00moo`0?
00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9o
o`0300moo`0?009oo`03001oogoo01Ioo`0067oo00<007oo00006Goo00D007ooOomoo`0?00eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool0
3goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoo`0000l00goo00@03gooOoml009o
o`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H0
3gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`@001Qoo`05001oogooOol0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03goo
Ool03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03goo001oo`0?00=oo`0400mo
og`000l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000KOol00`00Oomoo`0F
Ool20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03goo
001oo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo
000dOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500l0
07ooOol03`03Ool0100?O01oo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Io
o`006Goo0P006Goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo
009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?001oogoo00l00goo00@03g`0Ool03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00
Oomoo`0FOol001Qoo`04001oogoo000HOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03goo
Ool01Goo00<03gooOol00goo00D007ooOomoo`0?00=oo`04O01oogoo00l2Ool01@0?Ool03goo00l0
3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo
00<03goo00l00Woo00<007ooOol05Woo000FOol00`00Ool00002Ool00`00Oomoo`0AOol20003Ool0
1@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol0
3`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`05001oogooOol0
3`03Ool017`0Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`05
00moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo
1P004goo00<007oo00000Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0000moo`02Ool01@0?Oomoogoo00l00Woo00P03gooOol03goo00moo`0?3Goo00<0
3gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo
00l00Woo00<007ooOol05Woo000KOol00`00Oomoo`0<Ool30002Ool00`00Ool00002Ool2001:00l0
0`0000l03`1000l2000HOol002moo`8000=oo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03goo
Ool01Goo00L03gooOomoo`00Ool03`03Ool01@0?Ooml07oo00l00Woo00P03gooOol03goo00moo`0?
3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo
00<03goo00l00Woo00<007ooOol05Woo000IOol2000DOol00`00Oomoo`02Ool01@00Oomoogoo00l0
3Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo
00moo`0?Ool03`eoo`0300moogoo00Eoo`0700moogooOol007oo00l00goo00D03g`0Oomoo`0?009o
o`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo0P0000=oo`00Ool0
4goo0P000Woo0P000Woo00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0400moogoo0002
Ool01P0?Oomoogoo00ml009oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<0
07ooOol05Woo000HOol200000goo001oo`0GOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300mo
ogoo00Eoo`0400moogoo0002Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2
Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Uoo`03001oo`0001Qoo`05001oogooOol03`0=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo
00moo`0?3Goo00<03gooOol01Goo00<03goo00000goo00D03gooOomoo`0?00=oo`0400moogoo00l2
Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`06
00moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000dOol20002Ool00`0?Oomoo`0;
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol0
3goo00moo`0?3Goo00<03gooOol01Goo00<03`00Ool00goo00D03gooOomoog`000=oo`0400moogoo
00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000dOol01@00Oomoogoo00l0
3Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo
00moo`0?Ool03`eoo`0300moogoo00Eoo`03001oogoo00=oo`0500moogooO0003`03Ool0100?Oomo
o`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`00=7oo00D007ooOomoo`0?
00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomo
o`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`00Oomoo`03Ool01@0?Ooml07oo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`80009oo`0300mo
ogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?
Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`04Ool00`0000moo`04Ool01@0?Oomoogoo00l00goo00@0
3gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol0031oo`<00003Ool0
07oo009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l2Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`03Ool00`00Ool03`05Ool01@0?O01o
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol0
035oo`04001oogoo0003Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00<03gooOol00goo00<007oo00l0
1Goo00El07ooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<0
07ooOol05Woo000ZOol30002Ool400000goo0000001200l00`0000l03`0600l00g`000l03`0o00l2
000HOol002moo`03001oo`00009oo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?3Goo00D03gooOomoo`00
00=oo`0300moogoo009oo`03O0003goo009oo`0500moogooOol03`02Ool0200?Oomoo`0?Ool03goo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2
Ool00`0?Ool03`02Ool00`00Oomoo`0FOol0031oo`80009oo`05001oogooOol03`0=Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?
3Goo00@03gooOol000Aoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D0
3goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?Oomo
o`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`0067oo10005Goo00<007ooOol00P000Woo
00<03gooOol02goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9o
o`0800moogoo00moo`0?Ool03`eoo`0400moogoo0004Ool0100?Oomoog`00Woo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000GOol0
0`00Oomoo`02Ool00`00Oomoo`0EOol01@00Oomoogoo00l03Goo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`eoo`0300moo`0000Eo
o`0400moogooO002Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?
Ool03`02Ool00`00Oomoo`0FOol001Ioo`03001oogoo00Aoo`03001oogoo01Aoo`05001oogooOol0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P03goo
Ool03goo00moo`0?3Goo00<03`00Ool01Goo00<03gooO0000goo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000dOol20002Ool00`0?
Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00P0
3gooOol03goo00moo`0?3Goo00<007ooOol01Goo00<03gooO0000goo00D03gooOomoo`0?00=oo`04
00moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000dOol01@00Oomo
ogoo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`08
00moogoo00moo`0?Ool03`aoo`0300003goo00Ioo`0300moogoo00=oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`006Goo0P006Goo
00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l2Ool0200?Oomoo`0?Ool03goo00l<Ool00`0000moo`06Ool00g`0Oomoo`03Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qo
o`04001oogoo000HOol20002Ool00`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?2goo00<007oo00l01Woo00=l000?
Ool017oo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo
00<007ooOol05Woo000FOol00`00Ool00002Ool00`00Oomoo`0AOol30002Ool01@00Oomoogoo00l0
3Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo
00moo`0?Ool03`Yoo`04001oogoo00l5Ool00g`0Ool03`05Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00H03gooOol03goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Ioo`H001=oo`03001o
ogoo009oo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00P03gooOol03goo00moo`0?2Goo00D007ooOomoo`0?00Moo`0300moogoo00=o
o`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`03
00moogoo00=oo`0500moogooOol03`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001o
ogoo01Ioo`006goo00<007ooOol037oo0`000goo00@007ooOomoo`8003P03`0300003`0?00H03`03
O0003`0?04T03`8001Qoo`005Woo00<007ooOol00Woo00<007ooOol04Woo00D007ooOomoo`0000=o
o`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2
Ool0200?Oomoo`0?Ool03goo00l7Ool00`00Oomoo`03Ool0100?Oomoog`017oo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007oo
Ool05Woo000FOol6000COol00`00Ool00002Ool01@00Oomoogoo00l03Goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0800moogoo00moo`0?Ool03`Ioo`03001o
ogoo00Aoo`0300moog`000Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`005Woo00<007oo00000Woo00<007oo
Ool04Woo00@007ooOomoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l5Ool00`00Oomoo`05Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2
Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Ioo`03001oo`00009oo`03001oogoo01Ioo`05001o
ogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00P03gooOol03goo00moo`0?0goo0P001goo0W`01goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007ooOol05Woo000GOol01000
Ool000006Goo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l2Ool00`00Oomoo`05Ool2O0000goo00moo`06
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2Ool00`0?
Ool03`02Ool00`00Oomoo`0FOol003Aoo`80009oo`0300moogoo00]oo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0200?Oomoo`0?Ool03goo00l2000;Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol03goo00l2
Ool00`0?Ool03`02Ool00`00Oomoo`0FOol003Aoo`05001oogooOol03`0=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo00l20007Ool2O004
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Ioo`03001oogoo00Aoo`03001oogoo01Ao
o`05001oogooOol03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0Woo00<03gooOol00`0000=oo`0?Ool017oo0W`01Woo00<03gooOol01Goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0600moogoo00moo`0?0Woo00<03goo00l00Woo00<007oo
Ool05Woo000GOol00`00Oomoo`02Ool00`00Oomoo`0EOol20002Ool00`0?Oomoo`0;Ool00`0?Oomo
o`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?1@0000H03goo00moo`0?Ool2O00:
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00H03gooOol0
3goo00l2Ool00`0?Ool03`02Ool00`00Oomoo`0FOol001Qoo`@001Aoo`05001oogooOol00003Ool0
0`0?Oomoo`0;Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0100?Oomoogoo1@000Woo00@03gooOol0
3`9l0003Ool03g`000aoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?
Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol0
3`03Ool01P0?Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`00;goo00<007oo0000
0Woo00D007ooOomoo`0?00eoo`0300moogoo00Eoo`T00003O0003goo00Al000800moog`0O01oo`0?
Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool01P0?
Oomoo`0?Ool03`9oo`0300moo`0?009oo`03001oogoo01Ioo`00;goo00<007oo00000Woo0P000Woo
17`00P000g`00P0017`00P0017`000<0000?O0000g`000H03gooO01l07oo00l2Ool0100?Oomoo`0?
0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool01P0?Oomoo`0?Ool03`9oo`0400moo`0?Ool2000HOol002moo`03001oo`00009oo`05
001oogooOol0000=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool01000Oomoo`0?
0Woo00P03gooOol03goo00moo`003Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`00
00=oo`0400moogoo00l2Ool01@0?Ool03goo00003Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0000=oo`0600moogoo00moo`0?0Woo00<03goo00000Woo00<007ooOol05Woo000_Ool0
0`00Ool00002OonA000HOol0031oo`03001oogoo0:Yoo`00gGoo003MOol00=eoo`00gGoo003MOol0
02ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo00D000ioo`03001oogoo009oo`03001o
ogoo009oo`03001oogoo009oo`8000Aoo`03001oogoo00D001=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Eoo`D001eoo`03001oogoo00Ioo`D0009oo`03001oogoo01Qoo`00;Goo00<0
07oo00001goo00<007oo00000goo00<007ooOol03Goo00<007oo00001goo00<007oo00000Woo1000
27oo00<007ooOol04Woo00<007oo00001goo00<007oo000027oo00<007ooOol077oo00<007oo0000
2Goo00L007ooOomoo`00Ool0000IOol002eoo`03001oo`0000Moo`03001oo`0000=oo`03001oogoo
00eoo`03001oo`0000Moo`03001oo`0000=oo`<000Qoo`03001oogoo019oo`03001oo`0000Uoo`03
001oogoo00Ioo`03001oogoo01ioo`03001oogoo00Moo`07001oogooOol007oo00006Goo000]Ool0
0`00Ool00007Ool00`00Ool00003Ool00`00Oomoo`0=Ool00`00Ool00007Ool00`00Ool00002Ool2
00000goo001oo`07Ool00`00Oomoo`0BOol00`00Ool00007Ool20009Ool00`00Oomoo`0LOol2000:
Ool01`00Oomoogoo001oo`0001Uoo`00;Goo00<007oo00001goo00<007oo00000goo00<007ooOol0
3Goo00<007oo00001goo00<007oo00000Woo0P0000=oo`00Ool01goo00<007ooOol04Woo00<007oo
00001goo00<007ooOol027oo00<007ooOol077oo00<007ooOol02Goo00L007ooOomoo`00Ool0000I
Ool002ioo`03001oogoo00Moo`04001oogooOol2000@Ool00`00Oomoo`07Ool01000Oomoogoo0`00
27oo0P005Goo00<007ooOol01Woo0`001goo0P007Woo0`0027oo0P0017oo00<007ooOol067oo003M
Ool00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo0000\
\>"],
  ImageRangeCache->{{{0, 220.875}, {287, 0}} -> {-0.0250052, -0.033245, 
  0.00475387, 0.00475387}, {{5.25, 215.562}, {280, 150}} -> {-3.23716, 
  -58.6608, 0.0219425, 0.467693}, {{5.25, 215.562}, {137, 6.9375}} -> {
  -3.23535, -43.4496, 0.0219277, 0.164837}},
  CellTags->"3.5"],

Cell[TextData[{
  "Except for zero\[Hyphen]pole mapping, which naturally operates on ",
  StyleBox["ZeroPoleGain", "MR"],
  " objects, the conversion from the continuous\[Hyphen] to the discrete\
\[Hyphen]time domain is implemented with state\[Hyphen]space algorithms. \
Therefore, the transformation to and from ",
  StyleBox["StateSpace", "MR"],
  " objects can be avoided if the system is represented in ",
  StyleBox["StateSpace", "MR"],
  " in the first place. "
}], "Text",
  CellTags->"3.5"],

Cell[TextData[{
  "This is our lag system as a ",
  StyleBox["StateSpace", "MR"],
  " object.  "
}], "MathCaption",
  CellTags->"3.5"],

Cell["lag1 = StateSpace[lag]//Simplify", "Input",
  CellLabel->"In[59]:=",
  CellTags->"3.5"],

Cell[BoxData[
    \(StateSpace[{{\(-\(1\/b\)\)}}, {{1}}, {{\(\(-a\) + b\)\/b\^2}}, {{a\/b}}]
      \)], "Output",
  CellLabel->"Out[59]=",
  CellTags->"3.5"],

Cell["\<\
This converts the system to discrete time using the bilinear \
transform. \
\>", "MathCaption",
  CellTags->"3.5"],

Cell["\<\
ToDiscreteTime[lag1,
 Sampled -> Period[T],
 Method -> BilinearTransform
] //Simplify //ReviewForm\
\>", "Input",
  CellLabel->"In[60]:=",
  CellTags->"3.5"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(\(2\ b - T\)\/\(2\ b + T\)\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(\(2\ b\)\/\(2\ b + T\)\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(\(2\ \((\(-a\) + b)\)\ T\)\/\(b\ \((2\ b + T)\)\)\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(\(2\ a + T\)\/\(2\ b + T\)\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[60]//ReviewForm=",
  CellTags->"3.5"],

Cell["3.6 Discrete\[Hyphen]Time Models of Systems with Delay", "Subsection",
  CellTags->"3.6"],

Cell[TextData[{
  StyleBox["ToDiscreteTime", "MR"],
  " can also find the discrete\[Hyphen]time approximation of analog state\
\[Hyphen]space systems of the form "
}], "Text",
  CellTags->"3.6"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{
                OverscriptBox[
                  StyleBox["\<\"x\"\>",
                    "TB"], "."], \((t)\)}],
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
                StyleBox["\<\"A\"\>",
                  "TB"], 
                StyleBox["\<\"x\"\>",
                  "TB"], \((t)\), "+", 
                StyleBox["\<\"B\"\>",
                  "TB"], 
                StyleBox["\<\"u\"\>",
                  "TB"], \((t - \[Lambda])\)}],
              "DisplayFormula"]},
          {
            StyleBox[
              RowBox[{
                StyleBox["\<\"y\"\>",
                  "TB"], \((t)\)}],
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
                StyleBox["\<\"C\"\>",
                  "TB"], 
                StyleBox["\<\"x\"\>",
                  "TB"], \((t)\)}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->"3.6"],

Cell[TextData[{
  "which corresponds to systems with time delay ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)], "InlineFormula",
    CellTags->"S0.0.7"],
  ". The systems can be represented as conventional ",
  StyleBox["StateSpace", "MR"],
  " objects with a ",
  StyleBox["Delay", "MR"],
  " option added. The conversion implements the modified ",
  Cell[BoxData[
      \(TraditionalForm\`z\)], "InlineFormula",
    CellTags->"S0.0.7"],
  "\[Hyphen]transform algorithm described in Franklin ",
  StyleBox["et al.", "TI"],
  " (1990), Section\[NonBreakingSpace]2.4.4. \nCurrently, ",
  StyleBox["ToDiscreteTime", "MR"],
  " is the ",
  StyleBox["only", "TI"],
  " function that takes the ",
  StyleBox["Delay", "MR"],
  " option into consideration and, even more restrictively, it handles the \
only case of numerical values of the ratio ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]/T\_s\)], "InlineFormula",
    CellTags->"S0.0.7"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`T\_s\)], "InlineFormula",
    CellTags->"S0.0.7"],
  " is the sampling period. Negative delay is equivalent to prediction of the \
system's behavior and can be used as long as the delay is not longer than the \
sampling period. "
}], "Text",
  CellTags->"3.6"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], " "},
          {
            StyleBox[
              FormBox["Delay",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["0",
                "StandardForm"],
              "Text"], 
            StyleBox[\(time\ delay\ in\ the\ state - space\ model\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{RowLines->{True, False}},
  CellTags->"3.6"],

Cell[TextData[{
  "Option in ",
  StyleBox["State-Space", "MR"],
  " to introduce a delay in control. "
}], "Caption",
  CellTags->"3.6"],

Cell[TextData[{
  "Here is a simple state\[Hyphen]space system with delay of ",
  StyleBox["lambda", "MR"],
  ". "
}], "MathCaption",
  CellTags->"3.6"],

Cell["ss = StateSpace[{{1}}, {{1}}, {{1}}, Delay -> lambda]", "Input",
  CellLabel->"In[61]:= ",
  CellTags->"3.6"],

Cell[BoxData[
    \(StateSpace[{{1}}, {{1}}, {{1}}, Delay \[Rule] lambda]\)], "Output",
  CellLabel->"Out[61]= ",
  CellTags->"3.6"],

Cell["\<\
This is its discrete\[Hyphen]time approximation when the delay \
equals the sampling period. \
\>", "MathCaption",
  CellTags->"3.6"],

Cell["ToDiscreteTime[ss/.lambda->tau, Sampled -> Period[tau]]", "Input",
  CellLabel->"In[62]:= ",
  CellTags->"3.6"],

Cell[BoxData[
    \(StateSpace[{{E\^tau, \(-1\) + E\^tau}, {0, 0}}, {{0}, {1}}, {{1, 0}}, 
      Sampled \[Rule] Period[tau]]\)], "Output",
  CellLabel->"Out[62]= ",
  CellTags->"3.6"],

Cell["\<\
If the delay increases, then so does the dimension of the state \
space. \
\>", "MathCaption",
  CellTags->"3.6"],

Cell["\<\
ToDiscreteTime[ss/.lambda -> 2tau,
 Sampled -> Period[tau]]\
\>", "Input",
  CellLabel->"In[63]:= ",
  CellTags->"3.6"],

Cell[BoxData[
    \(StateSpace[{{E\^tau, \(-1\) + E\^tau, 0}, {0, 0, 1}, {0, 0, 0}}, 
      {{0}, {0}, {1}}, {{1, 0, 0}}, Sampled \[Rule] Period[tau]]\)], "Output",\

  CellLabel->"Out[63]= ",
  CellTags->"3.6"],

Cell["\<\
This is an example of the transformation of a system with a \
negative delay. \
\>", "MathCaption",
  CellTags->"3.6"],

Cell["ToDiscreteTime[ss/.lambda->-1/2 tau, Sampled->Period[tau]]", "Input",
  CellLabel->"In[64]:= ",
  CellTags->"3.6"],

Cell[BoxData[
    \(StateSpace[{{E\^tau}}, 
      {{E\^\(tau/2\)\ \((\(-1\) + E\^\(tau/2\))\) + 
            E\^tau\ \((\(-1\) + E\^\(tau/2\))\)}}, {{1}}, 
      {{\(-1\) + E\^\(tau/2\)}}, Sampled \[Rule] Period[tau]]\)], "Output",
  CellLabel->"Out[64]= ",
  CellTags->"3.6"],

Cell["3.7 Continuous\[Hyphen]Time Models of Discrete\[Hyphen]Time Systems", 
  "Subsection",
  CellTags->"3.7"],

Cell[TextData[{
  "The function ",
  StyleBox["ToContinuousTime", "MR"],
  ", when applied to discrete\[Hyphen]time objects, converts them to the \
continuous\[Hyphen]time domain. In many respects ",
  StyleBox["ToContinuousTime", "MR"],
  " behaves as an inverse function to ",
  StyleBox["ToDiscreteTime", "MR"],
  " and applies inverse algorithms to those described previously (",
  ButtonBox["Section 3.6",
    ButtonData:>{"Delay in Discrete Time Models"},
    ButtonStyle->"AddOnsLink"],
  "). Again, the methods can be chosen through the ",
  StyleBox["Method", "MR"],
  " option, which accepts the same values. The conversion attempts to find \
the slowest possible continuous\[Hyphen]time model the outputs of which would \
match the ones of the discrete\[Hyphen]time model at the sample time. "
}], "Text",
  CellTags->"3.7"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ToContinuousTime",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            
            StyleBox[
              \(find\ the\ continuous - time\ model\ of\ the\ discrete - 
                time\ object\ system\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.38, 0.62}},
  CellTags->"3.7"],

Cell["\<\
Finding continuous\[Hyphen]time equivalents of \
discrete\[Hyphen]time systems. \
\>", "Caption",
  CellTags->"3.7"],

Cell["\<\
Here a continuous\[Hyphen]time system from an earlier example is \
converted to the discrete\[Hyphen]time domain. \
\>", "MathCaption",
  CellTags->"3.7"],

Cell["\<\
ToDiscreteTime[
 StateSpace[{{0, 1}, {0, -1}}, {{0}, {1}},
 {{1, 0}}], Sampled -> Period[T]
]\
\>", "Input",
  CellLabel->"In[65]:= ",
  CellTags->"3.7"],

Cell[BoxData[
    \(StateSpace[{{1, E\^\(-T\)\ \((\(-1\) + E\^T)\)}, {0, E\^\(-T\)}}, 
      {{E\^\(-T\)\ \((1 - E\^T + E\^T\ T)\)}, 
        {E\^\(-T\)\ \((\(-1\) + E\^T)\)}}, {{1, 0}}, 
      Sampled \[Rule] Period[T]]\)], "Output",
  CellLabel->"Out[65]= ",
  CellTags->"3.7"],

Cell["This brings the system back to continuous time. ", "MathCaption",
  CellTags->"3.7"],

Cell["ToContinuousTime[%]", "Input",
  CellLabel->"In[66]:= ",
  CellTags->"3.7"],

Cell[BoxData[
    \(StateSpace[{{0, \(-\(Log[E\^\(-T\)]\/T\)\)}, {0, Log[E\^\(-T\)]\/T}}, 
      {{\(T + Log[E\^\(-T\)]\)\/T}, {\(-\(Log[E\^\(-T\)]\/T\)\)}}, {{1, 0}}]
      \)], "Output",
  CellLabel->"Out[66]= ",
  CellTags->"3.7"],

Cell[TextData[{
  "As our time variable ",
  StyleBox["t", "MR"],
  " is real\[Hyphen]valued, we can simplify the result and see that the \
system is the same as the one we started with. "
}], "MathCaption",
  CellTags->"3.7"],

Cell["ComplexExpand /@ %", "Input",
  CellLabel->"In[67]:= ",
  CellTags->"3.7"],

Cell[BoxData[
    \(StateSpace[{{0, 1}, {0, \(-1\)}}, {{0}, {1}}, {{1, 0}}]\)], "Output",
  CellLabel->"Out[67]= ",
  CellTags->"3.7"],

Cell["Here is the lag system used earlier. ", "MathCaption",
  CellTags->"3.7"],

Cell["lag1", "Input",
  CellLabel->"In[68]:= ",
  CellTags->"3.7"],

Cell[BoxData[
    \(StateSpace[{{\(-\(1\/b\)\)}}, {{1}}, {{\(\(-a\) + b\)\/b\^2}}, {{a\/b}}]
      \)], "Output",
  CellLabel->"Out[68]= ",
  CellTags->"3.7"],

Cell["\<\
This converts the system to the discrete\[Hyphen]time domain using \
the bilinear transform with frequency prewarping. \
\>", "MathCaption",
  CellTags->"3.7"],

Cell["\<\
ToDiscreteTime[%,
 Sampled -> Period[T],
 Method -> BilinearTransform,
 CriticalFrequency -> wc
] //Simplify\
\>", "Input",
  CellLabel->"In[69]:= ",
  CellTags->"3.7"],

Cell[BoxData[
    \(StateSpace[
      {{\(b\ wc - Tan[\(T\ wc\)\/2]\)\/\(b\ wc + Tan[\(T\ wc\)\/2]\)}}, 
      {{\(b\ wc\)\/\(b\ wc + Tan[\(T\ wc\)\/2]\)}}, 
      {{\(2\ \((\(-a\) + b)\)\ Tan[\(T\ wc\)\/2]\)\/\(b\ \((b\ wc + Tan[\(T\ \
wc\)\/2])\)\)}}, 
      {{\(a\ wc + Tan[\(T\ wc\)\/2]\)\/\(b\ wc + Tan[\(T\ wc\)\/2]\)}}, 
      Sampled \[Rule] Period[T]]\)], "Output",
  CellLabel->"Out[69]= ",
  CellTags->"3.7"],

Cell["This brings the system back to continuous time. ", "MathCaption",
  CellTags->"3.7"],

Cell["\<\
ToContinuousTime[%,
 Method -> BilinearTransform,
 CriticalFrequency -> wc
] //Simplify\
\>", "Input",
  CellLabel->"In[70]:= ",
  CellTags->"3.7"],

Cell[BoxData[
    \(StateSpace[{{\(-\(1\/b\)\)}}, {{1}}, {{\(\(-a\) + b\)\/b\^2}}, {{a\/b}}]
      \)], "Output",
  CellLabel->"Out[70]= ",
  CellTags->"3.7"],

Cell["\<\
This is the discrete\[Hyphen]time approximation of the lag system \
obtained with the first\[Hyphen]order hold. \
\>", "MathCaption",
  CellTags->"3.7"],

Cell["\<\
ToDiscreteTime[lag1,
 Sampled -> Period[T],
 Method -> FirstOrderHold
]//Simplify\
\>", "Input",
  CellLabel->"In[71]:= ",
  CellTags->"3.7"],

Cell[BoxData[
    \(StateSpace[{{E\^\(-\(T\/b\)\)}}, 
      {{\(b\^2\ E\^\(-\(\(2\ T\)\/b\)\)\ \((\(-1\) + \
E\^\(T\/b\))\)\^2\)\/T}}, {{\(\(-a\) + b\)\/b\^2}}, 
      {{\(a - a\ E\^\(-\(T\/b\)\) + b\ \((\(-1\) + E\^\(-\(T\/b\)\))\) + \
T\)\/T}}, Sampled \[Rule] Period[T]]\)], "Output",
  CellLabel->"Out[71]= ",
  CellTags->"3.7"],

Cell["This converts the result back to continuous time. ", "MathCaption",
  CellTags->"3.7"],

Cell["ToContinuousTime[%, Method->FirstOrderHold]//Simplify", "Input",
  CellLabel->"In[72]:= ",
  CellTags->"3.7"],

Cell[BoxData[
    \(StateSpace[{{\(-\(1\/b\)\)}}, {{1}}, {{\(\(-a\) + b\)\/b\^2}}, {{a\/b}}]
      \)], "Output",
  CellLabel->"Out[72]= ",
  CellTags->"3.7"],

Cell[TextData[{
  "Note that in the case of the ",
  StyleBox["FirstOrderHold", "MR"],
  " method, ",
  StyleBox["ToContinuousTime", "MR"],
  " cannot use the inverse of the state\[Hyphen]space algorithm implemented \
in ",
  StyleBox["ToDiscreteTime", "MR"],
  " and, as an exception, resorts to the conversion using transfer functions, \
which is far less efficient. "
}], "Text",
  CellTags->"3.7"]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
ScreenStyleEnvironment->"Working",
WindowSize->{484, 284},
WindowMargins->{{3, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> "Manual.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "3.0"->{
    Cell[1717, 49, 71, 1, 68, "Section",
      CellTags->"3.0"],
    Cell[1791, 52, 446, 8, 80, "Text",
      CellTags->"3.0"]},
  "3.1"->{
    Cell[2240, 62, 78, 1, 56, "Subsection",
      CellTags->"3.1"],
    Cell[2321, 65, 806, 23, 118, "Text",
      CellTags->"3.1"],
    Cell[3130, 90, 4906, 138, 96, "DefinitionBox",
      CellTags->"3.1"],
    Cell[8039, 230, 91, 1, 26, "Caption",
      CellTags->"3.1"],
    Cell[8133, 233, 64, 1, 40, "MathCaption",
      CellTags->"3.1"],
    Cell[8200, 236, 77, 2, 39, "Input",
      CellTags->"3.1"],
    Cell[8280, 240, 264, 6, 69, "MathCaption",
      CellTags->"3.1"],
    Cell[8547, 248, 112, 2, 54, "Input",
      CellTags->"3.1"],
    Cell[8662, 252, 148, 4, 54, "Output",
      CellTags->"3.1"],
    Cell[8813, 258, 128, 4, 40, "MathCaption",
      CellTags->"3.1"],
    Cell[8944, 264, 65, 2, 39, "Input",
      CellTags->"3.1"],
    Cell[9012, 268, 116, 3, 54, "Output",
      CellTags->"3.1"],
    Cell[9131, 273, 163, 4, 54, "MathCaption",
      CellTags->"3.1"],
    Cell[9297, 279, 70, 2, 39, "Input",
      CellTags->"3.1"],
    Cell[9370, 283, 207, 5, 38, "Output",
      CellTags->"3.1"],
    Cell[9580, 290, 180, 5, 54, "MathCaption",
      CellTags->"3.1"],
    Cell[9763, 297, 86, 2, 30, "Input",
      CellTags->"3.1"],
    Cell[9852, 301, 105, 3, 43, "Output",
      CellTags->"3.1"],
    Cell[9960, 306, 194, 7, 48, "MathCaption",
      CellTags->"3.1"],
    Cell[10157, 315, 65, 2, 30, "Input",
      CellTags->"3.1"],
    Cell[10225, 319, 86, 3, 42, "Output",
      CellTags->"3.1"],
    Cell[10314, 324, 315, 7, 71, "Text",
      CellTags->"3.1"],
    Cell[10632, 333, 227, 7, 31, "MathCaption",
      CellTags->"3.1"],
    Cell[10862, 342, 82, 2, 30, "Input",
      CellTags->"3.1"],
    Cell[10947, 346, 105, 3, 43, "Output",
      CellTags->"3.1"],
    Cell[11055, 351, 443, 10, 90, "Text",
      CellTags->"3.1"],
    Cell[11501, 363, 394, 14, 39, "TopSpanBox",
      CellTags->"3.1"],
    Cell[11898, 379, 1202, 33, 26, "MiddleBox",
      CellTags->"3.1"],
    Cell[13103, 414, 397, 14, 23, "MiddleSpanBox",
      CellTags->"3.1"],
    Cell[13503, 430, 1202, 33, 42, "BottomBox",
      CellTags->"3.1"],
    Cell[14708, 465, 94, 1, 16, "Caption",
      CellTags->"3.1"],
    Cell[14805, 468, 94, 1, 31, "MathCaption",
      CellTags->"3.1"],
    Cell[14902, 471, 129, 5, 48, "Input",
      CellTags->"3.1"],
    Cell[15034, 478, 168, 5, 44, "Output",
      CellTags->"3.1"],
    Cell[15205, 485, 115, 4, 31, "MathCaption",
      CellTags->"3.1"],
    Cell[15323, 491, 78, 2, 30, "Input",
      CellTags->"3.1"],
    Cell[15404, 495, 265, 6, 70, "Output",
      CellTags->"3.1"],
    Cell[15672, 503, 121, 4, 31, "MathCaption",
      CellTags->"3.1"],
    Cell[15796, 509, 79, 2, 30, "Input",
      CellTags->"3.1"],
    Cell[15878, 513, 169, 5, 44, "Output",
      CellTags->"3.1"],
    Cell[16050, 520, 402, 12, 90, "Text",
      CellTags->"3.1"],
    Cell[16455, 534, 184, 5, 48, "MathCaption",
      CellTags->"3.1"],
    Cell[16642, 541, 96, 2, 30, "Input",
      CellTags->"3.1"],
    Cell[16741, 545, 128, 3, 42, "Output",
      CellTags->"3.1"],
    Cell[16872, 550, 232, 8, 48, "MathCaption",
      CellTags->"3.1"],
    Cell[17107, 560, 79, 2, 30, "Input",
      CellTags->"3.1"],
    Cell[17189, 564, 143, 4, 42, "Output",
      CellTags->"3.1"],
    Cell[17335, 570, 80, 2, 30, "Input",
      CellTags->"3.1"],
    Cell[17418, 574, 169, 5, 51, "Output",
      CellTags->"3.1"],
    Cell[17590, 581, 512, 12, 90, "Text",
      CellTags->"3.1"],
    Cell[18105, 595, 652, 23, 39, "TopSpanBox",
      CellTags->"3.1"],
    Cell[18760, 620, 390, 11, 42, "MiddleBox",
      CellTags->"3.1"],
    Cell[19153, 633, 774, 27, 23, "MiddleSpanBox",
      CellTags->"3.1"],
    Cell[19930, 662, 1331, 37, 42, "BottomBox",
      CellTags->"3.1"],
    Cell[21264, 701, 105, 4, 16, "Caption",
      CellTags->"3.1"],
    Cell[21372, 707, 389, 10, 71, "Text",
      CellTags->"3.1"],
    Cell[21764, 719, 77, 1, 31, "MathCaption",
      CellTags->"3.1"],
    Cell[21844, 722, 110, 2, 30, "Input",
      CellTags->"3.1"],
    Cell[21957, 726, 140, 4, 42, "Output",
      CellTags->"3.1"],
    Cell[22100, 732, 225, 5, 65, "MathCaption",
      CellTags->"3.1"],
    Cell[22328, 739, 77, 2, 30, "Input",
      CellTags->"3.1"],
    Cell[22408, 743, 142, 4, 29, "Output",
      CellTags->"3.1"],
    Cell[22553, 749, 222, 7, 48, "MathCaption",
      CellTags->"3.1"],
    Cell[22778, 758, 81, 2, 30, "Input",
      CellTags->"3.1"],
    Cell[22862, 762, 169, 5, 44, "Output",
      CellTags->"3.1"],
    Cell[23034, 769, 86, 1, 31, "MathCaption",
      CellTags->"3.1"],
    Cell[23123, 772, 80, 2, 30, "Input",
      CellTags->"3.1"],
    Cell[23206, 776, 169, 5, 44, "Output",
      CellTags->"3.1"],
    Cell[23378, 783, 312, 10, 52, "Text",
      CellTags->"3.1"],
    Cell[23693, 795, 325, 9, 48, "MathCaption",
      CellTags->"3.1"],
    Cell[24021, 806, 98, 2, 30, "Input",
      CellTags->"3.1"],
    Cell[24122, 810, 115, 3, 29, "Output",
      CellTags->"3.1"],
    Cell[24240, 815, 188, 5, 106, "MathCaption",
      CellTags->"3.1"],
    Cell[24431, 822, 81, 2, 50, "Input",
      CellTags->"3.1"],
    Cell[24515, 826, 106, 3, 120, "Output",
      CellTags->"3.1"],
    Cell[24624, 831, 1017, 27, 442, "Text",
      CellTags->"3.1"],
    Cell[25644, 860, 135, 5, 92, "MathCaption",
      CellTags->"3.1"],
    Cell[25782, 867, 96, 2, 50, "Input",
      CellTags->"3.1"],
    Cell[25881, 871, 123, 3, 162, "Output",
      CellTags->"3.1"],
    Cell[26007, 876, 152, 5, 92, "MathCaption",
      CellTags->"3.1"],
    Cell[26162, 883, 75, 2, 50, "Input",
      CellTags->"3.1"],
    Cell[26240, 887, 119, 3, 162, "Output",
      CellTags->"3.1"],
    Cell[26362, 892, 1323, 32, 498, "Text",
      CellTags->"3.1"],
    Cell[27688, 926, 4256, 120, 98, "DefinitionBox",
      CellTags->"3.1"],
    Cell[31947, 1048, 76, 1, 26, "Caption",
      CellTags->"3.1"]},
  "3.2"->{
    Cell[32026, 1051, 80, 1, 68, "Subsection",
      CellTags->"3.2"],
    Cell[32109, 1054, 120, 2, 42, "Text",
      CellTags->"3.2"],
    Cell[32232, 1058, 1078, 33, 60, "DisplayFormula",
      CellTags->"3.2"],
    Cell[33313, 1093, 122, 2, 42, "Text",
      CellTags->"3.2"],
    Cell[33438, 1097, 1041, 32, 582, "DisplayFormula",
      CellTags->"3.2"],
    Cell[34482, 1131, 4156, 152, 2206, "Text",
      CellTags->"3.2"],
    Cell[38641, 1285, 8152, 227, 115, "DefinitionBox",
      CellTags->"3.2"],
    Cell[46796, 1514, 74, 1, 26, "Caption",
      CellTags->"3.2"],
    Cell[46873, 1517, 160993, 2986, 138, 149697, 2841, "GraphicsData", 
    "PostScript", "Picture",
      Evaluatable->False,
      CellTags->"3.2"],
    Cell[207869, 4505, 168, 5, 27, "Caption",
      CellTags->"3.2"],
    Cell[208040, 4512, 157, 7, 43, "Text",
      CellTags->"3.2"],
    Cell[208200, 4521, 166776, 3007, 139, 155699, 2865, "GraphicsData", 
    "PostScript", "Picture",
      Evaluatable->False,
      CellTags->"3.2"],
    Cell[374979, 7530, 172, 6, 27, "Caption",
      CellTags->"3.2"],
    Cell[375154, 7538, 852, 27, 114, "Text",
      CellTags->"3.2"],
    Cell[376009, 7567, 127, 4, 40, "MathCaption",
      CellTags->"3.2"],
    Cell[376139, 7573, 129, 5, 54, "Input",
      CellTags->"3.2"],
    Cell[376271, 7580, 139, 4, 53, "Output",
      CellTags->"3.2"],
    Cell[376413, 7586, 118, 4, 40, "MathCaption",
      CellTags->"3.2"],
    Cell[376534, 7592, 136, 5, 54, "Input",
      CellTags->"3.2"],
    Cell[376673, 7599, 147, 4, 53, "Output",
      CellTags->"3.2"],
    Cell[376823, 7605, 148, 4, 54, "MathCaption",
      CellTags->"3.2"],
    Cell[376974, 7611, 98, 2, 39, "Input",
      CellTags->"3.2"],
    Cell[377075, 7615, 83, 3, 38, "Output",
      CellTags->"3.2"],
    Cell[377161, 7620, 668, 12, 128, "Text",
      CellTags->"3.2"],
    Cell[377832, 7634, 675, 19, 52, "DisplayFormula",
      CellTags->"3.2"],
    Cell[378510, 7655, 683, 23, 52, "Text",
      CellTags->"3.2"],
    Cell[379196, 7680, 5760, 148, 119, "DisplayFormula",
      CellTags->"3.2"],
    Cell[384959, 7830, 1456, 50, 90, "Text",
      CellTags->"3.2"],
    Cell[386418, 7882, 218, 7, 31, "DisplayFormula",
      CellTags->"3.2"],
    Cell[386639, 7891, 233, 5, 52, "Text",
      CellTags->"3.2"],
    Cell[386875, 7898, 71, 1, 31, "MathCaption",
      CellTags->"3.2"],
    Cell[386949, 7901, 108, 2, 30, "Input",
      CellTags->"3.2"],
    Cell[387060, 7905, 143, 4, 42, "Output",
      CellTags->"3.2"],
    Cell[387206, 7911, 96, 1, 31, "MathCaption",
      CellTags->"3.2"],
    Cell[387305, 7914, 75, 2, 30, "Input",
      CellTags->"3.2"],
    Cell[387383, 7918, 254, 6, 67, "Output",
      CellTags->"3.2"],
    Cell[387640, 7926, 263, 7, 48, "MathCaption",
      CellTags->"3.2"],
    Cell[387906, 7935, 75, 2, 30, "Input",
      CellTags->"3.2"],
    Cell[387984, 7939, 1576, 48, 179, "Output",
      CellTags->"3.2"],
    Cell[389563, 7989, 180, 5, 48, "MathCaption",
      CellTags->"3.2"],
    Cell[389746, 7996, 142, 5, 48, "Input",
      CellTags->"3.2"],
    Cell[389891, 8003, 1548, 46, 207, "Output",
      CellTags->"3.2"],
    Cell[391442, 8051, 139, 4, 54, "MathCaption",
      CellTags->"3.2"],
    Cell[391584, 8057, 94, 2, 39, "Input",
      CellTags->"3.2"],
    Cell[391681, 8061, 143, 4, 54, "Output",
      CellTags->"3.2"],
    Cell[391827, 8067, 1923, 54, 221, "Text",
      CellTags->"3.2"]},
  "3.3"->{
    Cell[393753, 8123, 107, 2, 68, "Subsection",
      CellTags->"3.3"],
    Cell[393863, 8127, 2043, 55, 64, "DefinitionBox",
      CellTags->"3.3"],
    Cell[395909, 8184, 94, 1, 26, "Caption",
      CellTags->"3.3"],
    Cell[396006, 8187, 80, 1, 40, "MathCaption",
      CellTags->"3.3"],
    Cell[396089, 8190, 130, 5, 54, "Input",
      CellTags->"3.3"],
    Cell[396222, 8197, 139, 4, 53, "Output",
      CellTags->"3.3"],
    Cell[396364, 8203, 92, 1, 40, "MathCaption",
      CellTags->"3.3"],
    Cell[396459, 8206, 75, 2, 39, "Input",
      CellTags->"3.3"],
    Cell[396537, 8210, 1366, 44, 124, "Output",
      CellTags->"3.3"],
    Cell[397906, 8256, 386, 11, 77, "Text",
      CellTags->"3.3"],
    Cell[398295, 8269, 116, 4, 40, "MathCaption",
      CellTags->"3.3"],
    Cell[398414, 8275, 63, 2, 39, "Input",
      CellTags->"3.3"],
    Cell[398480, 8279, 139, 4, 53, "Output",
      CellTags->"3.3"]},
  "3.4"->{
    Cell[398622, 8285, 108, 2, 68, "Subsection",
      CellTags->"3.4"],
    Cell[398733, 8289, 2150, 52, 336, "Text",
      CellTags->"3.4"],
    Cell[400886, 8343, 11615, 319, 253, "DefinitionBox",
      CellTags->"3.4"],
    Cell[412504, 8664, 130, 4, 26, "Caption",
      CellTags->"3.4"],
    Cell[412637, 8670, 217, 5, 55, "MathCaption",
      CellTags->"3.4"],
    Cell[412857, 8677, 98, 2, 39, "Input",
      CellTags->"3.4"],
    Cell[412958, 8681, 83, 3, 38, "Output",
      CellTags->"3.4"],
    Cell[413044, 8686, 128, 4, 40, "MathCaption",
      CellTags->"3.4"],
    Cell[413175, 8692, 126, 6, 69, "Input",
      CellTags->"3.4"],
    Cell[413304, 8700, 84, 3, 38, "Output",
      CellTags->"3.4"],
    Cell[413391, 8705, 296, 10, 56, "MathCaption",
      CellTags->"3.4"],
    Cell[413690, 8717, 131, 6, 66, "Input",
      CellTags->"3.4"],
    Cell[413824, 8725, 84, 3, 29, "Output",
      CellTags->"3.4"],
    Cell[413911, 8730, 301, 8, 65, "MathCaption",
      CellTags->"3.4"],
    Cell[414215, 8740, 82, 2, 39, "Input",
      CellTags->"3.4"],
    Cell[414300, 8744, 88, 3, 38, "Output",
      CellTags->"3.4"],
    Cell[414391, 8749, 139, 4, 40, "MathCaption",
      CellTags->"3.4"],
    Cell[414533, 8755, 98, 2, 39, "Input",
      CellTags->"3.4"],
    Cell[414634, 8759, 84, 3, 38, "Output",
      CellTags->"3.4"],
    Cell[414721, 8764, 78, 1, 40, "MathCaption",
      CellTags->"3.4"],
    Cell[414802, 8767, 78, 2, 39, "Input",
      CellTags->"3.4"],
    Cell[414883, 8771, 84, 3, 38, "Output",
      CellTags->"3.4"]},
  "3.5"->{
    Cell[414970, 8776, 111, 2, 68, "Subsection",
      CellTags->"3.5"],
    Cell[415084, 8780, 1085, 25, 160, "Text",
      CellTags->"3.5"],
    Cell[416172, 8807, 2073, 56, 76, "TopBox",
      CellTags->"3.5"],
    Cell[418248, 8865, 908, 29, 32, "MiddleSpanBox",
      CellTags->"3.5"],
    Cell[419159, 8896, 1567, 41, 61, "MiddleBox",
      CellTags->"3.5"],
    Cell[420729, 8939, 418, 12, 36, "BottomBox",
      CellTags->"3.5"],
    Cell[421150, 8953, 126, 4, 26, "Caption",
      CellTags->"3.5"],
    Cell[421279, 8959, 92, 1, 40, "MathCaption",
      CellTags->"3.5"],
    Cell[421374, 8962, 95, 2, 39, "Input",
      CellTags->"3.5"],
    Cell[421472, 8966, 116, 3, 52, "Output",
      CellTags->"3.5"],
    Cell[421591, 8971, 298, 8, 69, "MathCaption",
      CellTags->"3.5"],
    Cell[421892, 8981, 104, 2, 39, "Input",
      CellTags->"3.5"],
    Cell[421999, 8985, 198, 5, 56, "Output",
      CellTags->"3.5"],
    Cell[422200, 8992, 117, 4, 40, "MathCaption",
      CellTags->"3.5"],
    Cell[422320, 8998, 73, 2, 39, "Input",
      CellTags->"3.5"],
    Cell[422396, 9002, 198, 5, 44, "Output",
      CellTags->"3.5"],
    Cell[422597, 9009, 109, 2, 31, "MathCaption",
      CellTags->"3.5"],
    Cell[422709, 9013, 144, 7, 84, "Input",
      CellTags->"3.5"],
    Cell[422856, 9022, 1360, 44, 115, "Output",
      CellTags->"3.5"],
    Cell[424219, 9068, 283, 7, 48, "MathCaption",
      CellTags->"3.5"],
    Cell[424505, 9077, 107, 2, 30, "Input",
      CellTags->"3.5"],
    Cell[424615, 9081, 298, 6, 67, "Output",
      CellTags->"3.5"],
    Cell[424916, 9089, 121, 5, 31, "MathCaption",
      CellTags->"3.5"],
    Cell[425040, 9096, 74, 2, 30, "Input",
      CellTags->"3.5"],
    Cell[425117, 9100, 1483, 44, 1030, "Output",
      CellTags->"3.5"],
    Cell[426603, 9146, 1492, 37, 582, "Text",
      CellTags->"3.5"],
    Cell[428098, 9185, 142, 4, 92, "MathCaption",
      CellTags->"3.5"],
    Cell[428243, 9191, 92, 2, 50, "Input",
      CellTags->"3.5"],
    Cell[428338, 9195, 143, 4, 274, "Output",
      CellTags->"3.5"],
    Cell[428484, 9201, 125, 4, 31, "MathCaption",
      CellTags->"3.5"],
    Cell[428612, 9207, 80, 2, 30, "Input",
      CellTags->"3.5"],
    Cell[428695, 9211, 17828, 515, 186, 5091, 352, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"3.5"],
    Cell[446526, 9728, 773, 17, 158, "MathCaption",
      CellTags->"3.5"],
    Cell[447302, 9747, 228, 9, 120, "Input",
      CellTags->"3.5"],
    Cell[447533, 9758, 20428, 597, 186, 6743, 422, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"3.5"],
    Cell[467964, 10357, 66, 1, 49, "Subsubsection",
      CellTags->"3.5"],
    Cell[468033, 10360, 1204, 31, 236, "Text",
      CellTags->"3.5"],
    Cell[469240, 10393, 1116, 35, 101, "DefinitionBox3Col",
      CellTags->"3.5"],
    Cell[470359, 10430, 116, 2, 16, "Caption",
      CellTags->"3.5"],
    Cell[470478, 10434, 211, 6, 48, "MathCaption",
      CellTags->"3.5"],
    Cell[470692, 10442, 140, 5, 48, "Input",
      CellTags->"3.5"],
    Cell[470835, 10449, 168, 4, 42, "Output",
      CellTags->"3.5"],
    Cell[471006, 10455, 130, 4, 31, "MathCaption",
      CellTags->"3.5"],
    Cell[471139, 10461, 141, 5, 48, "Input",
      CellTags->"3.5"],
    Cell[471283, 10468, 174, 4, 67, "Output",
      CellTags->"3.5"],
    Cell[471460, 10474, 123, 4, 31, "MathCaption",
      CellTags->"3.5"],
    Cell[471586, 10480, 147, 6, 66, "Input",
      CellTags->"3.5"],
    Cell[471736, 10488, 201, 5, 67, "Output",
      CellTags->"3.5"],
    Cell[471940, 10495, 145, 4, 31, "MathCaption",
      CellTags->"3.5"],
    Cell[472088, 10501, 133, 5, 48, "Input",
      CellTags->"3.5"],
    Cell[472224, 10508, 199, 5, 44, "Output",
      CellTags->"3.5"],
    Cell[472426, 10515, 250, 8, 31, "MathCaption",
      CellTags->"3.5"],
    Cell[472679, 10525, 170, 8, 102, "Input",
      CellTags->"3.5"],
    Cell[472852, 10535, 203, 5, 73, "Output",
      CellTags->"3.5"],
    Cell[473058, 10542, 212, 6, 48, "MathCaption",
      CellTags->"3.5"],
    Cell[473273, 10550, 107, 2, 30, "Input",
      CellTags->"3.5"],
    Cell[473383, 10554, 129, 3, 42, "Output",
      CellTags->"3.5"],
    Cell[473515, 10559, 118, 4, 31, "MathCaption",
      CellTags->"3.5"],
    Cell[473636, 10565, 99, 2, 30, "Input",
      CellTags->"3.5"],
    Cell[473738, 10569, 123301, 3616, 296, 55590, 2774, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"3.5"],
    Cell[597042, 14187, 92, 1, 31, "MathCaption",
      CellTags->"3.5"],
    Cell[597137, 14190, 155, 6, 66, "Input",
      CellTags->"3.5"],
    Cell[597295, 14198, 218, 5, 67, "Output",
      CellTags->"3.5"],
    Cell[597516, 14205, 363, 7, 107, "MathCaption",
      CellTags->"3.5"],
    Cell[597882, 14214, 206, 12, 174, "Input",
      CellTags->"3.5"],
    Cell[598091, 14228, 124621, 3687, 296, 56615, 2842, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"3.5"],
    Cell[722715, 17917, 213, 7, 48, "MathCaption",
      CellTags->"3.5"],
    Cell[722931, 17926, 179, 8, 102, "Input",
      CellTags->"3.5"],
    Cell[723113, 17936, 268, 6, 86, "Output",
      CellTags->"3.5"],
    Cell[723384, 17944, 166, 4, 48, "MathCaption",
      CellTags->"3.5"],
    Cell[723553, 17950, 208, 12, 174, "Input",
      CellTags->"3.5"],
    Cell[723764, 17964, 125084, 3693, 296, 56608, 2842, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"3.5"],
    Cell[848851, 21659, 498, 11, 93, "Text",
      CellTags->"3.5"],
    Cell[849352, 21672, 134, 5, 41, "MathCaption",
      CellTags->"3.5"],
    Cell[849489, 21679, 93, 2, 39, "Input",
      CellTags->"3.5"],
    Cell[849585, 21683, 157, 4, 54, "Output",
      CellTags->"3.5"],
    Cell[849745, 21689, 124, 4, 40, "MathCaption",
      CellTags->"3.5"],
    Cell[849872, 21695, 167, 7, 84, "Input",
      CellTags->"3.5"],
    Cell[850042, 21704, 1757, 53, 152, "Output",
      CellTags->"3.5"]},
  "3.6"->{
    Cell[851802, 21759, 95, 1, 68, "Subsection",
      CellTags->"3.6"],
    Cell[851900, 21762, 194, 5, 59, "Text",
      CellTags->"3.6"],
    Cell[852097, 21769, 1235, 40, 60, "DisplayFormula",
      CellTags->"3.6"],
    Cell[853335, 21811, 1269, 34, 150, "Text",
      CellTags->"3.6"],
    Cell[854607, 21847, 661, 21, 69, "DefinitionBox3Col",
      CellTags->"3.6"],
    Cell[855271, 21870, 137, 5, 26, "Caption",
      CellTags->"3.6"],
    Cell[855411, 21877, 152, 5, 41, "MathCaption",
      CellTags->"3.6"],
    Cell[855566, 21884, 115, 2, 54, "Input",
      CellTags->"3.6"],
    Cell[855684, 21888, 132, 3, 38, "Output",
      CellTags->"3.6"],
    Cell[855819, 21893, 143, 4, 54, "MathCaption",
      CellTags->"3.6"],
    Cell[855965, 21899, 117, 2, 54, "Input",
      CellTags->"3.6"],
    Cell[856085, 21903, 184, 4, 54, "Output",
      CellTags->"3.6"],
    Cell[856272, 21909, 123, 4, 40, "MathCaption",
      CellTags->"3.6"],
    Cell[856398, 21915, 129, 5, 54, "Input",
      CellTags->"3.6"],
    Cell[856530, 21922, 211, 5, 54, "Output",
      CellTags->"3.6"],
    Cell[856744, 21929, 128, 4, 40, "MathCaption",
      CellTags->"3.6"],
    Cell[856875, 21935, 120, 2, 54, "Input",
      CellTags->"3.6"],
    Cell[856998, 21939, 276, 6, 582, "Output",
      CellTags->"3.6"]},
  "3.7"->{
    Cell[857277, 21947, 111, 2, 50, "Subsection",
      CellTags->"3.7"],
    Cell[857391, 21951, 835, 18, 330, "Text",
      CellTags->"3.7"],
    Cell[858229, 21971, 630, 20, 386, "DefinitionBox",
      CellTags->"3.7"],
    Cell[858862, 21993, 126, 4, 26, "Caption",
      CellTags->"3.7"],
    Cell[858991, 21999, 164, 4, 54, "MathCaption",
      CellTags->"3.7"],
    Cell[859158, 22005, 163, 7, 72, "Input",
      CellTags->"3.7"],
    Cell[859324, 22014, 279, 6, 72, "Output",
      CellTags->"3.7"],
    Cell[859606, 22022, 90, 1, 40, "MathCaption",
      CellTags->"3.7"],
    Cell[859699, 22025, 81, 2, 39, "Input",
      CellTags->"3.7"],
    Cell[859783, 22029, 233, 5, 93, "Output",
      CellTags->"3.7"],
    Cell[860019, 22036, 226, 6, 55, "MathCaption",
      CellTags->"3.7"],
    Cell[860248, 22044, 80, 2, 39, "Input",
      CellTags->"3.7"],
    Cell[860331, 22048, 134, 3, 38, "Output",
      CellTags->"3.7"],
    Cell[860468, 22053, 79, 1, 40, "MathCaption",
      CellTags->"3.7"],
    Cell[860550, 22056, 66, 2, 39, "Input",
      CellTags->"3.7"],
    Cell[860619, 22060, 158, 4, 54, "Output",
      CellTags->"3.7"],
    Cell[860780, 22066, 169, 4, 54, "MathCaption",
      CellTags->"3.7"],
    Cell[860952, 22072, 178, 8, 99, "Input",
      CellTags->"3.7"],
    Cell[861133, 22082, 419, 9, 153, "Output",
      CellTags->"3.7"],
    Cell[861555, 22093, 90, 1, 40, "MathCaption",
      CellTags->"3.7"],
    Cell[861648, 22096, 157, 7, 84, "Input",
      CellTags->"3.7"],
    Cell[861808, 22105, 158, 4, 54, "Output",
      CellTags->"3.7"],
    Cell[861969, 22111, 162, 4, 54, "MathCaption",
      CellTags->"3.7"],
    Cell[862134, 22117, 151, 7, 72, "Input",
      CellTags->"3.7"],
    Cell[862288, 22126, 332, 7, 118, "Output",
      CellTags->"3.7"],
    Cell[862623, 22135, 92, 1, 28, "MathCaption",
      CellTags->"3.7"],
    Cell[862718, 22138, 115, 2, 42, "Input",
      CellTags->"3.7"],
    Cell[862836, 22142, 158, 4, 42, "Output",
      CellTags->"3.7"],
    Cell[862997, 22148, 401, 11, 64, "Text",
      CellTags->"3.7"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"3.0", 864311, 22185},
  {"3.1", 864451, 22190},
  {"3.2", 870261, 22361},
  {"3.3", 873696, 22458},
  {"3.4", 874628, 22485},
  {"3.5", 876190, 22530},
  {"3.6", 882121, 22694},
  {"3.7", 883435, 22731}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 71, 1, 68, "Section",
  CellTags->"3.0"],
Cell[1791, 52, 446, 8, 80, "Text",
  CellTags->"3.0"],
Cell[2240, 62, 78, 1, 56, "Subsection",
  CellTags->"3.1"],
Cell[2321, 65, 806, 23, 118, "Text",
  CellTags->"3.1"],
Cell[3130, 90, 4906, 138, 96, "DefinitionBox",
  CellTags->"3.1"],
Cell[8039, 230, 91, 1, 26, "Caption",
  CellTags->"3.1"],
Cell[8133, 233, 64, 1, 40, "MathCaption",
  CellTags->"3.1"],
Cell[8200, 236, 77, 2, 39, "Input",
  CellTags->"3.1"],
Cell[8280, 240, 264, 6, 69, "MathCaption",
  CellTags->"3.1"],
Cell[8547, 248, 112, 2, 54, "Input",
  CellTags->"3.1"],
Cell[8662, 252, 148, 4, 54, "Output",
  CellTags->"3.1"],
Cell[8813, 258, 128, 4, 40, "MathCaption",
  CellTags->"3.1"],
Cell[8944, 264, 65, 2, 39, "Input",
  CellTags->"3.1"],
Cell[9012, 268, 116, 3, 54, "Output",
  CellTags->"3.1"],
Cell[9131, 273, 163, 4, 54, "MathCaption",
  CellTags->"3.1"],
Cell[9297, 279, 70, 2, 39, "Input",
  CellTags->"3.1"],
Cell[9370, 283, 207, 5, 38, "Output",
  CellTags->"3.1"],
Cell[9580, 290, 180, 5, 54, "MathCaption",
  CellTags->"3.1"],
Cell[9763, 297, 86, 2, 30, "Input",
  CellTags->"3.1"],
Cell[9852, 301, 105, 3, 43, "Output",
  CellTags->"3.1"],
Cell[9960, 306, 194, 7, 48, "MathCaption",
  CellTags->"3.1"],
Cell[10157, 315, 65, 2, 30, "Input",
  CellTags->"3.1"],
Cell[10225, 319, 86, 3, 42, "Output",
  CellTags->"3.1"],
Cell[10314, 324, 315, 7, 71, "Text",
  CellTags->"3.1"],
Cell[10632, 333, 227, 7, 31, "MathCaption",
  CellTags->"3.1"],
Cell[10862, 342, 82, 2, 30, "Input",
  CellTags->"3.1"],
Cell[10947, 346, 105, 3, 43, "Output",
  CellTags->"3.1"],
Cell[11055, 351, 443, 10, 90, "Text",
  CellTags->"3.1"],
Cell[11501, 363, 394, 14, 39, "TopSpanBox",
  CellTags->"3.1"],
Cell[11898, 379, 1202, 33, 26, "MiddleBox",
  CellTags->"3.1"],
Cell[13103, 414, 397, 14, 23, "MiddleSpanBox",
  CellTags->"3.1"],
Cell[13503, 430, 1202, 33, 42, "BottomBox",
  CellTags->"3.1"],
Cell[14708, 465, 94, 1, 16, "Caption",
  CellTags->"3.1"],
Cell[14805, 468, 94, 1, 31, "MathCaption",
  CellTags->"3.1"],
Cell[14902, 471, 129, 5, 48, "Input",
  CellTags->"3.1"],
Cell[15034, 478, 168, 5, 44, "Output",
  CellTags->"3.1"],
Cell[15205, 485, 115, 4, 31, "MathCaption",
  CellTags->"3.1"],
Cell[15323, 491, 78, 2, 30, "Input",
  CellTags->"3.1"],
Cell[15404, 495, 265, 6, 70, "Output",
  CellTags->"3.1"],
Cell[15672, 503, 121, 4, 31, "MathCaption",
  CellTags->"3.1"],
Cell[15796, 509, 79, 2, 30, "Input",
  CellTags->"3.1"],
Cell[15878, 513, 169, 5, 44, "Output",
  CellTags->"3.1"],
Cell[16050, 520, 402, 12, 90, "Text",
  CellTags->"3.1"],
Cell[16455, 534, 184, 5, 48, "MathCaption",
  CellTags->"3.1"],
Cell[16642, 541, 96, 2, 30, "Input",
  CellTags->"3.1"],
Cell[16741, 545, 128, 3, 42, "Output",
  CellTags->"3.1"],
Cell[16872, 550, 232, 8, 48, "MathCaption",
  CellTags->"3.1"],
Cell[17107, 560, 79, 2, 30, "Input",
  CellTags->"3.1"],
Cell[17189, 564, 143, 4, 42, "Output",
  CellTags->"3.1"],
Cell[17335, 570, 80, 2, 30, "Input",
  CellTags->"3.1"],
Cell[17418, 574, 169, 5, 51, "Output",
  CellTags->"3.1"],
Cell[17590, 581, 512, 12, 90, "Text",
  CellTags->"3.1"],
Cell[18105, 595, 652, 23, 39, "TopSpanBox",
  CellTags->"3.1"],
Cell[18760, 620, 390, 11, 42, "MiddleBox",
  CellTags->"3.1"],
Cell[19153, 633, 774, 27, 23, "MiddleSpanBox",
  CellTags->"3.1"],
Cell[19930, 662, 1331, 37, 42, "BottomBox",
  CellTags->"3.1"],
Cell[21264, 701, 105, 4, 16, "Caption",
  CellTags->"3.1"],
Cell[21372, 707, 389, 10, 71, "Text",
  CellTags->"3.1"],
Cell[21764, 719, 77, 1, 31, "MathCaption",
  CellTags->"3.1"],
Cell[21844, 722, 110, 2, 30, "Input",
  CellTags->"3.1"],
Cell[21957, 726, 140, 4, 42, "Output",
  CellTags->"3.1"],
Cell[22100, 732, 225, 5, 65, "MathCaption",
  CellTags->"3.1"],
Cell[22328, 739, 77, 2, 30, "Input",
  CellTags->"3.1"],
Cell[22408, 743, 142, 4, 29, "Output",
  CellTags->"3.1"],
Cell[22553, 749, 222, 7, 48, "MathCaption",
  CellTags->"3.1"],
Cell[22778, 758, 81, 2, 30, "Input",
  CellTags->"3.1"],
Cell[22862, 762, 169, 5, 44, "Output",
  CellTags->"3.1"],
Cell[23034, 769, 86, 1, 31, "MathCaption",
  CellTags->"3.1"],
Cell[23123, 772, 80, 2, 30, "Input",
  CellTags->"3.1"],
Cell[23206, 776, 169, 5, 44, "Output",
  CellTags->"3.1"],
Cell[23378, 783, 312, 10, 52, "Text",
  CellTags->"3.1"],
Cell[23693, 795, 325, 9, 48, "MathCaption",
  CellTags->"3.1"],
Cell[24021, 806, 98, 2, 30, "Input",
  CellTags->"3.1"],
Cell[24122, 810, 115, 3, 29, "Output",
  CellTags->"3.1"],
Cell[24240, 815, 188, 5, 106, "MathCaption",
  CellTags->"3.1"],
Cell[24431, 822, 81, 2, 50, "Input",
  CellTags->"3.1"],
Cell[24515, 826, 106, 3, 120, "Output",
  CellTags->"3.1"],
Cell[24624, 831, 1017, 27, 442, "Text",
  CellTags->"3.1"],
Cell[25644, 860, 135, 5, 92, "MathCaption",
  CellTags->"3.1"],
Cell[25782, 867, 96, 2, 50, "Input",
  CellTags->"3.1"],
Cell[25881, 871, 123, 3, 162, "Output",
  CellTags->"3.1"],
Cell[26007, 876, 152, 5, 92, "MathCaption",
  CellTags->"3.1"],
Cell[26162, 883, 75, 2, 50, "Input",
  CellTags->"3.1"],
Cell[26240, 887, 119, 3, 162, "Output",
  CellTags->"3.1"],
Cell[26362, 892, 1323, 32, 498, "Text",
  CellTags->"3.1"],
Cell[27688, 926, 4256, 120, 98, "DefinitionBox",
  CellTags->"3.1"],
Cell[31947, 1048, 76, 1, 26, "Caption",
  CellTags->"3.1"],
Cell[32026, 1051, 80, 1, 68, "Subsection",
  CellTags->"3.2"],
Cell[32109, 1054, 120, 2, 42, "Text",
  CellTags->"3.2"],
Cell[32232, 1058, 1078, 33, 60, "DisplayFormula",
  CellTags->"3.2"],
Cell[33313, 1093, 122, 2, 42, "Text",
  CellTags->"3.2"],
Cell[33438, 1097, 1041, 32, 582, "DisplayFormula",
  CellTags->"3.2"],
Cell[34482, 1131, 4156, 152, 2206, "Text",
  CellTags->"3.2"],
Cell[38641, 1285, 8152, 227, 115, "DefinitionBox",
  CellTags->"3.2"],
Cell[46796, 1514, 74, 1, 26, "Caption",
  CellTags->"3.2"],
Cell[46873, 1517, 160993, 2986, 138, 149697, 2841, "GraphicsData", 
"PostScript", "Picture",
  Evaluatable->False,
  CellTags->"3.2"],
Cell[207869, 4505, 168, 5, 27, "Caption",
  CellTags->"3.2"],
Cell[208040, 4512, 157, 7, 43, "Text",
  CellTags->"3.2"],
Cell[208200, 4521, 166776, 3007, 139, 155699, 2865, "GraphicsData", 
"PostScript", "Picture",
  Evaluatable->False,
  CellTags->"3.2"],
Cell[374979, 7530, 172, 6, 27, "Caption",
  CellTags->"3.2"],
Cell[375154, 7538, 852, 27, 114, "Text",
  CellTags->"3.2"],
Cell[376009, 7567, 127, 4, 40, "MathCaption",
  CellTags->"3.2"],
Cell[376139, 7573, 129, 5, 54, "Input",
  CellTags->"3.2"],
Cell[376271, 7580, 139, 4, 53, "Output",
  CellTags->"3.2"],
Cell[376413, 7586, 118, 4, 40, "MathCaption",
  CellTags->"3.2"],
Cell[376534, 7592, 136, 5, 54, "Input",
  CellTags->"3.2"],
Cell[376673, 7599, 147, 4, 53, "Output",
  CellTags->"3.2"],
Cell[376823, 7605, 148, 4, 54, "MathCaption",
  CellTags->"3.2"],
Cell[376974, 7611, 98, 2, 39, "Input",
  CellTags->"3.2"],
Cell[377075, 7615, 83, 3, 38, "Output",
  CellTags->"3.2"],
Cell[377161, 7620, 668, 12, 128, "Text",
  CellTags->"3.2"],
Cell[377832, 7634, 675, 19, 52, "DisplayFormula",
  CellTags->"3.2"],
Cell[378510, 7655, 683, 23, 52, "Text",
  CellTags->"3.2"],
Cell[379196, 7680, 5760, 148, 119, "DisplayFormula",
  CellTags->"3.2"],
Cell[384959, 7830, 1456, 50, 90, "Text",
  CellTags->"3.2"],
Cell[386418, 7882, 218, 7, 31, "DisplayFormula",
  CellTags->"3.2"],
Cell[386639, 7891, 233, 5, 52, "Text",
  CellTags->"3.2"],
Cell[386875, 7898, 71, 1, 31, "MathCaption",
  CellTags->"3.2"],
Cell[386949, 7901, 108, 2, 30, "Input",
  CellTags->"3.2"],
Cell[387060, 7905, 143, 4, 42, "Output",
  CellTags->"3.2"],
Cell[387206, 7911, 96, 1, 31, "MathCaption",
  CellTags->"3.2"],
Cell[387305, 7914, 75, 2, 30, "Input",
  CellTags->"3.2"],
Cell[387383, 7918, 254, 6, 67, "Output",
  CellTags->"3.2"],
Cell[387640, 7926, 263, 7, 48, "MathCaption",
  CellTags->"3.2"],
Cell[387906, 7935, 75, 2, 30, "Input",
  CellTags->"3.2"],
Cell[387984, 7939, 1576, 48, 179, "Output",
  CellTags->"3.2"],
Cell[389563, 7989, 180, 5, 48, "MathCaption",
  CellTags->"3.2"],
Cell[389746, 7996, 142, 5, 48, "Input",
  CellTags->"3.2"],
Cell[389891, 8003, 1548, 46, 207, "Output",
  CellTags->"3.2"],
Cell[391442, 8051, 139, 4, 54, "MathCaption",
  CellTags->"3.2"],
Cell[391584, 8057, 94, 2, 39, "Input",
  CellTags->"3.2"],
Cell[391681, 8061, 143, 4, 54, "Output",
  CellTags->"3.2"],
Cell[391827, 8067, 1923, 54, 221, "Text",
  CellTags->"3.2"],
Cell[393753, 8123, 107, 2, 68, "Subsection",
  CellTags->"3.3"],
Cell[393863, 8127, 2043, 55, 64, "DefinitionBox",
  CellTags->"3.3"],
Cell[395909, 8184, 94, 1, 26, "Caption",
  CellTags->"3.3"],
Cell[396006, 8187, 80, 1, 40, "MathCaption",
  CellTags->"3.3"],
Cell[396089, 8190, 130, 5, 54, "Input",
  CellTags->"3.3"],
Cell[396222, 8197, 139, 4, 53, "Output",
  CellTags->"3.3"],
Cell[396364, 8203, 92, 1, 40, "MathCaption",
  CellTags->"3.3"],
Cell[396459, 8206, 75, 2, 39, "Input",
  CellTags->"3.3"],
Cell[396537, 8210, 1366, 44, 124, "Output",
  CellTags->"3.3"],
Cell[397906, 8256, 386, 11, 77, "Text",
  CellTags->"3.3"],
Cell[398295, 8269, 116, 4, 40, "MathCaption",
  CellTags->"3.3"],
Cell[398414, 8275, 63, 2, 39, "Input",
  CellTags->"3.3"],
Cell[398480, 8279, 139, 4, 53, "Output",
  CellTags->"3.3"],
Cell[398622, 8285, 108, 2, 68, "Subsection",
  CellTags->"3.4"],
Cell[398733, 8289, 2150, 52, 336, "Text",
  CellTags->"3.4"],
Cell[400886, 8343, 11615, 319, 253, "DefinitionBox",
  CellTags->"3.4"],
Cell[412504, 8664, 130, 4, 26, "Caption",
  CellTags->"3.4"],
Cell[412637, 8670, 217, 5, 55, "MathCaption",
  CellTags->"3.4"],
Cell[412857, 8677, 98, 2, 39, "Input",
  CellTags->"3.4"],
Cell[412958, 8681, 83, 3, 38, "Output",
  CellTags->"3.4"],
Cell[413044, 8686, 128, 4, 40, "MathCaption",
  CellTags->"3.4"],
Cell[413175, 8692, 126, 6, 69, "Input",
  CellTags->"3.4"],
Cell[413304, 8700, 84, 3, 38, "Output",
  CellTags->"3.4"],
Cell[413391, 8705, 296, 10, 56, "MathCaption",
  CellTags->"3.4"],
Cell[413690, 8717, 131, 6, 66, "Input",
  CellTags->"3.4"],
Cell[413824, 8725, 84, 3, 29, "Output",
  CellTags->"3.4"],
Cell[413911, 8730, 301, 8, 65, "MathCaption",
  CellTags->"3.4"],
Cell[414215, 8740, 82, 2, 39, "Input",
  CellTags->"3.4"],
Cell[414300, 8744, 88, 3, 38, "Output",
  CellTags->"3.4"],
Cell[414391, 8749, 139, 4, 40, "MathCaption",
  CellTags->"3.4"],
Cell[414533, 8755, 98, 2, 39, "Input",
  CellTags->"3.4"],
Cell[414634, 8759, 84, 3, 38, "Output",
  CellTags->"3.4"],
Cell[414721, 8764, 78, 1, 40, "MathCaption",
  CellTags->"3.4"],
Cell[414802, 8767, 78, 2, 39, "Input",
  CellTags->"3.4"],
Cell[414883, 8771, 84, 3, 38, "Output",
  CellTags->"3.4"],
Cell[414970, 8776, 111, 2, 68, "Subsection",
  CellTags->"3.5"],
Cell[415084, 8780, 1085, 25, 160, "Text",
  CellTags->"3.5"],
Cell[416172, 8807, 2073, 56, 76, "TopBox",
  CellTags->"3.5"],
Cell[418248, 8865, 908, 29, 32, "MiddleSpanBox",
  CellTags->"3.5"],
Cell[419159, 8896, 1567, 41, 61, "MiddleBox",
  CellTags->"3.5"],
Cell[420729, 8939, 418, 12, 36, "BottomBox",
  CellTags->"3.5"],
Cell[421150, 8953, 126, 4, 26, "Caption",
  CellTags->"3.5"],
Cell[421279, 8959, 92, 1, 40, "MathCaption",
  CellTags->"3.5"],
Cell[421374, 8962, 95, 2, 39, "Input",
  CellTags->"3.5"],
Cell[421472, 8966, 116, 3, 52, "Output",
  CellTags->"3.5"],
Cell[421591, 8971, 298, 8, 69, "MathCaption",
  CellTags->"3.5"],
Cell[421892, 8981, 104, 2, 39, "Input",
  CellTags->"3.5"],
Cell[421999, 8985, 198, 5, 56, "Output",
  CellTags->"3.5"],
Cell[422200, 8992, 117, 4, 40, "MathCaption",
  CellTags->"3.5"],
Cell[422320, 8998, 73, 2, 39, "Input",
  CellTags->"3.5"],
Cell[422396, 9002, 198, 5, 44, "Output",
  CellTags->"3.5"],
Cell[422597, 9009, 109, 2, 31, "MathCaption",
  CellTags->"3.5"],
Cell[422709, 9013, 144, 7, 84, "Input",
  CellTags->"3.5"],
Cell[422856, 9022, 1360, 44, 115, "Output",
  CellTags->"3.5"],
Cell[424219, 9068, 283, 7, 48, "MathCaption",
  CellTags->"3.5"],
Cell[424505, 9077, 107, 2, 30, "Input",
  CellTags->"3.5"],
Cell[424615, 9081, 298, 6, 67, "Output",
  CellTags->"3.5"],
Cell[424916, 9089, 121, 5, 31, "MathCaption",
  CellTags->"3.5"],
Cell[425040, 9096, 74, 2, 30, "Input",
  CellTags->"3.5"],
Cell[425117, 9100, 1483, 44, 1030, "Output",
  CellTags->"3.5"],
Cell[426603, 9146, 1492, 37, 582, "Text",
  CellTags->"3.5"],
Cell[428098, 9185, 142, 4, 92, "MathCaption",
  CellTags->"3.5"],
Cell[428243, 9191, 92, 2, 50, "Input",
  CellTags->"3.5"],
Cell[428338, 9195, 143, 4, 274, "Output",
  CellTags->"3.5"],
Cell[428484, 9201, 125, 4, 31, "MathCaption",
  CellTags->"3.5"],
Cell[428612, 9207, 80, 2, 30, "Input",
  CellTags->"3.5"],
Cell[428695, 9211, 17828, 515, 186, 5091, 352, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"3.5"],
Cell[446526, 9728, 773, 17, 158, "MathCaption",
  CellTags->"3.5"],
Cell[447302, 9747, 228, 9, 120, "Input",
  CellTags->"3.5"],
Cell[447533, 9758, 20428, 597, 186, 6743, 422, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"3.5"],
Cell[467964, 10357, 66, 1, 49, "Subsubsection",
  CellTags->"3.5"],
Cell[468033, 10360, 1204, 31, 236, "Text",
  CellTags->"3.5"],
Cell[469240, 10393, 1116, 35, 101, "DefinitionBox3Col",
  CellTags->"3.5"],
Cell[470359, 10430, 116, 2, 16, "Caption",
  CellTags->"3.5"],
Cell[470478, 10434, 211, 6, 48, "MathCaption",
  CellTags->"3.5"],
Cell[470692, 10442, 140, 5, 48, "Input",
  CellTags->"3.5"],
Cell[470835, 10449, 168, 4, 42, "Output",
  CellTags->"3.5"],
Cell[471006, 10455, 130, 4, 31, "MathCaption",
  CellTags->"3.5"],
Cell[471139, 10461, 141, 5, 48, "Input",
  CellTags->"3.5"],
Cell[471283, 10468, 174, 4, 67, "Output",
  CellTags->"3.5"],
Cell[471460, 10474, 123, 4, 31, "MathCaption",
  CellTags->"3.5"],
Cell[471586, 10480, 147, 6, 66, "Input",
  CellTags->"3.5"],
Cell[471736, 10488, 201, 5, 67, "Output",
  CellTags->"3.5"],
Cell[471940, 10495, 145, 4, 31, "MathCaption",
  CellTags->"3.5"],
Cell[472088, 10501, 133, 5, 48, "Input",
  CellTags->"3.5"],
Cell[472224, 10508, 199, 5, 44, "Output",
  CellTags->"3.5"],
Cell[472426, 10515, 250, 8, 31, "MathCaption",
  CellTags->"3.5"],
Cell[472679, 10525, 170, 8, 102, "Input",
  CellTags->"3.5"],
Cell[472852, 10535, 203, 5, 73, "Output",
  CellTags->"3.5"],
Cell[473058, 10542, 212, 6, 48, "MathCaption",
  CellTags->"3.5"],
Cell[473273, 10550, 107, 2, 30, "Input",
  CellTags->"3.5"],
Cell[473383, 10554, 129, 3, 42, "Output",
  CellTags->"3.5"],
Cell[473515, 10559, 118, 4, 31, "MathCaption",
  CellTags->"3.5"],
Cell[473636, 10565, 99, 2, 30, "Input",
  CellTags->"3.5"],
Cell[473738, 10569, 123301, 3616, 296, 55590, 2774, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"3.5"],
Cell[597042, 14187, 92, 1, 31, "MathCaption",
  CellTags->"3.5"],
Cell[597137, 14190, 155, 6, 66, "Input",
  CellTags->"3.5"],
Cell[597295, 14198, 218, 5, 67, "Output",
  CellTags->"3.5"],
Cell[597516, 14205, 363, 7, 107, "MathCaption",
  CellTags->"3.5"],
Cell[597882, 14214, 206, 12, 174, "Input",
  CellTags->"3.5"],
Cell[598091, 14228, 124621, 3687, 296, 56615, 2842, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"3.5"],
Cell[722715, 17917, 213, 7, 48, "MathCaption",
  CellTags->"3.5"],
Cell[722931, 17926, 179, 8, 102, "Input",
  CellTags->"3.5"],
Cell[723113, 17936, 268, 6, 86, "Output",
  CellTags->"3.5"],
Cell[723384, 17944, 166, 4, 48, "MathCaption",
  CellTags->"3.5"],
Cell[723553, 17950, 208, 12, 174, "Input",
  CellTags->"3.5"],
Cell[723764, 17964, 125084, 3693, 296, 56608, 2842, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"3.5"],
Cell[848851, 21659, 498, 11, 93, "Text",
  CellTags->"3.5"],
Cell[849352, 21672, 134, 5, 41, "MathCaption",
  CellTags->"3.5"],
Cell[849489, 21679, 93, 2, 39, "Input",
  CellTags->"3.5"],
Cell[849585, 21683, 157, 4, 54, "Output",
  CellTags->"3.5"],
Cell[849745, 21689, 124, 4, 40, "MathCaption",
  CellTags->"3.5"],
Cell[849872, 21695, 167, 7, 84, "Input",
  CellTags->"3.5"],
Cell[850042, 21704, 1757, 53, 152, "Output",
  CellTags->"3.5"],
Cell[851802, 21759, 95, 1, 68, "Subsection",
  CellTags->"3.6"],
Cell[851900, 21762, 194, 5, 59, "Text",
  CellTags->"3.6"],
Cell[852097, 21769, 1235, 40, 60, "DisplayFormula",
  CellTags->"3.6"],
Cell[853335, 21811, 1269, 34, 150, "Text",
  CellTags->"3.6"],
Cell[854607, 21847, 661, 21, 69, "DefinitionBox3Col",
  CellTags->"3.6"],
Cell[855271, 21870, 137, 5, 26, "Caption",
  CellTags->"3.6"],
Cell[855411, 21877, 152, 5, 41, "MathCaption",
  CellTags->"3.6"],
Cell[855566, 21884, 115, 2, 54, "Input",
  CellTags->"3.6"],
Cell[855684, 21888, 132, 3, 38, "Output",
  CellTags->"3.6"],
Cell[855819, 21893, 143, 4, 54, "MathCaption",
  CellTags->"3.6"],
Cell[855965, 21899, 117, 2, 54, "Input",
  CellTags->"3.6"],
Cell[856085, 21903, 184, 4, 54, "Output",
  CellTags->"3.6"],
Cell[856272, 21909, 123, 4, 40, "MathCaption",
  CellTags->"3.6"],
Cell[856398, 21915, 129, 5, 54, "Input",
  CellTags->"3.6"],
Cell[856530, 21922, 211, 5, 54, "Output",
  CellTags->"3.6"],
Cell[856744, 21929, 128, 4, 40, "MathCaption",
  CellTags->"3.6"],
Cell[856875, 21935, 120, 2, 54, "Input",
  CellTags->"3.6"],
Cell[856998, 21939, 276, 6, 582, "Output",
  CellTags->"3.6"],
Cell[857277, 21947, 111, 2, 50, "Subsection",
  CellTags->"3.7"],
Cell[857391, 21951, 835, 18, 330, "Text",
  CellTags->"3.7"],
Cell[858229, 21971, 630, 20, 386, "DefinitionBox",
  CellTags->"3.7"],
Cell[858862, 21993, 126, 4, 26, "Caption",
  CellTags->"3.7"],
Cell[858991, 21999, 164, 4, 54, "MathCaption",
  CellTags->"3.7"],
Cell[859158, 22005, 163, 7, 72, "Input",
  CellTags->"3.7"],
Cell[859324, 22014, 279, 6, 72, "Output",
  CellTags->"3.7"],
Cell[859606, 22022, 90, 1, 40, "MathCaption",
  CellTags->"3.7"],
Cell[859699, 22025, 81, 2, 39, "Input",
  CellTags->"3.7"],
Cell[859783, 22029, 233, 5, 93, "Output",
  CellTags->"3.7"],
Cell[860019, 22036, 226, 6, 55, "MathCaption",
  CellTags->"3.7"],
Cell[860248, 22044, 80, 2, 39, "Input",
  CellTags->"3.7"],
Cell[860331, 22048, 134, 3, 38, "Output",
  CellTags->"3.7"],
Cell[860468, 22053, 79, 1, 40, "MathCaption",
  CellTags->"3.7"],
Cell[860550, 22056, 66, 2, 39, "Input",
  CellTags->"3.7"],
Cell[860619, 22060, 158, 4, 54, "Output",
  CellTags->"3.7"],
Cell[860780, 22066, 169, 4, 54, "MathCaption",
  CellTags->"3.7"],
Cell[860952, 22072, 178, 8, 99, "Input",
  CellTags->"3.7"],
Cell[861133, 22082, 419, 9, 153, "Output",
  CellTags->"3.7"],
Cell[861555, 22093, 90, 1, 40, "MathCaption",
  CellTags->"3.7"],
Cell[861648, 22096, 157, 7, 84, "Input",
  CellTags->"3.7"],
Cell[861808, 22105, 158, 4, 54, "Output",
  CellTags->"3.7"],
Cell[861969, 22111, 162, 4, 54, "MathCaption",
  CellTags->"3.7"],
Cell[862134, 22117, 151, 7, 72, "Input",
  CellTags->"3.7"],
Cell[862288, 22126, 332, 7, 118, "Output",
  CellTags->"3.7"],
Cell[862623, 22135, 92, 1, 28, "MathCaption",
  CellTags->"3.7"],
Cell[862718, 22138, 115, 2, 42, "Input",
  CellTags->"3.7"],
Cell[862836, 22142, 158, 4, 42, "Output",
  CellTags->"3.7"],
Cell[862997, 22148, 401, 11, 64, "Text",
  CellTags->"3.7"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

