(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    422788,      10510]*)
(*NotebookOutlinePosition[    436116,      10900]*)
(*  CellTagsIndexPosition[    435888,      10888]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["8. Realizations", "Section",
  CellTags->"8.0"],

Cell["A realization is any pair of equations ", "Text",
  CellTags->"8.0"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{
                OverscriptBox[
                  StyleBox["\<\"x\"\>",
                    "TB"], "."], \((t)\), "=", 
                StyleBox["\<\"A\"\>",
                  "TB"], 
                StyleBox["\<\"x\"\>",
                  "TB"], \((t)\), "+", 
                StyleBox["\<\"B\"\>",
                  "TB"], 
                StyleBox["\<\"u\"\>",
                  "TB"], \((t)\)}],
              "DisplayFormula"]},
          {
            StyleBox[
              RowBox[{
                StyleBox["\<\"y\"\>",
                  "TB"], \((t)\), "=", 
                StyleBox["\<\"C\"\>",
                  "TB"], 
                StyleBox["\<\"x\"\>",
                  "TB"], \((t)\), "+", 
                StyleBox["\<\"D\"\>",
                  "TB"], 
                StyleBox["\<\"u\"\>",
                  "TB"], \((t)\)}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right}], TraditionalForm]], "DisplayFormula",
  CellTags->"8.0"],

Cell[TextData[{
  "or the corresponding quadruple of the matrices ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            StyleBox["\<\"A\"\>",
              "TB"], ",", 
            StyleBox["\<\"B\"\>",
              "TB"], ",", 
            StyleBox["\<\"C\"\>",
              "TB"], ",", 
            StyleBox["\<\"D\"\>",
              "TB"]}], "}"}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  ", or, for the purposes of this guide, the corresponding \
state\[Hyphen]space object ",
  StyleBox["StateSpace[a,", "MR"],
  " ",
  StyleBox["b,", "MR"],
  " ",
  StyleBox["c,", "MR"],
  " ",
  StyleBox["d]", "MR"],
  " that leads to the required input\[Hyphen]output relations for the system \
(usually specified as a transfer function matrix ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"H\"\>",
            "TB"], \((s)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.1"],
  "). A realization can also refer to a discrete\[Hyphen]time \
state\[Hyphen]space realization (with the obvious change from the \
differential to difference in the equations). Because there can be \
innumerable ways to satisfy the input\[Hyphen]output relations, a physical \
system can have an infinite number of realizations. In this chapter, several \
means of converting between different realizations are described, including \
means of obtaining realizations of a smaller order. All the functions operate \
on continuous\[Hyphen] and discrete\[Hyphen]time objects. \nThe first group \
of functions represents the means to convert between different types of \
realizations.  By convention, their names end with ",
  StyleBox["Form", "MR"],
  ". For example, to convert a system to Kalman controllable form, the \
function ",
  StyleBox["KalmanControllableForm", "MR"],
  " would be applied to the system. The list of all forms available in ",
  StyleBox["Control System Professional", "TI"],
  " can be obtained with ",
  StyleBox["?ControlSystems`*`*Form", "MR"],
  ". \nThe other group comprises functions that select a subsystem (typically \
a subspace) possessing certain properties. These functions end with ",
  StyleBox["Subsystem", "MR"],
  " (",
  StyleBox["e.g.", "TI"],
  ", ",
  StyleBox["ControllableSubsystem", "MR"],
  " or ",
  StyleBox["DominantSubsystem", "MR"],
  "). The exception to this convention is ",
  StyleBox["MinimalRealization", "MR"],
  ", used for computing a minimal realization, which represents the \
intersection of the controllable and observable subspaces; therefore, this \
function does effectively select a subsystem. Also introduced is ",
  StyleBox["SimilarityTransform", "MR"],
  ", a function that transforms between equivalent realizations of the same \
system. "
}], "Text",
  CellTags->"8.0"],

Cell[CellGroupData[{

Cell["8.1 Irreducible (Minimal) Realizations", "Subsection",
  CellTags->"8.1"],

Cell[TextData[{
  "The internal structure of a system may allow some of the integrators (or \
delay elements) to be shared by several input\[Hyphen]output pairs and still \
result in the same transfer matrix. The system that realizes the maximum \
possible degree of sharing (and, consequently, the smallest possible \
dimension of the associated state space) is called the irreducible (or \
minimal) realization (see, ",
  StyleBox["e.g.", "TI"],
  ", Brogan (1991), Section\[NonBreakingSpace]12.4). The function ",
  StyleBox["MinimalRealization", "MR"],
  " tries to find such a realization. "
}], "Text",
  CellTags->"8.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["MinimalRealization",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"8.1"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["a",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["minimal",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["realization",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["for",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"8.1"],

Cell["Finding the irreducible (minimal) realization. ", "Caption",
  CellTags->"8.1"],

Cell[TextData[{
  "The input system for ",
  StyleBox["MinimalRealization", "MR"],
  " can be in either state\[Hyphen] space or transfer function form. For SISO \
transfer function systems, pole\[Hyphen]zero cancellation is attempted. \
Otherwise, ",
  StyleBox["MinimalRealization", "MR"],
  " uses the Kalman canonical forms to find a minimal realization in the \
state space. The result is a subsystem that is both completely observable and \
controllable. Implementationally, identification of the observable subsystem \
is attempted first and then the controllable subsystem of the result is \
sought. A message is generated if the process does not result in a system of \
a smaller dimension. The intermediary functions used in either case are \
directly accessible by the user, and thus ",
  StyleBox["MinimalRealization", "MR"],
  " provides a high\[Hyphen]level interface to these routines.     "
}], "Text",
  CellTags->"8.1"],

Cell["Load the application. ", "MathCaption",
  CellTags->"8.1"],

Cell["<<ControlSystems`", "Input",
  CellLabel->"In[1]:=",
  CellTags->"8.1"],

Cell["\<\
Consider a third\[Hyphen]order state\[Hyphen]space system with two \
inputs and two outputs. The first mode is uncontrollable, and the second one \
is unobservable. These modes, then, have no effect on the \
input\[Hyphen]output relations and so can be dropped without changing the \
transfer function. \
\>", "MathCaption",
  CellTags->"8.1"],

Cell[CellGroupData[{

Cell["\<\
(ss = StateSpace[
 DiagonalMatrix[{a1, a2, a3}],
 {{0, 0}, {b1, 0}, {0, b2}},
 {{c1, 0, 0}, {0, 0, c3}},
 {{d11, d12}, {d21, d22}}]
)//ReviewForm\
\>", "Input",
  CellLabel->"In[2]:= ",
  CellTags->"8.1"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"a1", "0", "0"},
                  {"0", "a2", "0"},
                  {"0", "0", "a3"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "0"},
                  {"b1", "0"},
                  {"0", "b2"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"c1", "0", "0"},
                  {"0", "0", "c3"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"d11", "d12"},
                  {"d21", "d22"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[2]//ReviewForm= ",
  CellTags->"8.1"]
}, Open  ]],

Cell["We can verify that this system is not controllable. ", "MathCaption",
  CellTags->"8.1"],

Cell[CellGroupData[{

Cell["Controllable[ss]", "Input",
  CellLabel->"In[3]:= ",
  CellTags->"8.1"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[3]= ",
  CellTags->"8.1"]
}, Open  ]],

Cell["Neither is it observable. ", "MathCaption",
  CellTags->"8.1"],

Cell[CellGroupData[{

Cell["Observable[ss]", "Input",
  CellLabel->"In[4]:= ",
  CellTags->"8.1"],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[4]= ",
  CellTags->"8.1"]
}, Open  ]],

Cell["\<\
This finds a minimal realization. Note that only the third mode \
remains in the result. \
\>", "MathCaption",
  CellTags->"8.1"],

Cell[CellGroupData[{

Cell["MinimalRealization[ss]//ReviewForm", "Input",
  CellLabel->"In[5]:= ",
  CellTags->"8.1"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox["a3",
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "b2"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0"},
                  {"c3"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"d11", "d12"},
                  {"d21", "d22"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[5]//ReviewForm= ",
  CellTags->"8.1"]
}, Open  ]],

Cell["Now the realization is both controllable and observable. ", 
  "MathCaption",
  CellTags->"8.1"],

Cell[CellGroupData[{

Cell["Controllable[%] == Observable[%] == True", "Input",
  CellLabel->"In[6]:= ",
  CellTags->"8.1"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[6]= ",
  CellTags->"8.1"]
}, Open  ]],

Cell[TextData[{
  "As an interface function, ",
  StyleBox["MinimalRealization", "MR"],
  " inherits options from its constituents\n",
  StyleBox["ControllableSubsystem", "MR"],
  " and ",
  StyleBox["ObservableSubsystem", "MR"],
  " or ",
  StyleBox["PoleZeroCancel", "MR"],
  ", whichever is applicable. "
}], "Text",
  CellTags->"8.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.2 Kalman Canonical Forms", "Subsection",
  CellTags->"8.2"],

Cell[TextData[{
  "The state equations can be transformed to the Kalman controllable \
canonical form (see, ",
  StyleBox["e.g.", "TI"],
  ", Brogan (1991), Section\[NonBreakingSpace]11.7), "
}], "Text",
  CellTags->"8.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{"[", GridBox[{
                    {
                      StyleBox[
                        SubscriptBox[
                          OverscriptBox[
                            StyleBox["\<\"w\"\>",
                              "TB"], "."], "1"],
                        "DisplayFormula"]},
                    {
                      StyleBox[
                        SubscriptBox[
                          OverscriptBox[
                            StyleBox["\<\"w\"\>",
                              "TB"], "."], "2"],
                        "DisplayFormula"]}
                    },
                  ColumnAlignments->{Center}], "]"}],
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            RowBox[{"[", 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubsuperscriptBox[
                            StyleBox["\<\"T\"\>",
                              "TB"], "1", "T"], 
                          SubscriptBox[
                            StyleBox["\<\"AT\"\>",
                              "TB"], "1"]}],
                        "DisplayFormula"], 
                      StyleBox[
                        RowBox[{
                          SubsuperscriptBox[
                            StyleBox["\<\"T\"\>",
                              "TB"], "1", "T"], 
                          SubscriptBox[
                            StyleBox["\<\"AT\"\>",
                              "TB"], "2"]}],
                        "DisplayFormula"]},
                    {
                      StyleBox["\<\"0\"\>",
                        "TB"], 
                      StyleBox[
                        RowBox[{
                          SubsuperscriptBox[
                            StyleBox["\<\"T\"\>",
                              "TB"], "2", "T"], 
                          SubscriptBox[
                            StyleBox["\<\"AT\"\>",
                              "TB"], "2"]}],
                        "DisplayFormula"]}
                    },
                  ColumnAlignments->{Center}],
                "DisplayFormula"], 
              StyleBox["]",
                "DisplayFormula"]}], 
            StyleBox[
              RowBox[{"[", GridBox[{
                    {
                      StyleBox[
                        SubscriptBox[
                          StyleBox["\<\"w\"\>",
                            "TB"], "1"],
                        "DisplayFormula"]},
                    {
                      StyleBox[
                        SubscriptBox[
                          StyleBox["\<\"w\"\>",
                            "TB"], "2"],
                        "DisplayFormula"]}
                    },
                  ColumnAlignments->{Center}], "]"}],
              "DisplayFormula"], 
            StyleBox["+",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{"[", GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubsuperscriptBox[
                            StyleBox["\<\"T\"\>",
                              "TB"], "1", "T"], 
                          StyleBox["\<\"B\"\>",
                            "TB"]}],
                        "DisplayFormula"]},
                    {
                      StyleBox["\<\"0\"\>",
                        "TB"]}
                    },
                  ColumnAlignments->{Center}], "]"}],
              "DisplayFormula"], 
            StyleBox["\<\"u\"\>",
              "TB"]},
          {
            StyleBox["y",
              FontWeight->"Bold",
              FontSlant->"Plain"], "=", 
            RowBox[{
              RowBox[{"[", GridBox[{
                    {
                      StyleBox[
                        SubscriptBox[
                          StyleBox["\<\"CT\"\>",
                            "TB"], "1"],
                        "DisplayFormula"], 
                      StyleBox[
                        SubscriptBox[
                          StyleBox["\<\"CT\"\>",
                            "TB"], "2"],
                        "DisplayFormula"]}
                    },
                  ColumnAlignments->{Center}], "]"}], 
              StyleBox[" ",
                "DisplayFormula"]}], 
            StyleBox[
              RowBox[{"[", GridBox[{
                    {
                      StyleBox[
                        SubscriptBox[
                          StyleBox["\<\"w\"\>",
                            "TB"], "1"],
                        "DisplayFormula"]},
                    {
                      StyleBox[
                        SubscriptBox[
                          StyleBox["\<\"w\"\>",
                            "TB"], "2"],
                        "DisplayFormula"]}
                    },
                  ColumnAlignments->{Center}], "]"}],
              "DisplayFormula"], "+", 
            StyleBox["D",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["u",
              FontWeight->"Bold",
              FontSlant->"Plain"]}
          },
        ColumnAlignments->{
          Center, Center, Center, Center, Center, Center, Center, Left}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->"8.2"],

Cell[TextData[{
  "using a similarity transform ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"x\"\>",
            "TB"], "=", 
          RowBox[{
            StyleBox["\<\"T\"\>",
              "TB"], " ", 
            StyleBox["\<\"w\"\>",
              "TB"]}]}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  ", where the orthogonal transform matrix ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"T\"\>",
            "TB"], "=", 
          RowBox[{"[", GridBox[{
                {
                  StyleBox[
                    SubscriptBox[
                      StyleBox["\<\"T\"\>",
                        "TB"], "1"],
                    "InlineFormula"], 
                  StyleBox[
                    SubscriptBox[
                      StyleBox["\<\"T\"\>",
                        "TB"], "2"],
                    "InlineFormula"]}
                },
              ColumnAlignments->{Center}], "]"}]}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S0.0.3"],
  " is constucted and partitioned in such a way that ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\<\"T\"\>",
            "TB"], "1"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " represents the subspace spanned by the columns of the controllability \
matrix and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\<\"T\"\>",
            "TB"], "2"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " is the subspace orthogonal to ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\<\"T\"\>",
            "TB"], "1"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  ". The space vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"w\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " is partitioned into two corresponding parts, too: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\<\"w\"\>",
            "TB"], "=", 
          RowBox[{"[", GridBox[{
                {
                  StyleBox[
                    SubscriptBox[
                      StyleBox["\<\"w\"\>",
                        "TB"], "1"],
                    "InlineFormula"]},
                {
                  StyleBox[
                    SubscriptBox[
                      StyleBox["\<\"w\"\>",
                        "TB"], "2"],
                    "InlineFormula"]}
                },
              ColumnAlignments->{Center}], "]"}], "."}], TraditionalForm]], 
    "InlineFormula",
    CellTags->"S0.0.3"],
  " It is seen from the above equations that state variables ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\<\"w\"\>",
            "TB"], "2"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " are uncontrollable, since there is no way to change ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\<\"w\"\>",
            "TB"], "2"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " either directly through input ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"u\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " or indirectly through ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\<\"w\"\>",
            "TB"], "1"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " coupling.  \nSimilarly, in the Kalman observable canonical form,  "
}], "Text",
  CellTags->"8.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{"[", GridBox[{
                    {
                      StyleBox[
                        SubscriptBox[
                          OverscriptBox[
                            StyleBox["\<\"v\"\>",
                              "TB"], "."], "1"],
                        "DisplayFormula"]},
                    {
                      StyleBox[
                        SubscriptBox[
                          OverscriptBox[
                            StyleBox["\<\"v\"\>",
                              "TB"], "."], "2"],
                        "DisplayFormula"]}
                    },
                  ColumnAlignments->{Center}], "]"}],
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            RowBox[{"[", 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubsuperscriptBox[
                            StyleBox["\<\"V\"\>",
                              "TB"], "1", "T"], 
                          SubscriptBox[
                            StyleBox["\<\"AV\"\>",
                              "TB"], "1"]}],
                        "DisplayFormula"], 
                      StyleBox["0",
                        FontWeight->"Bold"]},
                    {
                      StyleBox[
                        RowBox[{
                          SubsuperscriptBox[
                            StyleBox["\<\"V\"\>",
                              "TB"], "2", "T"], 
                          SubscriptBox[
                            StyleBox["\<\"AV\"\>",
                              "TB"], "1"]}],
                        "DisplayFormula"], 
                      StyleBox[
                        RowBox[{
                          SubsuperscriptBox[
                            StyleBox["\<\"V\"\>",
                              "TB"], "2", "T"], 
                          SubscriptBox[
                            StyleBox["\<\"AV\"\>",
                              "TB"], "2"]}],
                        "DisplayFormula"]}
                    },
                  ColumnAlignments->{Center}],
                "DisplayFormula"], 
              StyleBox["]",
                "DisplayFormula"]}], 
            StyleBox[
              RowBox[{"[", GridBox[{
                    {
                      StyleBox[
                        SubscriptBox[
                          StyleBox["\<\"v\"\>",
                            "TB"], "1"],
                        "DisplayFormula"]},
                    {
                      StyleBox[
                        SubscriptBox[
                          StyleBox["\<\"v\"\>",
                            "TB"], "2"],
                        "DisplayFormula"]}
                    },
                  ColumnAlignments->{Center}], "]"}],
              "DisplayFormula"], 
            StyleBox["+",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{"[", GridBox[{
                    {
                      StyleBox[
                        RowBox[{
                          SubsuperscriptBox[
                            StyleBox["\<\"V\"\>",
                              "TB"], "1", "T"], 
                          StyleBox["\<\"B\"\>",
                            "TB"]}],
                        "DisplayFormula"]},
                    {
                      StyleBox[
                        RowBox[{
                          SubsuperscriptBox[
                            StyleBox["\<\"V\"\>",
                              "TB"], "2", "T"], 
                          StyleBox["\<\"B\"\>",
                            "TB"]}],
                        "DisplayFormula"]}
                    },
                  ColumnAlignments->{Center}], "]"}],
              "DisplayFormula"], 
            StyleBox["\<\"u\"\>",
              "TB"]},
          {
            StyleBox["y",
              SingleLetterItalics->False,
              FontWeight->"Bold"], 
            StyleBox["=",
              SingleLetterItalics->False], 
            RowBox[{
              StyleBox["[",
                SingleLetterItalics->False], 
              StyleBox[GridBox[{
                    {
                      StyleBox[
                        SubscriptBox[
                          StyleBox["\<\"CV\"\>",
                            "TB"], "1"],
                        "DisplayFormula"], 
                      StyleBox["0",
                        FontWeight->"Bold"]}
                    },
                  ColumnAlignments->{Center}],
                "DisplayFormula",
                SingleLetterItalics->False], 
              StyleBox["]",
                "DisplayFormula",
                SingleLetterItalics->False]}], 
            StyleBox[
              RowBox[{"[", GridBox[{
                    {
                      StyleBox[
                        SubscriptBox[
                          StyleBox["\<\"v\"\>",
                            "TB"], "1"],
                        "DisplayFormula"]},
                    {
                      StyleBox[
                        SubscriptBox[
                          StyleBox["\<\"v\"\>",
                            "TB"], "2"],
                        "DisplayFormula"]}
                    },
                  ColumnAlignments->{Center}], "]"}],
              "DisplayFormula"], 
            StyleBox["+",
              "DisplayFormula"], 
            StyleBox["\<\"D\"\>",
              "TB"], 
            StyleBox["\<\"u\"\>",
              "TB"]}
          },
        ColumnAlignments->{
          Center, Center, Center, Center, Center, Center, Center, Left}], 
      TraditionalForm]], "DisplayFormula",
  CellTags->"8.2"],

Cell[TextData[{
  "the state space is divided into observable ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\<\"v\"\>",
            "TB"], "1"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " and unobservable ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["\<\"v\"\>",
            "TB"], "2"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.3"],
  " subspaces. Kalman controllable and observable canonical forms can be \
arrived at by using the functions ",
  StyleBox["KalmanControllableForm", "MR"],
  " and ",
  StyleBox["KalmanObservableForm", "MR"],
  ".   "
}], "Text",
  CellTags->"8.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["KalmanControllableForm",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"8.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Kalman",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["controllable",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["canonical",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["form",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"8.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["KalmanObservableForm",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"8.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Kalman",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["observable",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["canonical",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["form",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"8.2"],

Cell["Finding Kalman canonical forms. ", "Caption",
  CellTags->"8.2"],

Cell["\<\
This is the Kalman controllable canonical form of an example system \
defined previously. We can see that the uncontrollable mode (the third one) \
is moved to the end of the state vector. \
\>", "MathCaption",
  CellTags->"8.2"],

Cell[CellGroupData[{

Cell["KalmanControllableForm[ss]//ReviewForm", "Input",
  CellLabel->"In[7]:= ",
  CellTags->"8.2"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"a2", "0", "0"},
                  {"0", "a3", "0"},
                  {"0", "0", "a1"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"b1", "0"},
                  {"0", "b2"},
                  {"0", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "0", "c1"},
                  {"0", "c3", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"d11", "d12"},
                  {"d21", "d22"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[7]//ReviewForm= ",
  CellTags->"8.2"]
}, Open  ]],

Cell["\<\
This is the Kalman observable canonical form of the same system. \
Now the unobservable mode (the second one) is moved to the end. \
\>", 
  "MathCaption",
  CellTags->"8.2"],

Cell[CellGroupData[{

Cell["KalmanObservableForm[ss]//ReviewForm", "Input",
  CellLabel->"In[8]:= ",
  CellTags->"8.2"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"a1", "0", "0"},
                  {"0", "a3", "0"},
                  {"0", "0", "a2"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "0"},
                  {"0", "b2"},
                  {"b1", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"c1", "0", "0"},
                  {"0", "c3", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"d11", "d12"},
                  {"d21", "d22"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[8]//ReviewForm= ",
  CellTags->"8.2"]
}, Open  ]],

Cell[TextData[{
  "Similar to the functions ",
  StyleBox["KalmanControllableForm", "MR"],
  " and ",
  StyleBox["KalmanObservableForm", "MR"],
  " are the functions ",
  StyleBox["ControllableSubsystem", "MR"],
  " and ",
  StyleBox["ObservableSubsystem", "MR"],
  ". The difference between the two types of functions is that the former \
merely rearranges the order of variables in the state vector, whereas the \
latter ",
  StyleBox["selects", "TI"],
  " controllable or observable subspaces of the given system. These functions \
share the same computational engine and set of options. In addition to the \
options related to the Kalman transform, ",
  StyleBox["KalmanObservableForm", "MR"],
  " and ",
  StyleBox["ObservableSubsystem", "MR"],
  " also accept the options pertinent to ",
  StyleBox["Dual", "MR"],
  ".  "
}], "Text",
  CellTags->"8.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ControllableSubsystem",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"8.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["select",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["controllable",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["subspace",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "MiddleBox",
  GeneratedCell->True,
  CellTags->"8.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["ObservableSubsystem",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "MiddleSpanBox",
  GeneratedCell->True,
  CellTags->"8.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["select",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["observable",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["subspace",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"8.2"],

Cell["Selecting controllable and observable subspaces. ", "Caption",
  CellTags->"8.2"],

Cell["This selects the controllable subspace. ", "MathCaption",
  CellTags->"8.2"],

Cell[CellGroupData[{

Cell["ControllableSubsystem[ss]//ReviewForm", "Input",
  CellLabel->"In[9]:= ",
  CellTags->"8.2"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"a2", "0"},
                  {"0", "a3"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"b1", "0"},
                  {"0", "b2"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "0"},
                  {"0", "c3"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"d11", "d12"},
                  {"d21", "d22"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[9]//ReviewForm= ",
  CellTags->"8.2"]
}, Open  ]],

Cell["This selects the observable subspace. ", "MathCaption",
  CellTags->"8.2"],

Cell[CellGroupData[{

Cell["ObservableSubsystem[ss]//ReviewForm", "Input",
  CellLabel->"In[10]:= ",
  CellTags->"8.2"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"a1", "0"},
                  {"0", "a3"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "0"},
                  {"0", "b2"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"c1", "0"},
                  {"0", "c3"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"d11", "d12"},
                  {"d21", "d22"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[10]//ReviewForm= ",
  CellTags->"8.2"]
}, Open  ]],

Cell["\<\
By selecting the controllable subspace of the observable subspace, \
we arrive at a minimal realization. \
\>", "MathCaption",
  CellTags->"8.2"],

Cell[CellGroupData[{

Cell["ControllableSubsystem[%]//ReviewForm", "Input",
  CellLabel->"In[11]:= ",
  CellTags->"8.2"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox["a3",
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "b2"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0"},
                  {"c3"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"d11", "d12"},
                  {"d21", "d22"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[11]//ReviewForm= ",
  CellTags->"8.2"]
}, Open  ]],

Cell[TextData[{
  "The decomposition into controllable and uncontrollable (or observable and \
unobservable) subspaces can be performed using several methods that are \
accessible through the option ",
  StyleBox["DecompositionMethod", "MR"],
  ". The default ",
  StyleBox["Automatic", "MR"],
  " value for this option invokes the built\[Hyphen]in function ",
  StyleBox["RowReduce", "MR"],
  " for exact systems and ",
  StyleBox["SingularValues", "MR"],
  " for inexact ones. Other currently available option values are ",
  StyleBox["QRDecomposition", "MR"],
  " and ",
  StyleBox["NullSpace", "MR"],
  ". Like all other functions in ",
  StyleBox["Control System Professional", "TI"],
  ", the functions related to Kalman canonical forms accept the options \
belonging to the method employed and pass them on to their destinations. \
Kalman decomposition\[Hyphen]related functions also accept the option ",
  StyleBox["RandomOrthogonalComplement", "MR"],
  ".    "
}], "Text",
  CellTags->"8.2"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], " "},
          {
            StyleBox[
              FormBox["DecompositionMethod",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(method\ to\ find\ the\ controllable\ or\ observable\ subspace
                \),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.33, 0.3, 0.37},
  RowLines->{True, False}},
  CellTags->"8.2"],

Cell["\<\
Option specific to functions related to the Kalman canonical forms. \
\
\>", "Caption",
  CellTags->"8.2"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.3 Jordan Canonical (Modal) Form", "Subsection",
  CellTags->"8.3"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["JordanCanonicalForm",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"8.3"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["Jordan",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["canonical",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["form",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"8.3"],

Cell["Finding the Jordan canonical form. ", "Caption",
  CellTags->"8.3"],

Cell["Let us create a diagonal matrix. ", "MathCaption",
  CellTags->"8.3"],

Cell[CellGroupData[{

Cell["m = DiagonalMatrix[{-1, -2, -3}]", "Input",
  CellLabel->"In[12]:= ",
  CellTags->"8.3"],

Cell[BoxData[
    \({{\(-1\), 0, 0}, {0, \(-2\), 0}, {0, 0, \(-3\)}}\)], "Output",
  CellLabel->"Out[12]= ",
  CellTags->"8.3"]
}, Open  ]],

Cell["Here is some nonsingular matrix. ", "MathCaption",
  CellTags->"8.3"],

Cell[CellGroupData[{

Cell["t = {{0, 1, 0}, {-1, 0, -1}, {1, -1, 0}}", "Input",
  CellLabel->"In[13]:= ",
  CellTags->"8.3"],

Cell[BoxData[
    \({{0, 1, 0}, {\(-1\), 0, \(-1\)}, {1, \(-1\), 0}}\)], "Output",
  CellLabel->"Out[13]= ",
  CellTags->"8.3"]
}, Open  ]],

Cell["\<\
This creates a matrix with the predefined set of eigenvalues. \
\>",
   "MathCaption",
  CellTags->"8.3"],

Cell[CellGroupData[{

Cell["Inverse[t] . m . t", "Input",
  CellLabel->"In[14]:= ",
  CellTags->"8.3"],

Cell[BoxData[
    \({{\(-3\), 2, 0}, {0, \(-1\), 0}, {1, \(-2\), \(-2\)}}\)], "Output",
  CellLabel->"Out[14]= ",
  CellTags->"8.3"]
}, Open  ]],

Cell[TextData[{
  "We use the previous matrix as matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"A\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.4"],
  " in our test state\[Hyphen]space object ",
  StyleBox["ss", "MR"],
  ". "
}], "MathCaption",
  CellTags->"8.3"],

Cell[CellGroupData[{

Cell["ReplacePart[ss, %, 1]//ReviewForm", "Input",
  CellLabel->"In[15]:= ",
  CellTags->"8.3"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(-3\), "2", "0"},
                  {"0", \(-1\), "0"},
                  {"1", \(-2\), \(-2\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "0"},
                  {"b1", "0"},
                  {"0", "b2"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"c1", "0", "0"},
                  {"0", "0", "c3"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"d11", "d12"},
                  {"d21", "d22"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[15]//ReviewForm= ",
  CellTags->"8.3"]
}, Open  ]],

Cell["\<\
This finds the Jordan canonical form of the preceding system. \
\>",
   "MathCaption",
  CellTags->"8.3"],

Cell[CellGroupData[{

Cell["JordanCanonicalForm[%]//ReviewForm", "Input",
  CellLabel->"In[16]:= ",
  CellTags->"8.3"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(-3\), "0", "0"},
                  {"0", \(-2\), "0"},
                  {"0", "0", \(-1\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"b1", "0"},
                  {"0", "b2"},
                  {\(-b1\), "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(-c1\), "0", \(-c1\)},
                  {"c3", "c3", "c3"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"d11", "d12"},
                  {"d21", "d22"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[16]//ReviewForm= ",
  CellTags->"8.3"]
}, Open  ]],

Cell[TextData[{
  "In the case of an exact input system, ",
  StyleBox["JordanCanonicalForm", "MR"],
  " relies on the built\[Hyphen]in function \n",
  StyleBox["JordanDecomposition", "MR"],
  "; otherwise the eigenvalue  decomposition is used. The latter method may \
lead to significant numerical errors if eigenvalues happen to be multiple.  "
}], "Text",
  CellTags->"8.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.4 Internally Balanced Realizations", "Subsection",
  CellTags->"8.4"],

Cell[TextData[{
  "The Kalman minimal realization algorithm may result in structurally \
unstable  models. In such cases another model reduction technique, based on \
the ",
  StyleBox["internally balanced", "TI"],
  " realization, may be applied (Moore (1981)). The controllable and \
observable realization is said to be internally balanced if its \
controllability and observability Gramians are represented by the same \
(positive definite) diagonal matrix. ",
  StyleBox["InternallyBalancedForm", "MR"],
  " attempts to construct such a realization. "
}], "Text",
  CellTags->"8.4"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["InternallyBalancedForm",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["statespace",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"8.4"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["find",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["internally",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["balanced",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["realization",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["of",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"8.4"],

Cell["Finding the internally balanced form. ", "Caption",
  CellTags->"8.4"],

Cell["\<\
Consider a SISO system in its controllable canonical form (see \
Example\[NonBreakingSpace]1 in the above\[Hyphen]cited paper of Moore \
(1981)). Evidently, the realization is poorly balanced. \
\>", "MathCaption",
  CellTags->"8.4"],

Cell[CellGroupData[{

Cell["\<\
(original = StateSpace[
   {{0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1},
   {-50, -79, -33, -5}}, {{0}, {0}, {0}, {1}},
   {{50, 15, 1, 0}}] //N
) //ReviewForm\
\>", "Input",
  CellLabel->"In[17]:= ",
  CellTags->"8.4"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "1.`", "0", "0"},
                  {"0", "0", "1.`", "0"},
                  {"0", "0", "0", "1.`"},
                  {\(-50.`\), \(-79.0000000000000035`\), 
                    \(-32.9999999999999982`\), \(-5.`\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0"},
                  {"0"},
                  {"0"},
                  {"1.`"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"50.`", "15.`", "1.`", "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[17]//ReviewForm= ",
  CellTags->"8.4"]
}, Open  ]],

Cell["This finds the internally balanced realization. ", "MathCaption",
  CellTags->"8.4"],

Cell[CellGroupData[{

Cell["balanced = InternallyBalancedForm[%]", "Input",
  CellLabel->"In[18]:= ",
  CellTags->"8.4"],

Cell[BoxData[
    \(StateSpace[{{\(-0.518281875293597771`\), 1.45031071555571999`, 
          0.391097991454766322`, 0.350053647978135629`}, {
          \(-1.45031071555578421`\), \(-2.19538943171496336`\), 
          \(-4.75333902189908563`\), \(-1.21804683821583603`\)}, {
          0.391097991454749305`, 4.75333902189904478`, 
          \(-0.629678710241224237`\), \(-1.19628291181103962`\)}, {
          \(-0.350053647978145754`\), \(-1.21804683821586801`\), 
          1.1962829118110141`, \(-1.65664998275021506`\)}}, {{
          0.772914654689759306`}, {0.804697405836113865`}, {
          \(-0.337348487340045544`\)}, {0.252315576977423905`}}, {{
          0.77291465468975451`, \(-0.804697405836098056`\), 
          \(-0.337348487340056069`\), \(-0.252315576977423994`\)}}]\)], 
  "Output",
  CellLabel->"Out[18]= ",
  CellTags->"8.4"]
}, Open  ]],

Cell["\<\
We can verify that the realization returned has equal and diagonal \
controllability and observability Gramians. \
\>", "MathCaption",
  CellTags->"8.4"],

Cell[CellGroupData[{

Cell["ControllabilityGramian[%]//Chop", "Input",
  CellLabel->"In[19]:= ",
  CellTags->"8.4"],

Cell[BoxData[
    \({{0.576324478929320793`, 0, 0, 0}, {0, 0.1474767769227957`, 0, 0}, {0, 
        0, 0.0903667219962242818`, 0}, {0, 0, 0, 0.0192144240027588573`}}\)], 
  "Output",
  CellLabel->"Out[19]= ",
  CellTags->"8.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ObservabilityGramian[%%]//Chop", "Input",
  CellLabel->"In[20]:= ",
  CellTags->"8.4"],

Cell[BoxData[
    \({{0.576324478929329142`, 0, 0, 0}, {0, 0.147476776922788737`, 0, 0}, {
        0, 0, 0.0903667219962176204`, 0}, {0, 0, 0, 0.0192144240027577151`}}
      \)], "Output",
  CellLabel->"Out[20]= ",
  CellTags->"8.4"]
}, Open  ]],

Cell["\<\
Finally, we can see that the two forms are in fact different \
realizations of the same transfer function. \
\>", "MathCaption",
  CellTags->"8.4"],

Cell[CellGroupData[{

Cell["TransferFunction[s, original]//Chop", "Input",
  CellLabel->"In[21]:= ",
  CellTags->"8.4"],

Cell[BoxData[
    \(TransferFunction[
      s, {{\(\(50.`\[InvisibleSpace]\) + 15.`\ s + 1.`\ s\^2\)\/\(\(50.`
              \[InvisibleSpace]\) + 79.0000000000000035`\ s + 
              32.9999999999999982`\ s\^2 + 5.`\ s\^3 + s\^4\)}}]\)], "Output",\

  CellLabel->"Out[21]= ",
  CellTags->"8.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell["TransferFunction[s, balanced]//Chop", "Input",
  CellLabel->"In[22]:= ",
  CellTags->"8.4"],

Cell[BoxData[
    \(TransferFunction[
      s, {{\(\(49.9999999999995559`\[InvisibleSpace]\) + 
              14.9999999999998623`\ s + 
              0.99999999999999396`\ s\^2\)\/\(\(49.9999999999997513`
              \[InvisibleSpace]\) + 78.9999999999999591`\ s + 
              33.0000000000000293`\ s\^2 + 5.00000000000000088`\ s\^3 + 
              s\^4\)}}]\)], "Output",
  CellLabel->"Out[22]= ",
  CellTags->"8.4"]
}, Open  ]],

Cell[TextData[{
  "The controllability and observability Gramians in the preceding example \
reveal the modes that are ",
  StyleBox["relatively small", "TI"],
  " and, therefore, contribute little to the input\[Hyphen]output \
characteristic. This suggests a way of reducing the order of the system by \
eliminating these weak modes. What is meant by \"relatively small\" is, of \
course, a matter of convention and will be addressed in the context of the \
option ",
  StyleBox["RejectionLevel", "MR"],
  " later in this section. \nSchematically, the system breaks up into \
dominant and weak subsystems connected as shown in \
Figure\[NonBreakingSpace]8.1. ",
  StyleBox["DominantSubsystem", "MR"],
  " can be used to select the dominant part.    \n",
  Cell["", "Message",
    GeneratedCell->False,
    CellAutoOverwrite->False,
    CellTags->"S0.0.5"],
  "   "
}], "Text",
  CellTags->"8.4"],

Cell[GraphicsData["PostScript", "\<\
%!PS-Adobe-2.0 EPSF-1.2
%%BoundingBox: 47 4 375 140
%%HiResBoundingBox: 47 4 375 140
%%Creator: (Mathematica Macintosh 3.0)
%%Title: Clipboard
%%CreationDate: (Friday, January 31, 1997) (10:45:22 AM)
%%DocumentNeededResources: (atend)
%%DocumentFonts: (atend)
%%DocumentNeededFonts: (atend)
%%EndComments
0 144 translate 1 -1 scale
gsave
47 140 translate
328 -136 scale
1 string
1303 540 1 [1303 0 0 540 0 0] {
 currentfile
  1 index
   readhexstring
    pop
    } image
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
0000000000000000000000000000000000000000000000007FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
0000000000000000000000000000000000000000000000003FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
0000000000000000000000000000000000000000000000007FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
0000000000000000000000000000000000000000000000003FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE055555555555555555555555555555555
5555555555555555555555555555555555555555555555507FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFDFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFBFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC17FFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF80BFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC0017FFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
00000000000000000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE0002FFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
00000000000000000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000000000
000000000000000000000005FFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
00000000000000000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000000000000000
000000000000000000000000BFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
00000000000000000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000000000
0000000000000000000000000161FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
00000000000000000000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800000000000000000
00000000000000000000000002A1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00000000000000000
00000000000000000000000017E1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80AAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAA00000BFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC00007FFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF8003FFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF005FFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFF8DFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE2FFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF57FFFFFFFFE1FFFFFFFFFFFFF7FDFFF5FD75F5757F75
FF77F757D57FE7FD7F57F5F575757FFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFF3FEFFE0F830E0E0FF8A
FA3AFB23E23FEFE2BF07A0F83070FFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFF3FCFF81104070E1FF1E
78407071C79FC7E7CF11057070707FFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFE3FCFF87F8F0F0E3FFBE
38F8F8F8EF8FC3EFCE1F0FB8F8F8FFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFC1F87F07F070F0C1FF7C
307070705F0FC3EF061E0FF070707FFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFE3F87F0FF8F0F083FFF8
38F8F8F8FE0F83FE0E1E1FF8F8F8FFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFC1F07F0FFC70F007FFC0
70707078701F05FC0E1E1FF070707FFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFF80F83F0ABF80F00FFFC0
F8F8F8F8603F8DF81E1E0AB8F8F8FFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFF80701F051DE0F01FFF81
F0707078407F05F07E1E143070707FFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFF82E0BF8F38F0F09FFF8F
F8F8F8F8E3FE0EE3FE1E1E38F8F8FFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFF0760DF071071F0CFFF8F
F070707047DE1EF1FE1F1C7070707FFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFF8F60DF8E38E0F0E7FF8F
B8F8F8F0E7DE1EE3EE1F8EF83830FFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFF0741CFC47C41F0F1FFC4
70707001F11C1E714C0304704001FFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFE0FA3EFFBFFAFF0EAFFEB
BAEAF8EBFABAAEBAAE0BEBFAEBEBFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFE0F81EFFFFFFFF0FFFFFF
FFFFF07FFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFE0F83EFFFFFFFF0FFFFFF
FFFFF8FFFFFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFC1F83F7FFFFFFF0FFFFFF
FFFFF07FFFFFFFFFFF9FFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFE1F83F7FFFFFFF0FFFFFF
FFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFF01D01C1FFFFFFF0FFFFFF
FFFFF07FFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFAAEABEBFFFFFFEAFFFFFF
FFFFEAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC5FFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFA2FFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF005FFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF800BFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFC00017FFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE00000BFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFF40000000000000001E1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
0017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFF80000000000000000021FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
0000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFF400000000000000000041FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
000005FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFE000000000000000000BE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
0000003FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFF0000000000000000017FE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
00000017FFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFE0002BFFFFFFFC0003FFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FEA00003FFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFF00017FFFFFFFF0005FFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFD00007FFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFE003FFFFFFFFFE02FFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFF8003FFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFC007FFFFFFFFFC17FFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFD000FFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFF803FFFFFFFFFEBFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFF007FFFFFFFFF7FFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFE03FFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFC07FFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFF80FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFF01FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFF83FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFF03FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFF07FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFF07FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFF81FFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFE0FFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFE07FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFF81FFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFE0FFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFF07FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFF07FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFF03FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFF83FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFF01FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFF83FFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
0000000000000000000000000000000000000000000000003FFFFFFFFFFF
FFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFC1FFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
0000000000000000000000000000000000000000000000007FFFFFFFFFFF
FFFFFFFF81FFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFC0FFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
0000000000000000000000000000000000000000000000003FFFFFFFFFFF
FFFFFFFF81FFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFC07FFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
0000000000000000000000000000000000000000000000007FFFFFFFFFFF
FFFFFFFF01FFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFF81FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC03FFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFC03FFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC03FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFA03FFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF003FFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FC00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFC00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0
01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00
3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00
7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFF801FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF801F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE007FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFC7FFFFFFFFFF
FFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFF83FFFFFFFFFF
FFFFFFFFFFFFFE2AFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF801FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFF91FFFFFFFFFF
FFFFFFFFFFFFFCFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFBFFFFFFFFFF
FFFFFFFFFFFFFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFDFFFFFFFFFF
FFFFFFFFFFFFFCFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFEA3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF81FFCFFFC47C1FF
DFF01C1F070517007FF0C1C1C1F11F81FFF01FC5F07041C1C1FC07C107F1
7C1C111FFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF3EFFCFFFCF3827F
CFF09F3F8F9FBE2BFFF3E3E782FBEF88FFE09FBE7CF8E3E3827C27EECFCF
BE3E7BEFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1F3FC7FFDF3073F
8FE1C71F9F9F1E7FFFF367C70777C71E7FC1CF3F3CF9F3E7073073C7CF9F
DF3E77C7FFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF3FBF87FFFF39FBF
8FE3FF3F8F9FBFFFFFE3E3E73FBFEE3FFFE3FE3FBCF8F3E39FB8FFCFCFBF
CE3E7FEFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1F1F17FFFC31FDF
17C7F71F9F9F1F87FFF3E7C71FDF867FFFC7FC7F1CF9F3E71FD1FDC7CF1F
C73E7F87FFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF3F9FBBFFF873FFF
3FEFFF3F8F9FBFB9FFE3E3E73FFE0E7FFFCFFEFF9CF8F3E33FFBFFCFCF3F
EE3E7E0FFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1F1F1BFFE073FFF
37C7FF1F9F9F1E3C7FF3E7C73FFC1C7FFFC7FC7F1CF9F3E73FF1FFC7CF1F
C73E7C1FFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF3F9E3BFFE3F3FFE
3BEFFF3F8F9FBE3EFFE3E3E73FF8FE7FFFEFFEFFBCF8F3E33FFBFFCFCF3F
CE3E78FFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1F1C7DFFC7F001C
79C0071F9F9F1C7C7FF3E7C70031FE007FC7DC7F1CF9F3E70011FFC7CF1F
CF3E71FFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF3F3EFDFFCFFBE3E
FFEFCF3F8F9FBE7CFFE3E3E7BE3BEE7CFFEFCE7F3CF8F3E3BE39FBCFCFBF
8E3E7BEFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1E3C7CFFCF7DE7C
7DF78F119F071E7C7FF3E1C71C71CF7C7FF7C77E7C71F1C7DE7DF1C7CFDF
1E1C73CFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF802FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF2078FEFFEE7EAF8
FEFBBE218F1A3FB8BFE2E28FEAFBEFB8FFFB9FBEF8A3E20FEAFEE38B8FEF
3E28FBAFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF11F57D7FF17F1F5
7D7C7FD1DFDC7FC7FFC1671FF1FD1FD1FFFC5FD1FDD7F31FF1FF1785DFF1
7F71FC5FFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF3E3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF3E7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE7FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF3FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1FFFFFFFFFFFFFF
FFFFFFFFDFFFFFFFFFFFE7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFE3FFFFFFFFFFFFFF
FFFFFFFF8FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4007FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1FFFFFFFFFFFFFF
FFFFFFFF1FFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF802FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4007FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFBFFAFFEFFF
AFFEFFEFFFFFFFFFFAFFEEFFBFFFFFFFEFFFFAFFEFFEFEFFFFFFFFEFFEEF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFD07E1E07F047C116
07F07F005FC1C1C1C57F001C0707FF1651FFE53F047C106107070703F001
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF8FE3E2BE3A78E3E
2BE2BE3E3FF3E3E7CFBE3E38278FFFBEFBFFEFBF3E78F3E38F8F9E2BE3E3
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD007FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1FC7C7DC7C71F1C
7DC7DC7C7FF1F3E79FDC7E71F3CFFF1EF9FF9FCF3F39F3E7CF9F1C3CC7E7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF8F8F8FE8FEF9FB8
FECFECFE7FF3E3E79FCEFE73FBCFFFBEF9FF9FEF3FB8F3E78F8F9CFEEFE7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1F1F8FF8FC71F18
FFC7F47C7FF1F3E71FC47E71FFCFFF1FE1FF1FC73F19F1E7CF9F1C7F47E7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF8E3F9FF8FEF9FB9
FF8FFCFE7FF3E3E73FECFE73FFCFFFBFA3FFBFEF3FB8FAE78F8F9CFFCFE7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1C3F9FF9FC71F19
FFDFFCFC7FF1F3E71FC47E73FFCFFF1F07FF1FC73F19FF47CF9F1CFFC7E7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF88FF8AB8FEF9FB9
FFCAACFE7FF3E3E7BFCEFE72ABCFFFBE3FFFBFEF3FB8FFE78F8F9CAAEFE7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0017FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF007FC51CFC71F1D
FDC50C7C7FF1F3E71FC47E7143CFFF1E7DFF1FC73F19F1E7CF9F1C50C7E7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF8A3FDFBEFEF9FBE
F9EF9EFE7FF3E3E7BF8E7E7BE3CFFFBE7BFFBF8F3E38FBE78F8FBEF8E7E7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1F0FCF1E7C71F1C
71E71F7C7FD1C5C7DF1F7C79C7CFFF1F79FFDF9F1C79F1C78F071F71F7C7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF8F8FEA3FB8F9E3F
A3FA3FBA7FE30E0FEE3FBA7E8FCFFEBFBBFFEE3F20F8BCEF8F883FA3FBA7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1FC7F57FD475F7F
D7FD7FD47FFF5F5FF57FD67F5FCFFFDFD5FFF57F35F07F5FFFDD7FD7FD67
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF8FC7FFFFFEFFFFF
FFFFFFFE7FFFFFFFFFFFFE7FFFCFFFFFFFFFFFFF3FF8FFFFFFFFFFFFFFE7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1FC7FFFFFC7FFFF
FFFFFFFC7FFFFFFFFFFFFE7FFFCFFFFFFFFFFFFF3FFDFFFFFFFFFFFFFFE7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF8F8FFFFFFEFFFFF
FFFFFFFE7FFFFFFFFFFFFE7FFFCFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFE7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF1F0FFFFFFC7FFFF
FFFFFFFC7FFFFFFFFFFFFE7FFFCFFF1FFFFFFFFF3FFFFFFFDFFFFFFFFFE7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFF0A3FFFFFF8FFFFF
FFFFFFFA7FFFFFFFFFFFFA7FFF8FFF3FFFFFFFFE3FFFFFFF8FFFFFFFFFA7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFD55FFFFFFFF7FFFF
FFFFFFFF7FFFFFFFFFFFFF7FFFDFFF3FFFFFFFFFBFFFFFFFDFFFFFFFFFF7
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA00FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD007FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFC00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0007FFFFFFF
FFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFF
FFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFF
FFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFC7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFF
FFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFF8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFF
FFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA00FFFFFF
FFFFFFFFFFFFFFFFFFA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFF
FFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFF
FFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFF
FFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
E1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFF
FFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFF
FFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFC
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFF
FFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4007FF
FFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FF
FFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFC5FFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FF
FFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFD7FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFF8FFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FF
FFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFE8FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001F
FFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFF07FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA00F
FFFFFFFFFFFFFA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFF8BFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001
FFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFF05FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800
FFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFC3FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00
7FFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFDFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80
3FFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC0
07FFFFFFFFF801FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFF07FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
03FFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFE8BFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFF017FFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4
007FFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFD05FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFA2FFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE
003FFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFE0BFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
001FFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFF07FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E00FFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF817FFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F001FFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFF41FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA2BFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FE00FFFFA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFA2FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD017FFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF001FFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFD017FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA7FFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF800FFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFE0BFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD7FC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFC007F001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC17FF7FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE2B83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF803E003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD001FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFC00001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF401FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF80003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE82E1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC17FF7FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC0007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC5FC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFF0BFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE8FFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFD0017FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFC001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFD005FFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFEA0FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF8000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF80BFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFDFFD5FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFE00001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF5FF57FFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFE02BFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF800E00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFA03FFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFF5007
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF001F001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFD0015FFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFEF
FEBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE00FF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFEBFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FE0015FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF001FFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF5007FFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFEA03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FE007FFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFA02BFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFF5FF055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F801FFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF55FF95FFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFEA02AFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
E003FFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEA00BFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFF507FD57FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C007FFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD7F
E055FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE802AFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
803FFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAA03F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFD501FF155FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
007FFFFFFF801FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5FFC0157FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFA800AFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
03FFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEAA00FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF547FC0557FFFFFFFFFFFFFFFFFFFFFFC0
07FFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFF553FF00557FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAA803FFBFFFFFFFFFFFFFFFFFF80
0FFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFEA002BFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD7FF00001FFD55FFFFFFFFF00
1FFFFFFFFFFF001FFFFFFFFFFFFFFFF540007FD55FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFE0002BFEBFFE00
FFFFFFFFFFFF800FFFFFFFFEAAA03FFAAAFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF557FE000001
F800007FE0000007000007FC15557FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00F
FFFFEAFFEAAAA803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001F
FFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003F
FFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007F
FFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FF
FFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FF
FFFFFFFFFFFFFFF801FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFF
FFFFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFF
FFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFF
FFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFF
FFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFF
FFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFF
FFFFFFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFF
FFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFF
FFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFF
FFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4007FFFFFF
FFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFF
FFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFF
FFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFF
FFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFF
FFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF802FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4007FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFD007FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0017FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF801FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0017FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4007FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA00FFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF801FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4007FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF800FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF800FFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF801FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF803F
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC007
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFC007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF001
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFF801FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFA00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0
0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0
01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC
007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFE007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
C007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FE00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF001FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFF803FFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFE01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFC01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFF807FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFF03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFE07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFE03FFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF01FFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFF80FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF80FFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFF01FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFC07FFFFFFFFFFFFFFFFFFFFFF7C1F7FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFE03FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFE07FFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF03FFFFFFFFFFFFFFFFFFFFFFFC1F7FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFE0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF83FFFFFFFFFFFFFFFFFFFFFFBE1EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFC0FFFFFFFFFFFFFFFFFFFFFF555555555555555555555555555555555
5555555555555555555555555555555555555555555555557FFFFFFFFFFF
FFFFFFFF01FFFFFFFFFFFFFFFFFFFFFF9C1E7FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFF81FFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
0000000000000000000000000000000000000000000000003FFFFFFFFFFF
FFFFFFFF80FFFFFFFFFFFFFFFFFFFFFFBE1EFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFF81FFFFFFFFFFFFFFFFFFFFFC000000000000000000000000000000000
0000000000000000000000000000000000000000000000007FFFFFFFFFFF
FFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFDC1CFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFF83FFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
0000000000000000000000000000000000000000000000003FFFFFFFFFFF
FFFFFFFFE0FFFFFFFFFFFFFFFFFFFFFFCE18FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFF03FFFFFFFFFFFFFFFFFFFFFC000000000000000000000000000000000
0000000000000000000000000000000000000000000000007FFFFFFFFFFF
FFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFC411FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFF03FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFF07FFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFE0FFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFE07FFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFF81FFFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFE0FFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFF07FFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFF81FFFFFFFFFFFFFFFFFFFFFE001FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFF07FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFF83FFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFF07FFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFF01FFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFF03FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFF01FFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFF03FFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFF80FFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFE07FFFFFFFFFFFFFFFFFFFFFF003FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFC07FFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFF007FFFFFFFFFFFFFFFFFFDFFF007FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFE03FFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFF00FFFFFFFFFFFFFFFFFFF8FFF807FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFE01FFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFC01FFFFFFFFFFFFFFFFFFF8FFF007FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFF80FFFFFFFFFFEFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFE803FFFFFFFFFFFFFFFFFFF8FFF80FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFF001FFFFFFFFFF07FFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFF4007FFFFFFFFFFFFFFFFFFF8FFF807FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFE003FFFFFFFFFE0BFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFA003FFFFFFFFFFFFFFFFFFFF8FFF80FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFF0007FFFFFFFFF001FFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFC0007FFFFFFFFFFFFFFFFFFF5057F80FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFF8000BFFFFFFFF8002FFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFEA0000FFFFFFFFFFFFFFFFFFFE0003F80FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFC000001555555400005FFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8155555555555
00000007FFFFFFFFFFFFFFFFFFFE0003FC0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFA000000000000000003FE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
0000003FFFFFFFFFFFFFFFFFFFFEA8ABFC0FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFF000000000000000000141FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
0000017FFFFFFFFFFFFFFFFFFFFFF8FFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC37FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFE3BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFE80000000000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
00002FFFFFFFFFFFFFFFFFFFFFFFF8FFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFE77FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFF0107FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFD0000000000000000041FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
00017FFFFFFFFFFFFFFFFFFFFFFFF8FFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFF8E0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFEAAAAAAAA000002FE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFF82AAAAAAAAAAA
ABFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFE3FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFF070FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFC00001FFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF07FFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF8FFFC1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFF8F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF8000BFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE1BFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFFFE3FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFF070FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0017FFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF1DFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFF8F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE0BFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFF070FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF05FFFFFFFC1FFFFFFFFFFF7FFFFFFFFFFFFFFF7FFFF
F7FFF7FDFFFFDFFDFFDFDDFFFFDFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFF8F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFEFFFFFFFFFE1FFFFE00BFF89F8383820E0E0E0C38383
C3FF89F82BEE8FA0FFCFC23E0F83E0E0E0FFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFF070FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFF0707F1C787070707060C1018707
85FF3C704060C19E3FCFC71C0604E0E1E1FFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFC07FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFF8F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFF0F83E3E387878F8F0E0C383878F
86FF7EF0E1E1E3BF3F8FFFBC3E3EE0E1E1FFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF837FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFF070FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFF07C1C3C3878707070F1C3C78707
07FF7C70E1E1F1BF1F07DF1C3C1FF1E1E1FFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7FFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF877FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFF0E0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFF0FE1C3E387878F8F0E0E383878F
8FFFF870E1E1F0FC3F87FE1C3C3FE0E1E1FFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF87BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFF555FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFF07E1C3C1878707070F1F1C78707
07FFC070E1E1F0F03F07F01C3C3FF1E1E1FFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF4017FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF073FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFF0FE0C3E387878F8F0E0FA83878F
8FFF80F0E1E1F0E03E0BE03C3C2AE0E1E1FFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE0003FFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0FBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFF07E0C3C1878707070F1F7078707
07FF01F0E1E1F0C0FC19C07C3C1071E1E1FFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000001FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFC071FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFF0FE0C3E387878F8F0E0E383878F
8FFF0FF0E1E1F083FE3BC3FC3C38E0E1E1FFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFF07E043C387870707071C1C78707
07FF1F70E1E1F187FC1DC7DC3C3C71E1E1FFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00054007FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFF0FE0E3E783838F8F0E1E387838F
8FFF3EF0E1E0E38FB83FEFBC3E38E0E0E3FFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE00FFFA03FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFF07E0F18784040F07001F3078407
05FF1C70E1E041C7383CC7141711F10101FFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC05DDDD00FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFF0FE0FA3FAE0E3EAEAE3F83FAE3E
02FFE2EAEBE18FE8BABAF8B82F8BEA838FFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF80FFFFFE07FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFF07C1FFFFFFFFFFFFFFFFFFFFFFF
07FFFFFFFFE1FFFFFFFFFFFC3FFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0177777703FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFF0FE3FFFFFFFFFFFFFFFFFFFFFFF
8FFFFFFFFFE1FFFFFFFFFFFE3FFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFE07FFFFFF83FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFF07C1FFFFFFFFFF9FFFFFFFFFFFF
C7FFFFFFFFE1FFFFFFFFFFFF3FFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1DDDDDDDC1FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFF0F87FFFFFFFFFF8FFFFFFFFFFFF
EFFFFFFFFFE1FFFFFFFFFFFFBFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFE0507FFFFFFFFFF07FFFFFFFFFFF
F7FFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF017777777707FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFEAABFFFFFFFFFFF8FFFFFFFFFFFF
FFFFFFFFFFEBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF03FFFFFFFF83FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF01FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFF05DDDDDDDD81FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFC3FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFC001FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC177777777741FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE3FFFFFFFFFE1FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00007FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF05FFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFC5FFFFFFFFC1DDDDDDDDDC1FFFFFFFFFFFFFFFFFFF
FFD1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE0BFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF83FFFFFFFC3FFFFFFFFFE0FFFFFFFFFFFFFFFFFFF
FFFE2FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00007FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF0017FFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC007FFFFFC3777777777707FFFFFFFFFFFFFFFFFF
FFFF007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFEAAAAAAAAAAAAAAAAAAAAAAAA00002AAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAA8002AFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFE000BFFFF83FFFFFFFFFF0FFFFFFFFFFFFFFFFFFF
FFFFE00BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFC0000000000000000000000000000000000000000000
00000000000000000000005FFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00001FFF85DDDDDDDDDD07FFFFFFFFFFFFFFFFFF
FFFFE00017FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFC0000000000000000000000000000000000000000000
000000000000000000000003FFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF82AAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAA000002FF87FFFFFFFFFF82AAAAAAAAAAAAAAAAAA
AAAAA00002FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFC0000000000000000000000000000000000000000000
00000000000000000000000007C1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
000000000000000000000000000707777777777700000000000000000000
000000000005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFC0000000000000000000000000000000000000000000
00000000000000000000000000A1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
000000000000000000000000000007FFFFFFFFFF80000000000000000000
0000000000003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFC0000000000000000000000000000000000000000000
0000000000000000000000000141FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
000000000000000000000000000105DDDDDDDDDD00000000000000000000
00000000000001FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000BFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
00000000000000000000000000BF87FFFFFFFFFF80000000000000000000
000000000000BFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8001FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE000007FFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8000000000000
00000000000000000000000005FF87777777777705555555555555555555
555550000007FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFE003FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFE0003FFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFE0002FFFF83FFFFFFFFFF8FFFFFFFFFFFFFFFFFFF
FFFFF00003FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF007FFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFF8005FFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFC001FFFFF85DDDDDDDDDD07FFFFFFFFFFFFFFFFFF
FFFFC0005FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFA2FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFE02FFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF80FFFFFFF83FFFFFFFFFF0FFFFFFFFFFFFFFFFFFF
FFFF802FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF457FFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFC17FFFFFFFC1777777777707FFFFFFFFFFFFFFFFFF
FFFF057FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFBFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFBFFFFFFFFFC3FFFFFFFFFE0FFFFFFFFFFFFFFFFFFF
FFFABFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFC1DDDDDDDDDC1FFFFFFFFFFFFFFFFFFF
FFF7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE0FFFFFFFFFE1FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFE077777777741FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFFE0FFFFFFFFF83FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFF05DDDDDDDD03FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFF83FFFFFFFF07FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFF017777777407FFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFFC1FFFFFFFE0FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFFC05DDDDDD81FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFEA8ABFE03FFFFFF03FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC1FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF87FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFE0003FF0177777407FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE0AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA83FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFE0003FF803FFFF80FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000000000000000000000
0000000000000000000000000000000000000000000000007FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF5057FFC015DDC01FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFE000000000000000000000000000000000
0000000000000000000000000000000000000000000000003FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFFFF802FE803FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFC000000000000000000000000000000000
0000000000000000000000000000000000000000000000007FFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFFFF40000007FFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFE000003FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFC00017FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8FFFFFFFA02FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFFFFFFFFDFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFE
pop
grestore
%%Trailer
%%EOF
\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{328, 136},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000580000R1000`40O003h00OogooBGoo003oOom9
Ool005Moo`03IcUNmekg04mNm`03Kg]oogoo09aoo`00Egoo00DQ20Q248@@Q0Q202<@Q0035:D@Q124
028@Q006248@Q12448@8@S6<WWoo001GOol00b48G_Moo`1>Ool00d8@<Haoo`2MOol005Moo`038@QN
mgoo04ioo`03@Q0aS7oo09eoo`00C7oo00=g_GooOol027oo00<Q25kgOol0CWoo00=2436<Ool0WGoo
001<Ool01WNmE[DaS4YBG_M_N`Eoo`038@QNmgoo04ioo`03@Q0Q25kg02eNm`03Mkeoogoo06eoo`00
:Woo00=Nmb488@P08B4800/8@P00000001S6:DY245kgKg/Q25kg04moo`03@Q00000002d00003G_Mo
ogoo06eoo`00:Woo00=BU000<H`02C6<00<YBS6<<H`05C6<00/8@P00000000Q2:DY245:DKg/Q25kg
02]oo`03BU9Nmgoo025oo`03@Q0aS7oo02aoo`0348ANmgoo06ioo`00:Woo00=BU124Ool07goo00Eg
_D8@>Li:DUJe00Ioo`038@QNmgoo00]oo`04MkeoogooMkd2Ool2Mkd00gooKg]g_@02Mkd016mkMke_
Ngoo0gNm00AoogNmMkeoo`Eg_@06Kg]g_E:DIcUg_Goo0WNm00aoofmkMkeoofmkOom_NgNmKg]g_Fmk
MkdBOol00d8@<Haoo`0/Ool00a24G_Moo`1^Ool002Yoo`03DY@@Q7oo02Yoo`038@QNmgoo00]oo`0R
BU9F]Goo>LioogNm48ABU5kg2496<AS6E[DQ23W>@Q1oofmkDY@icVLi48AF]AS6Kg/HaV]J8@QBU5kg
:DYoodYBF]H2G_L03CW>IcTHaUJe48ABU6mk48ANm`Q2IcT8@Vmk019oo`03@Q0aS7oo02aoo`0348AN
mgoo06ioo`00:Woo00=BU124Ool0:Woo00<Q25kgOol02goo010HaS6<Kg/006LiG_LHaUkgIcU:DT8@
8@QNm`Q26<Ig_@9oo`0O<H`HaVLi48A_Na24Kg/@Q7oo8@QBU1S6<Haooa24BU9ooc6<8@QNmb48G_LH
aUJeIcT@Q6mk48A_Na24Kg/04Woo00=2436<Ool0;7oo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0Z
Ool00b48G_Moo`0:Ool04Fmk249F]CW>:DYF]GNm6<I:DUJe6<I:DS6<G_LQ24YBKg/00Woo00`Q26Li
IcT@Q6mk48A_Na24G_L@Q5JeBU82E[D04AS6G_MW>C6<G_MF]AS6IcTHaTYBG_L@Q4ic48A:DQ24Mkd0
4Woo00=2436<Ool0;7oo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0ZOol00b48G_Moo`0:Ool01SW>
:DYoo`Q2E[ENm`9oo`09MkeoogooKg]ooekg8@Qg_Fmk009oo`=g_@05Kg]g_FmkKg/@Q002Mkd00goo
Kg]g_@02Kg/2Mkd2Kg/00gNm:DYg_@02Mkd00gooKg]g_@03MkdCOol00d8@<Haoo`0/Ool00a24G_Mo
o`1^Ool002Yoo`03DY@@Q7oo021oo`03IcUg_Goo00Moo`038@QNmgoo00Uoo`08Mke245:DIcTaS5kg
F]IW>@Ioo`03IcU247oo00Uoo`03Kg/icWoo00]oo`03Mkeoogoo01Yoo`03@Q0aS7oo02aoo`0348AN
mgoo06ioo`00:Woo00=:DQBUOol087oo00Eg_D8@8@Pe[EJe00Eoo`038@QNmgoo04ioo`03@Q0YBWoo
02aoo`035:ENmgoo06ioo`00:Woo00=BU124Ool05goo00=g_EJe@Q00248@00X8@P0000000124:DY2
45Je8@QNmdmoo`03@Q0HaT8@00e24003E[E_Ngoo01aoo`0348ANmgoo06ioo`00:Woo00=BU124Ool0
5Goo00EJeR480000012400PQ20@000068@PaS4YBIcTHaUkgCgoo00=240Q28@P0324800H@Q0000008
@RU:G_LJOol00a24G_Moo`1^Ool002Yoo`03DY@@Q7oo01=oo`06MkdHaP00:DYNmfmk1goo00I_NcW>
<HaF]FLiMkd4Ool00b48G_Moo`1>Ool00d8@<Haoo`0=Ool01gNmIcU:DRU:000HaVLi01Qoo`0348AN
mgoo06ioo`00:Woo00=BU124Ool04Woo00Ag_AS66<IW>@Uoo`03Mkeoogoo00Qoo`038@QNmgoo04io
o`03@Q0aS7oo015oo`04IcTQ2000Kg/GOol00a24G_Moo`1^Ool002Yoo`03DY@@Q7oo019oo`03BU88
@WNm01Eoo`038@QNmgoo04ioo`03@Q0aS7oo019oo`03MkdQ22U:01Moo`0348ANmgoo06ioo`00:Woo
00=BU124Ool04Woo00<YBS6<Ool05Goo00<Q25kgOol0CWoo00=2436<Ool04goo00=24124Ool05Woo
00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0BOol00dYB48Aoo`0EOol00b48G_Moo`1>Ool00d8@<Hao
o`0COol00aS6<Haoo`0FOol00a24G_Moo`1^Ool002Yoo`03DY@@Q7oo019oo`03IcT005kg01Eoo`03
8@PHaR4804hQ200348@aS7oo019oo`03DY@006Li01Moo`0348ANmgoo06ioo`00:Woo00=BU124Ool0
4goo00<aS0Q2Kg/057oo00=W>EkgG_L0Cekg00=_NgooOol047oo00=W>@Q2<H`067oo00<@Q5kgOol0
KWoo000ZOol00e:D48Aoo`0COol00fmk248YBP1hOol00fLi248YBP0IOol00a24G_Moo`1^Ool002Yo
o`03DY@@Q7oo01Aoo`03IcT8@S6<07Ioo`04IcT8@RU:Kg/IOol00a24G_Moo`1^Ool002Yoo`03DY@@
Q7oo01Eoo`03IcT8@S6<07Aoo`04IcT8@RU:Kg/JOol00a24G_Moo`1^Ool002Yoo`03DY@@Q7oo01Io
o`04IcT8@Q24IcUaOol0148@000aS7Nm6goo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0GOol016Li
6<H8@UkgKWoo00AW>B48249241eoo`0348ANmgoo06ioo`00:Woo00=BU124Ool06Goo00@icP00:DYW
>F]oo`04@Q0001S6IcTNOol00a24G_Moo`1^Ool002Yoo`03DY@@Q7oo01Yoo`04G_LHaPQ2BU9XOol0
15:D2488@TYB87oo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0LOol0148@2488@VLiI7oo00EW>BU:
000icVmk025oo`0348ANmgoo06ioo`00:Woo00=BU124Ool07Goo00E_Nc6<000YBVLi065oo`04<H`0
01S6IcTSOol00a24G_Moo`1^Ool002Yoo`03DY@@Q7oo01moo`04E[DHaPQ2BU9NOol014YB2488@U:D
9Goo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0QOol0148@2488@VLiFWoo00EW>B48248icVmk02Io
o`0348ANmgoo00]oo`03Kg/YBWNm01Moo`03BU9BU6Li04Ioo`00:Woo00=BU124Ool08Woo00E_Nc6<
000YBVLi05Ioo`05MkdaS0006<IW>@0XOol00a24G_Moo`08Ool00fLiG_M_N`02Ool02E[FOomoogoo
F]IF]GNmBU9F]@02Ool07VLiOom_NdYBHaQNmfLiMke:DWNmDYA_NekgF]I:DSW>MkeoofmkG_MJeVLi
F]I_NdYBG_Mg_EkgIcUoo`9:DP9oo`04Mke245[FOol2IcT01gNmDYAg_DYBG_MJeVLi009JeP0?DYAg
_F<HBU9_NfLiG_MBU7NmKg]W>FmkIcUJeVLi00=Nma=oo`00:Woo00=BU124Ool097oo00ANmaS6249:
DUAoo`04BU88@PQ2E[DZOol00a24G_Moo`08Ool01T8@Kg]BU6mkG_LicP=oo`0;Kg/YBU:D>Lig_FLi
Kg/aS7oo@Q1W>@02G_L02U:DOolaS7oo@Q1_Ne:DKg]F]Fmk0Woo00eBU5Je@Q1_Nc6<G_M247NmIcU_
NbU:BU9W>@02Mkd01gooBU9BU6mkG_MJeWoo0092400EOolaS7oo@Q1Nme:D:DYg_Ekg:DYg_FLi@Q1_
Nd8@Oom247ooDYAW>D8@009Nm`03Kg/aS6]J019oo`00:Woo00=BU124Ool09Woo00A240Q2249Nme1o
o`05IcTQ20Q2>Li_N`0[Ool00a24G_Moo`08Ool01d8@Kg]:DVLi>LiW>Fmk009oo`07:DYNmfLiAS5B
U6LiBU800VLi00i245kgDYANme:DOolaS7oo@Q1_Ne:D>Li_NcW>0Woo02eBU5kg@Q1_Nc6<IcU6<E:D
IcTicVLi>LiNmdYBMkeooe:DKg]W>E:DIcUoocW>@Q1ooc6<Oom245kgDY@icUJeF]HicWooMke246mk
@Q1oocW>OolicVLi@Q000Ukg00<icUkgOol04Woo000ZOol00e:D48Aoo`0WOol01Fmk<H`002U:IcT0
C7oo00Eg_C6<000Q26Li02eoo`0348ANmgoo00Qoo`07@Q1:DTYBKg]:DWooF]H00Woo00YF]DYBOomW
>E:DMke247ooG_Mg_@9Nm`05IcU245:DDYA_N`02BU803fLiKg]Nme:DMkeoodYBAS5244ic@Q1g_Ekg
BU9g_@02F]H017NmIcTe[GNm0Woo021NmdicMkeW>EJeMkeBU5kgDYAg_D8@>Lig_FmkDYAg_FmkG_MB
U3W>G_MBU7ooKg]W>E:DKg]:DT8@MkeF]E:D4goo000ZOol00e:D48Aoo`0YOol015kg6<H8@TYBBGoo
00Eg_D8@2488@UJe02moo`0348ANmgoo00Qoo`03>Li_Ngoo01Eoo`03G_Moogoo00Moo`04Mke_Nd8@
Kg/POol2Mkd00ekgOomoo`0KOol002Yoo`03DY@@Q7oo02]oo`05DY@8@PQ2E[Eg_@15Ool01E[F2488
@SW>Kg/0<7oo00<@Q5kgOol027oo00=_NgNmOol057oo00=g_FmkOol02Woo00=g_GooOol08Goo00=_
NgooOol06goo000ZOol00e:D48Aoo`0/Ool01Fmk>Lh001S6F]H0@Woo00EW>AS6001247Nm039oo`03
48ANmgoo06ioo`00:Woo00=BU124Ool0;Woo00Eg_BU:000YBWNm03ioo`05MkdicP008@QW>@0dOol0
0a24G_Moo`1^Ool002Yoo`03DY@@Q7oo031oo`05G_LHaP00@Q1g_@0kOol01E[F248@Q4YBMkd0=Goo
00<@Q5kgOol03Goo00=g_GooOol00WNm0Woo00Eg_GooOomoofmk009oo`04MkeoogooMkd:Ool00fmk
Oomoo`02Mkd2Ool00gNmOomoo`05Ool00gNmOomoo`02Ool016mkOomoogNm0Woo00=g_GooMkd027oo
00=g_GooOol00WNm6goo000ZOol00e:D48Aoo`0aOol01GNmBU88@QS6F]H0>7oo00ENmaS6001:DWNm
03Moo`0348ANmgoo00Qoo`0[BU9247Nm:DY_NbU:E[EW>C6<G_LQ27Nm<Ha>LdYB<HaBU6Li@Q1BU6Li
@Q1F]BU:Kg]oodicDYA245Je>Li_NcW>Kg]NmdYBE[DaS5[F<Ha246Li:DX00Woo00E_NdYBE[E_Nd8@
009oo`0HDYA_Ne:DOolaS5kgF]HaS6Li<HaF]DYB8@Qg_B48MkdYBU:D>LiBU5kgBU96<DYB6Woo000Z
Ool00e:D48Aoo`0cOol01GNm:DX001S6Mkd0=7oo00Eg_CW>000YBVLi03Uoo`0348ANmgoo00Qoo`0@
DYA:DRU:MkeNmdYBKg]NmdYBOolYBVmk@Q1_Ne:D>Lh2Ool01SW>Kg]W>CW>OolaS09oo`08G_MBU5:D
G_M246LiDYAoo`8icP07Oom245kgCW=_NgNm@Q000Woo00E_Ne:DMkdicU:D009oo`0F@Q1ooe:DKg]2
47oo@Q0aS7ooE[E>Lekg<Haooc6<OolaS48@IcU_Nd8@Kg/2G_LJOol002Yoo`03DY@@Q7oo03Eoo`05
G_LHaP00>Lig_@0aOol01E:D000@Q5:DMkd0>Woo00<@Q5kgOol027oo015BU36<>LiS67oo@Q0icVmk
CW=g_B48Kg]245kgDYAJeUkg009BU005CW=245[FMkdYBP02Ool04DicBU8icUJe<Hag_E[FIcTicU:D
MkdaS7NmBU8YBVmk@Q000Woo00EW>E:DJeYNme[F009oo`0HDYAg_CW>MkdaS4YBDY@aS7Nm>LiF]FLi
:DYoob48G_LicVLiE[DQ26LiG_M>Lekg6Woo000ZOol00e:D48Aoo`0fOol01GNmBU8@Q124F]H0;Woo
00EJeQS6001:DWNm03aoo`0348ANmgoo00Qoo`9BU005MkdYBWooMke_N`02Ool00fmk:DYg_@02Mkd2
Ool016mkOomoofmk0Woo00=_Nc6<Ool00Woo17Nm00=oogNmKg/00Woo00=_Nd8@Ool00WNm00=ood8@
Ool00Woo00Ag_GooMke_N`=oo`0:Kg]g_Goo@Q1_Ngoo@Q1g_GooKg/3Ool3Mkd01gooMkeg_GooMkeF
]Ekg01Yoo`00:Woo00=F]@Q2Ool0>7oo00Ag_@Q2000Q22aoo`04BU8000Q2G_LnOol00`Q2G_Moo`08
Ool3@Q000f]JOomoo`03Ool00gNm:DYoo`0;Ool00cF]Oomoo`0;Ool00d8@Oomoo`02Ool01D8@Oomo
oekgE[D027oo00=g_DYBOol01Woo00=:DWooOol01goo0Ukg6Woo000ZOol00e:D48Aoo`0jOol014YB
248@Q5Je:7oo00AW>AS6000aS41oo`0348ANmgoo06ioo`00:Woo00=BU124Ool0>goo00EW>BU:000Y
BVmk02Aoo`05Kg/icPQ2:DYW>@11Ool00a24G_Moo`1^Ool002Yoo`03DY@@Q7oo03eoo`04IcTHaPQ2
>LhROol015Je2488@TYB@goo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0oOol014YB248@Q5Je7Woo
00AW>AS6000icTEoo`0348ANmgoo06ioo`00:Woo00=BU124Ool0@7oo00EW>BU:000HaVLi01Yoo`05
Kg/icPQ2:DYW>@16Ool00a24G_Moo`0KOol00fLiOomoo`1@Ool000ioo`03Mkeoogoo01Uoo`03DY@@
Q7oo049oo`05IcTQ20Q2>Lig_@0GOol015:D2488@U:DB7oo00<@Q5kgOol06Goo00=g_EJeF]H0DWoo
000>Ool00e[FG_Moo`0IOol00e:D48Aoo`14Ool014YB2488@UJe57oo00AW>AS6248icTYoo`0348AN
mgoo01Moo`03IcU:DU[F05Aoo`004Goo00=g_EJeIcT05Woo00=BU124Ool0AGoo00EW>C6<000HaVLi
011oo`05Kg/aS000:DYW>@1;Ool00a24G_Moo`0DOol016mkOomoogNmEWoo000COol016LiE[EBU5kg
4goo00=BU124Ool0Agoo00EW>B48248icVmk00eoo`04BU88@PQ2E[E=Ool00a24G_Moo`0@Ool01Fmk
G_MF]E:DIcT0FGoo000FOol01GNmOomooe[FG_L03goo00=BU124Ool0BGoo00A:DPQ2249F]@Yoo`04
G_LHaPQ2>Li?Ool00a24G_Moo`0<Ool01FmkIcUoogooE[D0GGoo000JOol01FmkDYAF]EJeMkd02goo
00=BU124Ool0BWoo00Eg_C6<000HaVLi00Ioo`05Kg/aS000:DYW>@1@Ool00a24G_Moo`08Ool01Fmk
DYABU5JeG_L0HGoo000POol01VLiE[EF]EJeG_Mg_@Aoo`03DY@@Q7oo04aoo`05IcTYBPQ2>Li_N`03
Ool014YB2488@UJeDWoo00<@Q5kgOol00Woo00EW>EJeCW=F]GNm06Moo`0097oo00Ag_FmkOomg_@9F
]@03>Lh@Q7oo04ioo`03BU88@PQ2009F]@036<H8@SW>059oo`04MkeNma24@Q02Ool00ekgIcUoo`1Z
Ool002Yoo`03DY@8@Ukg009oo`05F]IF]EkgG_Mg_@19Ool01B48000001S6IcT0C7oo00AW>EkgE[EW
>@9oo`9F]@03Mkd@Q5kg06moo`00:Woo00=BU124Ool01Goo00=_NeJeMkd00Woo00EF]E:DE[ENmfLi
03moo`08MkdaS0006<He[@00:DYW>D5oo`03MkeW>Ekg009F]@06DYAg_GooKg]BU6Li27oo00<@Q5kg
Ool0KWoo000ZOol00e:D48Aoo`0>Ool03WNmOomooe[FG_MBU5JeDYAg_GooKg]W>FmkMkdaOol014YB
48@@Q5[F0Woo00EJeQS6001:DWNm03Aoo`9_N`9oo`06IcUBU5JeE[ENmfmk0Woo00=_NgooOol03goo
00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0IOol01FmkIcUF]EJeG_L00Woo00=Nme:DDY@00UJe00=g
_GooKg/00Vmk00=g_GooOol07Woo00EW>AS6000icWNm00Eoo`04DY@8@Q24DY@UOol02FmkOomoogNm
G_MBU5kgDYANm`02Ool01EkgE[EBU5kgKg/077oo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0WOol0
0gNmKg]Nm`02E[D01UkgOomoofLiDYANm`9BU004MkeoogNmE[D3G_L00fmkOomoo`02Kg/00gNmOomo
o`06Ool01GNm:DX001S6Mkd027oo00Eg_CW>000YBVLi011oo`03Kg]W>Ekg009Nm`04MkeoofmkG_L2
DY@02UJeG_MoogooIcUBU5JeDYAF]GNm:Woo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0kOol02fmk
OomoofmkG_MF]E:DG_Mg_GooIcT00UJe00DaS1246<IJeWoo00=Nm`05E[EBU7ooOom_N`03DY@01CW>
6<H004YBE[D015kg00Ag_GooIcUF]@9Nm`04DYAW>GooOol3Kg/lOol00a24G_Moo`1^Ool002Yoo`03
DY@@Q7oo04Ioo`05G_LHaP00>Lig_@0?Ool015:D248@Q5:DC7oo00<@Q5kgOol0KWoo000ZOol00e:D
48Aoo`14Ool01GNm:DX001S6Mkd04Woo00Eg_CW>000Q26Li04Yoo`0348ANmgoo06ioo`00:Woo00=B
U124Ool0@Woo00Eg_DYB248HaU[F01Ioo`05G_LHaP00BU9g_@18Ool00a24G_Moo`1^Ool002Yoo`03
DY@@Q7oo045oo`05E[DHaP00>Lig_@0IOol015[F48@@Q5:DAgoo00<@Q5kgOol0KWoo000ZOol00e:D
48Aoo`0oOol01GNm:DX0036<Mkd077oo00Eg_CW>000HaVLi04Eoo`0348ANmgoo06ioo`00:Woo00=B
U124Ool0?Goo00Eg_DYB248HaU[F021oo`05IcTHaP00>Lig_@13Ool00a24G_Moo`1^Ool002Yoo`03
DY@@Q7oo03aoo`05E[DHaP00>Lig_@0SOol015[F48@@Q4YB@Woo00<@Q5kgOol0KWoo000ZOol00e:D
48Aoo`0jOol01Fmk:DX003W>Mkd09Woo00Eg_CW>000HaVLi041oo`0348ANmgoo06ioo`00:Woo00=B
U124Ool0>7oo00Eg_DYB000HaU[F02Yoo`05Kg/HaP00<Hag_@0nOol00a24G_Moo`1^Ool002Yoo`03
DY@@Q7oo03Moo`04DY@@Q000BU8^Ool015[F48@@Q4YB?Goo00<@Q5kgOol0KWoo000ZOol00e:D48Ao
o`0eOol01FLi:DX003W>Mkd0<7oo00Eg_CW>000HaVLi03]oo`0348ANmgoo06ioo`00:Woo00=BU124
Ool0<goo00Eg_DYB000HaU[F03Aoo`05MkdHaP00:DYg_@0iOol00a24G_Moo`1^Ool002Yoo`03DY@@
Q7oo039oo`04DY@@Q000DY@hOol01E[F6<H@Q4YBMkd0=goo00<@Q5kgOol0KWoo000ZOol00e:D48Ao
o`0`Ool01FLi:DX003W>Mkd0>Woo00Eg_CW>000HaUkg03Ioo`0348ANmgoo06ioo`00:Woo00=:DQBU
Ool0;goo00ANm`00249:DSioo`04Mkd8@P00=JdeOol00aBUG_Moo`1^Ool002Yoo`03DY@@Q7oo02eo
o`05F]HQ2000<Ha_N`10Ool01Fmk>Lh8@R48IcT0<goo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0[
Ool01GNm>Lh00248G_L0A7oo00EW>AS6000Q25kg035oo`0348ANmgoo06ioo`00:Woo00=BU124Ool0
:Goo00Eg_E:D000@Q5[F04Qoo`05E[DDY@00>Lig_@0_Ool00a24G_Moo`1^Ool002Yoo`03DY@@Q7oo
02Qoo`05F]HHaP00BU9g_@1;Ool015:D48@@Q5:D;Woo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0V
Ool01GNm>Lh002U:Mkd0CWoo00Eg_C6<000HaU[F02aoo`0348ANmgoo06ioo`00:Woo00=BU124Ool0
97oo00Eg_DYB000HaU[F059oo`05IcTQ2000>Lig_@0ZOol00a24G_Moo`1^Ool002Yoo`03DY@@Q7oo
02=oo`05F]HHaP00BU9g_@1EOol015:D48@005:D:Goo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0Q
Ool01GNm8@P002U:Mkd0F7oo00Eg_D8@000HaU[F02Moo`0348ANmgoo06ioo`00:Woo00=BU124Ool0
7goo00Eg_DYB000HaU[F05aoo`05IcTYBP00>Lig_@0UOol00a24G_Moo`1^Ool002Yoo`03DY@@Q7oo
01ioo`05F]HHaP00BU9g_@1OOol015:D48@005:D97oo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0L
Ool01GNm8@P002U:Mkd0HWoo00Eg_DYB000HaU[F029oo`0348ANmgoo06ioo`00:Woo00=BU124Ool0
6Woo00Eg_DYB000HaUkg06Ioo`05IcTYBP00>Lig_@0POol00a24G_Moo`1^Ool002Yoo`03DY@@Q7oo
01Uoo`05F]HHaPQ2BU9g_@1YOol015:D48@005:D7goo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0H
Ool015:D000YBWNmK7oo00Eg_DYB000HaWNm01eoo`0348ANmgoo06ioo`00:Woo00=BU124Ool05Woo
00Ag_BU:001:DW1oo`04IcTHaP00F]HLOol00a24G_Moo`1^Ool002Yoo`03DY@@Q7oo01Eoo`04MkdH
aPQ2E[EbOol017Nm<H`005:D6goo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0DOol017Nm6<H@Q6mk
MGoo00=BU000DY@06Woo00<@Q5kgOol0KWoo000ZOol00e:D48Aoo`0DOol00c6<249_N`1gOol00e:D
001BU00IOol00a24G_Moo`1^Ool002Yoo`03DY@@Q7oo01=oo`03DY@005[F07Uoo`03DY@005[F01Io
o`05Mkeooa24G_Mg_@1^Ool002Yoo`03DY@@Q7oo019oo`03Mkd8@T8@01Eoo`05G_MBU5:DDYA:DP0S
DY@00eJeDYABU00RDY@00dYBDYABU002DY@00ekgOomoo`0AOol00c6<48Ag_@0EOol01FLiMkd@Q5kg
F]H0KWoo000ZOol00e:D48Aoo`0BOol00e:D001g_@0EOol00a246<HQ201>8@P00a24<Haoo`0BOol0
0gNm2492400FOol013W>248aS5:DKWoo000ZOol00e:D48Aoo`0BOol00bU:<Haoo`0EOol00a24G_Mo
o`1>Ool00d8@<Haoo`0COol00cW>6<Ioo`0EOol01124000006LiKWoo000ZOol00e:D48Aoo`0BOol0
0d8@6<Ioo`0EOol00a24G_Moo`1>Ool00d8@<Haoo`0COol00c6<48Aoo`0EOol0136<000007NmKWoo
000ZOol00e:D48Aoo`0BOol00fLi248aS00EOol00a24G_Moo`1>Ool00d8@<Haoo`0BOol00e:D2492
400BOol01gNmIcUoogooBU80012406moo`00:Woo00=BU124Ool04goo00ABU0Q2:DYF]@Uoo`03IcUB
U6Li00Moo`0348ANmgoo04ioo`03@Q0aS7oo00moo`05MkeBU248248icP0COol01ekg@Q1oogooE[D0
036<06moo`00:Woo00=BU124Ool057oo00EW>AS62488@RU:009240IBU007>Lh000006<HicTYBE[D0
0Woo00<@Q5kgOol0CWoo00=241S6DY@02U:D00U:DT8@@Q0aS1S60008@S6<IcT04goo00PicQS648@Q
27ooKg/0048@:7oo00=JeUkgOol0A7oo0009Ool0148@DY@icWNm7Goo00=BU124Ool05Woo00A_Ne:D
:DXQ20P@Q0032480000000<000046<HicPQ2G_LaOol00fmkOomoo`0KOol00d8@248@Q00<48@28@P0
0d8@E[Eg_@0FOol00ekg@Q1oo`02Ool00a24IcUoo`0WOol00e[FG_Mg_@14Ool000Uoo`0348A_N`00
01ioo`03DY@@Q7oo025oo`07DY@8@R48<Ha:DUkgMkd00Woo00<@Q5kgOol0;goo00=g_C6<IcT077oo
00=2436<Ool09goo00=_NfLiOol00Woo00<HaVmkOol0:7oo00=F]DYBOol0@goo0009Ool00a24Kg/0
000NOol00e:D48Aoo`0POol2IcT00gNmOomoo`05Ool00a24G_Moo`03Ool01Ukg:DYNmcW>MkeW>@9:
DP0fMkdQ26mk8@Q_NbU:G_LaS5kg<HaBU3W>@Q1:DR48G_LQ26mk:DYg_B48IcUoofmkE[EBU7oo8@Q:
DT8@G_M244YBF]IF]E:DHaQood8@OomJeUJeDYAJeS6<IcTaS5:DIcTQ26Li<HaW>C6<3Goo00=2436<
Ool0;7oo00=BU7ooOol0:7oo00<Q22U:Ool0@goo0009Ool00c6<G_LaS00NOol00e:D48Aoo`0ZOol0
0a24G_Moo`03Ool00ekg48Aoo`02>Lh06248G_LaS5Je001oo`00Kg/@Q6mk48ANmb48DY@aS5:DCW<@
Q6mk001_Na24Kg/@Q09oo`0DMke:DQ24Ool005kg8@QNmb48Ool8@Vmk<H`icWNm249Nmfmk>LhYBP=2
4008<Ha_Nfmk48ANmb48G_LQ20eoo`03@Q0aS7oo02]oo`04G_LicT8@DY@WOol016mk249_NfLi@goo
000ZOol00e:D48Aoo`0ZOol00a24G_Moo`03Ool07Ekg48Aood8@6<HYBUkg<HaNm`00Mkd006Li48A_
Na24G_LHaU:D>Li245Je249g_@00IcT@Q6mk48@00Woo015Nmc6<G_Moo`00G_LQ25kg6<Ig_AS6:DY:
DWNm@Q0aS6<H009:DP0<IcU2448@BU8icR48HaP@Q5kg6<INmbU:3Goo00=2436<Ool0:Goo00QJeQS6
48@YBS6<6<H8@S6<9Goo00AW>EkgMke_Nd=oo`00:Woo00=BU124Ool0:Woo00<@Q5kgOol00goo00=N
ma24Ool00SW>00ag_EJeE[Eooe:DF]I:DU[FG_M_Ne:DKg/2DY@04VLiMkeBU5JeOomBU5[FE[ENm`Q2
IcUoogNmG_MF]GNmDYA_N`9Nm`0:6<IBU6LiIcUNmfLiF]IW>EkgKg/2G_L02cW><Hag_E:DG_Mg_EJe
BU9JeTYBIcT03Goo00=2436<Ool0:7oo00=BU0Q2BU8016mk00=Nmc6<6<H0Jgoo000ZOol00e:D48Ao
o`0ZOol00a24G_Moo`03Ool01E[F6<INmb48Kg/02Goo00=g_B48Ool02goo00=JeWooOol01goo00=N
mc6<Ool02goo00=W>GooOol057oo00=2436<Ool09goo00=JeP00IcT01fmk0S6<JWoo000YOol017Nm
248003F]:Woo00<8@UkgOol0CWoo00=243F]Ool09goo00<Q23F]JeX01f]J00=Nm`00JeX0JGoo000Y
Ool01BU:00000000DY@07Woo00E_Nd8@@Q1Nmfmk00Ioo`0348ANmgoo04ioo`03@Q0aS7oo01aoo`05
MkeNmcW>G_MW>@06Ool00`Q2Kg]_N`08Kg/00b48BU9oo`0DOol016mkE[EBU5kgD7oo000@Ool00dYB
48@DY@0F48@400000`Q248@@Q00648@00`Q248@@Q00E48@3000021248@PicUkgIcUooa24G_M?Ool0
0d8@8@QBU00MDY@02dYB8@P00000248Q23W>E[EW>EJe6<H02Vmk00=241S6DY@035:D00=F]E:DDY@0
1e:D00PYBP00248HaRU:DYANmgNmBWoo000@Ool00f<H@Q12400F@Q001B4800000000>Lh0848@00<H
aP0000000P0000H8@RU:@Q1F]A24G_M?Ool00d8@0000000S00001@Q28@Q243W>8@P02Vmk00=:DPQ2
48@0312400<8@Q2448@021241P0000<YBTicKg/0B7oo000ZOol00d8@:DYBU00OOol01WNmBU8HaSW>
BU9F]@Eoo`0348ANmgoo04ioo`03@Q0aS7oo01aoo`07MkeF]AS6<Ha245JeMkd00goo00=W>@Q2IcT0
2Fmk00=2436<Ool05Goo00Mg_B4848@aS48@E[Eg_@1<Ool004aoo`03Mkeoogoo00Qoo`0348ANmgoo
04ioo`03@Q0aS7oo01aoo`03Mkeoogoo00Qoo`0348ABU6mk00Q_N`0348AF]Goo01Aoo`03Mke_NgNm
055oo`00Egoo00<@Q5kgOol0CWoo00=2436<Ool08goo00MNmdYBOomood8@6<IW>@07Kg/00c6<48Ao
o`1YOol005Moo`0348ANmgoo04ioo`03@Q0aS7oo029oo`04F]I242U:DY@2Ool00aS68@QW>@05Kg/0
0d8@48AW>@1ZOol005Moo`0548@8@Q2448@DY@0S48@00`Q248@@Q00R48@01QBU48@@Q124248aS2=o
o`04G_LicRU:DY@2Ool02WNm<H`0036<DYAF]DYB6<H8@VLiJgoo003>Ool00fLiBU9oo`04Ool01VLi
>LhYBQS6>LiBU6eoo`00ogooBGoo003oOom9Ool00?moodUoo`00ogooBGoo003oOom9Ool00?moodUo
o`00ogooBGoo003oOom9Ool00001\
\>"],
  CellTags->"8.4"],

Cell[TextData[{
  StyleBox["Figure 8.1. ",
    FontWeight->"Bold"],
  "Model reduction based on decomposing the system into its dominant and weak \
parts."
}], "Caption",
  CellTags->"8.4"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["DominantSubsystem",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["system",
                "TI"], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"8.4"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox[\(find\ the\ dominant\ subsystem\ of\ the\ state\),
                SingleLetterItalics->False], 
              StyleBox["-",
                SingleLetterItalics->False], 
              RowBox[{
                StyleBox["space",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["system",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"]}]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"8.4"],

Cell["Model reduction by selection of the dominant subsystem. ", "Caption",
  CellTags->"8.4"],

Cell[TextData[{
  "A reduced\[Hyphen]order model of the system ",
  StyleBox["original", "MR"],
  " can be found by selecting the dominant subsystem. "
}], "MathCaption",
  CellTags->"8.4"],

Cell[CellGroupData[{

Cell["(reduced = DominantSubsystem[original])//ReviewForm", "Input",
  CellLabel->"In[23]:= ",
  CellTags->"8.4"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(-0.592248952068226675`\), "1.19293484040695464`", 
                    "0.643875102886481887`"},
                  {\(-1.19293484040722619`\), \(-1.29982421544395476`\), 
                    \(-5.6329023777758671`\)},
                  {"0.643875102886663253`", "5.63290237777709013`", 
                    \(-1.4935261251997824`\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0.826229470180249769`"},
                  {"0.619183148769274271`"},
                  {\(-0.519547996146807911`\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0.826229470180244085`", \(-0.6191831487690159`\), 
                    \(-0.519547996146746804`\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[\(-0.0384288480055197734`\),
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[23]//ReviewForm= ",
  CellTags->"8.4"]
}, Open  ]],

Cell[TextData[{
  StyleBox["DominantSubsystem", "MR"],
  " works by first finding the internally balanced realization, if necessary, \
and then selecting the dominant part. The user has control over both these \
steps with the following options. ",
  StyleBox["DominantSubsystem", "MR"],
  " also inherits options from ",
  StyleBox["InternallyBalancedForm", "MR"],
  ". "
}], "Text",
  CellTags->"8.4"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], 
            StyleBox[" ",
              "SO10"]},
          {
            StyleBox[
              FormBox["InternallyBalanced",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["False",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(whether\ the\ assumption\ will\ be\ made\ that\ the\ input\ 
                system\ is\ internally\ balanced\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["RejectionLevel",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["0.1",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(if\ the\ relative\ value\ of\ a\ diagonal\ element\ 
                \((compared\ with\ the\ biggest\ element)\)\ of\ the\ Gramians
                \ is\ equal\ to\ or\ less\ than\ this\ value, \ 
              the\ corresponding\ mode\ is\ to\ be\ dropped\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.31, 0.18, 0.51},
  RowLines->{True, False}},
  CellTags->"8.4"],

Cell[TextData[{
  "Options specific to ",
  StyleBox["DominantSubsystem", "MR"],
  ". "
}], "Caption",
  CellTags->"8.4"],

Cell[TextData[{
  "If the default value of ",
  StyleBox["RejectionLevel", "MR"],
  " is not appropriate for the particular case, the user may find the \
internally balanced realization \"manually\" and then choose a suitable value \
for ",
  StyleBox["RejectionLevel", "MR"],
  ". In such a case, the internally balanced realization may be passed to ",
  StyleBox["DominantSubsystem", "MR"],
  " and, to avoid the repeated balancing, the option ",
  StyleBox["InternallyBalanced", "MR"],
  " can be set to ",
  StyleBox["True", "MR"],
  ". "
}], "Text",
  CellTags->"8.4"],

Cell[TextData[{
  "Because we do have the internally balanced realization of the system ",
  StyleBox["original", "MR"],
  ", we use it to find the second\[Hyphen]order reduced model. "
}], "MathCaption",
  CellTags->"8.4"],

Cell[CellGroupData[{

Cell["\<\
(reduced2 = DominantSubsystem[balanced,
 InternallyBalanced -> True,
 RejectionLevel -> .2])//ReviewForm\
\>", "Input",
  CellLabel->"In[24]:= ",
  CellTags->"8.4"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(-0.314667501618761003`\), "3.62133936366558195`"},
                  {\(-3.62133936366562902`\), \(-22.5445742483951949`\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0.602246766544114819`"},
                  {"2.57868227870358435`"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0.602246766544110201`", \(-2.57868227870358879`\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox["0.142304595986929243`",
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[24]//ReviewForm= ",
  CellTags->"8.4"]
}, Open  ]],

Cell[TextData[{
  "This creates the Bode plots for the three systems and displays them at \
once. The solid line is for the initial system, and the dashed and dashed\
\[Hyphen]dotted ones are for the third\[Hyphen] and second\[Hyphen]order \
reduced models, respectively. Note that in the first plot we set up a plot \
range sufficient to display all three graphs, and in the second plot we tweak \
",
  StyleBox["PlotPoints", "MR"],
  " for the phase unwrapping mechanism to operate correctly. \nAs we can see, \
in the reduced models the low\[Hyphen]frequency behavior is preserved while \
the high\[Hyphen]frequency (fast) states are eliminated. "
}], "MathCaption",
  CellTags->"8.4"],

Cell[CellGroupData[{

Cell["\<\
DisplayTogetherGraphicsArray[
    BodePlot[original,
       PlotRange -> {All, {0, -600}} ],
    BodePlot[reduced,
       PlotStyle -> Dashing[{.02}],
       PlotPoints -> 75 ],
    BodePlot[reduced2,
       PlotStyle -> Dashing[{.05, .015, .005, .015}] ]
]\
\>", "Input",
  CellLabel->"In[25]:=",
  CellTags->"8.4"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.29787 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0309017 0.952381 [
[ 0 0 0 0 ]
[ 1 1.29787 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.29787 L
0 1.29787 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.0309017 0.97619 0.619505 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.618034 0.00103006 [
[.02381 -0.0125 -11 -12.5625 ]
[.02381 -0.0125 11 0 ]
[.2457 -0.0125 -11 -12.5625 ]
[.2457 -0.0125 11 0 ]
[.34127 -0.0125 -5 -12.5625 ]
[.34127 -0.0125 5 0 ]
[.56317 -0.0125 -5 -12.5625 ]
[.56317 -0.0125 5 0 ]
[.65873 -0.0125 -8 -12.5625 ]
[.65873 -0.0125 8 0 ]
[.88063 -0.0125 -8 -12.5625 ]
[.88063 -0.0125 8 0 ]
[.97619 -0.0125 -11 -12.5625 ]
[.97619 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .10301 -24 -4.5 ]
[-0.0125 .10301 0 4.5 ]
[-0.0125 .20601 -24 -4.5 ]
[-0.0125 .20601 0 4.5 ]
[-0.0125 .30902 -24 -4.5 ]
[-0.0125 .30902 0 4.5 ]
[-0.0125 .41202 -24 -4.5 ]
[-0.0125 .41202 0 4.5 ]
[-0.0125 .51503 -24 -4.5 ]
[-0.0125 .51503 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -36.5625 -35 ]
[-0.01875 .30902 -24 35 ]
[.02381 .63053 -11 0 ]
[.02381 .63053 11 12.5625 ]
[.2457 .63053 -11 0 ]
[.2457 .63053 11 12.5625 ]
[.34127 .63053 -5 0 ]
[.34127 .63053 5 12.5625 ]
[.56317 .63053 -5 0 ]
[.56317 .63053 5 12.5625 ]
[.65873 .63053 -8 0 ]
[.65873 .63053 8 12.5625 ]
[.88063 .63053 -8 0 ]
[.88063 .63053 8 12.5625 ]
[.97619 .63053 -11 0 ]
[.97619 .63053 11 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2457 0 m
.2457 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.56317 0 m
.56317 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.88063 0 m
.88063 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.11937 0 m
.11937 .61803 L
s
.17528 0 m
.17528 .61803 L
s
.21494 0 m
.21494 .61803 L
s
.27084 0 m
.27084 .61803 L
s
.29209 0 m
.29209 .61803 L
s
.3105 0 m
.3105 .61803 L
s
.32674 0 m
.32674 .61803 L
s
.43683 0 m
.43683 .61803 L
s
.49274 0 m
.49274 .61803 L
s
.5324 0 m
.5324 .61803 L
s
.5883 0 m
.5883 .61803 L
s
.60955 0 m
.60955 .61803 L
s
.62797 0 m
.62797 .61803 L
s
.6442 0 m
.6442 .61803 L
s
.7543 0 m
.7543 .61803 L
s
.8102 0 m
.8102 .61803 L
s
.84986 0 m
.84986 .61803 L
s
.90576 0 m
.90576 .61803 L
s
.92702 0 m
.92702 .61803 L
s
.94543 0 m
.94543 .61803 L
s
.96166 0 m
.96166 .61803 L
s
0 .10301 m
1 .10301 L
s
0 .20601 m
1 .20601 L
s
0 .30902 m
1 .30902 L
s
0 .41202 m
1 .41202 L
s
0 .51503 m
1 .51503 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 0 m
.2457 .00625 L
s
gsave
.2457 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 0 m
.56317 .00625 L
s
gsave
.56317 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 0 m
.88063 .00625 L
s
gsave
.88063 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 0 m
.11937 .00375 L
s
.17528 0 m
.17528 .00375 L
s
.21494 0 m
.21494 .00375 L
s
.27084 0 m
.27084 .00375 L
s
.29209 0 m
.29209 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.32674 0 m
.32674 .00375 L
s
.43683 0 m
.43683 .00375 L
s
.49274 0 m
.49274 .00375 L
s
.5324 0 m
.5324 .00375 L
s
.5883 0 m
.5883 .00375 L
s
.60955 0 m
.60955 .00375 L
s
.62797 0 m
.62797 .00375 L
s
.6442 0 m
.6442 .00375 L
s
.7543 0 m
.7543 .00375 L
s
.8102 0 m
.8102 .00375 L
s
.84986 0 m
.84986 .00375 L
s
.90576 0 m
.90576 .00375 L
s
.92702 0 m
.92702 .00375 L
s
.94543 0 m
.94543 .00375 L
s
.96166 0 m
.96166 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .10301 m
.00625 .10301 L
s
[(-500)] -0.0125 .10301 1 0 Mshowa
0 .20601 m
.00625 .20601 L
s
[(-400)] -0.0125 .20601 1 0 Mshowa
0 .30902 m
.00625 .30902 L
s
[(-300)] -0.0125 .30902 1 0 Mshowa
0 .41202 m
.00625 .41202 L
s
[(-200)] -0.0125 .41202 1 0 Mshowa
0 .51503 m
.00625 .51503 L
s
[(-100)] -0.0125 .51503 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(0)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0206 m
.00375 .0206 L
s
0 .0412 m
.00375 .0412 L
s
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .12361 m
.00375 .12361 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .28842 m
.00375 .28842 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .37082 m
.00375 .37082 L
s
0 .39142 m
.00375 .39142 L
s
0 .43262 m
.00375 .43262 L
s
0 .45322 m
.00375 .45322 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .53563 m
.00375 .53563 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -126.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
96 10.2813 translate
90 rotate
-96 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Phase) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
99.000000 12.812500 moveto
(H) show
105.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(deg) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(L) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 .61178 m
.2457 .61803 L
s
gsave
.2457 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 .61178 m
.34127 .61803 L
s
gsave
.34127 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 .61178 m
.56317 .61803 L
s
gsave
.56317 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 .61178 m
.65873 .61803 L
s
gsave
.65873 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 .61178 m
.88063 .61803 L
s
gsave
.88063 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 .61428 m
.11937 .61803 L
s
.17528 .61428 m
.17528 .61803 L
s
.21494 .61428 m
.21494 .61803 L
s
.27084 .61428 m
.27084 .61803 L
s
.29209 .61428 m
.29209 .61803 L
s
.3105 .61428 m
.3105 .61803 L
s
.32674 .61428 m
.32674 .61803 L
s
.43683 .61428 m
.43683 .61803 L
s
.49274 .61428 m
.49274 .61803 L
s
.5324 .61428 m
.5324 .61803 L
s
.5883 .61428 m
.5883 .61803 L
s
.60955 .61428 m
.60955 .61803 L
s
.62797 .61428 m
.62797 .61803 L
s
.6442 .61428 m
.6442 .61803 L
s
.7543 .61428 m
.7543 .61803 L
s
.8102 .61428 m
.8102 .61803 L
s
.84986 .61428 m
.84986 .61803 L
s
.90576 .61428 m
.90576 .61803 L
s
.92702 .61428 m
.92702 .61803 L
s
.94543 .61428 m
.94543 .61803 L
s
.96166 .61428 m
.96166 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 0 m
1 0 L
s
.99375 .10301 m
1 .10301 L
s
.99375 .20601 m
1 .20601 L
s
.99375 .30902 m
1 .30902 L
s
.99375 .41202 m
1 .41202 L
s
.99375 .51503 m
1 .51503 L
s
.125 Mabswid
.99625 .0206 m
1 .0206 L
s
.99625 .0412 m
1 .0412 L
s
.99625 .0618 m
1 .0618 L
s
.99625 .0824 m
1 .0824 L
s
.99625 .12361 m
1 .12361 L
s
.99625 .14421 m
1 .14421 L
s
.99625 .16481 m
1 .16481 L
s
.99625 .18541 m
1 .18541 L
s
.99625 .22661 m
1 .22661 L
s
.99625 .24721 m
1 .24721 L
s
.99625 .26781 m
1 .26781 L
s
.99625 .28842 m
1 .28842 L
s
.99625 .32962 m
1 .32962 L
s
.99625 .35022 m
1 .35022 L
s
.99625 .37082 m
1 .37082 L
s
.99625 .39142 m
1 .39142 L
s
.99625 .43262 m
1 .43262 L
s
.99625 .45322 m
1 .45322 L
s
.99625 .47383 m
1 .47383 L
s
.99625 .49443 m
1 .49443 L
s
.99625 .53563 m
1 .53563 L
s
.99625 .55623 m
1 .55623 L
s
.99625 .57683 m
1 .57683 L
s
.99625 .59743 m
1 .59743 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .6105 m
.05665 .60849 L
.08949 .60596 L
.12233 .60278 L
.15517 .59881 L
.18801 .59391 L
.22085 .58794 L
.25369 .58082 L
.28654 .57258 L
.31938 .56341 L
.35222 .55366 L
.38506 .54384 L
.4179 .53445 L
.45074 .52571 L
.48358 .517 L
.51642 .50474 L
.54926 .47339 L
.5821 .41543 L
.61494 .39373 L
.64778 .39114 L
.68062 .39428 L
.71346 .39928 L
.74631 .40464 L
.77915 .40965 L
.81199 .41405 L
.84483 .41774 L
.87767 .42077 L
.91051 .42322 L
.94335 .42518 L
.97619 .42675 L
s
[ .02 ] 0 setdash
0 .61162 m
.01523 .61088 L
.03239 .60994 L
.04955 .60888 L
.06671 .60768 L
.08387 .60633 L
.10103 .60481 L
.11819 .6031 L
.13535 .60119 L
.15251 .59905 L
.16967 .59667 L
.18683 .59402 L
.20399 .5911 L
.22115 .5879 L
.23831 .58441 L
.25547 .58064 L
.27263 .5766 L
.28979 .57231 L
.30695 .5678 L
.32411 .56312 L
.34127 .55829 L
.35843 .55334 L
.37559 .54831 L
.39275 .54321 L
.40991 .53801 L
.42707 .53269 L
.44423 .52719 L
.46139 .52139 L
.47855 .51512 L
.49571 .50809 L
.51287 .49982 L
.53003 .48938 L
.54719 .47492 L
.56435 .45273 L
.58151 .41894 L
.59867 .38173 L
.61583 .35369 L
.63299 .28165 L
.65015 .14736 L
.66731 .13594 L
.68447 .12749 L
.70163 .12038 L
.71879 .11416 L
.73595 .10859 L
.75311 .10358 L
.77027 .09905 L
.78743 .09497 L
.80459 .0913 L
.82175 .088 L
.83891 .08504 L
Mistroke
.85607 .0824 L
.87323 .08004 L
.89039 .07795 L
.90755 .07609 L
.92471 .07443 L
.94187 .07297 L
.95903 .07167 L
.97619 .07052 L
Mfstroke
[ .05 .015 .005 .015 ] 0 setdash
0 .61157 m
.03476 .60988 L
.08949 .60596 L
.14423 .60026 L
.19896 .59214 L
.25369 .58111 L
.30843 .56717 L
.36316 .55111 L
.4179 .53391 L
.47263 .51564 L
.52737 .49501 L
.5821 .46992 L
.63684 .43854 L
.69157 .40181 L
.74631 .3647 L
.80104 .3324 L
.85577 .30701 L
.91051 .28834 L
.96524 .27517 L
s
.96524 .27517 m
1 .26942 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.678366 0.97619 1.26697 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.603678 0.00736865 [
[.02381 -0.0125 -11 -12.5625 ]
[.02381 -0.0125 11 0 ]
[.2457 -0.0125 -11 -12.5625 ]
[.2457 -0.0125 11 0 ]
[.34127 -0.0125 -5 -12.5625 ]
[.34127 -0.0125 5 0 ]
[.56317 -0.0125 -5 -12.5625 ]
[.56317 -0.0125 5 0 ]
[.65873 -0.0125 -8 -12.5625 ]
[.65873 -0.0125 8 0 ]
[.88063 -0.0125 -8 -12.5625 ]
[.88063 -0.0125 8 0 ]
[.97619 -0.0125 -11 -12.5625 ]
[.97619 -0.0125 11 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -68 -25.125 ]
[.5 -0.0125 68 -12.5625 ]
[-0.0125 .01419 -18 -4.5 ]
[-0.0125 .01419 0 4.5 ]
[-0.0125 .16156 -18 -4.5 ]
[-0.0125 .16156 0 4.5 ]
[-0.0125 .30893 -18 -4.5 ]
[-0.0125 .30893 0 4.5 ]
[-0.0125 .4563 -18 -4.5 ]
[-0.0125 .4563 0 4.5 ]
[-0.0125 .60368 -6 -4.5 ]
[-0.0125 .60368 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -30.5625 -44 ]
[-0.01875 .30902 -18 44 ]
[.02381 .63053 -11 0 ]
[.02381 .63053 11 12.5625 ]
[.2457 .63053 -11 0 ]
[.2457 .63053 11 12.5625 ]
[.34127 .63053 -5 0 ]
[.34127 .63053 5 12.5625 ]
[.56317 .63053 -5 0 ]
[.56317 .63053 5 12.5625 ]
[.65873 .63053 -8 0 ]
[.65873 .63053 8 12.5625 ]
[.88063 .63053 -8 0 ]
[.88063 .63053 8 12.5625 ]
[.97619 .63053 -11 0 ]
[.97619 .63053 11 12.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 -0.0005 0 0 ]
[ 1 .61853 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 .5 r
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
.2457 0 m
.2457 .61803 L
s
.34127 0 m
.34127 .61803 L
s
.56317 0 m
.56317 .61803 L
s
.65873 0 m
.65873 .61803 L
s
.88063 0 m
.88063 .61803 L
s
.97619 0 m
.97619 .61803 L
s
.11937 0 m
.11937 .61803 L
s
.17528 0 m
.17528 .61803 L
s
.21494 0 m
.21494 .61803 L
s
.27084 0 m
.27084 .61803 L
s
.29209 0 m
.29209 .61803 L
s
.3105 0 m
.3105 .61803 L
s
.32674 0 m
.32674 .61803 L
s
.43683 0 m
.43683 .61803 L
s
.49274 0 m
.49274 .61803 L
s
.5324 0 m
.5324 .61803 L
s
.5883 0 m
.5883 .61803 L
s
.60955 0 m
.60955 .61803 L
s
.62797 0 m
.62797 .61803 L
s
.6442 0 m
.6442 .61803 L
s
.7543 0 m
.7543 .61803 L
s
.8102 0 m
.8102 .61803 L
s
.84986 0 m
.84986 .61803 L
s
.90576 0 m
.90576 .61803 L
s
.92702 0 m
.92702 .61803 L
s
.94543 0 m
.94543 .61803 L
s
.96166 0 m
.96166 .61803 L
s
0 .16156 m
1 .16156 L
s
0 .30893 m
1 .30893 L
s
0 .4563 m
1 .4563 L
s
0 g
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 0 m
.2457 .00625 L
s
gsave
.2457 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 0 m
.56317 .00625 L
s
gsave
.56317 -0.0125 -66 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 0 m
.88063 .00625 L
s
gsave
.88063 -0.0125 -69 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -72 -16.5625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 0 m
.11937 .00375 L
s
.17528 0 m
.17528 .00375 L
s
.21494 0 m
.21494 .00375 L
s
.27084 0 m
.27084 .00375 L
s
.29209 0 m
.29209 .00375 L
s
.3105 0 m
.3105 .00375 L
s
.32674 0 m
.32674 .00375 L
s
.43683 0 m
.43683 .00375 L
s
.49274 0 m
.49274 .00375 L
s
.5324 0 m
.5324 .00375 L
s
.5883 0 m
.5883 .00375 L
s
.60955 0 m
.60955 .00375 L
s
.62797 0 m
.62797 .00375 L
s
.6442 0 m
.6442 .00375 L
s
.7543 0 m
.7543 .00375 L
s
.8102 0 m
.8102 .00375 L
s
.84986 0 m
.84986 .00375 L
s
.90576 0 m
.90576 .00375 L
s
.92702 0 m
.92702 .00375 L
s
.94543 0 m
.94543 .00375 L
s
.96166 0 m
.96166 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -129 -29.125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Frequency) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Rad) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
147.000000 12.812500 moveto
(\\220) show
153.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Second) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
189.000000 12.812500 moveto
(L) show
195.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
0 .01419 m
.00625 .01419 L
s
[(-80)] -0.0125 .01419 1 0 Mshowa
0 .16156 m
.00625 .16156 L
s
[(-60)] -0.0125 .16156 1 0 Mshowa
0 .30893 m
.00625 .30893 L
s
[(-40)] -0.0125 .30893 1 0 Mshowa
0 .4563 m
.00625 .4563 L
s
[(-20)] -0.0125 .4563 1 0 Mshowa
0 .60368 m
.00625 .60368 L
s
[(0)] -0.0125 .60368 1 0 Mshowa
.125 Mabswid
0 .05103 m
.00375 .05103 L
s
0 .08787 m
.00375 .08787 L
s
0 .12472 m
.00375 .12472 L
s
0 .1984 m
.00375 .1984 L
s
0 .23525 m
.00375 .23525 L
s
0 .27209 m
.00375 .27209 L
s
0 .34577 m
.00375 .34577 L
s
0 .38262 m
.00375 .38262 L
s
0 .41946 m
.00375 .41946 L
s
0 .49315 m
.00375 .49315 L
s
0 .52999 m
.00375 .52999 L
s
0 .56683 m
.00375 .56683 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -129.281 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
105 10.2813 translate
90 rotate
-105 -10.2813 translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(Magnitude) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
123.000000 12.812500 moveto
(H) show
129.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(dB) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
141.000000 12.812500 moveto
(L) show
147.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Math2Mono
%%+ font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Math2Mono
%%+ Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Math2Mono
%%+ Courier
grestore
.02381 .61178 m
.02381 .61803 L
s
gsave
.02381 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.1) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.2457 .61178 m
.2457 .61803 L
s
gsave
.2457 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(0.5) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.34127 .61178 m
.34127 .61803 L
s
gsave
.34127 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(1) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.56317 .61178 m
.56317 .61803 L
s
gsave
.56317 .63053 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(5) show
69.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.65873 .61178 m
.65873 .61803 L
s
gsave
.65873 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(10) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.88063 .61178 m
.88063 .61803 L
s
gsave
.88063 .63053 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(50) show
75.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.97619 .61178 m
.97619 .61803 L
s
gsave
.97619 .63053 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
gsave
0.000000 0.000000 0.000000 setrgbcolor
1.000000 setlinewidth
gsave
newpath
 61.000000 16.562500 moveto
 460.000000 16.562500 lineto
 460.000000 4.000000 lineto
 61.000000 4.000000 lineto
 61.000000 16.562500 lineto
closepath
clip newpath
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
63.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
(100) show
81.000000 12.812500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000000 0.000000 0.000000 setrgbcolor
0.000000 0.000000 rmoveto
1.000000 setlinewidth
grestore
grestore
%%DocumentNeededResources: font Courier
%%DocumentSuppliedResources:
%%DocumentNeededFonts: Courier
%%DocumentSuppliedFonts:
%%DocumentFonts: Courier
grestore
.001 w
.11937 .61428 m
.11937 .61803 L
s
.17528 .61428 m
.17528 .61803 L
s
.21494 .61428 m
.21494 .61803 L
s
.27084 .61428 m
.27084 .61803 L
s
.29209 .61428 m
.29209 .61803 L
s
.3105 .61428 m
.3105 .61803 L
s
.32674 .61428 m
.32674 .61803 L
s
.43683 .61428 m
.43683 .61803 L
s
.49274 .61428 m
.49274 .61803 L
s
.5324 .61428 m
.5324 .61803 L
s
.5883 .61428 m
.5883 .61803 L
s
.60955 .61428 m
.60955 .61803 L
s
.62797 .61428 m
.62797 .61803 L
s
.6442 .61428 m
.6442 .61803 L
s
.7543 .61428 m
.7543 .61803 L
s
.8102 .61428 m
.8102 .61803 L
s
.84986 .61428 m
.84986 .61803 L
s
.90576 .61428 m
.90576 .61803 L
s
.92702 .61428 m
.92702 .61803 L
s
.94543 .61428 m
.94543 .61803 L
s
.96166 .61428 m
.96166 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01419 m
1 .01419 L
s
.99375 .16156 m
1 .16156 L
s
.99375 .30893 m
1 .30893 L
s
.99375 .4563 m
1 .4563 L
s
.99375 .60368 m
1 .60368 L
s
.125 Mabswid
.99625 .05103 m
1 .05103 L
s
.99625 .08787 m
1 .08787 L
s
.99625 .12472 m
1 .12472 L
s
.99625 .1984 m
1 .1984 L
s
.99625 .23525 m
1 .23525 L
s
.99625 .27209 m
1 .27209 L
s
.99625 .34577 m
1 .34577 L
s
.99625 .38262 m
1 .38262 L
s
.99625 .41946 m
1 .41946 L
s
.99625 .49315 m
1 .49315 L
s
.99625 .52999 m
1 .52999 L
s
.99625 .56683 m
1 .56683 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.05665 .6031 L
.08949 .60275 L
.12233 .6022 L
.15517 .60133 L
.18801 .59996 L
.22085 .59786 L
.25369 .5947 L
.28654 .59011 L
.31938 .58371 L
.35222 .57528 L
.38506 .56488 L
.4179 .55304 L
.45074 .54102 L
.48358 .53112 L
.51642 .52728 L
.54926 .53058 L
.5821 .49322 L
.61494 .42615 L
.64778 .36963 L
.68062 .3218 L
.71346 .27971 L
.74631 .24151 L
.77915 .20597 L
.81199 .17222 L
.84483 .13965 L
.87767 .10785 L
.91051 .07653 L
.94335 .04553 L
.97619 .01472 L
s
[ .02 ] 0 setdash
0 .6034 m
.01523 .60333 L
.03239 .60323 L
.04955 .6031 L
.06671 .60294 L
.08387 .60274 L
.10103 .60248 L
.11819 .60215 L
.13535 .60173 L
.15251 .6012 L
.16967 .60054 L
.18683 .59971 L
.20399 .59867 L
.22115 .5974 L
.23831 .59584 L
.25547 .59395 L
.27263 .59168 L
.28979 .58902 L
.30695 .58591 L
.32411 .58237 L
.34127 .57837 L
.35843 .57396 L
.37559 .56917 L
.39275 .56407 L
.40991 .55871 L
.42707 .55321 L
.44423 .54767 L
.46139 .54221 L
.47855 .53701 L
.49571 .53224 L
.51287 .52816 L
.53003 .52499 L
.54719 .52267 L
.56435 .51928 L
.58151 .50574 L
.59867 .4672 L
.61583 .40034 L
.63299 .21197 L
.65015 .34999 L
.66731 .37755 L
.68447 .38822 L
.70163 .39309 L
.71879 .39538 L
.73595 .39639 L
.75311 .39675 L
.77027 .39678 L
.78743 .39665 L
.80459 .39646 L
.82175 .39625 L
.83891 .39605 L
Mistroke
.85607 .39587 L
.87323 .39572 L
.89039 .3956 L
.90755 .39549 L
.92471 .39541 L
.94187 .39534 L
.95903 .39529 L
.97619 .39525 L
Mfstroke
[ .05 .015 .005 .015 ] 0 setdash
0 .60339 m
.03476 .60324 L
.08949 .60272 L
.14423 .6016 L
.19896 .59924 L
.25369 .59459 L
.30843 .58623 L
.36316 .57315 L
.4179 .55559 L
.47263 .53503 L
.52737 .51338 L
.5821 .49286 L
.63684 .47651 L
.69157 .46781 L
.74631 .46724 L
.80104 .47071 L
.85577 .47425 L
.91051 .47654 L
.96524 .47777 L
s
.96524 .47777 m
1 .47815 L
s
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[25]:=",
  ImageSize->{221.875, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003M000181000`40O003h00OgGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo001>Ool2000EOol2000EOol00`00Oomo
o`0lOol00`00Oomoo`0OOol004moo`03001oogoo01Aoo`03001oogoo019oo`03001oogoo01=oo`03
001oogoo02Qoo`03001oogoo01ioo`00?7oo0`000goo0`000goo0P000goo0`000Woo0`000Woo0P00
00=oo`0000000Woo00<007oo00000P000goo00<007ooOol04Goo00@007ooOomoo`<00003Ool007oo
00@0009oo`<000Eoo`03001oogoo009oo`<000=oo`80009oo`<000=oo`800003Ool00000009oo`03
001oogoo00<000Uoo`03001oogoo01eoo`00?Goo00<007ooOol00goo00D007ooOomoo`0000Aoo`06
001oogoo001oo`000Woo00<007oo000017oo00H007ooOol007oo0004Ool00`00Ool0000BOol00`00
Oomoo`02Ool01@00Oomoo`00Ool00`000Woo00@007ooOol000Eoo`03001oogoo009oo`03001oo`00
009oo`03001oogoo009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<0
07ooOol01goo00<007ooOol07Goo000mOol00`00Oomoo`03Ool01000Oomoogoo0`000Woo00H007oo
Ool007oo0002Ool00`00Ool000020002Ool01P00Oomoo`00Ool000Aoo`03001oo`00019oo`03001o
ogoo009oo`<000Aoo`04001oogoo0002Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03
0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo00Moo`03
001oogoo01eoo`00?Goo0P000goo100000Aoo`00000000=oo`D00004Ool00000Ool300000goo0000
00020002Ool3000017oo000007oo0P004Goo00<007ooOol00Woo00@007ooOol0009oo`8000=oo`<0
00Ioo`03001oogoo009oo`04001oogooOol30002Ool30003Ool200000goo000000020003Ool30009
Ool00`00Oomoo`0MOol003eoo`04001oogoo000jOol01@00Oomoogoo00000Woo00<007ooOol01goo
00<007ooOol017oo00L007ooOomoo`00Ool0000IOol00`00Oomoo`06Ool00`00Oomoo`0NOol003ao
o`D003]oo`03001oo`0000<000Uoo`8000Moo`03001oogoo00<001Qoo`8000Moo`03001oogoo01mo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo000bOol00`00Oomoo`02Ool00`00Oomo
o`05000COol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool5000MOol00`00Oomoo`06
Ool50002Ool00`00Oomoo`0GOol00`00Oomoo`02Ool01000Oomoogoo1@000Woo00<007ooOol00Woo
00<007ooOol05Goo000aOol00`00Ool00008Ool00`00Oomoo`0BOol00`00Ool00007Ool00`00Ool0
0008Ool00`00Oomoo`0LOol00`00Ool00009Ool01`00Oomoogoo001oo`0001Moo`03001oo`00009o
o`03001oo`0000Aoo`07001oogooOol007oo00000Woo00<007oo00005Woo000aOol00`00Ool00008
Ool00`00Oomoo`0BOol00`00Ool00009Ool00`00Oomoo`06Ool00`00Oomoo`0NOol00`00Oomoo`07
Ool01`00Oomoogoo001oo`0001Uoo`06001oogoo001oo`0017oo00L007ooOomoo`00Ool00002Ool0
0`00Ool0000FOol0035oo`03001oo`0000Qoo`03001oogoo019oo`03001oo`0000Moo`8000Uoo`03
001oogoo01aoo`8000Yoo`07001oogooOol007oo00005goo0P000goo00<007oo000017oo00L007oo
Oomoo`00Ool00002Ool00`00Ool0000FOol0035oo`03001oo`0000Qoo`03001oogoo019oo`03001o
o`0000Moo`03001oogoo00Qoo`03001oogoo01aoo`03001oogoo00Uoo`07001oogooOol007oo0000
5goo00<007ooOol00Woo00<007oo000017oo00L007ooOomoo`00Ool00002Ool00`00Ool0000FOol0
039oo`03001oogoo00Ioo`8001Eoo`03001oogoo00Ioo`<000Moo`8001ioo`<000Qoo`8000Aoo`03
001oogoo01Ioo`<000=oo`03001oogoo009oo`8000Aoo`03001oogoo009oo`03001oogoo01Eoo`00
gGoo003MOol00=eoo`00=WooT@005Woo000fOol01000Oomoo`003Goo00<007ooOol01Goo00<007oo
Ool00goo00D007ooOomoo`0000=oo`04001oogoo0002Ool01@00Ool007oo00003Goo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`06001oogoo001oo`000Woo00<0
07ooOol02Woo00<007ooOol01Goo00<007ooOol00goo00D007ooOomoo`0000=oo`04001oogoo0002
Ool01@00Ool007oo00000goo00<007ooOol057oo000fOol01000Oomoo`0?3Goo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?
0Woo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03goo00l00goo00<007ooOol057oo000fOol200000goo00moo`0<Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo
Ool03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00@03gooOol03`9oo`0500moo`0?Ool03`02Ool2000FOol003Ioo`04001oogoo00l=Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo
Ool03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0DOol003Ioo`04001oogoo00l=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0DOol003Ioo`800003
Ool03goo00aoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?
0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00=o
o`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?009oo`8001Ioo`00=Woo00@0
07ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?
0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00=o
o`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001oogoo01Aoo`00
=Woo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?
Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eoo`0300mo
ogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001oogoo
01Aoo`00=Woo0P0000=oo`0?Ool037oo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00Woo
0P005Woo000fOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo
00<007ooOol057oo000fOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo00<0
3gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moo`0000<0000300l000000080
00=oo`03001oogoo01Aoo`00=Woo0P0000=oo`0?Ool037oo00<03gooOol01Goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol0
2Woo00<03gooOol01Goo00<03gooOol00Woo0`000Woo100000@03gooOol03`9oo`0500moo`0?Ool0
3`02Ool2000FOol0019oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo009oo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02
Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?
Oomoo`05Ool0100?000007oo0P0000D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo
00l00goo00<007ooOol057oo000BOol6000>Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool0
0003Ool01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`04
00moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol0
0Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo00D03gooOomoo`00009o
o`8000Eoo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001oogoo
01Aoo`004Woo00H007ooOol007oo0009Ool30004Ool01P00Oomoo`00Ool0009oo`03001oo`0000=o
o`8006/03`<001l03`8001Ioo`004Woo00@007ooOol0011oo`8000=oo`03001oo`00009oo`03001o
o`0000=oo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`08Ool00`00Ool03`07Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00
Oomoo`0DOol001=oo`80015oo`03001oogoo009oo`03001oo`00009oo`03001oo`0000=oo`04001o
ogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`06Ool20002Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0D
Ool002Ioo`<000=oo`03001oogoo009oo`03001oogoo009oo`800003Ool03goo00aoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eo
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?
Ool03`9oo`0300moogoo009oo`8000Ioo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol0
3`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?009oo`8001Ioo`004Woo00<007ooOol00Woo00<0
07ooOol077oo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo008000Qoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=o
o`03001oogoo01Aoo`004Woo1P007Woo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=o
o`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300l007oo
00Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D0
3goo00moo`0?00=oo`03001oogoo01Aoo`0057oo00@007ooOol001ioo`800003Ool03goo00aoo`03
00moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00mo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01`0?
Oomoo`0?Ool03goo008000aoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00D03goo00moo`0?009oo`8001Ioo`0057oo00<007ooOol07goo00@007ooOol0
3`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D0
3goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2
Ool02@0?Oomoo`0?Ool03`00Ool03`0<Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0DOol001Eoo`<001ioo`04
001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol0
3`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0DOol0
01Moo`03001oogoo01aoo`800003Ool03goo00aoo`0300moogoo00Eoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0400moogoo00l2Ool02@0?Oomoo`0?Ool03`00Ool03`0<Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`02
Ool2000FOol003Ioo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0Woo00T03gooOol03goo00l007oo00l037oo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo00<0
07ooOol057oo000FOol2000NOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`9oo`0900moogoo00moo`0?001oo`0?00aoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?
00=oo`03001oogoo01Aoo`0057oo00@007oo000001ioo`800003Ool03goo00aoo`0300moogoo00Eo
o`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool02@0?Oomoo`0?Ool0
3`00Ool03`0<Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol0
3`9oo`0500moo`0?Ool03`02Ool2000FOol001Aoo`04001oo`00000?Ool30002Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo00<03goo
Ool01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l0
0goo00<007ooOol057oo000DOol4000@Ool01P00Oomoo`00Ool0009oo`03001oo`0000=oo`04001o
ogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0DOol001Mo
o`03001oogoo00Moo`<0009oo`@00004Ool007oo0002Ool00`00Ool00003Ool2001J00l00`0000l0
3`0`00l2000FOol002Ioo`03001oo`00009oo`03001oo`00009oo`03001oo`0000=oo`04001oogoo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00H03gooOol03goo0002Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0DOol001Aoo`80
0003Ool007oo00ioo`80009oo`03001oo`00009oo`03001oo`0000=oo`04001oogoo00l=Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo
Ool03goo0002Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0DOol001Aoo`800003Ool007oo
00moo`05001oogooOol00004Ool00`00Oomoo`02Ool200000goo00moo`0<Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo0002
Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`02Ool2000FOol001Aoo`800003Ool007oo01eoo`04001oogoo00l=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0DOol001Aoo`03001o
o`0001moo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00
Oomoo`0DOol003Ioo`800003Ool03goo00aoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?00003`9oo`0300moogoo00Yoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?
009oo`8001Ioo`00=Woo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?00003`9oo`0300moogoo00Yoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?
00=oo`03001oogoo01Aoo`005Goo0P007goo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?00003`9oo`0300mo
ogoo00Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00=oo`03001oogoo01Aoo`0057oo0P0000=oo`00Ool07Goo0P0000=oo`0?Ool0
37oo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?
Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9o
o`0600moogoo00l0000?0Woo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0400moogoo00l2Ool01P0?Ool03goo00moo`<001Ioo`0057oo0P0000=oo`00Ool0
7Goo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?
Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eoo`0300mo
ogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo1P000Woo00<007ooOol057oo000EOol0
0`00Ool0000NOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`9oo`0600moogoo00l0000?0Woo00<03gooOol02Woo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0300moogoo00800006Ool03goo00moo`0?0goo
00<007ooOol057oo000fOol200000goo00moo`0<Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03`0000l2Ool00`0?Oomoo`0:Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo0P0000Uoo`0?Oomoo`0?Ool03goo
00l00Woo0P005Woo000VOol20004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`0?3Goo
00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool0
3goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`06
00moogoo001oo`0?0Woo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol00goo00D03gooOomo
o`0?00<0000400moogoo00l2Ool01@0?Ool03goo00l00goo00<007ooOol057oo000XOol01P00Oomo
o`00Ool0009oo`03001oo`0000=oo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol007oo00l2Ool00`0?Oomoo`0:
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool00`0?Oomoo`020003Ool0100?Oomoo`0?0Woo00D03goo
00moo`0?00=oo`03001oogoo01Aoo`008Goo0`000goo00L007ooOomoo`00Ool00002Ool00`00Ool0
0003Ool2001h00l2000C00l2000FOol002Qoo`06001oogoo001oo`000Woo00<007oo00000goo00@0
07ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?
0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400mo
ogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo0080
0003Ool03goo009oo`0500moogooOol03`02Ool0200?Oomoo`0?Ool03goo00l3Ool00`00Oomoo`0D
Ool002Ioo`03001oo`00009oo`03001oo`00009oo`03001oo`0000=oo`04001oogoo00l=Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo
00003goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?00000003Ool01@0?Oomoogoo00l0
0goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0DOol002Moo`03001oogoo009o
o`03001oogoo009oo`03001oogoo009oo`800003Ool03goo00aoo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool0000?Ool03`9oo`0300mo
ogoo00Yoo`0300moogoo00Aoo`8000Eoo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo
00moo`0?009oo`8001Ioo`00=Woo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`05
00moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool0000?Ool03`9oo`0300moogoo00Yo
o`0300moogoo009oo`800003Ool03goo00Aoo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D0
3goo00moo`0?00=oo`03001oogoo01Aoo`00=Woo00@007ooOol03`eoo`0300moogoo00Eoo`0300mo
ogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo
00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Ool0000?Ool03`9oo`03
00moogoo00Yoo`0500moogooOol00003Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0DOol001Aoo`@001ioo`800003Ool03goo00ao
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo
00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0
1P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0400moogoo0004Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`02Ool2000FOol001=oo`03001oogoo009o
o`03001oogoo01]oo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
0`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03`00Ool03goo00l2Ool00`0?Oomoo`0:Ool00`0?001o
o`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03
Ool00`00Oomoo`0DOol0019oo`03001oogoo00Aoo`03001oogoo01Yoo`04001oogoo00l=Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H007oo
Ool03goo00l2Ool00`0?Oomoo`09Ool20007Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@0
3gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0DOol003Ioo`800003Ool03goo00aoo`03
00moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00mo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P00
Oomoo`0?Ool03`9oo`0300moogoo00Moo`800003Ool03goo00Ioo`0300moogoo00=oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?009oo`8001Ioo`00=Woo00@007ooOol03`eo
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo
00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0700moogoo00moo`00
00l00Woo00<03goo00l00Woo00<03gooOol01Goo0P000goo00<03gooOol01Goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo00<007ooOol057oo000E
Ool2000OOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo00<0
07ooOol057oo000DOol01000Oomoo`007Woo0P0000=oo`0?Ool037oo00<03gooOol01Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol0
1Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0300l0000000X00003Ool007oo
00Eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D0
3goo00moo`0?009oo`8001Ioo`004Woo00<007oo00000Woo00<007ooOol037oo0`000goo00<007oo
Ool00Woo00<007ooOol00Woo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0700moogoo00l007oo00000Woo00<03goo00l00Woo00@03gooOomoo`H0
00=oo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D0
3goo00moo`0?00=oo`03001oogoo01Aoo`004Woo1P003Woo00<007ooOol00Woo00<007oo00000Woo
00<007oo00000goo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol0
3`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`03
00moogoo009oo`0300moogoo00<0000600moogoo00moo`0?0Woo00@03goo000000Ioo`X00003Ool0
3goo00Aoo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001oogoo
01Aoo`005goo00<007ooOol01goo0`000goo00L007ooOomoo`00Ool00002Ool00`00Ool00003Ool2
001B00l00`0000l03`0900l00`0000l03`0@00l9000C00l2000FOol002Moo`07001oogooOol007oo
00000Woo00<007oo00000goo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo
009oo`0300moogoo009oo`0400moo`0000l2Ool01`0?Oomoo`0?Ool03goo008000aoo`0300moogoo
00Eoo`0300moogoo00=oo`0300moo`0000d0000300moo`0?00=oo`03001oogoo01Aoo`005Goo0P00
3goo00<007oo00000Woo00<007oo00000Woo00<007oo00000goo00@007ooOol03`eoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eo
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moo`0000l2Ool02@0?Oomoo`0?
Ool03`00Ool03`0<Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0300moo`00008000=oo`03001oogoo01Aoo`0057oo0P0000=oo`00Ool03Woo00<007oo
Ool00Woo00<007ooOol00Woo00<007ooOol00Woo0P0000=oo`0?Ool037oo00<03gooOol01Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00@03`00Ool03`9oo`0600moogoo00l0000?0Woo
00<03gooOol02Woo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo
00l2Ool01@0?Ool03goo00l00Woo0P005Woo000DOol200000goo001oo`0MOol01000Oomoo`0?3Goo
00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool0
3goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@007ooOol03`9oo`06
00moogoo00l0000?0Woo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo00<007ooOol057oo000EOol00`00Ool0
000NOol200000goo00moo`0<Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool01000Oomoo`0?0Woo00H03goo00003goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`02Ool2000F
Ool003Ioo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool01P0?Oomo
ogoo00003`9oo`0300moogoo00800004Ool03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00
Oomoo`0DOol003Ioo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool0
1P0?Oomoogoo00003`9oo`0400l0000000l2Ool00`0?Ool03`02Ool00`0?Oomoo`0:Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03
Ool00`00Oomoo`0DOol001Eoo`80009oo`03001oogoo01Yoo`800003Ool03goo00aoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eo
o`0300moogoo00Eoo`0300moogoo009oo`0600moogoo001oo`0?0`000Woo00H03gooOol03goo00l2
Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`02Ool2000FOol001Aoo`06001oogoo001oo`0077oo00@007ooOol0
3`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D0
3goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moo`000080000400moogoo00l2
Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500mo
ogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001oogoo01Aoo`0057oo00H0
07ooOol007oo000LOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo
00H03`00001oo`0000l2Ool0100?Oomoo`0?0Woo00<03goo00l00Woo00<03gooOol02Woo00<03goo
Ool01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l0
0goo00<007ooOol057oo000DOol5000MOol200000goo00moo`0<Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05
Ool0100?Oomoogoo0`000goo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo
00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool0
3goo00l00Woo0P005Woo000DOol00`00Oomoo`0>Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03goo00000P0000<03gooOol00Woo
00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo00<03gooOol01Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo00<007ooOol0
57oo000WOol01`00Oomoogoo001oo`00009oo`03001oo`0000=oo`04001oogoo00l=Ool00`0?Oomo
o`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=
Ool00`0?Oomoo`05Ool400000goo00moo`03Ool0100?Oomoo`0?0Woo00H03gooOol03goo00l2Ool0
0`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol0
3`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0DOol0019oo`03001oogoo00Aoo`03001oogoo00Eo
o`<000=oo`07001oogooOol007oo00000Woo00<007oo00000goo0P00@`0?1000AP0?0P005Woo000C
Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool01`00Oomoogoo001oo`00009oo`03001oo`0000=oo`04
001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol0
3`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`0500000`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0DOol0
01Aoo`@000moo`07001oogooOol007oo00000Woo00<007oo00000goo00@007ooOol03`eoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?
00aoo`H000=oo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?Ool0
3`9oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?
Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001oogoo01Aoo`009Woo0P0017oo00<007ooOol00Woo
00<007ooOol00Woo0P0000=oo`0?Ool037oo00<03gooOol01Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l027oo1P001goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00Woo0P00
5Woo000fOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool01@0?Ool03goo00l01Goo1@000goo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo00<03goo
Ool01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l0
0goo00<007ooOol057oo000fOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo0`001goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03goo
Ool02Woo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool0
1@0?Ool03goo00l00goo00<007ooOol057oo000fOol200000goo00moo`0<Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0400moo`0?Ool50009Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo00l2
Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`02Ool2000FOol003Ioo`04001oogoo00l=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`H000aoo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo
00Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D0
3goo00moo`0?00=oo`03001oogoo01Aoo`00=Woo00@007ooOol03`eoo`0300moogoo00Eoo`0300mo
ogoo00=oo`0500moogooOol03`03Ool00`0?Oomoo`04000017oo00moo`0?3Goo00<03gooOol01Goo
00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03goo
Ool02Woo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool0
1@0?Ool03goo00l00goo00<007ooOol057oo000fOol200000goo00moo`0<Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00Woo1@000Woo00D03goo00moo`0?00eoo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300mo
ogoo00Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?009oo`8001Ioo`00=Woo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo
00=oo`0300moo`0000D0000400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol0
2Woo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?
Ool03goo00l00goo00<007ooOol057oo000fOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03goo
00001`0000D03gooOomoo`0?009oo`0800moogoo00moo`0?Ool03`eoo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yo
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo
00moo`0?00=oo`03001oogoo01Aoo`00=Woo0P0000=oo`0?Ool037oo00@03gooOomoo`T00003Ool0
3goo009oo`0500moogooOol03`02Ool0200?Oomoo`0?Ool03goo00l=Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`0:
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`02Ool2000FOol0035oo`03001oogoo009oo`04001oogoo00l7Ool;0003Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo00l2Ool00`0?
Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`0500moo`0?Ool03`03Ool00`00Oomoo`0DOol0031oo`03001oo`0000=oo``000Eoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol00003Ool0100?Oomoo`0?0Woo00D03goo00moo`0000eo
o`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`04001oogoo00l2Ool01P0?Oomoo`0?
Ool03`9oo`03001oogoo00Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol00003Ool0
100?Oomoo`0?0Woo00D03goo00moo`0000=oo`03001oogoo01Aoo`00<7oo00<007oo00000gooT@00
5Woo000`Ool00`00Ool0002ZOol0031oo`03001oo`000:Yoo`00<Goo00<007ooOol0ZGoo003MOol0
0=eoo`00gGoo000bOol00`00Oomoo`02Ool00`00Oomoo`05000COol00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`05Ool5000MOol00`00Oomoo`06Ool50002Ool00`00Oomoo`0GOol00`00Oomo
o`02Ool01000Oomoogoo1@000Woo00<007ooOol00Woo00<007ooOol05Goo000aOol00`00Ool00008
Ool00`00Oomoo`0BOol00`00Ool00007Ool00`00Ool00008Ool00`00Oomoo`0LOol00`00Ool00009
Ool01`00Oomoogoo001oo`0001Moo`03001oo`00009oo`03001oo`0000Aoo`07001oogooOol007oo
00000Woo00<007oo00005Woo000aOol00`00Ool00008Ool00`00Oomoo`0BOol00`00Ool00009Ool0
0`00Oomoo`06Ool00`00Oomoo`0NOol00`00Oomoo`07Ool01`00Oomoogoo001oo`0001Uoo`06001o
ogoo001oo`0017oo00L007ooOomoo`00Ool00002Ool00`00Ool0000FOol0035oo`03001oo`0000Qo
o`03001oogoo019oo`03001oo`0000Moo`8000Uoo`03001oogoo01aoo`8000Yoo`07001oogooOol0
07oo00005goo0P000goo00<007oo000017oo00L007ooOomoo`00Ool00002Ool00`00Ool0000FOol0
035oo`03001oo`0000Qoo`03001oogoo019oo`03001oo`0000Moo`03001oogoo00Qoo`03001oogoo
01aoo`03001oogoo00Uoo`07001oogooOol007oo00005goo00<007ooOol00Woo00<007oo000017oo
00L007ooOomoo`00Ool00002Ool00`00Ool0000FOol0039oo`03001oogoo00Ioo`8001Eoo`03001o
ogoo00Ioo`<000Moo`8001ioo`<000Qoo`8000Aoo`03001oogoo01Ioo`<000=oo`03001oogoo009o
o`8000Aoo`03001oogoo009oo`03001oogoo01Eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eo
o`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol004]o
o`8001Eoo`8001Eoo`03001oogoo03aoo`03001oogoo029oo`00C7oo00<007ooOol057oo00<007oo
Ool04Woo00<007ooOol04goo00<007ooOol0:7oo00<007ooOol08Goo000iOol30003Ool30003Ool2
0003Ool30002Ool30002Ool200000goo00000002Ool00`00Ool000020003Ool00`00Oomoo`0AOol0
1000Oomoogoo0`0000=oo`00Ool010000Woo0`001Goo00<007ooOol00Woo0`000goo0P000Woo0`00
0goo0P0000=oo`0000000Woo00<007ooOol00`002Goo00<007ooOol087oo000jOol00`00Oomoo`03
Ool01@00Oomoogoo000017oo00H007ooOol007oo0002Ool00`00Ool00004Ool01P00Oomoo`00Ool0
00Aoo`03001oo`00019oo`03001oogoo009oo`05001oogoo001oo`030002Ool01000Oomoo`001Goo
00<007ooOol00Woo00<007oo00000Woo00<007ooOol00Woo00<007ooOol00Woo00H007ooOol007oo
0002Ool00`00Ool00002Ool00`00Oomoo`07Ool00`00Oomoo`0POol003Yoo`03001oogoo00=oo`04
001oogooOol30002Ool01P00Oomoo`00Ool0009oo`03001oo`000080009oo`06001oogoo001oo`00
17oo00<007oo00004Woo00<007ooOol00Woo0`0017oo00@007ooOol0009oo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00<0009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo
00000Woo00<007ooOol01goo00<007ooOol087oo000jOol20003Ool4000017oo000000000goo1@00
00Aoo`00001oo`<00003Ool000000080009oo`<00004Ool00000Ool2000AOol00`00Oomoo`02Ool0
1000Oomoo`000Woo0P000goo0`001Woo00<007ooOol00Woo00@007ooOomoo`<0009oo`<000=oo`80
0003Ool00000008000=oo`<000Uoo`03001oogoo021oo`00>Woo00@007ooOol003Yoo`05001oogoo
Ool00002Ool00`00Oomoo`07Ool00`00Oomoo`04Ool01`00Oomoogoo001oo`0001Uoo`03001oogoo
00Ioo`03001oogoo025oo`00>Goo1@00>goo00<007oo00000`002Goo0P001goo00<007ooOol00`00
67oo0P001goo00<007ooOol08Woo003MOol00=eoo`00gGoo003MOol00=eoo`00gGoo003MOol002mo
o`03001oogoo009oo`03001oogoo00D001=oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
00Eoo`D001eoo`03001oogoo00Ioo`D0009oo`03001oogoo01Moo`03001oogoo009oo`04001oogoo
Ool50002Ool00`00Oomoo`02Ool00`00Oomoo`0HOol002ioo`03001oo`0000Qoo`03001oogoo019o
o`03001oo`0000Moo`03001oo`0000Qoo`03001oogoo01aoo`03001oo`0000Uoo`07001oogooOol0
07oo00005goo00<007oo00000Woo00<007oo000017oo00L007ooOomoo`00Ool00002Ool00`00Ool0
000IOol002ioo`03001oo`0000Qoo`03001oogoo019oo`03001oo`0000Uoo`03001oogoo00Ioo`03
001oogoo01ioo`03001oogoo00Moo`07001oogooOol007oo00006Goo00H007ooOol007oo0004Ool0
1`00Oomoogoo001oo`00009oo`03001oo`0001Uoo`00;Woo00<007oo000027oo00<007ooOol04Woo
00<007oo00001goo0P002Goo00<007ooOol077oo0P002Woo00L007ooOomoo`00Ool0000GOol20003
Ool00`00Ool00004Ool01`00Oomoogoo001oo`00009oo`03001oo`0001Uoo`00;Woo00<007oo0000
27oo00<007ooOol04Woo00<007oo00001goo00<007ooOol027oo00<007ooOol077oo00<007ooOol0
2Goo00L007ooOomoo`00Ool0000GOol00`00Oomoo`02Ool00`00Ool00004Ool01`00Oomoogoo001o
o`00009oo`03001oo`0001Uoo`00;goo00<007ooOol01Woo0P005Goo00<007ooOol01Woo0`001goo
0P007Woo0`0027oo0P0017oo00<007ooOol05Woo0`000goo00<007ooOol00Woo0P0017oo00<007oo
Ool00Woo00<007ooOol067oo003MOol00=eoo`00gGoo000YOol00`00Oomoo`02Ool00`00Oomoo`02
OonA000IOol002Qoo`03001oo`00009oo`03001oo`0000=oo`04001oogoo000=Ool00`00Oomoo`05
Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00@007ooOol0009oo`05001oo`00Ool0000=Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00H007ooOol007oo
0002Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo00@0
07ooOol0009oo`05001oo`00Ool00003Ool00`00Oomoo`0GOol002=oo`<0009oo`03001oo`00009o
o`03001oo`0000=oo`800003Ool03goo00aoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?
009oo`8001Uoo`00:Goo00L007ooOomoo`00Ool00003Ool01000Oomoo`0?3Goo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<0
3gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?
0Woo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03goo00000goo00<007ooOol05goo000EOol6000=Ool00`00Ool00002Ool0
0`00Ool00003Ool01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03`0000l00goo
00<007ooOol05goo000EOol30002Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo
00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@0
3gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?000007oo00l00goo00<007ooOol05goo
000HOol00`00Oomoo`0HOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo00<0
3gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@00Ool03goo
00l00goo00<007ooOol05goo000EOol30002Ool00`00Oomoo`0FOol01000Oomoo`0?3Goo00<03goo
Ool01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l0
3Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo
00moo`0?0Woo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0;00moogoo00moo`0000moo`0?Ool03`03Ool00`00Oomoo`0GOol001Eoo`H001Qoo`04001oogoo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00/03gooOol03`00Ool03goo00moo`0?009oo`8001Uoo`005Goo00<007ooOol0
0Woo00<007ooOol05Woo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009o
o`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`000Woo00D03goo00moo`0?
00=oo`03001oogoo01Moo`00<goo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`05
00moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300mo
ogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yo
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Ool0000?0Woo00D03goo
00moo`0?00=oo`03001oogoo01Moo`006Goo0P0067oo00@007ooOol03`eoo`0300moogoo00Eoo`03
00moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300mo
ogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9o
o`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?001o
o`0?0Woo00D03goo00moo`0?00=oo`03001oogoo01Moo`005goo00@007oo000001Qoo`04001oogoo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00@007ooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0GOol001Moo`04
001oo`00000HOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?009oo`0500003gooOol03`02Ool01@0?Ool03goo00l0
0Woo0P006Goo000GOol4000HOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo
00<03gooOol01Goo00<03gooOol00goo00T03gooOomoo`0?Ool007oo00l00Woo00P03gooOol03goo
00moo`0?0goo00<007ooOol05goo000JOol00`00Oomoo`0FOol01000Oomoo`0?3Goo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00mo
o`0?0Woo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol00goo00H03gooOomoo`0?0002Ool0
100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001oogoo01Moo`00<goo00@007ooOol03`eoo`03
00moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00mo
o`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?
Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol0
0003Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001oogoo01Moo`0067oo0P000Woo00<0
07ooOol057oo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eo
o`0300moogoo00=oo`0500moogoo00003`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03
001oogoo01Moo`005goo00H007ooOol007oo000FOol01000Oomoo`0?3Goo00<03gooOol01Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo
00<03gooOol02Woo00<03gooOol01Goo00<03gooOol00goo00D03`00001oo`0?00=oo`0400moogoo
00l2Ool01@0?Ool03goo00l00Woo0P006Goo000GOol01P00Oomoo`00Ool001Ioo`04001oogoo00l=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@00Oomo
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0GOol001Moo`D001Mo
o`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0000moo`02Ool01@0?Oomoogoo00l00Woo00P03gooOol03goo00moo`0?0goo00<007oo
Ool05goo000GOol00`00Oomoo`0IOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<0
3gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol0
2Woo00<03gooOol01Goo00L03gooOomoo`00Ool03`03Ool01@0?Oomoogoo00l00Woo00P03gooOol0
3goo00moo`0?0goo00<007ooOol05goo000GOol01000Oomoo`003Goo0P0017oo00<007ooOol00Woo
00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eoo`0400moogoo
0002Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0G
Ool001Moo`@000eoo`03001oo`00009oo`03001oo`0000=oo`04001oogoo00l=Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo
00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool0100?Oomoo`000Woo00D03gooOomoo`0?00=oo`04
00moogoo00l2Ool01@0?Ool03goo00l00goo00<007ooOol05goo000GOol00`00Oomoo`09Ool30002
Ool00`00Ool00002Ool00`00Ool00003Ool2001d00l00`0000l03`0F00l2000IOol001Moo`03001o
ogoo00ioo`8000=oo`03001oo`0000=oo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo00l2Ool00`0?Oomo
o`0:Ool00`0?Oomoo`05Ool00`0?001oo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`03Ool00`00Oomoo`0GOol001Qoo`<000eoo`03001oogoo009oo`03001oo`0000=o
o`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`00Oomo
o`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0G
Ool001Yoo`03001oogoo00aoo`8000=oo`03001oogoo009oo`04001oogoo00l=Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo
00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`04Ool00`0000moo`04Ool01@0?Oomoogoo00l00goo00@0
3gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0GOol003=oo`04001oogoo00l=Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03goo
Ool03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`03Ool00`00Ool03`05Ool01@0?Oomoogoo00l0
0goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0GOol003=oo`04001oogoo00l=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`02Ool01000Oomoo`0?1Goo00D03goo
Oomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00Woo0P006Goo000GOol01000Oomoo`00
67oo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?
Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0500moogooOol00003Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00
Oomoo`0GOol001Eoo`03001oo`0000<001Qoo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05
Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03`0000l2Ool00`0?
Oomoo`0:Ool0100?Oomoo`0017oo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2
Ool01@0?Ool03goo00l00goo00<007ooOol05goo000JOol00`00Oomoo`0FOol01000Oomoo`0?3Goo
00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool0
3goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`06
00moogoo00l0000?0Woo00<03gooOol02Woo00<03goo00001Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo00<007ooOol05goo000cOol01000Oomo
o`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool0
1@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol0
3`9oo`0600moogoo00l0000?0Woo00<03gooOol02Woo00<03`00Ool01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo00<007ooOol05goo000GOol0
0`00Oomoo`0IOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?
00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<0
3gooOol00Woo00@03gooOol03`9oo`0600moogoo00l0000?0Woo00<03gooOol02Woo00<007ooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00Woo
0P006Goo000FOol4000IOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo00moo`000Woo00<03gooOol02Goo00<0
000?Ool01Woo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo
00l00goo00<007ooOol05goo000GOol01000Oomoo`0067oo00@007ooOol03`eoo`0300moogoo00Eo
o`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`03
00moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?Ool0
009oo`0300moogoo00Qoo`03001oo`0?00Moo`0300moogoo00=oo`0500moogooOol03`03Ool0100?
Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001oogoo01Moo`005goo00@007ooOol001Qoo`04001o
ogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomo
o`0?0Woo00H03gooOol007oo00l2Ool00`0?Oomoo`07Ool01000Oomoo`0?1goo00<03gooOol00goo
00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo00<007ooOol05goo000G
Ool00`00Ool0000IOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`9oo`0600moogoo001oo`0?0Woo00<03gooOol01Woo00D007oo
Oomoo`0?00Moo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00mo
o`0?00=oo`03001oogoo01Moo`00<goo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=o
o`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`03
00moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`00Ool0009oo`0300moogoo
00Ioo`05001oogooOol03`07Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9o
o`0500moo`0?Ool03`03Ool00`00Oomoo`0GOol001Moo`03001oogoo01Uoo`04001oogoo00l=Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?
Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H0
3gooOol007oo0002Ool00`0?Oomoo`05Ool00`00Oomoo`02Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`02Ool2000IOol001Moo`<0
01Uoo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@0
3gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool0100?Oomoo`0?0Woo00H03gooOol03goo0002Ool00`0?Oomoo`04Ool00`00Oomoo`03Ool00`0?
Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool0
3`03Ool00`00Oomoo`0GOol001Yoo`03001oogoo01Ioo`04001oogoo00l=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol007oo0002
Ool00`0?Oomoo`03Ool00`00Oomoo`04Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0GOol001Moo`03001oo`00
00moo`<0009oo`03001oogoo009oo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool0
1@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?
Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol007oo00l2Ool00`0?Oomoo`03
Ool00`00Oomoo`04Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0GOol001Moo`@000moo`06001oogoo001oo`00
0goo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?
Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009o
o`0400moogoo00l2Ool01P0?Oomoo`00Ool03`9oo`0300moogoo009oo`03001oogoo00Eoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?
00=oo`03001oogoo01Moo`006Woo00<007ooOol01Woo0`000Woo100000Aoo`00Ool000=oo`8005P0
3`0400003`0?000500l00`0000l03`0Y00l2000IOol002Qoo`03001oo`00009oo`03001oo`0000=o
o`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00T03gooOol03goo00l007oo00l00goo00<007ooOol01Woo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo00<0
07ooOol05goo000HOol2000?Ool20002Ool00`00Ool00003Ool01000Oomoo`0?3Goo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo
00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0900moogoo00mo
o`0?001oo`0?009oo`03001oogoo00Moo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol0
3`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001oogoo01Moo`005goo00@007ooOol0
00moo`05001oogooOol00004Ool01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`9oo`0;00moo`0000moo`0?001oo`0?Ool0000:Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?
Ool03`03Ool00`00Oomoo`0GOol001Eoo`03001oo`00009oo`03001oogoo01Ioo`04001oogoo00l=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00H03goo00003goo00l2Ool00`0?Ool0000:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0GOol001Eoo`H001Qo
o`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0
100?Oomoo`0?0Woo00X03goo00003goo00moo`0000l000]oo`0300moogoo00Eoo`0300moogoo00=o
o`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?009oo`8001Uoo`006Woo00<0
07ooOol05Woo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300mo
ogoo009oo`0400moogoo00l2Ool02@0?Ool0000?Ool03`00Ool0000<Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomo
o`0GOol003=oo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l0
0goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00T03gooOol03goo00moo`0000l037oo00<03gooOol01Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo00<007oo
Ool05goo000HOol2000IOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03goo
Oomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol0
0Woo00<03gooOol00Woo00@03gooOol03`9oo`0700moogoo00moo`0?Ool00P0037oo00<03gooOol0
1Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo
00<007ooOol05goo000GOol200000goo001oo`0GOol01000Oomoo`0?3Goo00<03gooOol01Goo00<0
3gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03goo
Ool01Goo00<03gooOol00Woo00<03gooOol00Woo00@03gooOol03`9oo`0900moo`0000moo`0?001o
o`0?00aoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00=oo`03001oogoo01Moo`005goo0P0000=oo`00Ool05goo00@007ooOol03`eo
o`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo
00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool0
1P0?Ool0000?Ool0009oo`0300moo`0000Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?009oo`8001Uoo`0067oo00<007oo000067oo
00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l2Ool01P0?001oo`0?Ool0009oo`0400moogoo0009Ool00`0?Oomoo`05Ool00`0?Oomo
o`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0G
Ool003=oo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo
00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomo
o`02Ool0100?Oomoo`0?0Woo00H03`00Ool03`0000l2Ool01@0?Oomoogoo00000Woo10000Woo1000
0Woo0`000Woo1@000Woo0`0000=oo`0?00000`0000=oo`0?00000`000goo00<007ooOol05goo000c
Ool01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo
00@03gooOol03`9oo`0600moogoo001oo`0?0Woo00<03gooOol02Woo00<03gooOol01Goo00<03goo
Ool00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo00<007ooOol0
5goo000cOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=o
o`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`9oo`0600moogoo001oo`0?0Woo00<03gooOol02Woo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo00<0
07ooOol05goo000cOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomo
o`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo
00<03gooOol00Woo00@03gooOol03`9oo`0600l0000000moo`0?0Woo00<03gooOol02Woo00<03goo
Ool01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l0
0goo00<007ooOol05goo000cOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`9oo`06001oo`0000moo`0?0Woo00<03gooOol02Woo
00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool0
3goo00l00Woo0P006Goo000cOol01000Oomoo`0?3Goo00<03gooOol01Goo00<03gooOol00goo00D0
3gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l03Goo00<03gooOol01Goo00<03goo
Ool00Woo00<03gooOol00Woo00@03gooOol03`9oo`800004Ool03goo00l2Ool00`0?Oomoo`0:Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?
Ool03`03Ool00`00Oomoo`0GOol003=oo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03`00Ool03goo00l2Ool00`0?Oomo
o`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`03Ool00`00Oomoo`0GOol002Qoo`<000=oo`03001oogoo009oo`04001oogoo00l=
Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500mo
o`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo
00H007ooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomo
ogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0GOol002Qoo`03001o
ogoo009oo`03001oo`0000=oo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomo
o`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H007ooOol03goo00l2Ool00`0?Oomoo`0:Ool0
0`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?
Ool03`03Ool00`00Oomoo`0GOol001Moo`@000Qoo`<000=oo`07001oogooOol007oo00000goo0P00
E00?0P00=`0?0P006Goo000FOol00`00Oomoo`02Ool00`00Oomoo`0;Ool01`00Oomoogoo001oo`00
00=oo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@0
3gooOol03`9oo`0500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01`0?Oomoo`0?Ool0000?009oo`0300moo`0?009oo`0300moogoo00Yoo`0300moogoo00Eoo`03
00moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001o
ogoo01Moo`005Goo00<007ooOol017oo00<007ooOol02Goo00<007oo00000Woo00<007oo00000goo
00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`04
00moogoo00l200001P0?Oomoo`0?Ool03`9oo`P00004Ool00000Ool8000017oo000007oo0P0000=o
o`0?Ool00Woo00D03gooOomoo`0?009oo`0800moogoo00moo`0?Ool03`=oo`03001oogoo01Moo`00
:Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo
00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eo
o`0300moogoo009oo`0300moogoo009oo`0800moogoo00l007oo00moo`800005Ool00000Ool03`0<
Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool6000017oo0000000?3P006Goo000cOol01000Oomoo`0?
3Goo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?
Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03gooOol00Woo00<03gooOol01@00
00Aoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol0
3`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001oogoo01Moo`0067oo0P006Goo00@0
07ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?
0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0300mo
o`0000800007Ool03gooOol03goo00l00Woo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol0
0goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00Woo0P006Goo000GOol0
1000Oomoo`0067oo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol0
3`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`04
00moogooOol200000goo00000002Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=o
o`03001oogoo01Moo`005Goo00<007oo00000Woo00<007ooOol05Woo00@007ooOol03`eoo`0300mo
ogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?
00eoo`0300moogoo00Eoo`0300moogoo009oo`0300moo`00009oo`0400l0000000l2Ool01P0?Oomo
o`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001oogoo01Moo`005Goo1P0067oo00@007oo
Ool03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo
00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo009oo`8000=oo`04001oogoo00l2Ool0
1P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogoo
Ool03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001oogoo01Moo`006Woo00<007oo
Ool05Woo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0
100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300moogoo00Eoo`0300moogoo0080000300moogoo
009oo`04001oogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eoo`03
00moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001o
ogoo01Moo`005Goo00<007ooOol00Woo00<007ooOol05Woo00@007ooOol03`eoo`0300moogoo00Eo
o`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`03
00moogoo00Eoo`0300l0000000<00005Ool0000000003`02Ool0100?Oomoo`0?0Woo00<03goo00l0
0Woo00<03gooOol02Woo00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400mo
ogoo00l2Ool01@0?Ool03goo00l00goo00<007ooOol05goo000EOol6000HOol01000Oomoo`0?3Goo
00<03gooOol01Goo00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool0
3goo00l03Goo00<03gooOol00Woo100000Eoo`00Oomoo`0?00<00005Ool03gooOol03`02Ool01P0?
Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol0
3`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?009oo`8001Uoo`005Goo00<007oo00000Woo00<0
07ooOol05Woo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03
Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00eoo`0300l0000000@00003Ool03goo00=oo`0300mo
ogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eo
o`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03
001oogoo01Moo`005Goo00<007oo00000Woo00<007ooOol05Woo00@007ooOol03`eoo`0300moogoo
00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00ao
o`@000Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo00l2Ool01P0?Oomoo`0?Ool03`9o
o`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00=oo`0500moogooOol03`03Ool0100?Oomo
o`0?0Woo00D03goo00moo`0?00=oo`03001oogoo01Moo`005Woo00@007oo000001Uoo`04001oogoo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`09Ool50007Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H0
3gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo
00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0GOol003=oo`04001oogoo
00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`06Ool40003Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?
Oomoo`0?0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03
Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0GOol0
03=oo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@0
3gooOol03`9oo`0500moo`0?Ool03`03Ool40006Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`02Ool2
000IOol001Eoo`03001oogoo00Aoo`03001oogoo01Aoo`04001oogoo00l=Ool00`0?Oomoo`05Ool0
0`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0400moo`0?Ool50009Ool00`0?
Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo00l2
Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03goo
Ool03`9oo`0500moo`0?Ool03`03Ool00`00Oomoo`0GOol001Ioo`03001oogoo009oo`03001oogoo
01Eoo`04001oogoo00l=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00D0
3gooOol03goo00L000aoo`0300moogoo00Eoo`0300moogoo009oo`0300moogoo009oo`0400moogoo
00l2Ool01P0?Oomoo`0?Ool03`9oo`0300moogoo00Yoo`0300moogoo00Eoo`0300moogoo00=oo`05
00moogooOol03`03Ool0100?Oomoo`0?0Woo00D03goo00moo`0?00=oo`03001oogoo01Moo`005goo
10004goo00<007ooOol00Woo00@007ooOol03`eoo`0300moogoo00Eoo`0300moogoo00=oo`0800mo
ogooOol03goo001oo`H0000500moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?
Oomoo`02Ool0100?Oomoo`0?0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05
Ool00`0?Oomoo`03Ool01@0?Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`03Ool0
0`00Oomoo`0GOol002eoo`03001oo`0000=oo`04001oogoo00l=Ool00`0?Oomoo`05Ool0100?Oomo
ogoo300000Uoo`0?Oomoo`0?Ool03goo00l03Goo00<03gooOol01Goo00<03gooOol00Woo00<03goo
Ool00Woo00@03gooOol03`9oo`0600moogoo00moo`0?0Woo00<03gooOol02Woo00<03gooOol01Goo
00<03gooOol00goo00D03gooOomoo`0?00=oo`0400moogoo00l2Ool01@0?Ool03goo00l00goo00<0
07ooOol05goo000]Ool00`00Ool00003OolO00001@0?Oomoogoo00l00goo00@03gooOol03`9oo`05
00moo`0?Ool03`0=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02Ool0100?Oomoo`0?
0Woo00H03gooOol03goo00l2Ool00`0?Oomoo`0:Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?
Oomoogoo00l00goo00@03gooOol03`9oo`0500moo`0?Ool03`02Ool2000IOol002eoo`03001oo`00
00=oo`04001oogoo000=Ool00`0?Oomoo`05Ool00`0?Oomoo`03Ool01@0?Oomoogoo00000goo00@0
3gooOol03`9oo`0500moo`0?Ool0000=Ool00`0?Oomoo`05Ool00`0?Oomoo`02Ool00`0?Oomoo`02
Ool01000Oomoo`0?0Woo00H03gooOol03goo00l2Ool00`00Oomoo`0:Ool00`0?Oomoo`05Ool00`0?
Oomoo`03Ool01@0?Oomoogoo00000goo00@03gooOol03`9oo`0500moo`0?Ool00003Ool00`00Oomo
o`0GOol002eoo`03001oo`0000=ooi4001Uoo`00;Woo00<007ooOol0[7oo003MOol00=eoo`00gGoo
003MOol00=eoo`00;goo00<007ooOol00Woo00<007ooOol01@004goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol01Goo1@007Goo00<007ooOol01Woo1@000Woo00<007ooOol05goo00<007oo
Ool00Woo00@007ooOomoo`D0009oo`03001oogoo009oo`03001oogoo01Qoo`00;Woo00<007oo0000
27oo00<007ooOol04Woo00<007oo00001goo00<007oo000027oo00<007ooOol077oo00<007oo0000
2Goo00L007ooOomoo`00Ool0000GOol00`00Ool00002Ool00`00Ool00004Ool01`00Oomoogoo001o
o`00009oo`03001oo`0001Uoo`00;Woo00<007oo000027oo00<007ooOol04Woo00<007oo00002Goo
00<007ooOol01Woo00<007ooOol07Woo00<007ooOol01goo00L007ooOomoo`00Ool0000IOol01P00
Oomoo`00Ool000Aoo`07001oogooOol007oo00000Woo00<007oo00006Goo000^Ool00`00Ool00008
Ool00`00Oomoo`0BOol00`00Ool00007Ool20009Ool00`00Oomoo`0LOol2000:Ool01`00Oomoogoo
001oo`0001Moo`8000=oo`03001oo`0000Aoo`07001oogooOol007oo00000Woo00<007oo00006Goo
000^Ool00`00Ool00008Ool00`00Oomoo`0BOol00`00Ool00007Ool00`00Oomoo`08Ool00`00Oomo
o`0LOol00`00Oomoo`09Ool01`00Oomoogoo001oo`0001Moo`03001oogoo009oo`03001oo`0000Ao
o`07001oogooOol007oo00000Woo00<007oo00006Goo000_Ool00`00Oomoo`06Ool2000EOol00`00
Oomoo`06Ool30007Ool2000NOol30008Ool20004Ool00`00Oomoo`0FOol30003Ool00`00Oomoo`02
Ool20004Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00=eoo`00gGoo003MOol00=eoo`00gGoo003M
Ool00=eoo`00gGoo003MOol00001\
\>"],
  ImageRangeCache->{{{0, 220.875}, {287, 0}} -> {-0.0250052, -0.033245, 
  0.00475387, 0.00475387}, {{5.25, 215.562}, {280, 
  150}} -> {-2.27007, -829.384, 0.0219425, 6.76258}, {{5.25, 215.562}, {137, 
  6.9375}} -> {-2.20246, -249.062, 0.0219277, 0.944698}},
  CellTags->"8.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.5 Pole\[Hyphen]Zero Cancellation", "Subsection",
  CellTags->"8.5"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["PoleZeroCancel",
                "MR"], 
              StyleBox["[",
                "MR"], 
              StyleBox["tf",
                "TI"], 
              StyleBox["]",
                "MR"]}], 
            RowBox[{
              StyleBox[\(cancel\ the\ common\ pole\),
                SingleLetterItalics->False], 
              StyleBox["-",
                SingleLetterItalics->False], 
              RowBox[{
                StyleBox["zero",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["pairs",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["in",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["the",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["transfer",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["function",
                  SingleLetterItalics->False], 
                StyleBox[" ",
                  SingleLetterItalics->False], 
                StyleBox["tf",
                  SingleLetterItalics->False,
                  FontSlant->"Italic"]}]}]}
          }], NotebookDefault]], "DefinitionBox",
  GeneratedCell->True,
  CellTags->"8.5"],

Cell["Canceling common pole\[Hyphen]zero pairs. ", "Caption",
  CellTags->"8.5"],

Cell[TextData[{
  "For the model reduction purposes, ",
  StyleBox["PoleZeroCancel", "MR"],
  " in its current implementation is most useful for SISO systems. "
}], "Text",
  CellTags->"8.5"],

Cell[TextData[{
  "Here is a ",
  Cell[BoxData[
      \(TraditionalForm\`z\)], "InlineFormula",
    CellTags->"S0.0.6"],
  "\[Hyphen]plane transfer function for a SISO system. "
}], "MathCaption",
  CellTags->"8.5"],

Cell[CellGroupData[{

Cell["\<\
TransferFunction[z, (z - .5)/(0.5 - 1.5*z + z^2),
 Sampled -> True]\
\>", "Input",
  CellLabel->"In[26]:= ",
  CellTags->"8.5"],

Cell[BoxData[
    RowBox[{"TransferFunction", "[", 
      RowBox[{"z", ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            FractionBox[
              RowBox[{
                RowBox[{"-", 
                  StyleBox["0.5`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->1]}], "+", "z"}], 
              RowBox[{
                RowBox[{
                  StyleBox["0.5`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->1], "\[InvisibleSpace]"}], "-", 
                \(1.5`\ z\), "+", \(z\^2\)}]], "}"}], "}"}], ",", 
        \(Sampled \[Rule] True\)}], "]"}]], "Output",
  CellLabel->"Out[26]= ",
  CellTags->"8.5"]
}, Open  ]],

Cell[TextData[{
  "This is the transfer function after the pole\[Hyphen]zero pair at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0.5\)], "InlineFormula",
    CellTags->"S0.0.6"],
  " is canceled. "
}], "MathCaption",
  CellTags->"8.5"],

Cell[CellGroupData[{

Cell["PoleZeroCancel[%]", "Input",
  CellLabel->"In[27]:= ",
  CellTags->"8.5"],

Cell[BoxData[
    \(TransferFunction[z, {{1\/\(\(-1.`\) + z\)}}, Sampled \[Rule] True]\)], 
  "Output",
  CellLabel->"Out[27]= ",
  CellTags->"8.5"]
}, Open  ]],

Cell[TextData[{
  "Note that if the common factors coincide within the precision of the \
elements, they can be canceled without calling ",
  StyleBox["PoleZeroCancel", "MR"],
  "\[LongDash]for example, just by factoring the elements of the transfer \
matrix. Therefore, ",
  StyleBox["PoleZeroCancel", "MR"],
  " is most useful when the match is not exact. In fact, the ",
  StyleBox["Tolerance", "MR"],
  " option allows cancellation of the factors within any desired difference. \
"
}], "Text",
  CellTags->"8.5"],

Cell["\<\
The common pair in the preceding transfer function cancel in the \
factored form, too. \
\>", "MathCaption",
  CellTags->"8.5"],

Cell[CellGroupData[{

Cell["FactorRational[%%]", "Input",
  CellLabel->"In[28]:= ",
  CellTags->"8.5"],

Cell[BoxData[
    \(TransferFunction[z, {{1\/\(\(-1.`\) + z\)}}, Sampled \[Rule] True]\)], 
  "Output",
  CellLabel->"Out[28]= ",
  CellTags->"8.5"]
}, Open  ]],

Cell["Here is another transfer function. ", "MathCaption",
  CellTags->"8.5"],

Cell[CellGroupData[{

Cell["TransferFunction[s, (s + .5)/(s + .4)]", "Input",
  CellLabel->"In[29]:= ",
  CellTags->"8.5"],

Cell[BoxData[
    RowBox[{"TransferFunction", "[", 
      RowBox[{"s", ",", 
        RowBox[{"{", 
          RowBox[{"{", 
            FractionBox[
              RowBox[{
                RowBox[{
                  StyleBox["0.5`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->1], "\[InvisibleSpace]"}], "+", "s"}], 
              RowBox[{
                RowBox[{
                  StyleBox["0.4`",
                    StyleBoxAutoDelete->True,
                    PrintPrecision->1], "\[InvisibleSpace]"}], "+", "s"}]], 
            "}"}], "}"}]}], "]"}]], "Output",
  CellLabel->"Out[29]= ",
  CellTags->"8.5"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Tolerance", "MR"],
  " allows cancellation of pairs with a significant difference. The pole at ",
  
  Cell[BoxData[
      \(TraditionalForm\`s = 0.4\)], "InlineFormula",
    CellTags->"S0.0.6"],
  " and the zero at ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0.5\)], "InlineFormula",
    CellTags->"S0.0.6"],
  " cancel so long as ",
  StyleBox["Tolerance", "MR"],
  " is set to ",
  Cell[BoxData[
      \(TraditionalForm\`0.1\)], "InlineFormula",
    CellTags->"S0.0.6"],
  ". "
}], "MathCaption",
  CellTags->"8.5"],

Cell[CellGroupData[{

Cell["PoleZeroCancel[%, Tolerance -> .1]", "Input",
  CellLabel->"In[30]:= ",
  CellTags->"8.5"],

Cell[BoxData[
    \(TransferFunction[s, {{1}}]\)], "Output",
  CellLabel->"Out[30]= ",
  CellTags->"8.5"]
}, Open  ]],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], " "},
          {
            StyleBox[
              FormBox["Tolerance",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["Automatic",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(maximum\ difference\ between\ a\ pole\ and\ a\ zero\ for\ 
                which\ they\ are\ considered\ a\ common\ pair\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{RowLines->{True, False}},
  CellTags->"8.5"],

Cell[TextData[{
  "Option to ",
  StyleBox["PoleZeroCancel", "MR"],
  ". "
}], "Caption",
  CellTags->"8.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell["8.6 Similarity Transform", "Subsection",
  CellTags->"8.6"],

Cell[TextData[{
  "There can be an infinite number of realizations of a physical system that \
correspond to the system's representations in different bases of state space. \
The transform ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          OverscriptBox[
            StyleBox["\<\"x\"\>",
              "TB"], "^"], \((t)\), "=", 
          StyleBox["\<\"T\"\>",
            "TB"], 
          StyleBox["\<\"x\"\>",
            "TB"], \((t)\)}], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.7"],
  " from basis ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"x\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.7"],
  " to another basis, ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["\<\"x\"\>",
            "TB"], "^"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.7"],
  ", may be performed with any nonsingular matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"T\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.7"],
  ". In the new basis, the state equations from Eq. (8.1) become "
}], "Text",
  CellTags->"8.6"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              RowBox[{
                OverscriptBox[
                  OverscriptBox[
                    StyleBox["\<\"x\"\>",
                      "TB"], "^"], "."], \((t)\), "=", 
                OverscriptBox[
                  StyleBox["\<\"A\"\>",
                    "TB"], "^"], 
                OverscriptBox[
                  StyleBox["\<\"x\"\>",
                    "TB"], "^"], \((t)\), "+", 
                OverscriptBox[
                  StyleBox["\<\"B\"\>",
                    "TB"], "^"], 
                StyleBox["\<\"u\"\>",
                  "TB"], \((t)\)}],
              "DisplayFormula"]},
          {
            StyleBox[
              RowBox[{
                StyleBox["\<\"y\"\>",
                  "TB"], \((t)\), "=", 
                OverscriptBox[
                  StyleBox["\<\"C\"\>",
                    "TB"], "^"], 
                OverscriptBox[
                  StyleBox["\<\"x\"\>",
                    "TB"], "^"], \((t)\), "+", 
                StyleBox["\<\"D\"\>",
                  "TB"], 
                StyleBox["\<\"u\"\>",
                  "TB"], \((t)\)}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right}], TraditionalForm]], "DisplayFormula",
  CellTags->"8.6"],

Cell["where ", "Text",
  CellTags->"8.6"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[
              OverscriptBox[
                StyleBox["\<\"A\"\>",
                  "TB"], "^"],
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
                StyleBox["\<\"T\"\>",
                  "TB"], 
                StyleBox["\<\"A\"\>",
                  "TB"], 
                SuperscriptBox[
                  StyleBox["\<\"T\"\>",
                    "TB"], \(-1\)]}],
              "DisplayFormula"]},
          {
            StyleBox[
              OverscriptBox[
                StyleBox["\<\"B\"\>",
                  "TB"], "^"],
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[\("T" "B"\),
              "TB"]},
          {
            StyleBox[
              OverscriptBox[
                StyleBox["\<\"C\"\>",
                  "TB"], "^"],
              "DisplayFormula"], 
            StyleBox["=",
              "DisplayFormula"], 
            StyleBox[
              RowBox[{
                StyleBox["\<\"C\"\>",
                  "TB"], 
                SuperscriptBox[
                  StyleBox["\<\"T\"\>",
                    "TB"], \(-1\)]}],
              "DisplayFormula"]}
          },
        ColumnAlignments->{Right, Center, Left}], TraditionalForm]], 
  "DisplayFormula",
  CellTags->"8.6"],

Cell[TextData[{
  "The result can be obtained using the function ",
  StyleBox["SimilarityTransform", "MR"],
  ". "
}], "Text",
  CellTags->"8.6"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            RowBox[{
              StyleBox["SimilarityTransform",
                "MR"], 
              StyleBox["[",
                "MR"], 
              RowBox[{
                StyleBox["statespace",
                  "TI"], 
                StyleBox[",",
                  "MR"], " ", 
                StyleBox["matrix",
                  "TI"]}], 
              StyleBox["]",
                "MR"]}]}
          }], NotebookDefault]], "TopSpanBox",
  GeneratedCell->True,
  CellTags->"8.6"],

Cell[BoxData[
    FormBox[GridBox[{
          {" ", 
            RowBox[{
              StyleBox["transforms",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["system",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["statespace",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["with",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["the",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["matrix",
                SingleLetterItalics->False], 
              StyleBox[" ",
                SingleLetterItalics->False], 
              StyleBox["matrix",
                SingleLetterItalics->False,
                FontSlant->"Italic"]}]}
          }], NotebookDefault]], "BottomBox",
  GeneratedCell->True,
  CellTags->"8.6"],

Cell["Finding the similarity transform. ", "Caption",
  CellTags->"8.6"],

Cell["Consider an earlier system. ", "MathCaption",
  CellTags->"8.6"],

Cell[CellGroupData[{

Cell["\<\
(system = StateSpace[
 {{-3, 2, 0}, {0, -1, 0}, {1, -2, -2}},
 {{0, 0}, {b1, 0}, {0, b2}},
 {{c1, 0, 0}, {0, 0, c3}},
 {{d11, d12}, {d21, d22}}]
)//ReviewForm\
\>", "Input",
  CellLabel->"In[31]:= ",
  CellTags->"8.6"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(-3\), "2", "0"},
                  {"0", \(-1\), "0"},
                  {"1", \(-2\), \(-2\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"0", "0"},
                  {"b1", "0"},
                  {"0", "b2"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"c1", "0", "0"},
                  {"0", "0", "c3"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"d11", "d12"},
                  {"d21", "d22"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[31]//ReviewForm= ",
  CellTags->"8.6"]
}, Open  ]],

Cell["\<\
Here its eigenvectors are arranged as columns of the matrix. \
\>", 
  "MathCaption",
  CellTags->"8.6"],

Cell[CellGroupData[{

Cell["(t = Eigenvectors[First[%]]//Transpose)//MatrixForm", "Input",
  CellLabel->"In[32]:= ",
  CellTags->"8.6"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {\(-1\), "0", \(-1\)},
            {"0", "0", \(-1\)},
            {"1", "1", "1"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output",
  CellLabel->"Out[32]//MatrixForm= ",
  CellTags->"8.6"]
}, Open  ]],

Cell["\<\
A similarity transform based on the inverse of that matrix can be \
used to represent the system in its canonical form. \
\>", "MathCaption",
  CellTags->"8.6"],

Cell[CellGroupData[{

Cell["SimilarityTransform[system, Inverse[t]]//ReviewForm", "Input",
  CellLabel->"In[33]:= ",
  CellTags->"8.6"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(-3\), "0", "0"},
                  {"0", \(-2\), "0"},
                  {"0", "0", \(-1\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"b1", "0"},
                  {"0", "b2"},
                  {\(-b1\), "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(-c1\), "0", \(-c1\)},
                  {"c3", "c3", "c3"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"d11", "d12"},
                  {"d21", "d22"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[33]//ReviewForm= ",
  CellTags->"8.6"]
}, Open  ]],

Cell[TextData[{
  "To avoid a double inversion of the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"T\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.7"],
  " in Eq. (8.5), either ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"T\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.7"],
  " or its inverse ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["\<\"T\"\>",
            "TB"], \(-1\)], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.7"],
  " can be supplied as an input argument to ",
  StyleBox["SimilarityTransform", "MR"],
  ". In the latter case, the option ",
  StyleBox["InvertedTransformMatrix", "MR"],
  " must be set to ",
  StyleBox["True", "MR"],
  ". Another way to look at this option is that it allows backward \
transformation from basis ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["\<\"x\"\>",
            "TB"], "^"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.7"],
  " to ",
  Cell[BoxData[
      FormBox[
        StyleBox["\<\"x\"\>",
          "TB"], TraditionalForm]], "InlineFormula",
    CellTags->"S0.0.7"],
  ". "
}], "Text",
  CellTags->"8.6"],

Cell[TextData[{
  "This performs the transform, assuming that matrix ",
  StyleBox["t", "MR"],
  " is the inverse of the transform matrix. "
}], "MathCaption",
  CellTags->"8.6"],

Cell[CellGroupData[{

Cell["\<\
SimilarityTransform[system, t,
 InvertedTransformMatrix -> True
]//ReviewForm\
\>", "Input",
  CellLabel->"In[34]:= ",
  CellTags->"8.6"],

Cell[BoxData[
    TagBox[GridBox[{
          {
            TagBox["\<\"A \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(-3\), "0", "0"},
                  {"0", \(-2\), "0"},
                  {"0", "0", \(-1\)}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"B \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"b1", "0"},
                  {"0", "b2"},
                  {\(-b1\), "0"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"C \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {\(-c1\), "0", \(-c1\)},
                  {"c3", "c3", "c3"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]},
          {
            TagBox["\<\"D \"\>",
              (TableForm[ #]&)], 
            TagBox[GridBox[{
                  {"d11", "d12"},
                  {"d21", "d22"}
                  },
                RowSpacings->1,
                ColumnSpacings->3,
                RowAlignments->Baseline,
                ColumnAlignments->{Left}],
              (TableForm[ #]&)]}
          },
        RowSpacings->2,
        ColumnSpacings->1,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #, TableSpacing -> {2}]&)]], "Output",
  CellLabel->"Out[34]//ReviewForm= ",
  CellTags->"8.6"]
}, Open  ]],

Cell["\<\
Further performance gain can be achieved if the transform matrix is \
known to be orthogonal, in which case the transpose of the matrix can be used \
instead of its inverse. \
\>", "Text",
  CellTags->"8.6"],

Cell[BoxData[
    FormBox[GridBox[{
          {
            StyleBox[\(option\ name\),
              "SO10"], 
            StyleBox[\(default\ value\),
              "SO10"], " "},
          {
            StyleBox[
              FormBox["InvertedTransformMatrix",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["False",
                "StandardForm"],
              "Text"], 
            StyleBox[\(whether\ the\ input\ matrix\ is\ already\ inverted\),
              SingleLetterItalics->False]},
          {
            StyleBox[
              FormBox["OrthogonalTransformMatrix",
                "StandardForm"],
              "Text"], 
            StyleBox[
              FormBox["False",
                "StandardForm"],
              "Text"], 
            
            StyleBox[
              \(whether\ the\ input\ matrix\ is\ known\ to\ be\ orthogonal\),
              SingleLetterItalics->False]}
          }], NotebookDefault]], "DefinitionBox3Col",
  GeneratedCell->True,
  GridBoxOptions->{ColumnWidths->{0.43, 0.15, 0.42},
  RowLines->{True, False}},
  CellTags->"8.6"],

Cell[TextData[{
  "Options to ",
  StyleBox["SimilarityTransform", "MR"],
  ". "
}], "Caption",
  CellTags->"8.6"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
ScreenStyleEnvironment->"Working",
WindowSize->{484, 284},
WindowMargins->{{2, Automatic}, {Automatic, 5}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
StyleDefinitions -> "Manual.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000]P2:?oQon82n@960dL5:0?l0080001804P000000]P2:001
0000I00000400`<300000BL?00400@0000000000000006P801T1T00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "8.0"->{
    Cell[1739, 51, 53, 1, 68, "Section",
      CellTags->"8.0"],
    Cell[1795, 54, 74, 1, 30, "Text",
      CellTags->"8.0"],
    Cell[1872, 57, 1078, 33, 45, "DisplayFormula",
      CellTags->"8.0"],
    Cell[2953, 92, 2817, 68, 378, "Text",
      CellTags->"8.0"]},
  "8.1"->{
    Cell[5795, 164, 79, 1, 56, "Subsection",
      CellTags->"8.1"],
    Cell[5877, 167, 627, 12, 112, "Text",
      CellTags->"8.1"],
    Cell[6507, 181, 388, 14, 36, "TopSpanBox",
      CellTags->"8.1"],
    Cell[6898, 197, 1039, 29, 24, "BottomBox",
      CellTags->"8.1"],
    Cell[7940, 228, 85, 1, 14, "Caption",
      CellTags->"8.1"],
    Cell[8028, 231, 936, 17, 161, "Text",
      CellTags->"8.1"],
    Cell[8967, 250, 64, 1, 28, "MathCaption",
      CellTags->"8.1"],
    Cell[9034, 253, 77, 2, 27, "Input",
      CellTags->"8.1"],
    Cell[9114, 257, 353, 7, 70, "MathCaption",
      CellTags->"8.1"],
    Cell[9492, 268, 214, 9, 102, "Input",
      CellTags->"8.1"],
    Cell[9709, 279, 1870, 59, 199, "Output",
      CellTags->"8.1"],
    Cell[11594, 341, 94, 1, 28, "MathCaption",
      CellTags->"8.1"],
    Cell[11713, 346, 77, 2, 27, "Input",
      CellTags->"8.1"],
    Cell[11793, 350, 83, 3, 26, "Output",
      CellTags->"8.1"],
    Cell[11891, 356, 68, 1, 28, "MathCaption",
      CellTags->"8.1"],
    Cell[11984, 361, 75, 2, 27, "Input",
      CellTags->"8.1"],
    Cell[12062, 365, 83, 3, 26, "Output",
      CellTags->"8.1"],
    Cell[12160, 371, 139, 4, 42, "MathCaption",
      CellTags->"8.1"],
    Cell[12324, 379, 95, 2, 27, "Input",
      CellTags->"8.1"],
    Cell[12422, 383, 1505, 49, 135, "Output",
      CellTags->"8.1"],
    Cell[13942, 435, 102, 2, 28, "MathCaption",
      CellTags->"8.1"],
    Cell[14069, 441, 101, 2, 27, "Input",
      CellTags->"8.1"],
    Cell[14173, 445, 82, 3, 26, "Output",
      CellTags->"8.1"],
    Cell[14270, 451, 338, 11, 73, "Text",
      CellTags->"8.1"]},
  "8.2"->{
    Cell[14645, 467, 67, 1, 56, "Subsection",
      CellTags->"8.2"],
    Cell[14715, 470, 222, 6, 48, "Text",
      CellTags->"8.2"],
    Cell[14940, 478, 5444, 148, 85, "DisplayFormula",
      CellTags->"8.2"],
    Cell[20387, 628, 3597, 115, 146, "Text",
      CellTags->"8.2"],
    Cell[23987, 745, 5824, 158, 85, "DisplayFormula",
      CellTags->"8.2"],
    Cell[29814, 905, 679, 22, 64, "Text",
      CellTags->"8.2"],
    Cell[30496, 929, 396, 14, 36, "TopSpanBox",
      CellTags->"8.2"],
    Cell[30895, 945, 1654, 45, 36, "MiddleBox",
      CellTags->"8.2"],
    Cell[32552, 992, 397, 14, 20, "MiddleSpanBox",
      CellTags->"8.2"],
    Cell[32952, 1008, 1652, 45, 38, "BottomBox",
      CellTags->"8.2"],
    Cell[34607, 1055, 70, 1, 14, "Caption",
      CellTags->"8.2"],
    Cell[34680, 1058, 239, 5, 56, "MathCaption",
      CellTags->"8.2"],
    Cell[34944, 1067, 99, 2, 27, "Input",
      CellTags->"8.2"],
    Cell[35046, 1071, 1870, 59, 199, "Output",
      CellTags->"8.2"],
    Cell[36931, 1133, 184, 5, 42, "MathCaption",
      CellTags->"8.2"],
    Cell[37140, 1142, 97, 2, 27, "Input",
      CellTags->"8.2"],
    Cell[37240, 1146, 1870, 59, 199, "Output",
      CellTags->"8.2"],
    Cell[39125, 1208, 858, 23, 132, "Text",
      CellTags->"8.2"],
    Cell[39986, 1233, 395, 14, 36, "TopSpanBox",
      CellTags->"8.2"],
    Cell[40384, 1249, 1048, 29, 23, "MiddleBox",
      CellTags->"8.2"],
    Cell[41435, 1280, 396, 14, 20, "MiddleSpanBox",
      CellTags->"8.2"],
    Cell[41834, 1296, 1046, 29, 24, "BottomBox",
      CellTags->"8.2"],
    Cell[42883, 1327, 87, 1, 14, "Caption",
      CellTags->"8.2"],
    Cell[42973, 1330, 82, 1, 28, "MathCaption",
      CellTags->"8.2"],
    Cell[43080, 1335, 98, 2, 27, "Input",
      CellTags->"8.2"],
    Cell[43181, 1339, 1783, 57, 167, "Output",
      CellTags->"8.2"],
    Cell[44979, 1399, 80, 1, 28, "MathCaption",
      CellTags->"8.2"],
    Cell[45084, 1404, 97, 2, 27, "Input",
      CellTags->"8.2"],
    Cell[45184, 1408, 1784, 57, 167, "Output",
      CellTags->"8.2"],
    Cell[46983, 1468, 155, 4, 42, "MathCaption",
      CellTags->"8.2"],
    Cell[47163, 1476, 98, 2, 27, "Input",
      CellTags->"8.2"],
    Cell[47264, 1480, 1506, 49, 135, "Output",
      CellTags->"8.2"],
    Cell[48785, 1532, 1000, 23, 166, "Text",
      CellTags->"8.2"],
    Cell[49788, 1557, 782, 25, 72, "DefinitionBox3Col",
      CellTags->"8.2"],
    Cell[50573, 1584, 116, 4, 14, "Caption",
      CellTags->"8.2"]},
  "8.3"->{
    Cell[50726, 1593, 74, 1, 56, "Subsection",
      CellTags->"8.3"],
    Cell[50803, 1596, 393, 14, 36, "TopSpanBox",
      CellTags->"8.3"],
    Cell[51199, 1612, 1495, 41, 38, "BottomBox",
      CellTags->"8.3"],
    Cell[52697, 1655, 73, 1, 14, "Caption",
      CellTags->"8.3"],
    Cell[52773, 1658, 75, 1, 28, "MathCaption",
      CellTags->"8.3"],
    Cell[52873, 1663, 94, 2, 27, "Input",
      CellTags->"8.3"],
    Cell[52970, 1667, 127, 3, 26, "Output",
      CellTags->"8.3"],
    Cell[53112, 1673, 75, 1, 28, "MathCaption",
      CellTags->"8.3"],
    Cell[53212, 1678, 102, 2, 27, "Input",
      CellTags->"8.3"],
    Cell[53317, 1682, 127, 3, 26, "Output",
      CellTags->"8.3"],
    Cell[53459, 1688, 115, 4, 28, "MathCaption",
      CellTags->"8.3"],
    Cell[53599, 1696, 80, 2, 27, "Input",
      CellTags->"8.3"],
    Cell[53682, 1700, 132, 3, 26, "Output",
      CellTags->"8.3"],
    Cell[53829, 1706, 312, 11, 29, "MathCaption",
      CellTags->"8.3"],
    Cell[54166, 1721, 95, 2, 27, "Input",
      CellTags->"8.3"],
    Cell[54264, 1725, 1880, 59, 199, "Output",
      CellTags->"8.3"],
    Cell[56159, 1787, 115, 4, 28, "MathCaption",
      CellTags->"8.3"],
    Cell[56299, 1795, 96, 2, 27, "Input",
      CellTags->"8.3"],
    Cell[56398, 1799, 1890, 59, 199, "Output",
      CellTags->"8.3"],
    Cell[58303, 1861, 377, 8, 89, "Text",
      CellTags->"8.3"]},
  "8.4"->{
    Cell[58717, 1874, 77, 1, 56, "Subsection",
      CellTags->"8.4"],
    Cell[58797, 1877, 587, 12, 113, "Text",
      CellTags->"8.4"],
    Cell[59387, 1891, 396, 14, 36, "TopSpanBox",
      CellTags->"8.4"],
    Cell[59786, 1907, 1505, 41, 38, "BottomBox",
      CellTags->"8.4"],
    Cell[61294, 1950, 76, 1, 14, "Caption",
      CellTags->"8.4"],
    Cell[61373, 1953, 243, 5, 56, "MathCaption",
      CellTags->"8.4"],
    Cell[61641, 1962, 226, 8, 87, "Input",
      CellTags->"8.4"],
    Cell[61870, 1972, 1610, 49, 177, "Output",
      CellTags->"8.4"],
    Cell[63495, 2024, 90, 1, 28, "MathCaption",
      CellTags->"8.4"],
    Cell[63610, 2029, 98, 2, 27, "Input",
      CellTags->"8.4"],
    Cell[63711, 2033, 847, 15, 101, "Output",
      CellTags->"8.4"],
    Cell[64573, 2051, 163, 4, 42, "MathCaption",
      CellTags->"8.4"],
    Cell[64761, 2059, 93, 2, 27, "Input",
      CellTags->"8.4"],
    Cell[64857, 2063, 227, 5, 41, "Output",
      CellTags->"8.4"],
    Cell[65121, 2073, 92, 2, 27, "Input",
      CellTags->"8.4"],
    Cell[65216, 2077, 233, 5, 41, "Output",
      CellTags->"8.4"],
    Cell[65464, 2085, 157, 4, 42, "MathCaption",
      CellTags->"8.4"],
    Cell[65646, 2093, 97, 2, 27, "Input",
      CellTags->"8.4"],
    Cell[65746, 2097, 299, 7, 45, "Output",
      CellTags->"8.4"],
    Cell[66082, 2109, 97, 2, 27, "Input",
      CellTags->"8.4"],
    Cell[66182, 2113, 424, 9, 45, "Output",
      CellTags->"8.4"],
    Cell[66621, 2125, 896, 21, 164, "Text",
      CellTags->"8.4"],
    Cell[67520, 2148, 196246, 3475, 144, 179835, 3267, "GraphicsData", 
    "PostScript", "Picture",
      Evaluatable->False,
      CellTags->"8.4"],
    Cell[263769, 5625, 189, 6, 15, "Caption",
      CellTags->"8.4"],
    Cell[263961, 5633, 387, 14, 36, "TopSpanBox",
      CellTags->"8.4"],
    Cell[264351, 5649, 664, 18, 38, "BottomBox",
      CellTags->"8.4"],
    Cell[265018, 5669, 94, 1, 14, "Caption",
      CellTags->"8.4"],
    Cell[265115, 5672, 189, 5, 43, "MathCaption",
      CellTags->"8.4"],
    Cell[265329, 5681, 113, 2, 42, "Input",
      CellTags->"8.4"],
    Cell[265445, 5685, 1992, 55, 167, "Output",
      CellTags->"8.4"],
    Cell[267452, 5743, 403, 10, 81, "Text",
      CellTags->"8.4"],
    Cell[267858, 5755, 1448, 43, 132, "DefinitionBox3Col",
      CellTags->"8.4"],
    Cell[269309, 5800, 121, 5, 14, "Caption",
      CellTags->"8.4"],
    Cell[269433, 5807, 573, 15, 99, "Text",
      CellTags->"8.4"],
    Cell[270009, 5824, 223, 5, 44, "MathCaption",
      CellTags->"8.4"],
    Cell[270257, 5833, 174, 6, 57, "Input",
      CellTags->"8.4"],
    Cell[270434, 5841, 1682, 49, 135, "Output",
      CellTags->"8.4"],
    Cell[272131, 5893, 688, 12, 135, "MathCaption",
      CellTags->"8.4"],
    Cell[272844, 5909, 326, 12, 162, "Input",
      CellTags->"8.4"],
    Cell[273173, 5923, 126236, 3767, 296, 57874, 2917, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"8.4"]},
  "8.5"->{
    Cell[399458, 9696, 75, 1, 56, "Subsection",
      CellTags->"8.5"],
    Cell[399536, 9699, 1683, 47, 52, "DefinitionBox",
      CellTags->"8.5"],
    Cell[401222, 9748, 80, 1, 14, "Caption",
      CellTags->"8.5"],
    Cell[401305, 9751, 191, 5, 47, "Text",
      CellTags->"8.5"],
    Cell[401499, 9758, 215, 7, 28, "MathCaption",
      CellTags->"8.5"],
    Cell[401739, 9769, 137, 5, 57, "Input",
      CellTags->"8.5"],
    Cell[401879, 9776, 700, 19, 42, "Output",
      CellTags->"8.5"],
    Cell[402594, 9798, 239, 7, 28, "MathCaption",
      CellTags->"8.5"],
    Cell[402858, 9809, 79, 2, 27, "Input",
      CellTags->"8.5"],
    Cell[402940, 9813, 148, 4, 42, "Output",
      CellTags->"8.5"],
    Cell[403103, 9820, 516, 12, 97, "Text",
      CellTags->"8.5"],
    Cell[403622, 9834, 137, 4, 42, "MathCaption",
      CellTags->"8.5"],
    Cell[403784, 9842, 80, 2, 27, "Input",
      CellTags->"8.5"],
    Cell[403867, 9846, 148, 4, 42, "Output",
      CellTags->"8.5"],
    Cell[404030, 9853, 77, 1, 28, "MathCaption",
      CellTags->"8.5"],
    Cell[404132, 9858, 100, 2, 27, "Input",
      CellTags->"8.5"],
    Cell[404235, 9862, 649, 18, 42, "Output",
      CellTags->"8.5"],
    Cell[404899, 9883, 550, 19, 44, "MathCaption",
      CellTags->"8.5"],
    Cell[405474, 9906, 96, 2, 27, "Input",
      CellTags->"8.5"],
    Cell[405573, 9910, 105, 3, 26, "Output",
      CellTags->"8.5"],
    Cell[405693, 9916, 779, 24, 86, "DefinitionBox3Col",
      CellTags->"8.5"],
    Cell[406475, 9942, 108, 5, 14, "Caption",
      CellTags->"8.5"]},
  "8.6"->{
    Cell[406620, 9952, 65, 1, 56, "Subsection",
      CellTags->"8.6"],
    Cell[406688, 9955, 1159, 36, 80, "Text",
      CellTags->"8.6"],
    Cell[407850, 9993, 1326, 39, 57, "DisplayFormula",
      CellTags->"8.6"],
    Cell[409179, 10034, 41, 1, 30, "Text",
      CellTags->"8.6"],
    Cell[409223, 10037, 1460, 49, 77, "DisplayFormula",
      CellTags->"8.6"],
    Cell[410686, 10088, 146, 5, 31, "Text",
      CellTags->"8.6"],
    Cell[410835, 10095, 544, 19, 36, "TopSpanBox",
      CellTags->"8.6"],
    Cell[411382, 10116, 1349, 37, 38, "BottomBox",
      CellTags->"8.6"],
    Cell[412734, 10155, 72, 1, 14, "Caption",
      CellTags->"8.6"],
    Cell[412809, 10158, 70, 1, 28, "MathCaption",
      CellTags->"8.6"],
    Cell[412904, 10163, 228, 9, 102, "Input",
      CellTags->"8.6"],
    Cell[413135, 10174, 1880, 59, 199, "Output",
      CellTags->"8.6"],
    Cell[415030, 10236, 114, 4, 28, "MathCaption",
      CellTags->"8.6"],
    Cell[415169, 10244, 113, 2, 42, "Input",
      CellTags->"8.6"],
    Cell[415285, 10248, 266, 9, 69, "Output",
      CellTags->"8.6"],
    Cell[415566, 10260, 170, 4, 42, "MathCaption",
      CellTags->"8.6"],
    Cell[415761, 10268, 113, 2, 42, "Input",
      CellTags->"8.6"],
    Cell[415877, 10272, 1890, 59, 199, "Output",
      CellTags->"8.6"],
    Cell[417782, 10334, 1244, 42, 81, "Text",
      CellTags->"8.6"],
    Cell[419029, 10378, 178, 5, 43, "MathCaption",
      CellTags->"8.6"],
    Cell[419232, 10387, 147, 6, 57, "Input",
      CellTags->"8.6"],
    Cell[419382, 10395, 1890, 59, 199, "Output",
      CellTags->"8.6"],
    Cell[421287, 10457, 217, 5, 46, "Text",
      CellTags->"8.6"],
    Cell[421507, 10464, 1136, 35, 106, "DefinitionBox3Col",
      CellTags->"8.6"],
    Cell[422646, 10501, 114, 5, 14, "Caption",
      CellTags->"8.6"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"8.0", 423697, 10534},
  {"8.1", 423977, 10543},
  {"8.2", 425619, 10592},
  {"8.3", 428114, 10663},
  {"8.4", 429518, 10704},
  {"8.5", 432478, 10788},
  {"8.6", 434049, 10833}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 53, 1, 68, "Section",
  CellTags->"8.0"],
Cell[1795, 54, 74, 1, 30, "Text",
  CellTags->"8.0"],
Cell[1872, 57, 1078, 33, 45, "DisplayFormula",
  CellTags->"8.0"],
Cell[2953, 92, 2817, 68, 378, "Text",
  CellTags->"8.0"],

Cell[CellGroupData[{
Cell[5795, 164, 79, 1, 56, "Subsection",
  CellTags->"8.1"],
Cell[5877, 167, 627, 12, 112, "Text",
  CellTags->"8.1"],
Cell[6507, 181, 388, 14, 36, "TopSpanBox",
  CellTags->"8.1"],
Cell[6898, 197, 1039, 29, 24, "BottomBox",
  CellTags->"8.1"],
Cell[7940, 228, 85, 1, 14, "Caption",
  CellTags->"8.1"],
Cell[8028, 231, 936, 17, 161, "Text",
  CellTags->"8.1"],
Cell[8967, 250, 64, 1, 28, "MathCaption",
  CellTags->"8.1"],
Cell[9034, 253, 77, 2, 27, "Input",
  CellTags->"8.1"],
Cell[9114, 257, 353, 7, 70, "MathCaption",
  CellTags->"8.1"],

Cell[CellGroupData[{
Cell[9492, 268, 214, 9, 102, "Input",
  CellTags->"8.1"],
Cell[9709, 279, 1870, 59, 199, "Output",
  CellTags->"8.1"]
}, Open  ]],
Cell[11594, 341, 94, 1, 28, "MathCaption",
  CellTags->"8.1"],

Cell[CellGroupData[{
Cell[11713, 346, 77, 2, 27, "Input",
  CellTags->"8.1"],
Cell[11793, 350, 83, 3, 26, "Output",
  CellTags->"8.1"]
}, Open  ]],
Cell[11891, 356, 68, 1, 28, "MathCaption",
  CellTags->"8.1"],

Cell[CellGroupData[{
Cell[11984, 361, 75, 2, 27, "Input",
  CellTags->"8.1"],
Cell[12062, 365, 83, 3, 26, "Output",
  CellTags->"8.1"]
}, Open  ]],
Cell[12160, 371, 139, 4, 42, "MathCaption",
  CellTags->"8.1"],

Cell[CellGroupData[{
Cell[12324, 379, 95, 2, 27, "Input",
  CellTags->"8.1"],
Cell[12422, 383, 1505, 49, 135, "Output",
  CellTags->"8.1"]
}, Open  ]],
Cell[13942, 435, 102, 2, 28, "MathCaption",
  CellTags->"8.1"],

Cell[CellGroupData[{
Cell[14069, 441, 101, 2, 27, "Input",
  CellTags->"8.1"],
Cell[14173, 445, 82, 3, 26, "Output",
  CellTags->"8.1"]
}, Open  ]],
Cell[14270, 451, 338, 11, 73, "Text",
  CellTags->"8.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14645, 467, 67, 1, 56, "Subsection",
  CellTags->"8.2"],
Cell[14715, 470, 222, 6, 48, "Text",
  CellTags->"8.2"],
Cell[14940, 478, 5444, 148, 85, "DisplayFormula",
  CellTags->"8.2"],
Cell[20387, 628, 3597, 115, 146, "Text",
  CellTags->"8.2"],
Cell[23987, 745, 5824, 158, 85, "DisplayFormula",
  CellTags->"8.2"],
Cell[29814, 905, 679, 22, 64, "Text",
  CellTags->"8.2"],
Cell[30496, 929, 396, 14, 36, "TopSpanBox",
  CellTags->"8.2"],
Cell[30895, 945, 1654, 45, 36, "MiddleBox",
  CellTags->"8.2"],
Cell[32552, 992, 397, 14, 20, "MiddleSpanBox",
  CellTags->"8.2"],
Cell[32952, 1008, 1652, 45, 38, "BottomBox",
  CellTags->"8.2"],
Cell[34607, 1055, 70, 1, 14, "Caption",
  CellTags->"8.2"],
Cell[34680, 1058, 239, 5, 56, "MathCaption",
  CellTags->"8.2"],

Cell[CellGroupData[{
Cell[34944, 1067, 99, 2, 27, "Input",
  CellTags->"8.2"],
Cell[35046, 1071, 1870, 59, 199, "Output",
  CellTags->"8.2"]
}, Open  ]],
Cell[36931, 1133, 184, 5, 42, "MathCaption",
  CellTags->"8.2"],

Cell[CellGroupData[{
Cell[37140, 1142, 97, 2, 27, "Input",
  CellTags->"8.2"],
Cell[37240, 1146, 1870, 59, 199, "Output",
  CellTags->"8.2"]
}, Open  ]],
Cell[39125, 1208, 858, 23, 132, "Text",
  CellTags->"8.2"],
Cell[39986, 1233, 395, 14, 36, "TopSpanBox",
  CellTags->"8.2"],
Cell[40384, 1249, 1048, 29, 23, "MiddleBox",
  CellTags->"8.2"],
Cell[41435, 1280, 396, 14, 20, "MiddleSpanBox",
  CellTags->"8.2"],
Cell[41834, 1296, 1046, 29, 24, "BottomBox",
  CellTags->"8.2"],
Cell[42883, 1327, 87, 1, 14, "Caption",
  CellTags->"8.2"],
Cell[42973, 1330, 82, 1, 28, "MathCaption",
  CellTags->"8.2"],

Cell[CellGroupData[{
Cell[43080, 1335, 98, 2, 27, "Input",
  CellTags->"8.2"],
Cell[43181, 1339, 1783, 57, 167, "Output",
  CellTags->"8.2"]
}, Open  ]],
Cell[44979, 1399, 80, 1, 28, "MathCaption",
  CellTags->"8.2"],

Cell[CellGroupData[{
Cell[45084, 1404, 97, 2, 27, "Input",
  CellTags->"8.2"],
Cell[45184, 1408, 1784, 57, 167, "Output",
  CellTags->"8.2"]
}, Open  ]],
Cell[46983, 1468, 155, 4, 42, "MathCaption",
  CellTags->"8.2"],

Cell[CellGroupData[{
Cell[47163, 1476, 98, 2, 27, "Input",
  CellTags->"8.2"],
Cell[47264, 1480, 1506, 49, 135, "Output",
  CellTags->"8.2"]
}, Open  ]],
Cell[48785, 1532, 1000, 23, 166, "Text",
  CellTags->"8.2"],
Cell[49788, 1557, 782, 25, 72, "DefinitionBox3Col",
  CellTags->"8.2"],
Cell[50573, 1584, 116, 4, 14, "Caption",
  CellTags->"8.2"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50726, 1593, 74, 1, 56, "Subsection",
  CellTags->"8.3"],
Cell[50803, 1596, 393, 14, 36, "TopSpanBox",
  CellTags->"8.3"],
Cell[51199, 1612, 1495, 41, 38, "BottomBox",
  CellTags->"8.3"],
Cell[52697, 1655, 73, 1, 14, "Caption",
  CellTags->"8.3"],
Cell[52773, 1658, 75, 1, 28, "MathCaption",
  CellTags->"8.3"],

Cell[CellGroupData[{
Cell[52873, 1663, 94, 2, 27, "Input",
  CellTags->"8.3"],
Cell[52970, 1667, 127, 3, 26, "Output",
  CellTags->"8.3"]
}, Open  ]],
Cell[53112, 1673, 75, 1, 28, "MathCaption",
  CellTags->"8.3"],

Cell[CellGroupData[{
Cell[53212, 1678, 102, 2, 27, "Input",
  CellTags->"8.3"],
Cell[53317, 1682, 127, 3, 26, "Output",
  CellTags->"8.3"]
}, Open  ]],
Cell[53459, 1688, 115, 4, 28, "MathCaption",
  CellTags->"8.3"],

Cell[CellGroupData[{
Cell[53599, 1696, 80, 2, 27, "Input",
  CellTags->"8.3"],
Cell[53682, 1700, 132, 3, 26, "Output",
  CellTags->"8.3"]
}, Open  ]],
Cell[53829, 1706, 312, 11, 29, "MathCaption",
  CellTags->"8.3"],

Cell[CellGroupData[{
Cell[54166, 1721, 95, 2, 27, "Input",
  CellTags->"8.3"],
Cell[54264, 1725, 1880, 59, 199, "Output",
  CellTags->"8.3"]
}, Open  ]],
Cell[56159, 1787, 115, 4, 28, "MathCaption",
  CellTags->"8.3"],

Cell[CellGroupData[{
Cell[56299, 1795, 96, 2, 27, "Input",
  CellTags->"8.3"],
Cell[56398, 1799, 1890, 59, 199, "Output",
  CellTags->"8.3"]
}, Open  ]],
Cell[58303, 1861, 377, 8, 89, "Text",
  CellTags->"8.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58717, 1874, 77, 1, 56, "Subsection",
  CellTags->"8.4"],
Cell[58797, 1877, 587, 12, 113, "Text",
  CellTags->"8.4"],
Cell[59387, 1891, 396, 14, 36, "TopSpanBox",
  CellTags->"8.4"],
Cell[59786, 1907, 1505, 41, 38, "BottomBox",
  CellTags->"8.4"],
Cell[61294, 1950, 76, 1, 14, "Caption",
  CellTags->"8.4"],
Cell[61373, 1953, 243, 5, 56, "MathCaption",
  CellTags->"8.4"],

Cell[CellGroupData[{
Cell[61641, 1962, 226, 8, 87, "Input",
  CellTags->"8.4"],
Cell[61870, 1972, 1610, 49, 177, "Output",
  CellTags->"8.4"]
}, Open  ]],
Cell[63495, 2024, 90, 1, 28, "MathCaption",
  CellTags->"8.4"],

Cell[CellGroupData[{
Cell[63610, 2029, 98, 2, 27, "Input",
  CellTags->"8.4"],
Cell[63711, 2033, 847, 15, 101, "Output",
  CellTags->"8.4"]
}, Open  ]],
Cell[64573, 2051, 163, 4, 42, "MathCaption",
  CellTags->"8.4"],

Cell[CellGroupData[{
Cell[64761, 2059, 93, 2, 27, "Input",
  CellTags->"8.4"],
Cell[64857, 2063, 227, 5, 41, "Output",
  CellTags->"8.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65121, 2073, 92, 2, 27, "Input",
  CellTags->"8.4"],
Cell[65216, 2077, 233, 5, 41, "Output",
  CellTags->"8.4"]
}, Open  ]],
Cell[65464, 2085, 157, 4, 42, "MathCaption",
  CellTags->"8.4"],

Cell[CellGroupData[{
Cell[65646, 2093, 97, 2, 27, "Input",
  CellTags->"8.4"],
Cell[65746, 2097, 299, 7, 45, "Output",
  CellTags->"8.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66082, 2109, 97, 2, 27, "Input",
  CellTags->"8.4"],
Cell[66182, 2113, 424, 9, 45, "Output",
  CellTags->"8.4"]
}, Open  ]],
Cell[66621, 2125, 896, 21, 164, "Text",
  CellTags->"8.4"],
Cell[67520, 2148, 196246, 3475, 144, 179835, 3267, "GraphicsData", 
"PostScript", "Picture",
  Evaluatable->False,
  CellTags->"8.4"],
Cell[263769, 5625, 189, 6, 15, "Caption",
  CellTags->"8.4"],
Cell[263961, 5633, 387, 14, 36, "TopSpanBox",
  CellTags->"8.4"],
Cell[264351, 5649, 664, 18, 38, "BottomBox",
  CellTags->"8.4"],
Cell[265018, 5669, 94, 1, 14, "Caption",
  CellTags->"8.4"],
Cell[265115, 5672, 189, 5, 43, "MathCaption",
  CellTags->"8.4"],

Cell[CellGroupData[{
Cell[265329, 5681, 113, 2, 42, "Input",
  CellTags->"8.4"],
Cell[265445, 5685, 1992, 55, 167, "Output",
  CellTags->"8.4"]
}, Open  ]],
Cell[267452, 5743, 403, 10, 81, "Text",
  CellTags->"8.4"],
Cell[267858, 5755, 1448, 43, 132, "DefinitionBox3Col",
  CellTags->"8.4"],
Cell[269309, 5800, 121, 5, 14, "Caption",
  CellTags->"8.4"],
Cell[269433, 5807, 573, 15, 99, "Text",
  CellTags->"8.4"],
Cell[270009, 5824, 223, 5, 44, "MathCaption",
  CellTags->"8.4"],

Cell[CellGroupData[{
Cell[270257, 5833, 174, 6, 57, "Input",
  CellTags->"8.4"],
Cell[270434, 5841, 1682, 49, 135, "Output",
  CellTags->"8.4"]
}, Open  ]],
Cell[272131, 5893, 688, 12, 135, "MathCaption",
  CellTags->"8.4"],

Cell[CellGroupData[{
Cell[272844, 5909, 326, 12, 162, "Input",
  CellTags->"8.4"],
Cell[273173, 5923, 126236, 3767, 296, 57874, 2917, "GraphicsData", 
"PostScript", "Graphics",
  CellTags->"8.4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[399458, 9696, 75, 1, 56, "Subsection",
  CellTags->"8.5"],
Cell[399536, 9699, 1683, 47, 52, "DefinitionBox",
  CellTags->"8.5"],
Cell[401222, 9748, 80, 1, 14, "Caption",
  CellTags->"8.5"],
Cell[401305, 9751, 191, 5, 47, "Text",
  CellTags->"8.5"],
Cell[401499, 9758, 215, 7, 28, "MathCaption",
  CellTags->"8.5"],

Cell[CellGroupData[{
Cell[401739, 9769, 137, 5, 57, "Input",
  CellTags->"8.5"],
Cell[401879, 9776, 700, 19, 42, "Output",
  CellTags->"8.5"]
}, Open  ]],
Cell[402594, 9798, 239, 7, 28, "MathCaption",
  CellTags->"8.5"],

Cell[CellGroupData[{
Cell[402858, 9809, 79, 2, 27, "Input",
  CellTags->"8.5"],
Cell[402940, 9813, 148, 4, 42, "Output",
  CellTags->"8.5"]
}, Open  ]],
Cell[403103, 9820, 516, 12, 97, "Text",
  CellTags->"8.5"],
Cell[403622, 9834, 137, 4, 42, "MathCaption",
  CellTags->"8.5"],

Cell[CellGroupData[{
Cell[403784, 9842, 80, 2, 27, "Input",
  CellTags->"8.5"],
Cell[403867, 9846, 148, 4, 42, "Output",
  CellTags->"8.5"]
}, Open  ]],
Cell[404030, 9853, 77, 1, 28, "MathCaption",
  CellTags->"8.5"],

Cell[CellGroupData[{
Cell[404132, 9858, 100, 2, 27, "Input",
  CellTags->"8.5"],
Cell[404235, 9862, 649, 18, 42, "Output",
  CellTags->"8.5"]
}, Open  ]],
Cell[404899, 9883, 550, 19, 44, "MathCaption",
  CellTags->"8.5"],

Cell[CellGroupData[{
Cell[405474, 9906, 96, 2, 27, "Input",
  CellTags->"8.5"],
Cell[405573, 9910, 105, 3, 26, "Output",
  CellTags->"8.5"]
}, Open  ]],
Cell[405693, 9916, 779, 24, 86, "DefinitionBox3Col",
  CellTags->"8.5"],
Cell[406475, 9942, 108, 5, 14, "Caption",
  CellTags->"8.5"]
}, Open  ]],

Cell[CellGroupData[{
Cell[406620, 9952, 65, 1, 56, "Subsection",
  CellTags->"8.6"],
Cell[406688, 9955, 1159, 36, 80, "Text",
  CellTags->"8.6"],
Cell[407850, 9993, 1326, 39, 57, "DisplayFormula",
  CellTags->"8.6"],
Cell[409179, 10034, 41, 1, 30, "Text",
  CellTags->"8.6"],
Cell[409223, 10037, 1460, 49, 77, "DisplayFormula",
  CellTags->"8.6"],
Cell[410686, 10088, 146, 5, 31, "Text",
  CellTags->"8.6"],
Cell[410835, 10095, 544, 19, 36, "TopSpanBox",
  CellTags->"8.6"],
Cell[411382, 10116, 1349, 37, 38, "BottomBox",
  CellTags->"8.6"],
Cell[412734, 10155, 72, 1, 14, "Caption",
  CellTags->"8.6"],
Cell[412809, 10158, 70, 1, 28, "MathCaption",
  CellTags->"8.6"],

Cell[CellGroupData[{
Cell[412904, 10163, 228, 9, 102, "Input",
  CellTags->"8.6"],
Cell[413135, 10174, 1880, 59, 199, "Output",
  CellTags->"8.6"]
}, Open  ]],
Cell[415030, 10236, 114, 4, 28, "MathCaption",
  CellTags->"8.6"],

Cell[CellGroupData[{
Cell[415169, 10244, 113, 2, 42, "Input",
  CellTags->"8.6"],
Cell[415285, 10248, 266, 9, 69, "Output",
  CellTags->"8.6"]
}, Open  ]],
Cell[415566, 10260, 170, 4, 42, "MathCaption",
  CellTags->"8.6"],

Cell[CellGroupData[{
Cell[415761, 10268, 113, 2, 42, "Input",
  CellTags->"8.6"],
Cell[415877, 10272, 1890, 59, 199, "Output",
  CellTags->"8.6"]
}, Open  ]],
Cell[417782, 10334, 1244, 42, 81, "Text",
  CellTags->"8.6"],
Cell[419029, 10378, 178, 5, 43, "MathCaption",
  CellTags->"8.6"],

Cell[CellGroupData[{
Cell[419232, 10387, 147, 6, 57, "Input",
  CellTags->"8.6"],
Cell[419382, 10395, 1890, 59, 199, "Output",
  CellTags->"8.6"]
}, Open  ]],
Cell[421287, 10457, 217, 5, 46, "Text",
  CellTags->"8.6"],
Cell[421507, 10464, 1136, 35, 106, "DefinitionBox3Col",
  CellTags->"8.6"],
Cell[422646, 10501, 114, 5, 14, "Caption",
  CellTags->"8.6"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

