(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     64070,       2569]*)
(*NotebookOutlinePosition[     66210,       2632]*)
(*  CellTagsIndexPosition[     65925,       2620]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ShowCellBracket->False,
  CellLabelMargins->{{10, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->9],

Cell[StyleData[All, "AllBrackets"],
  PageWidth->WindowWidth,
  ShowCellBracket->True,
  ScriptMinSize->9],

Cell[StyleData[All, "Presentation"],
  PageWidth->WindowWidth,
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ShowCellBracket->False,
  CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->5,
  PrivateFontOptions->{"FontType"->"Outline"}],

Cell[StyleData[All, "EnhancedPrintout"],
  PageWidth->PaperWidth,
  ShowCellBracket->False,
  CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->5,
  PrivateFontOptions->{"FontType"->"Outline"}],

Cell[StyleData[All, "EnhancedPrintoutNonGray"],
  PageWidth->PaperWidth,
  ShowCellBracket->False,
  CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
  ScriptMinSize->5,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PrintingStyleEnvironment->"Printout",
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PrintingOptions->{"PrintingMargins"->{{97, 97}, {180, 64}},
  "FirstPageHeader"->False,
  "FacingPages"->True},
  CellLabelAutoDelete->False,
  CellFrameLabelMargins->6,
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  CellMargins->{{12, Inherited}, {20, 40}},
  CellGroupingRules->{"TitleGrouping", 0},
  PageBreakAbove->True,
  PageBreakBelow->False,
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->36,
  FontWeight->"Bold"],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{2, 10}, {15, 30}},
  FontSize->30],

Cell[StyleData["Title", "EnhancedPrintout"],
  CellMargins->{{2, 10}, {15, 30}},
  FontFamily->"Futura",
  FontSize->30],

Cell[StyleData["Title", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 10}, {15, 30}},
  FontFamily->"Futura",
  FontSize->30]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  CellMargins->{{12, Inherited}, {10, 2}},
  CellGroupingRules->{"TitleGrouping", 10},
  PageBreakBelow->False,
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}},
  FontFamily->"Helvetica",
  FontSize->28],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{2, 10}, {10, 15}},
  FontSize->24],

Cell[StyleData["Subtitle", "EnhancedPrintout"],
  CellMargins->{{2, 10}, {10, 15}},
  FontFamily->"Futura",
  FontSize->24],

Cell[StyleData["Subtitle", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 10}, {10, 15}},
  FontFamily->"Futura",
  FontSize->24]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  CellMargins->{{12, Inherited}, {10, 20}},
  CellGroupingRules->{"TitleGrouping", 20},
  PageBreakBelow->False,
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontSlant->"Italic"],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontSize->12],

Cell[StyleData["Subsubtitle", "EnhancedPrintout"],
  CellMargins->{{2, 10}, {8, 10}},
  FontFamily->"Futura",
  FontSize->12],

Cell[StyleData["Subsubtitle", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 10}, {8, 10}},
  FontFamily->"Futura",
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellFrame->{{0, 0}, {0.5, 0}},
  CellMargins->{{10, Inherited}, {8, 30}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameMargins->8,
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->20,
  FontWeight->"Bold",
  CellTags->"Section"],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{2, 0}, {7, 24}},
  FontSize->16],

Cell[StyleData["Section", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {7, 24}},
  FontFamily->"Futura",
  FontSize->16],

Cell[StyleData["Section", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {7, 24}},
  FontFamily->"Futura",
  FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{24, Inherited}, {8, 30}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Helvetica",
  FontSize->14,
  FontWeight->"Bold",
  CellTags->"Subsection"],

Cell[StyleData["Subsection", "Printout"],
  CellMargins->{{9, 0}, {7, 24}},
  FontSize->12],

Cell[StyleData["Subsection", "EnhancedPrintout"],
  CellMargins->{{9, 0}, {7, 24}},
  FontFamily->"Futura",
  FontSize->14],

Cell[StyleData["Subsection", "EnhancedPrintoutNonGray"],
  CellMargins->{{9, 0}, {7, 24}},
  FontFamily->"Futura",
  FontSize->14]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellMargins->{{12, Inherited}, {8, 24}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CounterIncrements->"Subsubsection",
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  CellTags->"Subsubsection"],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{2, 0}, {7, 18}},
  FontSize->10],

Cell[StyleData["Subsubsection", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {7, 18}},
  FontFamily->"Futura",
  FontSize->10],

Cell[StyleData["Subsubsection", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {7, 18}},
  FontFamily->"Futura",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"Text"],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontSize->11],

Cell[StyleData["Text", "EnhancedPrintout"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["Text", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 2}, {6, 6}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SmallText"],
  CellMargins->{{12, 10}, {6, 6}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"SmallText",
  FontSize->9],

Cell[StyleData["SmallText", "Printout"],
  CellMargins->{{2, 2}, {5, 5}},
  TextJustification->1,
  FontSize->7],

Cell[StyleData["SmallText", "EnhancedPrintout"],
  CellMargins->{{2, 2}, {5, 5}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->7],

Cell[StyleData["SmallText", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 2}, {5, 5}},
  TextJustification->1,
  FontFamily->"Palatino",
  FontSize->7]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CopyrightText"],
  CellMargins->{{10, 4}, {0, 8}},
  ParagraphSpacing->{0, 0},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10],

Cell[StyleData["CopyrightText", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->8]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  ShowCellBracket->True,
  CellMargins->{{45, 10}, {5, 7}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  FontWeight->"Bold"],

Cell[StyleData["Input", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9],

Cell[StyleData["Input", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9],

Cell[StyleData["Input", "EnhancedPrintoutNonGray"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {4, 6}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  ShowCellBracket->True,
  CellMargins->{{46, 10}, {7, 5}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Output"],

Cell[StyleData["Output", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9],

Cell[StyleData["Output", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9],

Cell[StyleData["Output", "EnhancedPrintoutNonGray"],
  ShowCellBracket->False,
  CellMargins->{{39, 0}, {6, 4}},
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  ShowCellBracket->True,
  CellMargins->{{45, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Message",
  StyleMenuListing->None,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 0]],

Cell[StyleData["Message", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontSize->9,
  FontColor->GrayLevel[0]],

Cell[StyleData["Message", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->9,
  FontColor->GrayLevel[0]],

Cell[StyleData["Message", "EnhancedPrintoutNonGray"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->9,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Print"],
  ShowCellBracket->True,
  CellMargins->{{75, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  CounterIncrements->"Print",
  StyleMenuListing->None],

Cell[StyleData["Print", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{57, Inherited}, {Inherited, Inherited}},
  FontSize->9],

Cell[StyleData["Print", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{57, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->9],

Cell[StyleData["Print", "EnhancedPrintoutNonGray"],
  ShowCellBracket->False,
  CellMargins->{{57, Inherited}, {Inherited, Inherited}},
  FontFamily->"Courier",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  ShowCellBracket->True,
  CellMargins->{{47, Inherited}, {Inherited, Inherited}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  StyleMenuListing->None],

Cell[StyleData["Graphics", "Printout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontSize->9],

Cell[StyleData["Graphics", "EnhancedPrintout"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontFamily->"Courier",
  FontSize->9],

Cell[StyleData["Graphics", "EnhancedPrintoutNonGray"],
  ShowCellBracket->False,
  CellMargins->{{39, Inherited}, {Inherited, Inherited}},
  ImageSize->{250, 250},
  FontFamily->"Courier",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontColor->RGBColor[0, 0, 1]],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],

Cell[StyleData["CellLabel", "EnhancedPrintout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]],

Cell[StyleData["CellLabel", "EnhancedPrintoutNonGray"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inline Formatting", "Section"],

Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],

Cell[StyleData["RM"],
  StyleMenuListing->None,
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["BF"],
  StyleMenuListing->None,
  FontWeight->"Bold"],

Cell[StyleData["IT"],
  StyleMenuListing->None,
  FontSlant->"Italic"],

Cell[StyleData["TR"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["TI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["TB"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["TBI"],
  StyleMenuListing->None,
  FontFamily->"Times",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["MR"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["MO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["MB"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["MBO"],
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[StyleData["SR"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Plain"],

Cell[StyleData["SO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SB"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Plain"],

Cell[StyleData["SBO"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontWeight->"Bold",
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell[StyleData["SO10"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->10,
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SO10", "Printout"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->7,
  FontWeight->"Plain",
  FontSlant->"Italic"],

Cell[StyleData["SO10", "EnhancedPrintout"],
  StyleMenuListing->None,
  FontFamily->"Futura",
  FontSize->7,
  FontWeight->"Plain",
  FontSlant->"Italic"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Miscellaneous Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["MathCaption"],
  CellDingbat->"\[FilledSmallSquare]",
  CellMargins->{{46, 42}, {0, 14}},
  PageBreakBelow->False,
  LineSpacing->{1, 1},
  ParagraphSpacing->{0, 8},
  FontColor->RGBColor[0, 0, 0.6]],

Cell[StyleData["MathCaption", "Printout"],
  CellMargins->{{42, 42}, {0, 14}},
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["MathCaption", "EnhancedPrintout"],
  CellMargins->{{42, 42}, {0, 14}},
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0]],

Cell[StyleData["MathCaption", "EnhancedPrintoutNonGray"],
  CellMargins->{{42, 42}, {0, 14}},
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Commentary"],
  CellFrame->{{2, 0}, {0, 0}},
  CellMargins->{{36, 10}, {7, 7}},
  PageBreakBelow->False,
  CellFrameMargins->8,
  CellFrameColor->RGBColor[0, 0.2, 1],
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  FontSlant->"Italic"],

Cell[StyleData["Commentary", "Printout"],
  CellMargins->{{36, 0}, {6, 6}},
  CellFrameColor->GrayLevel[0.8],
  FontSize->10],

Cell[StyleData["Commentary", "EnhancedPrintout"],
  CellMargins->{{36, 0}, {6, 6}},
  CellFrameColor->GrayLevel[0.8],
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["Commentary", "EnhancedPrintoutNonGray"],
  CellMargins->{{36, 0}, {6, 6}},
  CellFrameColor->GrayLevel[0.8],
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedText"],
  CellMargins->{{20, 4}, {0, 4}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  ParagraphIndent->-21,
  CounterIncrements->"ItemizedText"],

Cell[StyleData["ItemizedText", "Printout"],
  ParagraphIndent->-18,
  FontSize->11],

Cell[StyleData["ItemizedText", "EnhancedPrintout"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["ItemizedText", "EnhancedPrintoutNonGray"],
  ParagraphIndent->-18,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ItemizedTextNote"],
  CellMargins->{{41, 4}, {0, 4}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  CounterIncrements->"Text"],

Cell[StyleData["ItemizedTextNote", "Printout"],
  CellMargins->{{38, 4}, {0, 4}},
  FontSize->11],

Cell[StyleData["ItemizedTextNote", "EnhancedPrintout"],
  CellMargins->{{38, 4}, {0, 4}},
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["ItemizedTextNote", "EnhancedPrintoutNonGray"],
  CellMargins->{{38, 4}, {0, 4}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndentedText"],
  CellMargins->{{20, 4}, {0, 6}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 8},
  CounterIncrements->"Text"],

Cell[StyleData["IndentedText", "Printout"],
  FontSize->10],

Cell[StyleData["IndentedText", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["IndentedText", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Emphasis Boxes and Pictures", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.3, 0.7},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox3Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.2, 0.3, 0.5},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox3Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox3Col", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox3Col", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox4Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.15, 0.35, 0.15, 0.35},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox4Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox4Col", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox4Col", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox5Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->0.2,
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox5Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox5Col", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox5Col", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DefinitionBox6Col"],
  CellFrame->0.5,
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.13, 0.24, 0.13, 0.13, 0.24, 0.13},
  ColumnAlignments->{Left}}],

Cell[StyleData["DefinitionBox6Col", "Printout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox6Col", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["DefinitionBox6Col", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 4}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TopBox"],
  CellFrame->{{0.5, 0.5}, {0, 0.5}},
  CellMargins->{{11, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left}}],

Cell[StyleData["TopBox", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["TopBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["TopBox", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MiddleBox"],
  CellFrame->{{0.5, 0.5}, {0, 0}},
  CellMargins->{{11, 4}, {0, -7}},
  CellHorizontalScrolling->True,
  PageBreakAbove->False,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left}}],

Cell[StyleData["MiddleBox", "Printout"],
  CellMargins->{{2, 0}, {0, 2}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["MiddleBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 4}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["MiddleBox", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 4}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MiddleSpacedBox"],
  CellFrame->{{0.5, 0.5}, {0, 0}},
  CellMargins->{{11, 4}, {0, -7}},
  CellHorizontalScrolling->True,
  PageBreakAbove->False,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left},
  RowMinHeight->1.2}],

Cell[StyleData["MiddleSpacedBox", "Printout"],
  CellMargins->{{2, 0}, {0, 0}},
  FontSize->10,
  Background->GrayLevel[0.900008],
  GridBoxOptions->{RowMinHeight->1.8}],

Cell[StyleData["MiddleSpacedBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008],
  GridBoxOptions->{RowMinHeight->1.8}],

Cell[StyleData["MiddleSpacedBox", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1],
  GridBoxOptions->{RowMinHeight->1.8}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BottomBox"],
  CellFrame->{{0.5, 0.5}, {0.5, 0}},
  CellMargins->{{11, 4}, {0, -7}},
  CellHorizontalScrolling->True,
  PageBreakAbove->False,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.31, 0.62},
  ColumnAlignments->{Left},
  RowMinHeight->1.2}],

Cell[StyleData["BottomBox", "Printout"],
  CellMargins->{{2, 0}, {0, -5}},
  FontSize->10,
  Background->GrayLevel[0.900008],
  GridBoxOptions->{RowMinHeight->2.2}],

Cell[StyleData["BottomBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, -5}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008],
  GridBoxOptions->{RowMinHeight->2.2}],

Cell[StyleData["BottomBox", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, -5}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1],
  GridBoxOptions->{RowMinHeight->2.2}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["TopSpanBox"],
  CellFrame->{{0.5, 0.5}, {0, 0.5}},
  CellMargins->{{11, 4}, {-2, 8}},
  CellHorizontalScrolling->True,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.9, 0.03},
  ColumnAlignments->{Left}}],

Cell[StyleData["TopSpanBox", "Printout"],
  CellMargins->{{2, 0}, {-2, 8}},
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["TopSpanBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {-4, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008]],

Cell[StyleData["TopSpanBox", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {-4, 8}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["MiddleSpanBox"],
  CellFrame->{{0.5, 0.5}, {0, 0}},
  CellMargins->{{11, 4}, {-3, -8}},
  CellHorizontalScrolling->True,
  PageBreakAbove->False,
  PageBreakBelow->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  FontWeight->"Plain",
  Background->RGBColor[1, 0.6, 0.6],
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->1,
  ColumnWidths->{0.9, 0.03},
  ColumnAlignments->{Left},
  RowMinHeight->1.2}],

Cell[StyleData["MiddleSpanBox", "Printout"],
  CellMargins->{{2, 0}, {-5, 0}},
  FontSize->10,
  Background->GrayLevel[0.900008],
  GridBoxOptions->{RowMinHeight->1.8}],

Cell[StyleData["MiddleSpanBox", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {-7, 0}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[0.900008],
  GridBoxOptions->{RowMinHeight->1.8}],

Cell[StyleData["MiddleSpanBox", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {-7, 0}},
  FontFamily->"Palatino",
  FontSize->10,
  Background->GrayLevel[1],
  GridBoxOptions->{RowMinHeight->1.8}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Picture"],
  CellMargins->{{12, Inherited}, {0, 8}},
  CellHorizontalScrolling->True],

Cell[StyleData["Picture", "Printout"],
  CellMargins->{{2, Inherited}, {0, 8}}],

Cell[StyleData["Picture", "EnhancedPrintout"],
  CellMargins->{{2, Inherited}, {0, 8}}],

Cell[StyleData["Picture", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, Inherited}, {0, 8}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Caption"],
  CellMargins->{{12, 4}, {0, 2}},
  PageBreakAbove->False,
  FontFamily->"Helvetica",
  FontSize->9],

Cell[StyleData["Caption", "Printout"],
  CellMargins->{{2, 4}, {2, 4}},
  FontSize->7],

Cell[StyleData["Caption", "EnhancedPrintout"],
  CellMargins->{{2, 4}, {2, 4}},
  FontFamily->"Futura",
  FontSize->7],

Cell[StyleData["Caption", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 4}, {2, 4}},
  FontFamily->"Futura",
  FontSize->7]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Tables", "Section"],

Cell[CellGroupData[{

Cell[StyleData["SingleRowTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnAlignments->{Left}}],

Cell[StyleData["SingleRowTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["SingleRowTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["SingleRowTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->{0.34, 0.64},
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["2ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["2ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["2ColumnTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["2ColumnEvenTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.49,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["2ColumnEvenTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["2ColumnEvenTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["2ColumnEvenTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->{0.28, 0.28, 0.43},
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["3ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["3ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["3ColumnTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["4ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.25,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["4ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["4ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["4ColumnTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["5ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.2,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["5ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["5ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["5ColumnTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["6ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.16,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["6ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["6ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["6ColumnTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["7ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.14,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["7ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["7ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["7ColumnTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["8ColumnTable"],
  CellMargins->{{10, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  StyleMenuListing->None,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->0.12,
  ColumnAlignments->{Left, Center}}],

Cell[StyleData["8ColumnTable", "Printout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["8ColumnTable", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["8ColumnTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 8}},
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Automatic Numbering", "Section"],

Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["NumberedEquation"],
  CellMargins->{{45, 10}, {7, 7}},
  CellFrameLabels->{{None, Cell[ 
          TextData[ {"(", 
            CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
  DefaultFormatType->DefaultTextFormatType,
  SpanMaxSize->Infinity,
  CounterIncrements->"NumberedEquation",
  FormatTypeAutoConvert->False],

Cell[StyleData["NumberedEquation", "Printout"],
  CellMargins->{{39, 55}, {0, 10}},
  FontSize->10],

Cell[StyleData["NumberedEquation", "EnhancedPrintout"],
  CellMargins->{{39, 55}, {0, 10}},
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["NumberedEquation", "EnhancedPrintoutNonGray"],
  CellMargins->{{39, 55}, {0, 10}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Formulas and Programming", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DisplayFormula"],
  CellMargins->{{45, Inherited}, {7, 7}},
  CellHorizontalScrolling->True,
  ScriptLevel->0,
  SingleLetterItalics->True,
  SpanMaxSize->Infinity,
  UnderoverscriptBoxOptions->{LimitsPositioning->True}],

Cell[StyleData["DisplayFormula", "Printout"],
  FontSize->10],

Cell[StyleData["DisplayFormula", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["DisplayFormula", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["DisplayMath"],
  CellMargins->{{45, 10}, {7, 7}},
  Evaluatable->False,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input"],

Cell[StyleData["DisplayMath", "Printout"],
  CellMargins->{{39, 0}, {6, 6}},
  FontSize->9],

Cell[StyleData["DisplayMath", "EnhancedPrintout"],
  CellMargins->{{39, 0}, {4, 6}},
  FontFamily->"WRICourier",
  FontSize->9],

Cell[StyleData["DisplayMath", "EnhancedPrintoutNonGray"],
  CellMargins->{{39, 0}, {4, 6}},
  FontFamily->"WRICourier",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["EquationNumber"],
  LineSpacing->{1.83, 0}],

Cell[StyleData["EquationNumber", "Printout"],
  LineSpacing->{1.7, 0},
  FontSize->10],

Cell[StyleData["EquationNumber", "EnhancedPrintout"],
  LineSpacing->{1.7, 0},
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["EquationNumber", "EnhancedPrintoutNonGray"],
  LineSpacing->{1.7, 0},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Program"],
  CellFrame->{{0, 0}, {0.5, 0.5}},
  CellMargins->{{12, Inherited}, {7, 7}},
  CellFrameMargins->{{0, 0}, {7, 5}},
  FontFamily->"Courier"],

Cell[StyleData["Program", "Printout"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontSize->9.5],

Cell[StyleData["Program", "EnhancedPrintout"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontFamily->"WRICourier",
  FontSize->9.5],

Cell[StyleData["Program", "EnhancedPrintoutNonGray"],
  CellMargins->{{18, 30}, {Inherited, 4}},
  FontFamily->"WRICourier",
  FontSize->9.5]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Contents and Index", "Section"],

Cell[CellGroupData[{

Cell[StyleData["ContentsTitle"],
  ShowGroupOpenCloseIcon->False,
  CellMargins->{{10, 4}, {0, 18}},
  CellGroupingRules->{"SectionGrouping", 60},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->26,
  FontWeight->"Bold"],

Cell[StyleData["ContentsTitle", "Printout"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontSize->18],

Cell[StyleData["ContentsTitle", "EnhancedPrintout"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->18],

Cell[StyleData["ContentsTitle", "EnhancedPrintoutNonGray"],
  CellMargins->{{2, 0}, {0, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->18]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["ContentsSection"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{35, 4}, {3, 18}},
  CellGroupingRules->{"SectionGrouping", 70},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold"],

Cell[StyleData["ContentsSection", "Printout"],
  CellMargins->{{20, 0}, {3, 18}},
  PageBreakBelow->False,
  FontSize->11],

Cell[StyleData["ContentsSection", "EnhancedPrintout"],
  CellMargins->{{20, 0}, {3, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->11],

Cell[StyleData["ContentsSection", "EnhancedPrintoutNonGray"],
  CellMargins->{{20, 0}, {3, 18}},
  PageBreakBelow->False,
  FontFamily->"Futura",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Contents"],
  ShowGroupOpenCloseIcon->False,
  CellMargins->{{50, 4}, {0, 5}},
  CellGroupingRules->{"SectionGrouping", 90},
  StyleMenuListing->None],

Cell[StyleData["Contents", "Printout"],
  CellMargins->{{40, 4}, {0, 5}},
  FontSize->11],

Cell[StyleData["Contents", "EnhancedPrintout"],
  CellMargins->{{40, 5}, {0, 5}},
  FontFamily->"Palatino",
  FontSize->11],

Cell[StyleData["Contents", "EnhancedPrintoutNonGray"],
  CellMargins->{{40, 5}, {0, 5}},
  FontFamily->"Palatino",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Index"],
  CellMargins->{{21, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["Index", "Printout"],
  CellMargins->{{13, 0}, {0, 0}},
  FontSize->10],

Cell[StyleData["Index", "EnhancedPrintout"],
  CellMargins->{{13, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["Index", "EnhancedPrintoutNonGray"],
  CellMargins->{{13, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["IndexSubentry"],
  CellMargins->{{36, 4}, {0, 0}},
  ParagraphIndent->-48,
  StyleMenuListing->None],

Cell[StyleData["IndexSubentry", "Printout"],
  CellMargins->{{24, 0}, {0, 0}},
  FontSize->10],

Cell[StyleData["IndexSubentry", "EnhancedPrintout"],
  CellMargins->{{24, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["IndexSubentry", "EnhancedPrintoutNonGray"],
  CellMargins->{{24, 0}, {0, 0}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Function List", "Section"],

Cell[CellGroupData[{

Cell[StyleData["FunctionName"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{24, 10}, {10, 12}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  FontFamily->"Courier",
  FontSize->14,
  FontWeight->"Bold",
  CellTags->"FunctionName"],

Cell[StyleData["FunctionName", "Printout"],
  CellMargins->{{9, 0}, {10, 10}},
  FontSize->12],

Cell[StyleData["FunctionName", "EnhancedPrintout"],
  CellMargins->{{9, 0}, {10, 10}},
  FontFamily->"Courier",
  FontSize->12],

Cell[StyleData["FunctionName", "EnhancedPrintoutNonGray"],
  CellMargins->{{9, 0}, {10, 10}},
  FontFamily->"Courier",
  FontSize->12]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SubsectionIcon"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{24, 10}, {0, 30}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  FontSize->14,
  FontWeight->"Bold",
  CellTags->"FunctionSection"],

Cell[StyleData["SubsectionIcon", "Printout"],
  CellMargins->{{20, 0}, {0, 20}},
  FontSize->13],

Cell[StyleData["SubsectionIcon", "EnhancedPrintout"],
  CellMargins->{{20, 0}, {0, 20}},
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["SubsectionIcon", "EnhancedPrintoutNonGray"],
  CellMargins->{{20, 0}, {0, 20}},
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FunctionSubsection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{36, 10}, {0, 6}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  FontWeight->"Bold",
  CellTags->"FunctionSubsection"],

Cell[StyleData["FunctionSubsection", "Printout"],
  CellMargins->{{30, 0}, {0, 6}}],

Cell[StyleData["FunctionSubsection", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {0, 6}},
  FontFamily->"Palatino",
  FontSize->11],

Cell[StyleData["FunctionSubsection", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {0, 6}},
  FontFamily->"Palatino",
  FontSize->11]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SubsubsectionIcon"],
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{36, 10}, {0, 6}},
  CellGroupingRules->{"SectionGrouping", 60},
  PageBreakBelow->False,
  FontWeight->"Bold",
  CellTags->"SubsubsectionIcon"],

Cell[StyleData["SubsubsectionIcon", "Printout"],
  CellMargins->{{30, 0}, {0, 6}},
  FontSize->11],

Cell[StyleData["SubsubsectionIcon", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {0, 6}},
  FontFamily->"Palatino",
  FontSize->9],

Cell[StyleData["SubsubsectionIcon", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {0, 6}},
  FontFamily->"Palatino",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FunctionDescription"],
  CellMargins->{{36, 10}, {4, 0}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"Text",
  FontWeight->"Plain"],

Cell[StyleData["FunctionDescription", "Printout"],
  CellMargins->{{30, 0}, {4, 0}},
  FontSize->11],

Cell[StyleData["FunctionDescription", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["FunctionDescription", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FunctionDescriptionRuled"],
  CellFrame->{{0, 0}, {0.25, 0.25}},
  CellMargins->{{36, 10}, {4, 0}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"Text"],

Cell[StyleData["FunctionDescriptionRuled", "Printout"],
  CellMargins->{{30, 0}, {4, 0}},
  FontSize->11],

Cell[StyleData["FunctionDescriptionRuled", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["FunctionDescriptionRuled", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FunctionDescriptionRuleTop"],
  CellFrame->{{0, 0}, {0, 0.25}},
  CellMargins->{{36, 10}, {4, 0}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"Text"],

Cell[StyleData["FunctionDescriptionRuleTop", "Printout"],
  CellMargins->{{30, 0}, {4, 0}},
  FontSize->11],

Cell[StyleData["FunctionDescriptionRuleTop", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["FunctionDescriptionRuleTop", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FunctionDescriptionRuleBottom"],
  CellFrame->{{0, 0}, {0.25, 0}},
  CellMargins->{{36, 10}, {4, 0}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0.7, 0},
  CounterIncrements->"Text"],

Cell[StyleData["FunctionDescriptionRuleBottom", "Printout"],
  CellMargins->{{30, 0}, {4, 0}},
  FontSize->11],

Cell[StyleData["FunctionDescriptionRuleBottom", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10],

Cell[StyleData["FunctionDescriptionRuleBottom", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {4, 0}},
  TextJustification->0,
  FontFamily->"Palatino",
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FunctionExample"],
  CellMargins->{{36, 10}, {4, 0}},
  StyleMenuListing->None,
  FontSize->10],

Cell[StyleData["FunctionExample", "Printout"],
  CellMargins->{{30, 0}, {4, 0}},
  FontSize->9],

Cell[StyleData["FunctionExample", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {4, 0}},
  FontFamily->"Palatino",
  FontSize->9],

Cell[StyleData["FunctionExample", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {4, 0}},
  FontFamily->"Palatino",
  FontSize->9]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["FunctionTextNote"],
  CellMargins->{{36, 4}, {0, 4}},
  LineSpacing->{1, 3},
  ParagraphSpacing->{0, 4},
  LineIndent->0],

Cell[StyleData["FunctionTextNote", "Printout"],
  CellMargins->{{36, 4}, {0, 4}},
  FontSize->9],

Cell[StyleData["FunctionTextNote", "EnhancedPrintout"],
  CellMargins->{{36, 4}, {0, 4}},
  FontFamily->"Palatino",
  FontSize->8],

Cell[StyleData["FunctionTextNote", "EnhancedPrintoutNonGray"],
  CellMargins->{{36, 4}, {0, 4}},
  FontFamily->"Palatino",
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["3ColumnFunctionTable"],
  CellMargins->{{36, 4}, {0, 8}},
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  AutoIndent->False,
  AutoSpacing->False,
  LineIndent->0,
  GridBoxOptions->{RowSpacings->1.5,
  ColumnSpacings->2,
  ColumnWidths->{0.28, 0.28, 0.43},
  ColumnAlignments->{Left}}],

Cell[StyleData["3ColumnFunctionTable", "Printout"],
  CellMargins->{{30, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["3ColumnFunctionTable", "EnhancedPrintout"],
  CellMargins->{{30, 0}, {0, 8}},
  FontSize->10],

Cell[StyleData["3ColumnFunctionTable", "EnhancedPrintoutNonGray"],
  CellMargins->{{30, 0}, {0, 8}},
  FontSize->10]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Browser Emulation", "Section"],

Cell[CellGroupData[{

Cell[StyleData["TextNormal"],
  CellMargins->{{12, 10}, {7, 7}},
  LineSpacing->{1, 3},
  CounterIncrements->"Text",
  FontFamily->"Times",
  FontSize->12],

Cell[StyleData["TextNormal", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["BrowserEmulation"],
  CellMargins->{{12, 1}, {7, 24}},
  CellGroupingRules->{"SectionGrouping", 70},
  LineSpacing->{1, 3},
  FontFamily->"Helvetica",
  GridBoxOptions->{ColumnWidths->0.25,
  ColumnAlignments->{Left},
  GridFrame->True,
  GridFrameMargins->0.5,
  ColumnLines->True}],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["CategoryDefs"],
  CellMargins->{{300, 10}, {7, 7}},
  LineSpacing->{1, 3},
  FontFamily->"Helvetica",
  Background->RGBColor[1, 0.8, 0.6],
  GridBoxOptions->{ColumnAlignments->{Left},
  GridFrame->False,
  RowLines->True,
  ColumnLines->True}],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{2, 2}, {6, 6}},
  FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Category1"],
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{12, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 50},
  FontSize->16,
  FontWeight->"Bold"],

Cell[StyleData["Category1", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Category2"],
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{85, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 60},
  FontSize->14,
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0, 0.500008]],

Cell[StyleData["Category2", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Category3"],
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{157, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 70},
  FontSize->12,
  FontWeight->"Bold",
  FontColor->RGBColor[0.2, 0, 0.4]],

Cell[StyleData["Category3", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Category4"],
  ShowCellBracket->False,
  ShowGroupOpenCloseIcon->True,
  CellMargins->{{230, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 80},
  FontWeight->"Bold",
  FontColor->RGBColor[0, 0.300008, 0.4]],

Cell[StyleData["Category4", "Printout"],
  CellMargins->{{2, 2}, {6, 6}}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->8,
  FontWeight->"Bold"],

Cell[StyleData["Header", "Printout"]],

Cell[StyleData["Header", "EnhancedPrintout"],
  FontFamily->"Futura"],

Cell[StyleData["Header", "EnhancedPrintoutNonGray"],
  FontFamily->"Futura"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->7,
  FontSlant->"Plain"],

Cell[StyleData["Footer", "Printout"]],

Cell[StyleData["Footer", "EnhancedPrintout"],
  FontFamily->"Futura"],

Cell[StyleData["Footer", "EnhancedPrintoutNonGray"],
  FontFamily->"Futura"]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->8,
  FontWeight->"Bold"],

Cell[StyleData["PageNumber", "Printout"]],

Cell[StyleData["PageNumber", "EnhancedPrintout"],
  FontFamily->"Futura"],

Cell[StyleData["PageNumber", "EnhancedPrintoutNonGray"],
  FontFamily->"Futura"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["Hyperlink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["Hyperlink", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["MainBookLink", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnsLink", "EnhancedPrintout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnsLink", "EnhancedPrintoutNonGray"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLinkText"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Times",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnsLinkText", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnsLinkText", "EnhancedPrintout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["AddOnsLinkText", "EnhancedPrintoutNonGray"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Printout"],
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["RefGuideLink", "EnhancedPrintout"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["RefGuideLink", "EnhancedPrintoutNonGray"],
  FontFamily->"WRICourier",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["GettingStartedLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["GettingStartedLink", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontSize->11,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherInformationLink", "EnhancedPrintout"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}],

Cell[StyleData["OtherInformationLink", "EnhancedPrintoutNonGray"],
  FontFamily->"Palatino",
  FontSize->10,
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Outline Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Outline1"],
  CellMargins->{{12, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 50},
  ParagraphIndent->-38,
  CounterIncrements->"Outline1",
  FontSize->18,
  FontWeight->"Bold",
  CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}],

Cell[StyleData["Outline1", "Printout"],
  CounterBoxOptions->{CounterFunction:>CapitalRomanNumeral}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline2"],
  CellMargins->{{59, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 60},
  ParagraphIndent->-27,
  CounterIncrements->"Outline2",
  FontSize->15,
  FontWeight->"Bold",
  CounterBoxOptions->{CounterFunction:>(Part[ 
      CharacterRange[ "A", "Z"], #]&)}],

Cell[StyleData["Outline2", "Printout"],
  CounterBoxOptions->{CounterFunction:>(Part[ 
      CharacterRange[ "A", "Z"], #]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline3"],
  CellMargins->{{108, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 70},
  ParagraphIndent->-21,
  CounterIncrements->"Outline3",
  FontSize->12,
  CounterBoxOptions->{CounterFunction:>Identity}],

Cell[StyleData["Outline3", "Printout"],
  CounterBoxOptions->{CounterFunction:>Identity}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Outline4"],
  CellMargins->{{158, 10}, {7, 7}},
  CellGroupingRules->{"SectionGrouping", 80},
  ParagraphIndent->-18,
  CounterIncrements->"Outline4",
  FontSize->10,
  CounterBoxOptions->{CounterFunction:>(Part[ 
      CharacterRange[ "a", "z"], #]&)}],

Cell[StyleData["Outline4", "Printout"]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
WindowSize->{503, 367},
WindowMargins->{{11, Automatic}, {Automatic, 2}},
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Section"->{
    Cell[6184, 218, 381, 11, 70, 26, 0, "StyleData", "Section", "All",
      CounterIncrements->"Section",
      CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
      CellTags->"Section"]},
  "Subsection"->{
    Cell[6946, 248, 349, 10, 70, 29, 0, "StyleData", "Subsection", "All",
      CounterIncrements->"Subsection",
      CounterAssignments->{{"Subsubsection", 0}},
      CellTags->"Subsection"]},
  "Subsubsection"->{
    Cell[7685, 277, 262, 7, 160, 32, 0, "StyleData", "Subsubsection", "All",
      CounterIncrements->"Subsubsection",
      CellTags->"Subsubsection"]},
  "FunctionName"->{
    Cell[45519, 1830, 264, 8, 70, 31, 0, "StyleData", "FunctionName", "All",
      CellTags->"FunctionName"]},
  "FunctionSection"->{
    Cell[46184, 1857, 241, 7, 70, 33, 0, "StyleData", "SubsectionIcon", 
    "All",
      CellTags->"FunctionSection"]},
  "FunctionSubsection"->{
    Cell[46834, 1883, 233, 6, 70, 37, 0, "StyleData", "FunctionSubsection", 
    "All",
      CellTags->"FunctionSubsection"]},
  "SubsubsectionIcon"->{
    Cell[47469, 1907, 229, 6, 143, 36, 0, "StyleData", "SubsubsectionIcon", 
    "All",
      CellTags->"SubsubsectionIcon"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Section", 64726, 2587},
  {"Subsection", 64949, 2592},
  {"Subsubsection", 65165, 2597},
  {"FunctionName", 65339, 2601},
  {"FunctionSection", 65473, 2604},
  {"FunctionSubsection", 65620, 2608},
  {"SubsubsectionIcon", 65773, 2612}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 37, 0, 64, "Subtitle"],
Cell[1779, 53, 193, 4, 52, "Text"],

Cell[CellGroupData[{
Cell[1997, 61, 42, 0, 53, "Section"],
Cell[2042, 63, 166, 4, 40, 31, 0, "StyleData", "All", "Working"],
Cell[2211, 69, 106, 3, 40, 35, 0, "StyleData", "All", "AllBrackets"],
Cell[2320, 74, 140, 4, 40, 36, 0, "StyleData", "All", "Presentation"],
Cell[2463, 80, 212, 5, 38, 32, 0, "StyleData", "All", "Printout"],
Cell[2678, 87, 220, 5, 38, 40, 0, "StyleData", "All", "EnhancedPrintout"],
Cell[2901, 94, 227, 5, 70, 47, 0, "StyleData", "All", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[3165, 104, 35, 0, 33, "Section"],
Cell[3203, 106, 99, 2, 70, "Text"],
Cell[3305, 110, 610, 16, 70, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3952, 131, 38, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[4015, 135, 371, 10, 70, 24, 0, "StyleData", "Title", "All",
  CounterIncrements->"Title",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subtitle", 0}, {"Subsubtitle", 0}}],
Cell[4389, 147, 88, 2, 70, 36, 0, "StyleData", "Title", "Printout"],
Cell[4480, 151, 120, 3, 70, 44, 0, "StyleData", "Title", "EnhancedPrintout"],
Cell[4603, 156, 127, 3, 70, 51, 0, "StyleData", "Title", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[4767, 164, 314, 8, 70, 27, 0, "StyleData", "Subtitle", "All",
  CounterIncrements->"Subtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
      "Subsubtitle", 0}}],
Cell[5084, 174, 91, 2, 70, 39, 0, "StyleData", "Subtitle", "Printout"],
Cell[5178, 178, 123, 3, 70, 47, 0, "StyleData", "Subtitle", \
"EnhancedPrintout"],
Cell[5304, 183, 130, 3, 70, 54, 0, "StyleData", "Subtitle", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[5471, 191, 317, 8, 70, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterIncrements->"Subsubtitle",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[5791, 201, 93, 2, 70, 42, 0, "StyleData", "Subsubtitle", "Printout"],
Cell[5887, 205, 125, 3, 70, 50, 0, "StyleData", "Subsubtitle", \
"EnhancedPrintout"],
Cell[6015, 210, 132, 3, 70, 57, 0, "StyleData", "Subsubtitle", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[6184, 218, 381, 11, 70, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  CellTags->"Section"],
Cell[6568, 231, 88, 2, 70, 38, 0, "StyleData", "Section", "Printout"],
Cell[6659, 235, 120, 3, 70, 46, 0, "StyleData", "Section", \
"EnhancedPrintout"],
Cell[6782, 240, 127, 3, 70, 53, 0, "StyleData", "Section", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[6946, 248, 349, 10, 70, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  CellTags->"Subsection"],
Cell[7298, 260, 91, 2, 70, 41, 0, "StyleData", "Subsection", "Printout"],
Cell[7392, 264, 123, 3, 70, 49, 0, "StyleData", "Subsection", \
"EnhancedPrintout"],
Cell[7518, 269, 130, 3, 70, 56, 0, "StyleData", "Subsection", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[7685, 277, 262, 7, 160, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection",
  CellTags->"Subsubsection"],
Cell[7950, 286, 94, 2, 75, 44, 0, "StyleData", "Subsubsection", "Printout"],
Cell[8047, 290, 126, 3, 92, 52, 0, "StyleData", "Subsubsection", \
"EnhancedPrintout"],
Cell[8176, 295, 133, 3, 92, 59, 0, "StyleData", "Subsubsection", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8358, 304, 39, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[8422, 308, 140, 4, 56, 23, 0, "StyleData", "Text", "All",
  CounterIncrements->"Text"],
Cell[8565, 314, 108, 3, 92, 35, 0, "StyleData", "Text", "Printout"],
Cell[8676, 319, 142, 4, 109, 43, 0, "StyleData", "Text", "EnhancedPrintout"],
Cell[8821, 325, 149, 4, 109, 50, 0, "StyleData", "Text", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[9007, 334, 165, 5, 56, 28, 0, "StyleData", "SmallText", "All",
  CounterIncrements->"SmallText"],
Cell[9175, 341, 112, 3, 70, 40, 0, "StyleData", "SmallText", "Printout"],
Cell[9290, 346, 146, 4, 70, 48, 0, "StyleData", "SmallText", \
"EnhancedPrintout"],
Cell[9439, 352, 153, 4, 70, 55, 0, "StyleData", "SmallText", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[9629, 361, 163, 5, 126, 32, 0, "StyleData", "CopyrightText", "All",
  StyleMenuListing->None],
Cell[9795, 368, 92, 2, 75, 44, 0, "StyleData", "CopyrightText", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9936, 376, 42, 0, 33, "Section"],
Cell[9981, 378, 246, 4, 143, "Text"],

Cell[CellGroupData[{
Cell[10252, 386, 429, 14, 56, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[10684, 402, 111, 3, 92, 36, 0, "StyleData", "Input", "Printout"],
Cell[10798, 407, 119, 3, 92, 44, 0, "StyleData", "Input", \
"EnhancedPrintout"],
Cell[10920, 412, 126, 3, 92, 51, 0, "StyleData", "Input", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[11083, 420, 416, 13, 56, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[11502, 435, 112, 3, 92, 37, 0, "StyleData", "Output", "Printout"],
Cell[11617, 440, 120, 3, 92, 45, 0, "StyleData", "Output", \
"EnhancedPrintout"],
Cell[11740, 445, 127, 3, 92, 52, 0, "StyleData", "Output", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[11904, 453, 549, 16, 56, 26, 0, "StyleData", "Message", "All",
  CounterIncrements->"Message",
  StyleMenuListing->None],
Cell[12456, 471, 164, 4, 109, 38, 0, "StyleData", "Message", "Printout"],
Cell[12623, 477, 197, 5, 126, 46, 0, "StyleData", "Message", \
"EnhancedPrintout"],
Cell[12823, 484, 204, 5, 126, 53, 0, "StyleData", "Message", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[13064, 494, 523, 15, 56, 24, 0, "StyleData", "Print", "All",
  CounterIncrements->"Print",
  StyleMenuListing->None],
Cell[13590, 511, 135, 3, 70, 36, 0, "StyleData", "Print", "Printout"],
Cell[13728, 516, 168, 4, 70, 44, 0, "StyleData", "Print", \
"EnhancedPrintout"],
Cell[13899, 522, 175, 4, 70, 51, 0, "StyleData", "Print", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[14111, 531, 414, 12, 70, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics",
  StyleMenuListing->None],
Cell[14528, 545, 163, 4, 70, 39, 0, "StyleData", "Graphics", "Printout"],
Cell[14694, 551, 196, 5, 70, 47, 0, "StyleData", "Graphics", \
"EnhancedPrintout"],
Cell[14893, 558, 203, 5, 70, 54, 0, "StyleData", "Graphics", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[15133, 568, 128, 4, 70, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[15264, 574, 130, 4, 70, 40, 0, "StyleData", "CellLabel", "Printout"],
Cell[15397, 580, 138, 4, 70, 48, 0, "StyleData", "CellLabel", \
"EnhancedPrintout"],
Cell[15538, 586, 145, 4, 70, 55, 0, "StyleData", "CellLabel", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15732, 596, 36, 0, 33, "Section"],
Cell[15771, 598, 121, 3, 70, "Text"],
Cell[15895, 603, 92, 3, 70, 21, 0, "StyleData", "RM", "All",
  StyleMenuListing->None],
Cell[15990, 608, 69, 2, 70, 21, 0, "StyleData", "BF", "All",
  StyleMenuListing->None],
Cell[16062, 612, 70, 2, 70, 21, 0, "StyleData", "IT", "All",
  StyleMenuListing->None],
Cell[16135, 616, 115, 4, 70, 21, 0, "StyleData", "TR", "All",
  StyleMenuListing->None],
Cell[16253, 622, 116, 4, 70, 21, 0, "StyleData", "TI", "All",
  StyleMenuListing->None],
Cell[16372, 628, 114, 4, 70, 21, 0, "StyleData", "TB", "All",
  StyleMenuListing->None],
Cell[16489, 634, 116, 4, 70, 22, 0, "StyleData", "TBI", "All",
  StyleMenuListing->None],
Cell[16608, 640, 117, 4, 70, 21, 0, "StyleData", "MR", "All",
  StyleMenuListing->None],
Cell[16728, 646, 118, 4, 70, 21, 0, "StyleData", "MO", "All",
  StyleMenuListing->None],
Cell[16849, 652, 116, 4, 70, 21, 0, "StyleData", "MB", "All",
  StyleMenuListing->None],
Cell[16968, 658, 118, 4, 70, 22, 0, "StyleData", "MBO", "All",
  StyleMenuListing->None],
Cell[17089, 664, 119, 4, 70, 21, 0, "StyleData", "SR", "All",
  StyleMenuListing->None],
Cell[17211, 670, 120, 4, 70, 21, 0, "StyleData", "SO", "All",
  StyleMenuListing->None],
Cell[17334, 676, 118, 4, 70, 21, 0, "StyleData", "SB", "All",
  StyleMenuListing->None],
Cell[17455, 682, 120, 4, 70, 22, 0, "StyleData", "SBO", "All",
  StyleMenuListing->None],

Cell[CellGroupData[{
Cell[17600, 690, 138, 5, 126, 23, 0, "StyleData", "SO10", "All",
  StyleMenuListing->None],
Cell[17741, 697, 149, 5, 126, 35, 0, "StyleData", "SO10", "Printout",
  StyleMenuListing->None],
Cell[17893, 704, 154, 5, 126, 43, 0, "StyleData", "SO10", "EnhancedPrintout",
  StyleMenuListing->None]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[18096, 715, 39, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[18160, 719, 215, 6, 56, 30, 0, "StyleData", "MathCaption", "All"],
Cell[18378, 727, 121, 3, 92, 42, 0, "StyleData", "MathCaption", "Printout"],
Cell[18502, 732, 155, 4, 109, 50, 0, "StyleData", "MathCaption", \
"EnhancedPrintout"],
Cell[18660, 738, 162, 4, 109, 57, 0, "StyleData", "MathCaption", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[18859, 747, 256, 8, 56, 29, 0, "StyleData", "Commentary", "All"],
Cell[19118, 757, 125, 3, 92, 41, 0, "StyleData", "Commentary", "Printout"],
Cell[19246, 762, 159, 4, 109, 49, 0, "StyleData", "Commentary", \
"EnhancedPrintout"],
Cell[19408, 768, 166, 4, 109, 56, 0, "StyleData", "Commentary", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[19611, 777, 177, 5, 56, 31, 0, "StyleData", "ItemizedText", "All",
  CounterIncrements->"ItemizedText"],
Cell[19791, 784, 83, 2, 75, 43, 0, "StyleData", "ItemizedText", "Printout"],
Cell[19877, 788, 117, 3, 92, 51, 0, "StyleData", "ItemizedText", \
"EnhancedPrintout"],
Cell[19997, 793, 124, 3, 92, 58, 0, "StyleData", "ItemizedText", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[20158, 801, 149, 4, 56, 35, 0, "StyleData", "ItemizedTextNote", "All",
  CounterIncrements->"Text"],
Cell[20310, 807, 97, 2, 75, 47, 0, "StyleData", "ItemizedTextNote", \
"Printout"],
Cell[20410, 811, 131, 3, 92, 55, 0, "StyleData", "ItemizedTextNote", \
"EnhancedPrintout"],
Cell[20544, 816, 138, 3, 109, 62, 0, "StyleData", "ItemizedTextNote", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[20719, 824, 145, 4, 56, 31, 0, "StyleData", "IndentedText", "All",
  CounterIncrements->"Text"],
Cell[20867, 830, 59, 1, 70, 43, 0, "StyleData", "IndentedText", "Printout"],
Cell[20929, 833, 93, 2, 70, 51, 0, "StyleData", "IndentedText", \
"EnhancedPrintout"],
Cell[21025, 837, 100, 2, 70, 58, 0, "StyleData", "IndentedText", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[21174, 845, 46, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[21245, 849, 404, 14, 70, 32, 0, "StyleData", "DefinitionBox", "All",
  StyleMenuListing->None],
Cell[21652, 865, 128, 3, 70, 44, 0, "StyleData", "DefinitionBox", \
"Printout"],
Cell[21783, 870, 162, 4, 70, 52, 0, "StyleData", "DefinitionBox", \
"EnhancedPrintout"],
Cell[21948, 876, 162, 4, 70, 59, 0, "StyleData", "DefinitionBox", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[22147, 885, 413, 14, 70, 36, 0, "StyleData", "DefinitionBox3Col", "All",
  StyleMenuListing->None],
Cell[22563, 901, 132, 3, 70, 48, 0, "StyleData", "DefinitionBox3Col", \
"Printout"],
Cell[22698, 906, 166, 4, 70, 56, 0, "StyleData", "DefinitionBox3Col", \
"EnhancedPrintout"],
Cell[22867, 912, 166, 4, 70, 63, 0, "StyleData", "DefinitionBox3Col", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[23070, 921, 422, 14, 70, 36, 0, "StyleData", "DefinitionBox4Col", "All",
  StyleMenuListing->None],
Cell[23495, 937, 132, 3, 70, 48, 0, "StyleData", "DefinitionBox4Col", \
"Printout"],
Cell[23630, 942, 166, 4, 70, 56, 0, "StyleData", "DefinitionBox4Col", \
"EnhancedPrintout"],
Cell[23799, 948, 166, 4, 70, 63, 0, "StyleData", "DefinitionBox4Col", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[24002, 957, 401, 14, 70, 36, 0, "StyleData", "DefinitionBox5Col", "All",
  StyleMenuListing->None],
Cell[24406, 973, 132, 3, 70, 48, 0, "StyleData", "DefinitionBox5Col", \
"Printout"],
Cell[24541, 978, 166, 4, 70, 56, 0, "StyleData", "DefinitionBox5Col", \
"EnhancedPrintout"],
Cell[24710, 984, 166, 4, 70, 63, 0, "StyleData", "DefinitionBox5Col", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[24913, 993, 434, 14, 70, 36, 0, "StyleData", "DefinitionBox6Col", "All",
  StyleMenuListing->None],
Cell[25350, 1009, 132, 3, 70, 48, 0, "StyleData", "DefinitionBox6Col", \
"Printout"],
Cell[25485, 1014, 166, 4, 70, 56, 0, "StyleData", "DefinitionBox6Col", \
"EnhancedPrintout"],
Cell[25654, 1020, 166, 4, 70, 63, 0, "StyleData", "DefinitionBox6Col", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[25857, 1029, 417, 14, 70, 25, 0, "StyleData", "TopBox", "All",
  StyleMenuListing->None],
Cell[26277, 1045, 121, 3, 70, 37, 0, "StyleData", "TopBox", "Printout"],
Cell[26401, 1050, 155, 4, 70, 45, 0, "StyleData", "TopBox", \
"EnhancedPrintout"],
Cell[26559, 1056, 155, 4, 70, 52, 0, "StyleData", "TopBox", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[26751, 1065, 444, 15, 70, 28, 0, "StyleData", "MiddleBox", "All",
  StyleMenuListing->None],
Cell[27198, 1082, 124, 3, 70, 40, 0, "StyleData", "MiddleBox", "Printout"],
Cell[27325, 1087, 158, 4, 70, 48, 0, "StyleData", "MiddleBox", \
"EnhancedPrintout"],
Cell[27486, 1093, 158, 4, 70, 55, 0, "StyleData", "MiddleBox", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[27681, 1102, 471, 16, 70, 34, 0, "StyleData", "MiddleSpacedBox", "All",
  StyleMenuListing->None],
Cell[28155, 1120, 169, 4, 70, 46, 0, "StyleData", "MiddleSpacedBox", \
"Printout"],
Cell[28327, 1126, 203, 5, 70, 54, 0, "StyleData", "MiddleSpacedBox", \
"EnhancedPrintout"],
Cell[28533, 1133, 203, 5, 70, 61, 0, "StyleData", "MiddleSpacedBox", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[28773, 1143, 467, 16, 70, 28, 0, "StyleData", "BottomBox", "All",
  StyleMenuListing->None],
Cell[29243, 1161, 164, 4, 70, 40, 0, "StyleData", "BottomBox", "Printout"],
Cell[29410, 1167, 198, 5, 70, 48, 0, "StyleData", "BottomBox", \
"EnhancedPrintout"],
Cell[29611, 1174, 198, 5, 70, 55, 0, "StyleData", "BottomBox", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[29846, 1184, 421, 14, 70, 29, 0, "StyleData", "TopSpanBox", "All",
  StyleMenuListing->None],
Cell[30270, 1200, 126, 3, 70, 41, 0, "StyleData", "TopSpanBox", "Printout"],
Cell[30399, 1205, 160, 4, 70, 49, 0, "StyleData", "TopSpanBox", \
"EnhancedPrintout"],
Cell[30562, 1211, 160, 4, 70, 56, 0, "StyleData", "TopSpanBox", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[30759, 1220, 469, 16, 70, 32, 0, "StyleData", "MiddleSpanBox", "All",
  StyleMenuListing->None],
Cell[31231, 1238, 168, 4, 70, 44, 0, "StyleData", "MiddleSpanBox", \
"Printout"],
Cell[31402, 1244, 202, 5, 70, 52, 0, "StyleData", "MiddleSpanBox", \
"EnhancedPrintout"],
Cell[31607, 1251, 202, 5, 70, 59, 0, "StyleData", "MiddleSpanBox", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[31846, 1261, 101, 2, 70, 26, 0, "StyleData", "Picture", "All"],
Cell[31950, 1265, 79, 1, 70, 38, 0, "StyleData", "Picture", "Printout"],
Cell[32032, 1268, 87, 1, 70, 46, 0, "StyleData", "Picture", \
"EnhancedPrintout"],
Cell[32122, 1271, 94, 1, 70, 53, 0, "StyleData", "Picture", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[32253, 1277, 127, 4, 70, 26, 0, "StyleData", "Caption", "All"],
Cell[32383, 1283, 86, 2, 70, 38, 0, "StyleData", "Caption", "Printout"],
Cell[32472, 1287, 118, 3, 70, 46, 0, "StyleData", "Caption", \
"EnhancedPrintout"],
Cell[32593, 1292, 125, 3, 70, 53, 0, "StyleData", "Caption", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[32767, 1301, 25, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[32817, 1305, 299, 10, 70, 33, 0, "StyleData", "SingleRowTable", "All",
  StyleMenuListing->None],
Cell[33119, 1317, 94, 2, 70, 45, 0, "StyleData", "SingleRowTable", \
"Printout"],
Cell[33216, 1321, 102, 2, 70, 53, 0, "StyleData", "SingleRowTable", \
"EnhancedPrintout"],
Cell[33321, 1325, 109, 2, 70, 60, 0, "StyleData", "SingleRowTable", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[33467, 1332, 335, 11, 70, 31, 0, "StyleData", "2ColumnTable", "All",
  StyleMenuListing->None],
Cell[33805, 1345, 92, 2, 70, 43, 0, "StyleData", "2ColumnTable", "Printout"],
Cell[33900, 1349, 100, 2, 70, 51, 0, "StyleData", "2ColumnTable", \
"EnhancedPrintout"],
Cell[34003, 1353, 107, 2, 70, 58, 0, "StyleData", "2ColumnTable", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[34147, 1360, 331, 11, 70, 35, 0, "StyleData", "2ColumnEvenTable", "All",
  StyleMenuListing->None],
Cell[34481, 1373, 96, 2, 70, 47, 0, "StyleData", "2ColumnEvenTable", \
"Printout"],
Cell[34580, 1377, 104, 2, 70, 55, 0, "StyleData", "2ColumnEvenTable", \
"EnhancedPrintout"],
Cell[34687, 1381, 111, 2, 70, 62, 0, "StyleData", "2ColumnEvenTable", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[34835, 1388, 341, 11, 70, 31, 0, "StyleData", "3ColumnTable", "All",
  StyleMenuListing->None],
Cell[35179, 1401, 92, 2, 70, 43, 0, "StyleData", "3ColumnTable", "Printout"],
Cell[35274, 1405, 100, 2, 70, 51, 0, "StyleData", "3ColumnTable", \
"EnhancedPrintout"],
Cell[35377, 1409, 107, 2, 70, 58, 0, "StyleData", "3ColumnTable", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[35521, 1416, 327, 11, 70, 31, 0, "StyleData", "4ColumnTable", "All",
  StyleMenuListing->None],
Cell[35851, 1429, 92, 2, 70, 43, 0, "StyleData", "4ColumnTable", "Printout"],
Cell[35946, 1433, 100, 2, 70, 51, 0, "StyleData", "4ColumnTable", \
"EnhancedPrintout"],
Cell[36049, 1437, 107, 2, 70, 58, 0, "StyleData", "4ColumnTable", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[36193, 1444, 326, 11, 70, 31, 0, "StyleData", "5ColumnTable", "All",
  StyleMenuListing->None],
Cell[36522, 1457, 92, 2, 70, 43, 0, "StyleData", "5ColumnTable", "Printout"],
Cell[36617, 1461, 100, 2, 70, 51, 0, "StyleData", "5ColumnTable", \
"EnhancedPrintout"],
Cell[36720, 1465, 107, 2, 70, 58, 0, "StyleData", "5ColumnTable", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[36864, 1472, 327, 11, 70, 31, 0, "StyleData", "6ColumnTable", "All",
  StyleMenuListing->None],
Cell[37194, 1485, 92, 2, 70, 43, 0, "StyleData", "6ColumnTable", "Printout"],
Cell[37289, 1489, 100, 2, 70, 51, 0, "StyleData", "6ColumnTable", \
"EnhancedPrintout"],
Cell[37392, 1493, 107, 2, 70, 58, 0, "StyleData", "6ColumnTable", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[37536, 1500, 327, 11, 70, 31, 0, "StyleData", "7ColumnTable", "All",
  StyleMenuListing->None],
Cell[37866, 1513, 92, 2, 70, 43, 0, "StyleData", "7ColumnTable", "Printout"],
Cell[37961, 1517, 100, 2, 70, 51, 0, "StyleData", "7ColumnTable", \
"EnhancedPrintout"],
Cell[38064, 1521, 107, 2, 70, 58, 0, "StyleData", "7ColumnTable", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[38208, 1528, 327, 11, 70, 31, 0, "StyleData", "8ColumnTable", "All",
  StyleMenuListing->None],
Cell[38538, 1541, 92, 2, 75, 43, 0, "StyleData", "8ColumnTable", "Printout"],
Cell[38633, 1545, 100, 2, 75, 51, 0, "StyleData", "8ColumnTable", \
"EnhancedPrintout"],
Cell[38736, 1549, 107, 2, 75, 58, 0, "StyleData", "8ColumnTable", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[38892, 1557, 49, 0, 33, "Section"],
Cell[38944, 1559, 225, 4, 126, "Text"],

Cell[CellGroupData[{
Cell[39194, 1567, 342, 8, 56, 35, 0, "StyleData", "NumberedEquation", "All",
  CounterIncrements->"NumberedEquation"],
Cell[39539, 1577, 99, 2, 75, 47, 0, "StyleData", "NumberedEquation", \
"Printout"],
Cell[39641, 1581, 133, 3, 92, 55, 0, "StyleData", "NumberedEquation", \
"EnhancedPrintout"],
Cell[39777, 1586, 140, 3, 109, 62, 0, "StyleData", "NumberedEquation", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[39966, 1595, 43, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[40034, 1599, 236, 6, 56, 33, 0, "StyleData", "DisplayFormula", "All"],
Cell[40273, 1607, 61, 1, 58, 45, 0, "StyleData", "DisplayFormula", \
"Printout"],
Cell[40337, 1610, 95, 2, 75, 53, 0, "StyleData", "DisplayFormula", \
"EnhancedPrintout"],
Cell[40435, 1614, 102, 2, 75, 60, 0, "StyleData", "DisplayFormula", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[40574, 1621, 389, 12, 56, 30, 0, "StyleData", "DisplayMath", "All",
  CounterIncrements->"Input"],
Cell[40966, 1635, 91, 2, 70, 42, 0, "StyleData", "DisplayMath", "Printout"],
Cell[41060, 1639, 127, 3, 70, 50, 0, "StyleData", "DisplayMath", \
"EnhancedPrintout"],
Cell[41190, 1644, 134, 3, 70, 57, 0, "StyleData", "DisplayMath", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[41361, 1652, 59, 1, 70, 33, 0, "StyleData", "EquationNumber", "All"],
Cell[41423, 1655, 86, 2, 70, 45, 0, "StyleData", "EquationNumber", \
"Printout"],
Cell[41512, 1659, 120, 3, 70, 53, 0, "StyleData", "EquationNumber", \
"EnhancedPrintout"],
Cell[41635, 1664, 127, 3, 70, 60, 0, "StyleData", "EquationNumber", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[41799, 1672, 166, 4, 70, 26, 0, "StyleData", "Program", "All"],
Cell[41968, 1678, 98, 2, 70, 38, 0, "StyleData", "Program", "Printout"],
Cell[42069, 1682, 134, 3, 70, 46, 0, "StyleData", "Program", \
"EnhancedPrintout"],
Cell[42206, 1687, 141, 3, 70, 53, 0, "StyleData", "Program", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[42396, 1696, 37, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[42458, 1700, 237, 7, 70, 32, 0, "StyleData", "ContentsTitle", "All",
  StyleMenuListing->None],
Cell[42698, 1709, 119, 3, 70, 44, 0, "StyleData", "ContentsTitle", \
"Printout"],
Cell[42820, 1714, 151, 4, 70, 52, 0, "StyleData", "ContentsTitle", \
"EnhancedPrintout"],
Cell[42974, 1720, 158, 4, 70, 59, 0, "StyleData", "ContentsTitle", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[43169, 1729, 238, 7, 70, 34, 0, "StyleData", "ContentsSection", "All",
  StyleMenuListing->None],
Cell[43410, 1738, 122, 3, 70, 46, 0, "StyleData", "ContentsSection", \
"Printout"],
Cell[43535, 1743, 154, 4, 70, 54, 0, "StyleData", "ContentsSection", \
"EnhancedPrintout"],
Cell[43692, 1749, 161, 4, 70, 61, 0, "StyleData", "ContentsSection", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[43890, 1758, 166, 4, 70, 27, 0, "StyleData", "Contents", "All",
  StyleMenuListing->None],
Cell[44059, 1764, 89, 2, 70, 39, 0, "StyleData", "Contents", "Printout"],
Cell[44151, 1768, 123, 3, 70, 47, 0, "StyleData", "Contents", \
"EnhancedPrintout"],
Cell[44277, 1773, 130, 3, 70, 54, 0, "StyleData", "Contents", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[44444, 1781, 108, 3, 70, 24, 0, "StyleData", "Index", "All",
  StyleMenuListing->None],
Cell[44555, 1786, 86, 2, 70, 36, 0, "StyleData", "Index", "Printout"],
Cell[44644, 1790, 120, 3, 70, 44, 0, "StyleData", "Index", \
"EnhancedPrintout"],
Cell[44767, 1795, 127, 3, 70, 51, 0, "StyleData", "Index", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[44931, 1803, 116, 3, 70, 32, 0, "StyleData", "IndexSubentry", "All",
  StyleMenuListing->None],
Cell[45050, 1808, 94, 2, 70, 44, 0, "StyleData", "IndexSubentry", \
"Printout"],
Cell[45147, 1812, 128, 3, 70, 52, 0, "StyleData", "IndexSubentry", \
"EnhancedPrintout"],
Cell[45278, 1817, 135, 3, 70, 59, 0, "StyleData", "IndexSubentry", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[45462, 1826, 32, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[45519, 1830, 264, 8, 70, 31, 0, "StyleData", "FunctionName", "All",
  CellTags->"FunctionName"],
Cell[45786, 1840, 94, 2, 70, 43, 0, "StyleData", "FunctionName", "Printout"],
Cell[45883, 1844, 127, 3, 70, 51, 0, "StyleData", "FunctionName", \
"EnhancedPrintout"],
Cell[46013, 1849, 134, 3, 70, 58, 0, "StyleData", "FunctionName", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[46184, 1857, 241, 7, 70, 33, 0, "StyleData", "SubsectionIcon", "All",
  CellTags->"FunctionSection"],
Cell[46428, 1866, 96, 2, 70, 45, 0, "StyleData", "SubsectionIcon", \
"Printout"],
Cell[46527, 1870, 130, 3, 70, 53, 0, "StyleData", "SubsectionIcon", \
"EnhancedPrintout"],
Cell[46660, 1875, 137, 3, 70, 60, 0, "StyleData", "SubsectionIcon", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[46834, 1883, 233, 6, 70, 37, 0, "StyleData", "FunctionSubsection", \
"All",
  CellTags->"FunctionSubsection"],
Cell[47070, 1891, 83, 1, 70, 49, 0, "StyleData", "FunctionSubsection", \
"Printout"],
Cell[47156, 1894, 133, 3, 70, 57, 0, "StyleData", "FunctionSubsection", \
"EnhancedPrintout"],
Cell[47292, 1899, 140, 3, 70, 64, 0, "StyleData", "FunctionSubsection", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[47469, 1907, 229, 6, 143, 36, 0, "StyleData", "SubsubsectionIcon", \
"All",
  CellTags->"SubsubsectionIcon"],
Cell[47701, 1915, 98, 2, 75, 48, 0, "StyleData", "SubsubsectionIcon", \
"Printout"],
Cell[47802, 1919, 131, 3, 92, 56, 0, "StyleData", "SubsubsectionIcon", \
"EnhancedPrintout"],
Cell[47936, 1924, 138, 3, 109, 63, 0, "StyleData", "SubsubsectionIcon", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[48111, 1932, 178, 5, 56, 38, 0, "StyleData", "FunctionDescription", \
"All",
  CounterIncrements->"Text"],
Cell[48292, 1939, 100, 2, 75, 50, 0, "StyleData", "FunctionDescription", \
"Printout"],
Cell[48395, 1943, 158, 4, 109, 58, 0, "StyleData", "FunctionDescription", \
"EnhancedPrintout"],
Cell[48556, 1949, 165, 4, 126, 65, 0, "StyleData", "FunctionDescription", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[48758, 1958, 197, 5, 56, 43, 0, "StyleData", "FunctionDescriptionRuled", \
"All",
  CounterIncrements->"Text"],
Cell[48958, 1965, 105, 2, 70, 55, 0, "StyleData", "FunctionDescriptionRuled", \
"Printout"],
Cell[49066, 1969, 163, 4, 70, 63, 0, "StyleData", "FunctionDescriptionRuled", \
"EnhancedPrintout"],
Cell[49232, 1975, 170, 4, 70, 70, 0, "StyleData", "FunctionDescriptionRuled", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[49439, 1984, 196, 5, 70, 45, 0, "StyleData", \
"FunctionDescriptionRuleTop", "All",
  CounterIncrements->"Text"],
Cell[49638, 1991, 107, 2, 70, 57, 0, "StyleData", \
"FunctionDescriptionRuleTop", "Printout"],
Cell[49748, 1995, 165, 4, 70, 65, 0, "StyleData", \
"FunctionDescriptionRuleTop", "EnhancedPrintout"],
Cell[49916, 2001, 172, 4, 70, 72, 0, "StyleData", \
"FunctionDescriptionRuleTop", "EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[50125, 2010, 199, 5, 70, 48, 0, "StyleData", \
"FunctionDescriptionRuleBottom", "All",
  CounterIncrements->"Text"],
Cell[50327, 2017, 110, 2, 70, 60, 0, "StyleData", \
"FunctionDescriptionRuleBottom", "Printout"],
Cell[50440, 2021, 168, 4, 70, 68, 0, "StyleData", \
"FunctionDescriptionRuleBottom", "EnhancedPrintout"],
Cell[50611, 2027, 175, 4, 70, 75, 0, "StyleData", \
"FunctionDescriptionRuleBottom", "EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[50823, 2036, 111, 3, 92, 34, 0, "StyleData", "FunctionExample", "All",
  StyleMenuListing->None],
Cell[50937, 2041, 95, 2, 75, 46, 0, "StyleData", "FunctionExample", \
"Printout"],
Cell[51035, 2045, 129, 3, 92, 54, 0, "StyleData", "FunctionExample", \
"EnhancedPrintout"],
Cell[51167, 2050, 136, 3, 109, 61, 0, "StyleData", "FunctionExample", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[51340, 2058, 137, 4, 56, 35, 0, "StyleData", "FunctionTextNote", "All"],
Cell[51480, 2064, 96, 2, 70, 47, 0, "StyleData", "FunctionTextNote", \
"Printout"],
Cell[51579, 2068, 130, 3, 70, 55, 0, "StyleData", "FunctionTextNote", \
"EnhancedPrintout"],
Cell[51712, 2073, 137, 3, 70, 62, 0, "StyleData", "FunctionTextNote", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[51886, 2081, 315, 10, 211, 39, 0, "StyleData", "3ColumnFunctionTable", \
"All"],
Cell[52204, 2093, 101, 2, 75, 51, 0, "StyleData", "3ColumnFunctionTable", \
"Printout"],
Cell[52308, 2097, 109, 2, 75, 59, 0, "StyleData", "3ColumnFunctionTable", \
"EnhancedPrintout"],
Cell[52420, 2101, 116, 2, 92, 66, 0, "StyleData", "3ColumnFunctionTable", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[52585, 2109, 36, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[52646, 2113, 155, 5, 56, 29, 0, "StyleData", "TextNormal", "All",
  CounterIncrements->"Text"],
Cell[52804, 2120, 90, 2, 75, 41, 0, "StyleData", "TextNormal", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[52931, 2127, 299, 9, 70, 35, 0, "StyleData", "BrowserEmulation", "All"],
Cell[53233, 2138, 84, 2, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[53354, 2145, 259, 8, 70, 31, 0, "StyleData", "CategoryDefs", "All"],
Cell[53616, 2155, 84, 2, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[53737, 2162, 205, 6, 70, 28, 0, "StyleData", "Category1", "All"],
Cell[53945, 2170, 73, 1, 70, 40, 0, "StyleData", "Category1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[54055, 2176, 244, 7, 70, 28, 0, "StyleData", "Category2", "All"],
Cell[54302, 2185, 73, 1, 70, 40, 0, "StyleData", "Category2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[54412, 2191, 242, 7, 70, 28, 0, "StyleData", "Category3", "All"],
Cell[54657, 2200, 73, 1, 70, 40, 0, "StyleData", "Category3", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[54767, 2206, 231, 6, 70, 28, 0, "StyleData", "Category4", "All"],
Cell[55001, 2214, 73, 1, 70, 40, 0, "StyleData", "Category4", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[55123, 2221, 49, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[55197, 2225, 148, 5, 70, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[55348, 2232, 37, 0, 70, 37, 0, "StyleData", "Header", "Printout"],
Cell[55388, 2234, 69, 1, 70, 45, 0, "StyleData", "Header", \
"EnhancedPrintout"],
Cell[55460, 2237, 76, 1, 70, 52, 0, "StyleData", "Header", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[55573, 2243, 148, 5, 70, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[55724, 2250, 37, 0, 70, 37, 0, "StyleData", "Footer", "Printout"],
Cell[55764, 2252, 69, 1, 70, 45, 0, "StyleData", "Footer", \
"EnhancedPrintout"],
Cell[55836, 2255, 76, 1, 70, 52, 0, "StyleData", "Footer", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[55949, 2261, 152, 5, 70, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None],
Cell[56104, 2268, 41, 0, 70, 41, 0, "StyleData", "PageNumber", "Printout"],
Cell[56148, 2270, 73, 1, 70, 49, 0, "StyleData", "PageNumber", \
"EnhancedPrintout"],
Cell[56224, 2273, 80, 1, 70, 56, 0, "StyleData", "PageNumber", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[56353, 2280, 35, 0, 33, "Section"],
Cell[56391, 2282, 184, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[56600, 2290, 302, 8, 70, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[56905, 2300, 123, 3, 70, 40, 0, "StyleData", "Hyperlink", "Printout"],
Cell[57031, 2305, 157, 4, 70, 48, 0, "StyleData", "Hyperlink", \
"EnhancedPrintout"],
Cell[57191, 2311, 164, 4, 70, 55, 0, "StyleData", "Hyperlink", \
"EnhancedPrintoutNonGray"]
}, Closed]],
Cell[57370, 2318, 104, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[57499, 2325, 316, 8, 70, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[57818, 2335, 126, 3, 70, 43, 0, "StyleData", "MainBookLink", \
"Printout"],
Cell[57947, 2340, 160, 4, 70, 51, 0, "StyleData", "MainBookLink", \
"EnhancedPrintout"],
Cell[58110, 2346, 167, 4, 70, 58, 0, "StyleData", "MainBookLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[58314, 2355, 337, 9, 70, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[58654, 2366, 124, 3, 70, 41, 0, "StyleData", "AddOnsLink", "Printout"],
Cell[58781, 2371, 132, 3, 70, 49, 0, "StyleData", "AddOnsLink", \
"EnhancedPrintout"],
Cell[58916, 2376, 139, 3, 70, 56, 0, "StyleData", "AddOnsLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[59092, 2384, 339, 9, 70, 33, 0, "StyleData", "AddOnsLinkText", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[59434, 2395, 128, 3, 70, 45, 0, "StyleData", "AddOnsLinkText", \
"Printout"],
Cell[59565, 2400, 136, 3, 70, 53, 0, "StyleData", "AddOnsLinkText", \
"EnhancedPrintout"],
Cell[59704, 2405, 143, 3, 70, 60, 0, "StyleData", "AddOnsLinkText", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[59884, 2413, 341, 9, 70, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[60228, 2424, 126, 3, 70, 43, 0, "StyleData", "RefGuideLink", \
"Printout"],
Cell[60357, 2429, 162, 4, 70, 51, 0, "StyleData", "RefGuideLink", \
"EnhancedPrintout"],
Cell[60522, 2435, 169, 4, 70, 58, 0, "StyleData", "RefGuideLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[60728, 2444, 328, 8, 70, 37, 0, "StyleData", "GettingStartedLink", "All",
  
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[61059, 2454, 132, 3, 70, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"],
Cell[61194, 2459, 166, 4, 70, 57, 0, "StyleData", "GettingStartedLink", \
"EnhancedPrintout"],
Cell[61363, 2465, 173, 4, 70, 64, 0, "StyleData", "GettingStartedLink", \
"EnhancedPrintoutNonGray"]
}, Closed]],

Cell[CellGroupData[{
Cell[61573, 2474, 332, 8, 70, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[61908, 2484, 134, 3, 70, 51, 0, "StyleData", "OtherInformationLink", \
"Printout"],
Cell[62045, 2489, 168, 4, 70, 59, 0, "StyleData", "OtherInformationLink", \
"EnhancedPrintout"],
Cell[62216, 2495, 175, 4, 70, 66, 0, "StyleData", "OtherInformationLink", \
"EnhancedPrintoutNonGray"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[62440, 2505, 33, 0, 33, "Section"],

Cell[CellGroupData[{
Cell[62498, 2509, 264, 7, 51, 27, 0, "StyleData", "Outline1", "All",
  CounterIncrements->"Outline1"],
Cell[62765, 2518, 100, 1, 51, 39, 0, "StyleData", "Outline1", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[62902, 2524, 290, 8, 48, 27, 0, "StyleData", "Outline2", "All",
  CounterIncrements->"Outline2"],
Cell[63195, 2534, 126, 2, 48, 39, 0, "StyleData", "Outline2", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[63358, 2541, 232, 6, 46, 27, 0, "StyleData", "Outline3", "All",
  CounterIncrements->"Outline3"],
Cell[63593, 2549, 89, 1, 46, 39, 0, "StyleData", "Outline3", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[63719, 2555, 269, 7, 43, 27, 0, "StyleData", "Outline4", "All",
  CounterIncrements->"Outline4"],
Cell[63991, 2564, 39, 0, 43, 39, 0, "StyleData", "Outline4", "Printout"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

